# frozen_string_literal: true

# Copyright (c) 2015-2017, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge::Api
  class ObjectId
    include Comparable

    attr_accessor :type, :id, :cluster, :usr

    def initialize(s = nil)
      @type = 'none'
      @id = @cluster = @usr = 0

      return if s.nil?

      parts = s.split(':')
      if parts.length < 2
        raise Blockbridge::Api::InvalidObjectId.new("oid '#{s}' is incomplete")
      end

      @type = parts[0]

      begin
        @id = Integer(parts[1])
        @cluster = Integer(parts[2]) if parts.length > 2
        @usr = Integer(parts[3]) if parts.length > 3
      rescue
        raise Blockbridge::Api::InvalidObjectId.new("oid '#{s}' has invalid integer value(s)")
      end
    end

    def to_s
      if usr > 0
        "#{type}:#{id}:#{cluster}:#{usr}"
      elsif cluster > 0
        "#{type}:#{id}:#{cluster}"
      else
        "#{type}:#{id}"
      end
    end

    # pretend to be a string so comparisons work in both directions.
    def to_str
      to_s
    end

    def <=>(o)
      to_s <=> o.to_s
    end
  end
end
