# frozen_string_literal: true

# Copyright (c) 2015-2017, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

require 'blockbridge/api/hashie_mash'
require 'delegate'

module Blockbridge
  module Api
    class XmdDataDecorator < SimpleDelegator
      class Fragment
        attr_reader :key
        attr_reader :schema
        attr_reader :id
        attr_reader :ref
        attr_reader :mtime
        attr_reader :tags
        attr_reader :data

        def initialize(key, frag, xmd)
          @key    = key
          @frag   = frag
          @schema = frag._schema
          @data   = ::Blockbridge::HashieMash.new(@schema.nil? ? frag : (frag.data || {}))
          @id     = xmd.id
          @ref    = xmd.ref
          @mtime  = xmd.mtime
          @tags   = xmd.tags
        end

        def method_missing(meth, *args, &blk)
          @data.public_send(meth, *args, &blk)
        end

        def respond_to_missing?(method, include_private = false)
          super unless @data.respond_to?(method)
        end
      end

      def initialize(collection)
        super(collection || [])
      end

      def fragments
        @fragments ||= flat_map do |x|
          frags = {}
          x.data.each_pair do |dk, dv|
            frags[dk] = dv if dv.respond_to? :each_pair
          end
          frags.map { |xk, xd| Fragment.new(xk, xd, x) }
        end
      end

      def fragments_for(**kwargs)
        fragments.select do |f|
          kwargs.to_a.all? do |(k,v)|
            f.respond_to?(k) && f.send(k) == v
          end
        end
      end

      def schemas
        @schemas ||= fragments.map { |f| f.schema }.compact.uniq
      end

      def schema?(schema)
        schemas.include?(schema)
      end

      def tags
        @tags ||= flat_map { |x| x.tags }.uniq
      end

      def tag?(tag)
        tags.include?(tag)
      end
    end
  end
end
