require 'ruby-progressbar'
require 'clamp'
require 'pp'
require 'em-synchrony'
require 'em-synchrony/em-http'
require 'multi_json'

Clamp do

  def conn_options
    @conn_options ||= Hash.new.tap do |h|
      h[:inactivity_timeout] = 300
      if no_tls_verify?
        h[:ssl] = { verify_peer: false }
      end
    end
  end

  def req_options
    @req_options ||= Hash.new.tap do |o|
      o[:head] = Hash.new.tap do |h|
        h['Accept'] = 'application/vnd.blockbridge-3+json'
        h['Content-Type'] = 'application/json'
        h['X-Blockbridge-Task'] = "ext_auth=keystone/#{project}/#{user}"

        h[:authorization] = basic_auth.split(':', 2) if basic_auth
      end
    end
  end

  def project
    if project_id
      project_id
    elsif project_name
      "name=#{project_name}"
    end
  end

  def user
    if user_id
      user_id
    elsif user_name
      "name=#{user_name}"
    end
  end

  CAPACITY = 1024 * 1024 * 1024

  option('--host', 'HOST', 'specify api host',
         default: 'https://localhost/')
  option('-k', :flag, 'disable tls cert verification',
         attribute_name: 'no_tls_verify')
  option('-u', 'USER:PASS', 'basic auth in user:pass format',
         attribute_name: 'basic_auth')
  option('--project-id', 'ID', 'openstack project ID')
  option('--project-name', 'NAME', 'openstack project name', default: 'demo')
  option('--user-id', 'ID', 'openstack user ID')
  option('--user-name', 'NAME', 'openstack user name', default: 'demo')
  option(['-p', '--prefix'], 'PREFIX', 'object xref prefix',
         default: 'batch-test-',
         attribute_name: 'prefix')

  subcommand ['create', 'c'], 'create NUM things' do
    parameter 'NUM', 'num' do |v|
      Integer(v)
    end

    def execute
      EM.synchrony do
        multi = EventMachine::Synchrony::Multi.new
        pb = ProgressBar.create(title: 'creating', total: num, length: 80)

        num.times do |n|
          vol_id = "#{prefix}#{n}"

          create_params = {
            capacity: CAPACITY,
            name: vol_id,
          }

          # build request
          r = EventMachine::HttpRequest.new(host, conn_options)
          d = r.aput(req_options.merge(path: "/api/cinder/volumes/#{vol_id}",
                                       body: MultiJson.dump(create_params)))

          d.callback { pb.increment }
          d.errback  { pb.increment }

          multi.add vol_id, d
        end

        # execute requests
        res = multi.perform

        res.responses[:errback].each_pair do |name, data|
          puts "* request for id #{name} failed: #{data.error}"
        end

        res.responses[:callback].each_pair do |name, data|
          status = data.response_header.status
          unless [200, 201].include?(status)
            puts "* request for id #{name} failed with http status #{status}"
          end
        end

        EM.stop
      end
    end
  end

  subcommand ['remove', 'r'], 'remove NUM things' do
    parameter 'NUM', 'num' do |v|
      Integer(v)
    end

    def execute
      EM.synchrony do
        multi = EventMachine::Synchrony::Multi.new

        pb = ProgressBar.create(title: 'removing', total: num, length: 80)

        num.times do |n|
          vol_id = "#{prefix}#{n}"

          # build request
          r = EventMachine::HttpRequest.new(host, conn_options)
          d = r.adelete(req_options.merge(path: "/api/cinder/volumes/#{vol_id}"))

          d.callback { pb.increment }
          d.errback  { pb.increment }

          multi.add vol_id, d
        end

        # execute requests
        res = multi.perform

        res.responses[:errback].each_pair do |name, data|
          puts "* request for id #{name} failed: #{data.error}"
        end

        res.responses[:callback].each_pair do |name, data|
          unless [200].include?(status = data.response_header.status)
            puts "* remove for id #{name} failed with http status #{status}"
          end
        end

        EM.stop
      end
    end
  end
end
