# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

require 'rbconfig'

# Host configuration and maniuplation tools. Provides an abstraction layer for
# the command line (and other tools) to control and inspect the OS in a generic
# way.
module BlockbridgeHost
  # rubocop:disable Metrics/MethodLength
  def self.detect_os
    @detected_os ||= (
      host_os = RbConfig::CONFIG['host_os']
      case host_os
      when /mswin|msys|mingw|cygwin|bccwin|wince|emc/
        :windows
      when /darwin|mac os/
        :macosx
      when /linux/
        :linux
      when /solaris|bsd/
        :unix
      else
        fail "failed to detect operating system; (for #{host_os.inspect})"
      end
    )
  end

  def self.control(os: BlockbridgeHost.detect_os, **kwargs)
    case os
    when :linux
      require 'blockbridge/host/control/linux'
      LinuxControl.new(**kwargs)
    when :windows
      require 'blockbridge/host/control/windows'
      WindowsControl.new(**kwargs)
    else
      fail "don't know how to control host os '#{os}'"
    end
  end
end

require 'blockbridge/host/version'
require 'blockbridge/host/executor'
