##############################################################################
# Copyright (c) 2016, Blockbridge Networks LLC.  All rights reserved.
# Proprietary and confidential. Unauthorized copying of this file via any
# medium is strictly prohibited. Use of this source code is subject to the
# terms and conditions found in the LICENSE file.
##############################################################################

require 'ffi'

module LibC
  extend FFI::Library

  def self.fallocate_or_truncate(f, sz)
    if respond_to?(:posix_fallocate_raw)
      e = posix_fallocate_raw(f.fileno, 0, sz)
      raise SystemCallError.new("posix_fallocate failed", e) unless e == 0
    else
      f.truncate(sz)
    end
  end

  ffi_lib ['c']

  begin
    attach_function :makedev, :gnu_dev_makedev, [ :uint, :uint ], :ulong_long
  rescue FFI::NotFoundError
    def self.makedev(x, y)
      (((x)&0xfffff000) << 32) | \
      (((x)&0x00000fff) << 8)  | \
      (((y)&0xffffff00) << 12) | \
      (((y)&0x000000ff))
    end
  end

  begin
    attach_function :major,   :gnu_dev_major,   [ :ulong_long ],  :uint
  rescue FFI::NotFoundError
    def self.major(x)
      (((x)>>31>>1) & 0xfffff000) | (((x)>>8) & 0x00000fff)
    end
  end

  begin
    attach_function :minor,   :gnu_dev_minor,   [ :ulong_long ],  :uint
  rescue FFI::NotFoundError
    def self.minor(x)
      (((x)>>12) & 0xffffff00) | ((x) & 0x000000ff)
    end
  end

  begin
    attach_function :posix_fallocate_raw, :posix_fallocate,
                    [:int, :off_t, :off_t], :int
  rescue FFI::NotFoundError
  end
end
