# Copyright (c) 2018, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module BlockbridgeHost
  class LinuxDMIControl < LinuxControl

    SYSFS_DMI_ID = '/sys/devices/virtual/dmi/id'
    DMI_PRODUCT_NAME = 'product_name'
    DMI_PRODUCT_UUID = 'product_uuid'
    DMI_CHASSIS_VENDOR = 'chassis_vendor'
    DMI_BOARD_NAME = 'board_name'
    DMI_BOARD_SERIAL = 'board_serial'

    def product_name
      read_dmi_id(DMI_PRODUCT_NAME)
    end

    def chassis_vendor
      read_dmi_id(DMI_CHASSIS_VENDOR)
    end

    def product_uuid
      read_dmi_id(DMI_PRODUCT_UUID, as_root: true)
    end

    def board_name
      read_dmi_id(DMI_BOARD_NAME)
    end

    def board_serial
      read_dmi_id(DMI_BOARD_SERIAL, as_root: true)
    end

    private

    def read_dmi_id(*params)
      sanitize sysfs.read(SYSFS_DMI_ID, *params)
    end

    def sanitize(value)
      case v = value&.strip
      when 'None', '', nil
        nil
      else
        v
      end
    end
  end
end
