# Copyright (c) 2018, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module BlockbridgeHost
  class LinuxIPMIControl < GenericControl
    util :ipmitool, paths: ['/usr/bin','/bin']

    def sensors
      sensors = []
      data = ipmitool('sensor').out
      data&.lines.each do |data|
        fields = data.split('|').map { |f| f.strip }
        sensors.push({
          id:     fields[0],
          sensor: fields[1],
          units:  fields[2],
          status: fields[3],
        })
      end
      sensors
    end

    def sdr(type)
      sensors = []
      cmd = ['sdr']
      cmd.concat ['type', type] if type
      data = ipmitool(*cmd).out
      data&.lines.each do |data|
        fields = data.split('|').map { |f| f.strip }
        sensor = fields[4]
        units  = nil
        if fields[4] =~ /\d+/
          sensor, units = fields[4].split("\s")
        end
        sensors.push({
          id:     fields[0],
          sensor: sensor,
          units:  units,
          status: fields[2],
          entity: fields[3],
        })
      end
      sensors
    end

    def entity(entity)
      sensors = []
      cmd = ['sdr', 'entity', entity]
      data = ipmitool(*cmd).out
      data&.lines.each do |data|
        fields = data.split('|').map { |f| f.strip }
        sensor = fields[4]
        units  = nil
        if fields[4] =~ /\d+/
          sensor, units = fields[4].split("\s")
        end
        sensors.push({
          id:     fields[0],
          sensor: sensor,
          units:  units,
          status: fields[2],
          entity: fields[3],
        })
      end
      sensors
    end
  end
end
