# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module BlockbridgeHost
  class LinuxMDControl < GenericControl
    util :mdadm, paths: ['/bb/sbin/', '/sbin', '/usr/sbin'], from_package: 'mdadm'

    def create(md, level, devices, name = nil, host = nil, uuid = nil,
               layout = nil, chunk_size = nil, assume_clean = nil,
               bitmap = nil, bitmap_chunk = nil, metadata_type = nil,
               data_offset = nil, raid_devices = nil,
               force: false, verbose: false)
      raise Errno::EEXIST, "md exists: #{md}" if File.exist? md

      args = ['--create', md, '--run']
      args.concat ['--raid-devices', raid_devices ? raid_devices : devices.length]
      args.concat ['--level', level] if level
      args.concat ['--name', name] if name
      args.concat ['--uuid', uuid] if uuid
      args.concat ['--layout', layout] if layout
      args.concat ['--chunk', chunk_size] if chunk_size
      args.concat ['--assume-clean'] if assume_clean
      args.concat ['--bitmap', bitmap] if bitmap
      args.concat ['--bitmap-chunk', bitmap_chunk] if bitmap_chunk
      args.concat ['--metadata', metadata_type ] if metadata_type
      args.concat ['--data-offset', data_offset] if !data_offset.nil?
      args.concat ['--homehost', host] if host
      args.concat ['--force'] if force
      args.concat ['--verbose'] if verbose
      args.concat devices

      mdadm(*args)
    end

    def add(md, dev, verbose: false)
      args = [md, '--add', dev]
      args.concat ['--verbose'] if verbose
      mdadm(*args)
    end

    def fail(md, dev)
      args = [md, '--fail', dev]
      mdadm(*args)
    end

    def remove(md, dev, verbose: false)
      args = [md, '--remove', dev]
      args.concat ['--verbose'] if verbose
      mdadm(*args)
    end

    def stop(md, force: false)
      unless force
        return unless File.exist? md
      end
      args = ['--stop', md]
      mdadm(*args)
    end

    def assemble(md, uuid, devices, run = false, bitmap = false,
                 force: false, verbose: false)
      return if File.exist? md unless force
      args = ['--assemble', md]
      args.concat ['--uuid', uuid] if uuid
      args.concat ['--run'] if run
      args.concat ['--bitmap', bitmap] if bitmap
      args.concat ['--verbose'] if verbose
      args.concat devices if devices
      mdadm(*args)
    end

    def zero(dev)
      args = ['--zero-superblock', dev]
      mdadm(*args)
    end

    def detail(md, brief = false, export = false)
      args = ['--detail', md]
      args.concat ['--brief'] if brief
      args.concat ['--export'] if export
      mdadm(*args).out
    end

    def action(md, action)
      args = ['--action', action, md]
      mdadm(*args)
    end

    def add_bitmap(md, path, *addargs, force: false)
      args = ['--grow', md, '--bitmap', path]
      args.concat ['--force'] if force
      mdadm(*args, *addargs)
    end

    def examine(*args)
      mdadm('--examine', *args)
    end

    def test(md)
      args = ['--detail', '--brief', '--test', md]
      res = mdadm(*args, noraise: true)
      res.exitstatus
    end
  end
end
