# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module BlockbridgeHost
  class LinuxStunnelControl < GenericControl
    util :stunnel, privileged: false, run: :system, paths: ['/usr/bin'],
           from_package: { rpm: 'stunnel', dpkg: 'stunnel4' }
    util :pkill, paths: ['/usr/bin']
    util :semanage, paths: ['/usr/sbin']

    def start(name, cfg, cafile = nil)
      cfg_defaults = {
        global: {
          socket: ['r:TCP_NODELAY=1', 'l:TCP_NODELAY=1'],
          sslVersion: 'TLSv1.2',
          pid: '',
          fips: 'no',
        },
        client: {
          client: 'yes',
        },
      }

      cfg[:global] = cfg_defaults[:global].merge(cfg[:global] || {})
      cfg[:client] = cfg_defaults[:client].merge(cfg[:client] || {})
      fail 'missing connect host in client options' unless cfg[:client][:connect]

      if cafile
        cfg[:client][:CAfile] = cafile
        cfg[:client][:verify] = 3
      end

      port = nil
      40000.upto(42100).to_a.shuffle.each do |p|
        cfg[:client][:accept] = "127.0.0.1:#{p}"
        ssl_options = []
        cfg[:global].each do |key,val|
          if val.is_a? Array
            val.each do |val|
              ssl_options << "#{key}=#{val}"
            end
          else
            ssl_options << "#{key}=#{val}"
          end
        end
        ssl_options << "[client]"
        cfg[:client].each do |key,val|
          if val.is_a? Array
            val.each do |val|
              ssl_options << "#{key}=#{val}"
            end
          else
            ssl_options << "#{key}=#{val}"
          end
        end

        # open ports (selinux, best-effort)
        semanage('port', '-a', '-t', 'iscsi_port_t', '-p', 'tcp', '40000-42100') rescue nil

        retries = 0
        begin
          # run stunnel
          cfg_o, cfg_i = IO.pipe
          if options[:debug]
            debug_puts("# using stunnel configuration:")
            ssl_options.each { |o| debug_puts("# #{o}") }
          end
          cfg_i.puts ssl_options.join("\n")
          cfg_file = "/dev/fd/#{cfg_o.fileno}"
          File.open(cfg_file) do |fd|
            cfg_i.close
            stunnel('-fd', cfg_o.fileno, '--', name, spawn_options: { cfg_o => cfg_o.fileno })
          end
        rescue => e
          if e&.message&.include?('ZLIB compression is not supported') ||
             e&.message&.include?('option name is not valid here')
            ssl_options.reject! { |o| o.start_with? 'compression' }
            retries = retries + 1
            retry unless retries > 1
          end
          raise unless e.message =~ /bind: Address already in use/
          next
        end
        port = p
        break
      end
      port
    end

    def stop(name)
      pkill('-f', "stunnel.*#{name}") rescue nil
    end
  end
end
