# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge
  module Util
    def self.features
      return @features if @features
      f = []
      if Blockbridge::Util.constants.include? :Filesystem
        f.push "fs-inspection"
      end
      @features = f
    end

    def self.has_feature?(feature)
      feature = feature.to_s.gsub('_', '-')
      features.include? feature
    end

    def self.version_str
      ver = Blockbridge::Util::VERSION
      ver += " (#{features.join(', ')})"
      ver
    end

    def self.underscore(str)
      str.to_s.gsub(/::/, '/').
        gsub(/([A-Z]+)([A-Z][a-z])/,'\1_\2').
        gsub(/([a-z\d])([A-Z])/,'\1_\2').
        tr("-", "_").
        downcase
    end

    def self.uri_escape(value)
      URI::escape(value, Regexp.union(URI::UNSAFE, /[\/.]/))
    end

    GAIN_ROOT_COMMAND_DFL = '/usr/bin/sudo'

    def self.gain_root_command
      @gain_root_command ||= GAIN_ROOT_COMMAND_DFL
    end

    def self.gain_root_command=(cmd)
      @gain_root_command = cmd
    end

    def self.popen_root(args, quiet: true, stderr: false, &blk)
      raise ArgumentError, "args must be an array" unless args.is_a? Array
      if Process.euid != 0
        unless quiet
          STDERR.puts "using #{gain_root_command} to execute: #{args}"
        end
        args.unshift(gain_root_command)
      end
      if stderr
        args.push :err => [:child, :out]
      end
      IO.popen(args, &blk)
    end

    def self.system_root(args, quiet: true)
      raise ArgumentError, "args must be an array" unless args.is_a? Array
      if Process.euid != 0
        unless quiet
          STDERR.puts "using #{gain_root_command} to execute: #{args}"
        end
        args.unshift(gain_root_command)
      end
      system(*args)
    end
  end
end

require 'blockbridge/util/constants'
require 'blockbridge/util/filesystem'
require 'blockbridge/util/version'
