# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge
  module Util
    module Color
      class << self
        # borrowed from Paint gem (was 'unpaint')
        def strip(string)
          string.gsub(/\e\[(?:[0-9];?)+m/, '')
        end

        def has_color?(string)
          /\e\[(?:[0-9];?)+m/.match(string)
        end

        # length of string ignoring color codes
        def length(string)
          strip(string).length
        end

        # truncate string only touching non-color codes
        TRUNCATE_RX = /(?<c>\e\[(?:[0-9];?)+m)|(?<r>[^\e]+)/

        def truncate(string, len)
          out = ""
          olen = 0 # non-color-code length
          md = string.to_enum(:scan, TRUNCATE_RX).map { Regexp.last_match }
          md.each do |m|
            # always include color codes, if non-nil
            out << m[:c] unless m[:c].nil?

            # conditionally append printable text until the truncation limit is
            # reached.
            if m[:r] && olen < len
              s = m[:r][0, len - olen]
              olen += s.length
              out << s
            end
          end
          out
        end

      end
    end
  end
end
