# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

begin
  require 'sys/filesystem'
rescue LoadError => e
  # trap load failure -- ffi may not load.
end

if defined? Sys::Filesystem
  module Blockbridge
    module Util
      module Filesystem
        FsStats = Struct.new(:block_size, :inode_size)
        Info = Struct.new(:stat, :mtab)

        def self.mount_point(path)
          Sys::Filesystem.mount_point(path)
        end

        def self.stat(mnt_pt)
          Sys::Filesystem.stat(mnt_pt)
        end

        def self.mtab(mnt_pt)
          ent = Sys::Filesystem.mounts.find { |e| e.mount_point == mnt_pt }
          if ent.nil?
            raise "Failed to find mount entry for mount point '#{mnt_pt}'"
          end
          ent
        end

        def self.info(mnt_pt)
          Info.new(stat(mnt_pt), mtab(mnt_pt))
        end

        def self.inspect(path)
          @@inspector_cache ||= {}

          mnt_pt = mount_point(path)
          @@inspector_cache[mnt_pt] ||= Blockbridge::Util::Filesystem::Inspector.create(mnt_pt)
          @@inspector_cache[mnt_pt].stat(path)
        end
      end
    end
  end

  require 'blockbridge/util/filesystem/debugfs'
  require 'blockbridge/util/filesystem/inspector'
end
