# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge
  module Util
    module Filesystem
      class Ext4Inspector < Inspector

        def block_device
          @block_device ||= fsinfo.mtab.name
        end

        def debugfs
          @debugfs ||= Blockbridge::Util::Filesystem::DebugFs.new(block_device, mount_point)
        end

        def fs_stats
          raw = debugfs.stats
          Filesystem::FsStats.new(raw.attrs.block_size, raw.attrs.inode_size)
        end

        def stat(path)
          data = debugfs.stat(path)
          imap = debugfs.imap(path)

          data_extents = data.extents.map do |ex|
            {
              a: fs_block_to_scsi(ex.a),
              n: fs_block_to_scsi(ex.n)
            }
          end

          inode_extent = {
            a: fs_block_to_scsi(imap.block),
            n: inode_size
          }

          res = {
            mount_point: mount_point,
            dev: block_device,
            type: data.type,
            ino: data.inode,
            mode: data.mode,
            user: data.user,
            group: data.group,
            size: data.size,
            links: data.links,
            allocmeth: data.allocmeth,
            data_extents: data_extents,
            inode_extent: inode_extent
          }

          Hashie::Mash.new(res)
        end

        private

        def inode_size
          @inode_size ||= (Float(fs_stats.inode_size) / SCSI_BLK_SIZE).ceil
        end

      end
    end
  end
end
