# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

require 'hashie'

module Blockbridge
  module Util
    module Filesystem
      class Inspector
        include Blockbridge::Util::Constants

        def self.inherited(klass)
          # turns SvnLogFileReader in to :svn
          sfx = self.name.split('::').last
          key = klass.name.split('::').last.chomp(sfx)
          key = Blockbridge::Util.underscore(key).to_sym

          @subclasses ||= {}
          @subclasses[key] = klass
        end

        # factory method -- create an appropriate filesystem inspector given
        # the supplied path. the path may or may not be a mountpoint. throws
        # an exception if the discovered filesystem is not supported.
        def self.create(path)
          # get mountpoint
          mnt_pt = Blockbridge::Util::Filesystem.mount_point(path)

          # get filesystem information
          fsinfo = Blockbridge::Util::Filesystem.info(mnt_pt)
          mount_type = fsinfo.mtab.mount_type.to_sym

          # instantiate subclass for fs type
          if @subclasses && @subclasses.has_key?(mount_type)
            @subclasses[mount_type].new(mnt_pt, fsinfo)
          else
            raise "Unsupported filesystem type '#{mount_type}' mounted at '#{mnt_pt}'"
          end
        end

        # base class instance methods & attrs
        attr_reader :mount_point
        attr_reader :fsinfo

        def initialize(mnt_pt, fsinfo)
          @mount_point = mnt_pt
          @fsinfo = fsinfo
        end

        # retrieve filesystem statistics
        def fs_stats
          raise "fs_stats unimplemented"
        end

        # stat a single file
        def stat(path)
          raise "stat unimplemented"
        end

        # get the SCSI block to filesystem block multiplier
        def fs_block_to_scsi(blk)
          if @blk_mul.nil?
            sts = fs_stats
            if (sts.block_size % SCSI_BLK_SIZE) != 0
              raise "fs block size (#{sts}) is not a multiple of #{SCSI_BLK_SIZE}"
            end
            @blk_mul = sts.block_size / SCSI_BLK_SIZE
          end
          @blk_mul * blk
        end
      end

    end
  end
end

require 'blockbridge/util/filesystem/ext4_inspector'
