require 'blockbridge/util/color'

describe Blockbridge::Util::Color do
  describe '.strip' do
    it "removes color codes from a string" do
      c = "\e[31mtest\e[0m \e[32mfoo\e[0m \e[34mbar\e[0m \e[33mbaz\e[0m"
      s = "test foo bar baz"
      expect(s).to eq Blockbridge::Util::Color.strip(c)
    end

    it "leaves non-colored strings alone" do
      s = "test foo bar baz"
      expect(s).to eq Blockbridge::Util::Color.strip(s)
    end
  end

  describe '.has_color?' do
    it "is truthy for a string containing color" do
      c = "\e[31mtest\e[0m"
      expect(Blockbridge::Util::Color.has_color?(c)).to be_truthy
    end

    it "is falsy for a string which does not contain color" do
      c = "test"
      expect(Blockbridge::Util::Color.has_color?(c)).to be_falsey
    end
  end

  describe '.length' do
    it "does not count color codes" do
      c = "\e[31mtest\e[0m \e[32mfoo\e[0m \e[34mbar\e[0m \e[33mbaz\e[0m"
      s = "test foo bar baz"
      expect(s.length).to eq Blockbridge::Util::Color.length(c)
    end
  end

  describe '.truncate' do
    it "trucates a string mid-way through a colored section" do
      c = "\e[31mtest\e[0m \e[32mfoo\e[0m \e[34mbar\e[0m \e[33mbaz\e[0m"
      t = "\e[31mtest\e[0m \e[32mfoo\e[0m \e[34mba\e[0m\e[33m\e[0m"
      expect(t).to eq Blockbridge::Util::Color.truncate(c, 11)
    end

    it "leaves all color codes behind" do
      c = "\e[31mtest\e[0m \e[32mfoo\e[0m \e[34mbar\e[0m \e[33mbaz\e[0m"
      t = "\e[31m\e[0m\e[32m\e[0m\e[34m\e[0m\e[33m\e[0m"
      expect(t).to eq Blockbridge::Util::Color.truncate(c, 0)
    end
  end
end
