require 'blockbridge/util'
require 'blockbridge/util/filesystem/inspector'

describe Blockbridge::Util::Filesystem::Ext4Inspector do
  before :all do
    @inst = Blockbridge::Util::Filesystem::Inspector.create('/etc')
    expect(@inst).to be_an_instance_of Blockbridge::Util::Filesystem::Ext4Inspector
  end

  describe "#stat" do
    before :all do
      @tgt_file = '/etc/passwd'
      @dst = @inst.stat(@tgt_file)
    end

    it "returns reasonable data" do
      expect(@inst.stat('/etc/passwd')).to respond_to(:allocmeth, :type, :ino)
    end

    it "reports the same inode number as File::stat" do
      fst = File.stat(@tgt_file)
      expect(fst.ino).to eq @dst.ino
    end

    it "reports data extents" do
      expect(@dst.data_extents).to be_an_instance_of Array
      expect(@dst.data_extents.length).to be > 0
    end

    it "reports an inode extent" do
      expect(@dst).to respond_to(:inode_extent)
      expect(@dst.inode_extent).to respond_to(:a, :n)
    end
  end
end
