require 'blockbridge/util'
require 'blockbridge/util/filesystem/inspector'

describe Blockbridge::Util::Filesystem::Inspector do
  describe ".create" do
    it "raises an exception when given a bogus path" do
      expect do
        Blockbridge::Util::Filesystem::Inspector.create('/BoGuS/pAtH')
      end.to raise_error
    end

    it "raises an exception for an unsupported filesystem type (/proc)" do
      expect do
        Blockbridge::Util::Filesystem::Inspector.create('/proc')
      end.to raise_error
    end

    context "when inspecting a supported filesystem" do
      before :all do
        @inst = Blockbridge::Util::Filesystem::Inspector.create('/etc')
        expect(@inst).to be_an_instance_of Blockbridge::Util::Filesystem::Ext4Inspector
      end

      it "reports the correct mount point" do
        expect(@inst.mount_point).to eq '/'
      end

      it "has sensible filesystem information" do
        expect(@inst.fsinfo.mtab.mount_type).to eq 'ext4'
      end
    end
  end
end
