require "clamp/attribute/declaration"
require "clamp/option/definition"

module Clamp
  module Option

    module Declaration

      include Clamp::Attribute::Declaration

      def option(switches, type, description, opts = {}, &block)
        # merge any option-specific options into the current group options
        opts = current_option_group.merge(opts)

        Option::Definition.new(switches, type, description, opts).tap do |option|
          block ||= option.default_conversion_block
          define_accessors_for(option, &block)
          declared_options << option
        end
      end

      def option_group(name = nil, opts = {}, &block)
        new_group = current_option_group.merge(opts).tap do |h|
          h[:group] = name unless name.nil?
        end

        option_group_stack.push new_group

        begin
          yield current_option_group
        ensure
          option_group_stack.pop
        end
      end

      def find_option(switch)
        recognised_options.find { |o| o.handles?(switch) }
      end

      def declared_options
        @declared_options ||= []
      end

      def recognised_options
        unless @implicit_options_declared
          declare_implicit_help_option
          @implicit_options_declared = true
        end
        effective_options
      end

      private

      def declare_implicit_help_option
        return false if effective_options.find { |o| o.handles?("--help") }
        help_switches = ["--help"]
        help_switches.unshift("-h") unless effective_options.find { |o| o.handles?("-h") }
        option help_switches, :flag, "print help" do
          request_help
        end
      end

      def option_group_stack
        @option_group_stack ||= []
      end

      def current_option_group
        option_group_stack.last || {}
      end

      def effective_ancestor_options(options, ancestor)
        options_declared_on(ancestor).reject do |anc_o|
          options.find do |o|
            anc_o.switches.any? { |s| o.handles?(s) }
          end
        end
      end

      def effective_options
        ancestors.inject([]) do |options, ancestor|
          options + effective_ancestor_options(options, ancestor)
        end
      end

      def options_declared_on(ancestor)
        return [] unless ancestor.is_a?(Clamp::Option::Declaration)
        ancestor.declared_options
      end

    end

  end
end
