# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

require 'json'
require 'blockbridge/cli/version'
require 'blockbridge/cli/config'
require 'blockbridge/cli/errors'
require 'blockbridge/cli/view'
require 'blockbridge/cli/help'
require 'facets/string/word_wrap'
require 'deep_merge/rails_compat'

# Add requires for other files you add to your project here, so
# you just need to require this one file in your bin file

require 'clamp'

Clamp.allow_options_after_parameters = true

module Clamp
  class Command
    @@mixins = {}

    def self.mixin(*names, &block)
      opts = {}
      if names.last.is_a? Hash
        opts = names.pop
      end

      names.each do |name|
        if block_given?
          if @@mixins.has_key?(name.to_sym)
            raise "attempt to redefine mixin '#{name}'"
          end
          @@mixins[name.to_sym] = block
        else
          if !@@mixins.has_key?(name.to_sym)
            raise "no mixin named '#{name}'"
          end
          instance_exec(opts, &@@mixins[name.to_sym])
        end
      end
    end
  end

  module Subcommand
    module Execution

      # override default Subcommand#execute behavior to return the command
      # instance object. this is used in specs to reach in and examine state
      # after executing a command. yay!

      def execute
        # delegate to subcommand
        subcommand = instantiate_subcommand(subcommand_name)
        unless subcommand
          super
        else
          subcommand.run(subcommand_arguments)
          subcommand
        end
      end
    end
  end
end

require 'blockbridge/cli/main'
require 'blockbridge/cli/helpers'
require 'blockbridge/cli/command'

module Blockbridge::CLI

  USER_AGENT = "blockbridge-cli/#{Blockbridge::CLI::VERSION} (#{RUBY_PLATFORM}) ruby/#{RUBY_VERSION}"

  def self.package_version
    "#{Blockbridge::CLI::VERSION}-#{(ENV['BB_BUILD_NUMBER'] || "dev")}"
  end

  def self.user_agent
    @@user_agent ||= USER_AGENT
  end

  def self.user_agent=(agent)
    @@user_agent = agent
  end

  def self.verbose=(val)
    @@verbose = val
  end

  def self.verbose?
    @@verbose ||= false
  end
end
