# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge::CLI::Command
  class Authorization < Base
    self.default_subcommand = 'list'

    class AuthorizationCreate < Base
      apiopt('--notes', 'NOTES', 'specify authorization notes')
      apiopt('--fingerprint', 'STRING', 'specify client-side fingerprint', level: :expert)
      apiopt('--disable', :flag, 'create authorization in disabled state (default is enabled)',
             :param_name => :enabled,
             :param_value => false)
      apiopt('--restrict', 'CLASS', 'restrict authorization permissions by class. [none, auth]',
             default: 'auth', level: :advanced) do |v|
        enum_check(v, %w(none auth))
      end
      apiopt('--scope', 'VALUE', 'specify authorization permission scope')
      apiopt('--[no-]enforce-two-factor', :flag, 'enforce 2-factor auth', level: :advanced)

      apiopt('--user',
             'USER',
             'specify target user (default is currently authenticated user)',
             param_name: :user_id) do |v|
        obj_list(:user, restrict: :only_one, value: v).id
      end

      mixin :xref
      mixin :info_extraction

      def exec
        authz = api.authorization.create(api_params)
        process_results authz
      end
    end
    subcommand 'create', 'create a new persistent authorization', AuthorizationCreate, level: :basic

    mixin :authz
    mixin :info_extraction

    subcommand ['list', 'ls'], 'enumerate persistent authorizations', self, level: :basic do
      mixin :info_filtering
      mixin :sort_by

      def exec
        authzs = obj_list(:authz)
        process_results authzs, view: 'authorization_list'
      end
    end

    subcommand 'info', 'show persistent authorization details', self, level: :basic do
      mixin :info_filtering
      mixin :info_extraction

      def exec
        authzs = obj_list(:authz)
        process_results authzs
      end
    end

    subcommand 'update', 'update persistent authorization configuration', self, level: :basic do
      apiopt('--notes', 'NOTES', 'update authorization notes')
      apiopt('--disable', :flag, 'disable authorization',
             :param_name => :enabled,
             :param_value => false)
      apiopt('--enable', :flag, 'enable authorization',
             :param_name => :enabled,
             :param_value => true)
      apiopt('--scope', 'VALUE', 'update authorization permission scope')
      apiopt('--no-scope', :flag, 'clear restricted permission scope',
             param_name: :scope, param_value: nil)
      apiopt('--[no-]enforce-two-factor', :flag, 'enforce 2-factor auth', level: :advanced)

      def exec
        authz = obj_list(:authz, restrict: :only_one)

        authz = api.authorization.update(authz.id, api_params)
        process_obj_updated authz
      end
    end

    subcommand 'remove', 'remove an existing persistent authorization', self, level: :basic do
      def exec
        authz = obj_list(:authz, restrict: :only_one)
        api.authorization.remove(authz.id)
        process_obj_removed authz
      end
    end

  end
end
