# Copyright (c) 2016, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge::CLI::Command
  class Backup < Base
    self.default_subcommand = 'list'

    mixin :obj_store

    subcommand ['list', 'ls'], 'enumerate object-store based backups' do
      mixin :info_filtering
      mixin :info_extraction
      mixin :sort_by

      def exec
        obj_store = obj_list(:obj_store, restrict: :only_one)
        process_results api.obj_store.list_backups(obj_store.id, {}), view: 'backup_list'
      end
    end

    subcommand 'remove', 'remove a backup' do
      option '--backup', 'ID', 'ID of backup to remove', required: true
      def exec
        obj_store = obj_list(:obj_store, restrict: :only_one)
        rsp = api.obj_store.remove_backup(obj_store.id, backup)
        desc = rsp.empty? ? 'Completed' : 'Initiated'
        process_action_complete({ obj_store: obj_store, rsp: rsp },
                                desc: "#{desc} remove of #{backup}")
      end
    end

  end

end
