# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge::CLI::Command
  class Batch < Base
    subcommand ['list', 'ls'], 'list objects', self, level: :expert do
      apiopt '--scope', 'SCOPE', 'comma-separated list of object types'
      option '--xref', 'XREF', 'limit list to specified xref value'

      mixin :info_extraction
      mixin :info_filtering
      mixin :sort_by

      def exec
        if xref
          objects = api.objects.list_by_xref(xref, api_params)
        else
          objects = api.objects.list(api_params)
        end

        process_results objects, view: 'batch_list'
      end
    end

    subcommand 'remove', 'bulk delete objects', self, level: :expert do
      option '--xref', 'XREF', 'limit list to specified xref value', required: true
      apiopt '--scope', 'SCOPE', 'comma-separated list of object types'

      mixin :info_extraction

      def exec
        process_results api.objects.remove_by_xref(xref, api_params)
      end
    end
  end
end
