# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

require 'base64'

module Blockbridge::CLI::Command
  class CA < Base
    subcommand 'certificate', 'download the embedded CA certificate' do
      apiopt('--format', 'FORMAT', 'requested certificate format',
             :default => 'pem',
             :param_path => '/format',
             :param_name => 'cert_format') do |v|
        enum_check v, %w(pem der)
      end
      option '-o', 'FILE', 'output filename (default: stdout)', :attribute_name => 'file'

      def exec
        crt = api.ca_certificate.info(api_params)
        return if display_raw crt

        crt_data = cert_decode(crt)

        if file
          File.open(file, "w") do |f|
            f.print(crt_data)
          end
        else
          puts crt_data
        end
      end
    end
  end
end
