# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge::CLI::Command
  class Catalog < Base
    subcommand 'query', 'query the product catalog' do
      option '--count', 'COUNT', 'limit number of results (default 3)' do |c| Integer(c) end

      mixin :catalog_query_params
      mixin :info_filtering
      mixin :info_extraction

      parameter("[QUERY] ...", "catalog query parameters", :attribute_name => :tag_query)

      def exec
        params = query_params
        params[:count] = count unless count.nil?

        # add in extra tags specs
        params.deep_merge!(parse_tag_query(tag_query))

        results = api.product.search_create(params)

        if results[:products].empty? && fail_on_empty?
          runtime_error 'Query returned no results'
        end

        process_results results
      end
    end

    subcommand 'params', 'display catalog search parameters' do
      mixin :info_filtering
      mixin :info_extraction

      def exec
        params = api.product.search_parameters
        process_results params
      end
    end
  end
end
