# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

require 'ipaddr'

module Blockbridge::CLI::Command
  class Global < Base
    subcommand 'params', 'update management parameters' do
      subcommand 'openstack', 'update openstack parameters' do
        self.default_subcommand = 'info'

        subcommand 'info', 'info on openstack parameters' do
          mixin :info_extraction
          def exec
            node = only_one_management_node
            process_results(node, view: :params_idp)
          end
        end

        subcommand 'update', 'update openstack parameters' do
          option_group 'Identity Provider' do
            apiopt('--[no-]idp', :flag, 'enable or disable identity provider',
                  :param_name => %w(openstack_idp enabled))
            apiopt('--idp-url', 'URL', 'update the identity provider url',
                  :param_name => %w(openstack_idp url))
            apiopt('--idp-label', 'LABEL', 'update the identity provider label',
                  :param_name => %w(openstack_idp label))
            apiopt('--idp-user', 'USER', 'update the identity provider administrative user',
                  :param_name => %w(openstack_idp auth user name))
            apiopt('--idp-password', 'PASSWORD', 'update the identity provider administrative password',
                  :param_name => %w(openstack_idp auth user password))
            apiopt('--idp-project', 'PROJECT', 'update the identity provider administrative project',
                  :param_name => %w(openstack_idp auth project name))
            apiopt('--idp-domain', 'DOMAIN', 'update the identity provider domain',
                  :param_name => %w(openstack_idp auth domain name))
          end

          option_group 'Target Portal Filter' do
            apiopt('--no-portal-filter', :flag, 'clear openstack target portal filter',
                   :param_value => nil,
                   :param_name  => %w(openstack_portal_filter))
            apiopt('--portal-filter', 'NETWORK/MASK', 'update the openstack target portal filter in network mask CIDR notation (eg: 192.168.1.0/24)',
                   :param_name => %w(openstack_portal_filter)) do |val|
              addr = IPAddr.new(val)
              mask = addr.ipv4? ? '0.0.0.0' : '0:0:0:0:0:0:0:0'
              val.match(/\/([0-9]+)$/) { |cidr|
                mask = IPAddr.new(addr.ipv4? ? '255.255.255.255': 'FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF').mask(cidr[1]).to_s
              }
              {
                ip:   addr.to_s,
                mask: mask,
              }
            end
          end

          def exec
            node = only_one_management_node
            node = api.node.update(node.id, api_params)
            process_obj_updated node
          end
        end
      end
    end

  end
end
