# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge::CLI::Command
  class ObjStore < Base
    self.default_subcommand = 'list'

    subcommand 'create', 'create object store' do
      mixin :label_notes, obj_name: 'obj-store'
      apiopt('--bucket-name', 'BUCKET_NAME', 'bucket name', :required => true)
      apiopt('--host-name', 'HOST_NAME', 'host name')
      apiopt('--protocol', 'PROTOCOL', 'store protocol') do |val|
        enum_check(val, %w(https http))
      end
      apiopt('--uri-style', 'URI-STYLE', 'uri style (virtual_host, path)') do |val|
        enum_check(val, %w(virtual_host path))
      end
      apiopt('--access-key-id', 'ACCESS_KEY_ID', 'AccessKeyID')
      apiopt('--secret-access-key', 'SECRET_ACCESS_KEY', 'SecretAccessKey')
      apiopt('--default-wkey-password', 'PASS', 'default object passphrase')
      apiopt('--security-token', 'SECURITY_TOKEN', 'SecurityToken')
      apiopt('--city', 'CITY', 'specify object store city',
             param_name: %w(location city))
      apiopt('--state', 'STATE', 'specify object store state',
             param_name: %w(location state))
      apiopt('--country', 'COUNTRY', 'specify object store country',
             param_name: %w(location country))
      apiopt('--lat', 'LATITUDE', 'specify object store latitude',
             param_name: %w(location lat)) do |val| Float(val) end
      apiopt('--long', 'LONGITUDE', 'specify object store longitude',
             param_name: %w(location long)) do |val| Float(val) end

      def exec
        obj_store = api.obj_store.create(api_params)
        process_obj_created obj_store, desc: "Created obj-store '#{obj_store.label}'"
      end
    end

    subcommand 'remove', 'remove an existing object store' do
      mixin :obj_store
      def exec
        obj_store = obj_list(:obj_store, restrict: :only_one)
        _rsp = api.obj_store.remove(obj_store.id)
        process_obj_removed obj_store
      end
    end

    subcommand 'update', 'update object store parameters' do
      mixin :obj_store
      mixin :label_notes, obj_name: 'obj-store', hidden: false
      apiopt('--bucket-name', 'BUCKET_NAME', 'bucket name')
      apiopt('--host-name', 'HOST_NAME', 'host name')
      apiopt('--protocol', 'PROTOCOL', 'store protocol') do |val|
        enum_check(val, %w(https http))
      end
      apiopt('--uri-style', 'URI-STYLE', 'uri style (virtual_host, path)') do |val|
        enum_check(val, %w(virtual_host path))
      end
      apiopt('--access-key-id', 'ACCESS_KEY_ID', 'AccessKeyID')
      apiopt('--secret-access-key', 'SECRET_ACCESS_KEY', 'SecretAccessKey')
      apiopt('--security-token', 'SECURITY_TOKEN', 'SecurityToken')
      apiopt('--default-wkey-password', 'PASS', 'default object passphrase')
      apiopt('--city', 'CITY', 'specify object store city', param_name: %w(location city))
      apiopt('--state', 'STATE', 'specify object store state', param_name: %w(location state))
      apiopt('--country', 'COUNTRY', 'specify object store country', param_name: %w(location country))
      apiopt('--lat', 'LATITUDE', 'specify object store latitude',
             param_name: %w(location lat)) do |val| Float(val) end
      apiopt('--long', 'LONGITUDE', 'specify object store longitude',
             param_name: %w(location long)) do |val| Float(val) end

      def exec
        obj_store = obj_list(:obj_store, restrict: :only_one)
        obj_store = api.obj_store.update(obj_store.id, api_params)
        process_obj_updated obj_store
      end
    end

    subcommand ['list', 'ls'], 'enumerate object stores' do
      mixin :obj_store
      mixin :info_filtering
      mixin :sort_by

      def exec
        obj_stores = obj_list(:obj_store)
        process_results obj_stores, view: 'obj_store_list'
      end
    end

    subcommand 'info', 'show detailed object store information' do
      mixin :obj_store
      mixin :info_filtering
      mixin :info_extraction

      def exec
        obj_stores = obj_list(:obj_store)
        process_results obj_stores
      end
    end
  end
end
