# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

module Blockbridge::CLI::Command
  class Snapshot < Base
    self.default_subcommand = 'list'

    # create doesn't accept snap arg
    class SnapshotCreate < Base
      mixin :vss, :disk
      mixin :label_notes, obj_name: 'snapshot'
      option_group nil, :hidden => true do
        mixin :tags_create
      end
      mixin :info_extraction

      def exec
        vdisk = obj_list(:disk, restrict: :only_one)
        snap_params = api_params.merge(vdisk_id: vdisk.id)

        snap = api.snapshot.create(snap_params)
        process_obj_created(snap, desc: "Created snapshot #{snap} of disk #{vdisk}")
      end
    end
    subcommand 'create', 'create snapshot', SnapshotCreate, level: :basic

    # all other subcommands take a snap arg
    mixin :snapshot, :vss, :disk
    mixin :info_extraction

    subcommand ['list', 'ls'], 'enumerate snapshots', self, level: :basic do
      mixin :info_filtering
      mixin :sort_by

      def exec
        snapshots = obj_list(:snapshot)
        process_results snapshots, view: 'snapshot_list'
      end
    end

    subcommand 'info', 'show detailed snapshot information', self, level: :basic do
      mixin :vss, :disk

      mixin :info_extraction
      mixin :info_filtering

      option '--references', :flag, 'show snapshot references'

      def exec
        snapshots = obj_list(:snapshot)
        process_results snapshots, with_references: references?
      end
    end

    subcommand 'update', 'update snapshot metadata', self, level: :basic do
      mixin :label_notes, obj_name: 'snapshot', hidden: false
      mixin :tags_update

      def exec
        snap = obj_list(:snapshot, restrict: :only_one)

        snap = api.snapshot.update(snap.id, api_params)
        process_obj_updated snap
      end
    end

    subcommand 'remove', 'remove snapshot', self, level: :basic do
      def exec
        snap = obj_list(:snapshot, restrict: :only_one)

        rsp = api.snapshot.remove(snap.id)
        process_obj_removed snap
      end
    end

  end
end
