# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No accounts found."
  return
end

data.each do |obj|
  fieldset("Account: #{obj.name} (#{obj.serial})", heading: true) do
    field "name", obj.name
    partial(:obj_basics, obj)
    field "disabled", obj.disabled, :cast => :bool_yn
  end

  fieldset("Limits", verbose: true) do
    limits  = obj.limits
    options = obj.provisioning
    field "max number of vss", limits.vss_num, :nil_str => 'unlimited'
    field "storage reserve limit", limits.size_reserve_limit,
          :nil_str => 'unlimited', :cast => :bytes
    field "per vss iops reserve max", options.iops_reserve_max,
          :nil_str => 'unlimited'
    field "per vss storage reserve max", options.size_reserve_max,
          :nil_str => 'unlimited'
  end

  fieldset("Provisioning", verbose: true) do
    options = obj.provisioning
    field "tags permitted", options.tags_permit.join(',') if options.tags_permit
    field "tags permitted", 'all' if !options.tags_permit
    field "tags included", options.tags_include.join(',')
    field "tags excluded", options.tags_exclude.join(',')
  end

  if options.show_usage
    if (usage = obj.usage)
      fieldset("Usage") do
        field "size reserve", usage.size_reserve, :cast => :bytes
        field "iops reserve", usage.iops_reserve
        field "vss num", usage.vss_num
        field "vdisk num", usage.vdisk_num
        field "clones num", usage.clones_num
        field "repl num", usage.repl_num
        field "snapshot num", usage.snapshot_num
        field "target num", usage.target_num
        field "profile num", usage.profile_num
        field "user num", usage.user_num
      end
    end
  end
end
