# Copyright (c) 2020, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

stats = data[:stats]
obj = data[:obj]

tstart = DateTime.parse(stats.fetch(:tstart))
tend = DateTime.parse(stats.fetch(:tend))

fieldset("Datastore: #{obj.label} (#{obj.serial})", heading: true) do
  partial(:obj_basics, obj)
  field 'complex', obj[:cplx_id]
end

fieldset('Query Overview') do
  field 'start', tstart
  field 'end', tend
  field 'granularity', stats[:granularity]
end

stats[:usage].each_pair do |stat, info|
  fieldset(info[:desc], label_min: 8) do
    field 'stat', stat
    field 'units', info[:units]
    field 'datapoints', info[:num]
  end

  table(sort_cols: []) do |t|
    t.cols(
      { label: 'series' },
      { label: 'minimum', min: 10 },
      { label: 'maximum', min: 10 },
      { label: 'average', min: 10 },
      { label: 'std. deviation', min: 10 }
    )

    %w[min max avg].each do |row|
      name = case stats[:granularity]
             when 'day'
               "daily #{row}"
             when 'hour'
               "hourly #{row}"
             else
               row
             end
      t << [name].concat(info[row.to_sym])
    end
  end

  next unless info.key?(:data)

  table do |t|
    t.cols('time', 'min', 'max', 'avg')

    info[:data].each do |d|
      t << [d[:t], d.dig(:min, 0), d.dig(:max, 1), d.dig(:avg, 2)]
    end
  end
end
