# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

devs = data

show_inuse = cmd.inuse?
verbose = cmd.verbose?

if devs.length == 0
  header "No devices found."
  return
end

if show_inuse
  num_hidden = 0
else
  num_hidden = devs.count { |dev| dev.inuse }
end

dev_str = devs.length == 1 ? "device" : "devices"
hidden_str = num_hidden == 1 ? "device" : "devices"

header "Discovered #{devs.length} #{dev_str}."
header "(not showing #{num_hidden} in-use #{hidden_str})" if num_hidden > 0
vspace

devs.each do |dev|
  next if dev.inuse && !show_inuse

  inuse = dev.inuse ? color(" (IN-USE)", :red) : ""

  fieldset("Device: #{dev.name}#{inuse}") do
    field "path", dev.path
    field "size", dev.raw_size, :cast => :bytes
    field "type", dev.type

    field "preferred path", dev.preferred_path
    field_options(verbose: true) do
      dev.devlinks.each_with_index do |devlink, idx|
        field "devlink[#{idx}]", devlink
      end
      field "driver", dev.driver
      field "subsystem", dev.subsystem
      field "syspath", dev.syspath
      dev.properties.each do |p|
        field p.name, p.value
      end
    end
  end
end
