# frozen_string_literal: true

# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.empty?
  header 'No saved diagnostics files.'
  return
end

data.each do |obj|
  contents = obj[:contents]

  if contents.nil?
    header("Diagnostics #{File.basename(obj[:file])} corrupted or empty.", [:red])
    next
  end

  fieldset("Diagnostics #{File.basename(obj[:file])}", heading: true) do
    field 'diag uuid', contents[:uuid]
    field 'path', obj[:file], verbose: true
    field 'cli version', contents[:version]
    field 'created at', contents[:created_at], cast: :time
    field 'env uuid', -> { contents.dig(:config, :global, :uuid) }
  end

  fieldset('Config', verbose: true) do
    contents[:config].each_pair do |k, v|
      field k, v.to_json
    end
  end

  fieldset('Command') do
    field 'argv', contents[:argv].join(' ')
    field 'api url', contents[:api_url]
  end

  fieldset('Exception', data: contents[:exception]) do |_, ex|
    field 'class', ex[:class]
    field 'message', ex[:message]

    ex[:backtrace].each do |frame|
      field '|', frame
    end
  end
end
