# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No virtual disks found."
  return
end

show_disks = options.show_disks
show_targets = options.show_targets

data.each do |obj|
  fieldset("Virtual disk: #{obj}", heading: true) do
    partial(:obj_basics, obj)

    field "vss", obj.vss
    field "capacity", obj.capacity, :cast => :bytes
    if obj.encryption
      field "encryption", obj.encryption.cipher + "-" + obj.encryption.mode
    end
    field "vault", obj.locked ? color('locked', :yellow) : 'unlocked'
    field "data cache", obj.data_cache, verbose: true
    if obj.readahead
      field "readahead", obj.readahead[:size], :nil_str => 'none', :cast => :bytes, verbose: true
    end
    field "compression", obj.dig(:compression), :nil_str => 'none', verbose: true
    partial(:tags, obj.tags)
    partial(:xmd_refs, obj.xmd_refs)
  end

  if (basis = obj.basis)
    fieldset("Basis") do
      field "source", ref_str(basis.src_id? ? basis.src_id : basis.id)
      field "source vss", ref_str(basis.vss_id) if basis.vss_id
      if basis.object_key || basis.label
        field "backup", basis.label ? basis.label : basis.object_key
      end
      field "protocol", basis.protocol
      field "locality", basis.locality
      field "mode", basis.mode
    end
  end

  partial_out :xmd, obj.xmd

  fieldset("SCSI", verbose: true) do
    scsi = obj.scsi
    field "multi-map", scsi.multi_map
    field "read-only", scsi.read_only
    field "write-once", scsi.write_once

    if scsi.removable
      s = 'yes'
      if obj.media_loaded
        s << ", loaded for #{obj.loaded_profile}"
      else
        s << ", ejected"
      end
    else
      s = 'no'
    end
    field "removable", s
  end

  partial_out(:sizing, obj.sizing)

  fieldset("Quota", verbose: true) do
    quota = obj.quota
    size = quota[:size]
    iops = quota.iops
    field "size limit", partial(:disk_size_quota, size.limit, disk: obj)
    field "size notify", partial(:disk_size_quota, size.notify, disk: obj)
    field "size reserve", partial(:disk_size_quota, size.reserve, disk: obj)
    field "iops limit", iops.limit, :nil_str => 'none'
  end

  if (ext = obj.ext)
    fieldset("External") do
      if (iscsi = ext.iscsi)
        field "initiator name", iscsi.initiator_name
        field "initiator login", iscsi.initiator_login
        field "target host", iscsi.target_host
        field "target name", iscsi.target_name
        field "target port", iscsi.target_port
        if (mauth = iscsi.mutual_auth)
          field "mutual auth", true
          field "target login", iscsi.target_login
        end
      end
      if (scsi = ext.scsi)
        field "lun", scsi.lun
      end
    end

    if (transport = ext.transport)
      fieldset("Transport") do
        field "mode", transport.mode
      end
    end
  end

  #
  # show basic replication configuration
  #

  if slave_cfg = obj.replication&.slave
    slave_rts = obj.replication_rts.slave

    fieldset("Replication (master mode)") do
      rts_state = slave_rts.state || 'unavailable'
      field "state", "#{slave_cfg.state} (rts = #{rts_state})"

      slave_disk = ref_obj(slave_cfg.disk_id)
      field "slave disk", ref_str(slave_cfg.disk_id)

      if slave_disk
        slave_vss = ref_obj(slave_disk.vss_id)
        field "slave vss", ref_str(slave_vss.id)
      end
    end
  end

  if master_cfg = obj.replication&.master
    master_rts = obj.replication_rts.master

    fieldset("Replication (slave mode)") do
      field "state", master_rts.state, :nil_str => 'unavailable'

      master_disk = ref_obj(master_cfg.disk_id)
      field "master disk", ref_str(master_cfg.disk_id)

      if master_disk
        master_vss = ref_obj(master_disk.vss_id)
        field "master vss", ref_str(master_vss.id)
      end
    end
  end
end

return
