# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No replication masters found."
  return
end

data.each do |master|
  rsts = master.replication_status
  next if rsts.nil?

  fieldset("Replication: #{rsts.master.desc}", heading: true) do
    field "master disk", rsts.master.desc
    field "master vss", rsts.master.vss.desc
    field "master status", partial(:obj_status, master.status)
    field "slave disk", rsts.slave.desc
    if !rsts.slave.deleted
      field "slave vss", rsts.slave.vss.desc
      field "slave status", partial(:obj_status, rsts.slave.obj_status)
    end
  end

  slave_cfg = master.replication.slave
  fieldset("Configuration") do
    field('mode', slave_cfg.config.mode)
    field('recovery', slave_cfg.config.recovery)

    rbw = slave_cfg.config.rebuild_bandwidth
    field('rebuild bw', (rbw == 0) ? 'unlimited' : "#{format_bytes(rbw)}/s")

    field('timeout', "#{slave_cfg.config.timeout}ms")

    rhash = slave_cfg.config.rebuild_hash
    field('rebuild hash', rhash ? 'ghash' : 'none')
  end

  slave_rts = master.replication_rts.slave
  fieldset("Runtime") do
    field 'replication status', "#{slave_cfg.state} (rts = #{slave_rts.state || 'unknown'})"
    field 'slave status', rsts.slave.rts.master.state
    field 'slave consistency', rsts.slave.consistency
    field 'syndromes', rsts.syndromes_str
    field 'rebuild method', rsts.rebuild_method
  end

  case rsts.state
  when 'rebuild'
    rebuild = rsts.rebuild_status

    fieldset "Rebuild status" do
      if rebuild.nil?
        field 'status', 'not available'
      else
        # show details
        field 'mode', rebuild.mode
        field 'progress', rebuild.progress_str
        field 'transferred', rebuild.transfer_str
        field 'bandwidth', rebuild.bandwidth_str
        field 'started', rebuild.started_str
        field 'elapsed', rebuild.elapsed_str
        field 'completion', rebuild.completion_str
      end
    end
  end
end
