# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No disk-sets found."
  return
end

data.each do |obj|
  fieldset("Disk-set: #{obj.label} (#{obj.ref})", heading: true) do
    partial(:obj_basics, obj)
    field "ref", color(obj.ref, :bold)
    field "vss", ref_str(obj.vss_id) if obj.vss_id
    partial(:tags, obj.tags)
    partial(:xmd_refs, obj.xmd_refs)
    field "disks", obj[:data][:group][:data][:disks_num]
  end

  if obj.ext_status
    fieldset("External Status") do
      field "value", obj.ext_status.value
      field "indicator", obj.ext_status.indicator
      field "detail", obj.ext_status.detail
    end
  end

  header "Disks in Set"

  if obj.vdisks_in_set
    if obj.vdisks_in_set.length > 0
      table do |t|
        t.cols('idx', 'disk', 'capacity', 'size', 'reserved', 'attached')
        obj.vdisks_in_set.each { |v|
          disk_idx     = "disk:#{v.idx}"
          capacity_str = format_value(v.vdisk.capacity, :cast => :bytes)
          size_str     = format_value(v.vdisk.sizing[:size], :nil_str => '-', :cast => :bytes)
          reserve_str  = format_value(v.vdisk.quota[:size][:reserve], :cast => :bytes)
          attached_str = v.attached.length > 0 ? v.attached.join(',') : 'no' 

          t << [ disk_idx, v.vdisk, capacity_str, size_str, reserve_str, attached_str ]
        }
      end
    else
      empty_table " -none-"
    end
  end

  partial_out :xmd, obj.xmd
end
