# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

e = data

case e
when Blockbridge::CLI::RuntimeSuccess
  msg = e.message.word_wrap(76)
  puts msg.each_line { |line| puts "  #{line}" }

when Clamp::UsageError
  msg = e.message.word_wrap(70)
  msg.lines.each_with_index do |line, idx|
    if idx == 0
      puts "ERROR: #{line}"
    else
      puts "       #{line}"
    end
  end
  puts ""
  puts "See: '#{e.command.invocation_path} --help'"

when Blockbridge::CLI::RuntimeError
  msg = e.message.word_wrap(70)
  msg.lines.each_with_index do |line, idx|
    if idx == 0
      puts "ERROR: #{line}"
    else
      puts "       #{line}"
    end
  end

when Clamp::HelpWanted
  # display help with our custom builder.
  puts e.command.class.help(e.command.invocation_path,
                            Blockbridge::CLI::HelpBuilder.new(opts))

when Excon::Errors::SocketError
  if /Unable to verify certificate/.match(e.message)
    puts "ERROR: Failed to verify SSL certificate."
    puts ""
    puts "(You may disable verification using --no-ssl-verify-peer)"
  else
    puts "Failed to connect to API endpoint: #{e}"
  end

when Excon::Errors::NotFound, Blockbridge::Api::NotFoundError
  puts "Failed to find requested object."

when Excon::Errors::Gone
  puts "Requested object has been removed."

when Excon::Errors::Conflict
  puts "Object conflicts with existing resource: #{e}"

when Excon::Errors::HTTPStatusError
  partial_out :http_error, e.response

when Blockbridge::Api::UnauthorizedError
  if ENV['BLOCKBRIDGE_API_KEY']
    puts "Authentication failure. (using BLOCKBRIDGE_API_KEY from environment)"
  else
    puts "Authentication failure, please re-login."
    puts ""
  end

when Blockbridge::Api::ForbiddenError
  puts "Operation not permitted for user: #{e}"

when Blockbridge::Api::ValidationError
  partial_out :validation_errors, e.errors

when Blockbridge::Api::ExecutionError
  puts "ERROR: task execution failed with the following " \
  "#{e.errors.length > 1 ? 'errors' : 'error'}:"
  puts

  e.errors.each_with_index do |err, idx|
    puts "* #{err[:message]}"
  end

  puts
  puts "See: '#{cmd.invocation_path} --help'"
  puts

when Blockbridge::Api::ConflictError
  puts "ERROR: task execution failed with the following " \
  "#{e.errors.length > 1 ? 'errors' : 'error'}:"
  puts

  e.errors.each_with_index do |err, idx|
    puts "* #{err[:message]}"
  end

  puts

  if e.conflict
    puts "The operation conflicted with an existing object. " \
         "(#{e.conflict.map { |c| c[:serial] }.join(', ')})"
    puts
  end

  puts "See: '#{cmd.invocation_path} --help'"
  puts

when Blockbridge::Api::ClientError
  puts "Client error: #{e.message}"

when Excon::Errors::BadRequest
  puts "BAD REQUEST: #{e.message.chomp} (#{e.class})"

when SystemExit

when Interrupt

when RuntimeError
  puts "ERROR: #{e.message.chomp}"

when ArgumentError
  puts "ERROR: #{e.message.chomp}"

else
  if ENV['BLOCKBRIDGE_DIAGS']
    puts "UNHANDLED EXCEPTION: #{e.message.chomp} (#{e.class})"
  else
    puts "ERROR: #{e.message.chomp}"
  end
end
