# Copyright (c) 2018, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No host attachments found."
  return
end

hdr = data.first
fieldset("Localhost: #{hdr[:localhost]}", heading: true) do
  field "Hostname", hdr[:localhost] if hdr[:localhost]
  field "Initiator Name", hdr[:localinit] if hdr[:localinit]
end

hosts = data.map { |v| v[:host] }.uniq

hosts.each do |host|
  header "Disks attached to #{host}"
  table do |t|
    if options.cmd.debug? || options.cmd.verbose?
      t.cols('disk', 'capacity', 'paths', 'transport', 'mode', 'device',
              'uuid', 'targ_name')
    else
      t.cols('disk', 'capacity', 'paths', 'transport', 'mode', 'device')
    end
    data.select { |v| v[:host] == host }.each do |v|
      capacity_str = format_value(v[:vdisk]&.dig(:capacity),
                                  :nil_str => 'n/a',
                                  :cast => :bytes)
      if v[:paths_up].nil?
        paths_str = v[:paths_cfg]
      else
        paths_str = "#{v[:paths_up]}/#{v[:paths_cfg]}"
      end

      if v[:devs].nil? || v[:devs].empty?
        devs_str = '-'
      else
        if v[:mpath_dev]
          devs_str = "#{v[:mpath_dev]} (#{v[:devs].join(', ')})"
        else
          devs_str = v[:devs].join(', ')
        end
      end

      row = [ v[:vdisk],
              capacity_str,
              paths_str,
              v[:transport],
              v[:mode],
              devs_str ]

      if options.cmd.debug? || options.cmd.verbose?
        row.concat [ v[:data].dig('uuid'), v[:data].dig('targ_name') ]
      end

      t << row
    end
  end
end
