# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No nodes found."
  return
end

data.each do |obj|
  fieldset("Node: #{obj.label} (#{obj.serial})", heading: true) do
    partial(:obj_basics, obj)

    field "site", ref_str(obj.site_id)
    field "type", obj.type
    field "build version", obj.build_version
    field "build time", obj.build_time
    field "node time", obj.humantime
    field "public address", -> { obj.ip.pub_addr }
    field "private address", -> { obj.ip.prv_addr }
  end

  case obj.type
  when 'management'
    idp = obj.openstack_idp
    fieldset("OpenStack Identity Provider", verbose: true) do
      field "Label", idp.label
      field "URL", idp.url
      field "User name", idp.auth.user.name
      field "Project name", idp.auth.project.name
      field "Domain name", idp.auth.domain.name
      field "Enabled", idp.enabled
    end
    if (portal_filter = obj.openstack_portal_filter)
      fieldset("OpenStack Target Portal Filter", verbose: true) do
        field "Filter", "#{portal_filter.ip}/#{portal_filter.mask}"
      end
    end
  end

  if obj.cluster && obj.cluster.is_cluster
    fieldset('Cluster Status') do
      field 'health', partial(:obj_status, obj.cluster.status)
    end
    if obj.cluster.members.length > 0
      table do |t|
        t.cols('member', 'cluster ip', 'role', 'state', 'health', 'failover')
        obj.cluster.members.each do |mem|
          failover = mem.failover ? color('available', :green) : ''
          sts = partial(:obj_status, mem.status) if mem.status
          t << [ mem[:id], mem.cluster_ip, mem.role, mem.state, sts, failover ]
        end
      end
    end
  end

  fieldset("Software") do
    field "install token", obj.install_token,
          verbose: obj.activation_state == 'activated'
    field "install mode", obj.install_mode
    field "activation code", obj.activation_code
    field "activation state", obj.activation_state
    if obj.license.minutes_remaining
      if obj.license.minutes_remaining != 0
        remaining = format_duration(obj.license.minutes_remaining * 60 * 1000)
        field "license", "#{obj.license.type} (#{remaining})"
      else
        field "license", "#{obj.license.type} (expired)"
      end
    else
      field "license", obj.license.type
    end

    hide_if_empty
  end

  if obj.activation_state == 'activated'
    case obj.type
    when 'storage'
      fieldset("System Information", verbose: true) do
        field "cpu model", obj.cpu_model
        field "# processors", obj.cpu_processors
        field "total memory", obj.mem_total, :cast => :bytes

        if obj.sn # stat - may not be available
          field_options(:cast => :bytes) do
            field "data cache size", obj.sn.data_cache_size
            field "max data log size", obj.sn.max_data_log_size
            field "meta cache size limit", obj.sn.meta_cache_size_limit
            field "max meta cache size", obj.sn.max_meta_cache_size
          end
        end
      end

      if obj.sn&.usage&.any?
        fieldset("Resource Usage", verbose: true) do
          obj.sn.usage.each_pair { |k, v| field k.to_s, v.to_s }
        end
      end
    end
  end

  partial_out(:node_params, obj.params)

  # display enclosures if the data is available
  partial_out(:node_enclosures, obj.enclosures)
end
