# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No initiator profiles found."
  return
end

data.each do |obj|
  fieldset("Initiator profile: #{obj.label} (#{obj.serial})", heading: true) do
    partial(:obj_basics, obj)

    if obj.vss_id.nil?
      field "vss", "(global)"
    else
      field "vss", ref_str(obj.vss_id)
    end
    partial(:xmd_refs, obj.xmd_refs)
  end

  fieldset("Transport") do
    xprt = obj.transport

    field "mode", xprt.mode
    field "encryption policy", xprt.encryption_policy
    case xprt.mode
    when 'ikev2'
      mode_cfg = xprt.ikev2
      field "ikev2 mode", mode_cfg.mode
      field "ikev2 auth", mode_cfg.auth
      field "ikev2 user", mode_cfg.mschapv2_user
      field "ikev2 subnet", mode_cfg.tunnel_subnet if mode_cfg.tunnel_subnet
    when 'tls'
      mode_cfg = xprt.tls
      field "tls portal addr", mode_cfg.portal_ipaddr
      field "tls portal port", mode_cfg.portal_ipport
    end
  end

  fieldset("iSCSI") do
    iscsi = obj.iscsi
    field "auth method", iscsi.auth_method
    case iscsi.initiator_chap_mode
    when 'username'
      field "initiator login",
            iscsi.initiator_login + iscsi.initiator_login_suffix
    when 'token'
      field "initiator login", "secure access token"
    end
    if iscsi.initiator_pass_set == false
      field 'initiator password set', color('no', :red)
    end
    field "initiator chap mode", iscsi.initiator_chap_mode
    field "mutual auth", iscsi.mutual_auth
    field "target login", iscsi.target_login
  end

  if (atok = obj.access_token)
    fieldset("Secure Access Token", verbose: !atok.valid) do
      field "configured", atok.valid, cast: :bool_yn
      field "created", atok.created_stamp, cast: :time
      field "identifier", atok[:id]
    end
  end

  if (entries = obj.iscsi.initiator_list).length > 0
    header "Permitted initiators"
    table(header: false) do |t|
      t.cols({ lpad: 1 })
      entries.each { |ini| t << [ ini ] }
    end
  end

  fieldset("Policy") do
    field "disk commands", obj.rules.disk.commands
  end

  if (ips = obj.rules.access.ip).length > 0
    header "IP Address"
    table(sort_cols: %w(action IP)) do |t|
      t.cols('IP', 'Mask', 'action')
      ips.each { |ip|
        t << [ ip.ip, ip.mask, ip.type ]
      }
    end
  end

  partial_out :xmd, obj.xmd
end
