# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No rules found."
  return
end

data.each do |obj|
  fieldset("Rule: #{obj.label} (#{obj.serial})", heading: true) do
    partial(:obj_basics, obj)
    field 'vss', ref_str(obj.vss_id)
    field 'disk', ref_str(obj.ref_id), :nil_str => '-unassigned-'
    partial(:tags, obj.tags)
    partial(:xmd_refs, obj.xmd_refs)
  end

  partial_out :xmd, obj.xmd

  if (sensors = obj.sensors)
    header "Sensors"
    if sensors.length > 0
      # xxx
    else
      empty_table
    end
  end

  if (filters = obj.filters)
    header "Filters"
    if filters.length > 0
      table do |t|
        t.cols({ label: 'label', lpad: 1 }, 'type', 'detail')
        filters.each do |f|
          detail_a = []

          detail_a << "monitor" if f.monitor
          detail_a << "access=#{f.access}" if f.access

          t << [ f.label, f.type, detail_a.join(',') ]
        end
      end
    else
      empty_table
    end
  end

  if (actions = obj.actions)
    header "Actions"
    if actions.length > 0
      table do |t|
        t.cols( { type: 'type', lpad: 1 }, 'when', 'detail')

        actions.each do |a|
          detail_a = []

          case a.type
          when 'latency'
            detail_a << "delay for #{a.time}ms"
          when 'attention_required'
            if a.email_user
              profile = not_found_ok { api.user_profile.info(a.email_user) }
              detail_a << "email #{profile.email}" if profile
            end
            detail_a << (a.scsi_cmd_wait ? "sync" : "async")
          end

          t << [ a.type, a.when, detail_a.join(', ') ]
        end
      end
    else
      empty_table
    end
  end
end
