# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No targets found."
  return
end

data.each do |obj|
  fieldset("Target: #{obj.label} (#{obj.serial})", heading: true) do
    partial(:obj_basics, obj)

    field "vss", ref_str(obj.vss_id)
    field "iqn", obj.iqn
    field "automap", obj.automap
    field "alias", obj.alias
    partial(:xmd_refs, obj.xmd_refs)
  end

  header "Portals"
  if (portals = obj.portals).length > 0
    table do |t|
      t.cols({ label: 'interface', lpad: 1}, 'up', 'link', 'hostname', 'addrs')
      portals.each do |p|
        if p.speed && p.duplex
          link_str = "#{p.speed}-#{p.duplex}"
        end
        ip_str = p.ipaddrs.map { |a| "#{a.addr}:#{a.port}" }.join(', ')

        t << [ p.interface, p.up, link_str, p.hostname, ip_str ]
      end
    end
  end

  header "Disk mappings"
  if (mappings = obj.luns).length > 0
    table do |t|
      t.cols({ label: 'lun', lpad: 1}, 'disk', 'disk status')
      mappings.each do |m|
        d = ref_obj(m.vdisk_id)
        t << [ m.lun, ref_str(m.vdisk_id), partial(:obj_status, d.status) ]
      end
    end
  else
    empty_table
  end

  header "Access control entries"
  if (entries = obj.acl.entries).length > 0
    table do |t|
      t.cols({label: 'profile', lpad: 1}, 'privacy', 'discover', 'access')
      entries.each do |e|
        t << [ ref_str(e.profile_id), e.privacy, e.discover, e.access ]
      end
    end
  else
    empty_table
  end

  partial_out :xmd, obj.xmd
end
