# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No users found."
  return
end

perm_desc = api.user_profile.permissions

data.each do |user|
  fieldset("User: #{user.to_s}") do
    field 'login',    user.login
    field "serial",   user.serial
    field "account",  ref_str(user.account_id)
    field "created",  user.ctime, :cast => :time
    field "modified", user.mtime, :cast => :time
    if !user.password_set
      field 'password set', color('no', :red)
    end
    field 'activated', user.activated, :cast => :bool_yn
    field 'profile enabled', user.access.web, :cast => :bool_yn
  end

  fieldset("IDP", data: user.idp) do |fs, idp|
    field 'label', idp[:label]
    field 'type', idp[:type]
  end

  fieldset("Additional Parameters") do
    field 'account admin', user.account_admin, :cast => :bool_yn
    field 'default ui app', user.app_default
    field 'allow su', user.allow_su, :cast => :bool_yn
    field 'time zone', user.timezone
  end

  fieldset("E-Mail") do
    field 'email', user.email, :nil_str => '(unspecified)'
    field 'notifications', user.email_notify, :cast => :bool_yn
    field 'verified', user.email_verified, :cast => :bool_yn
  end

  user.permissions.each_pair do |scope, info|
    fieldset("#{scope} permissions") do |fs|
      fs.col(0).max = 34
      fs.col(0).min = 34

      case scope
      when 'vss'
        if !info.all_account_scope
          vo = info.vsses.map { |id| ref_obj(id) }
          field 'vss access', vo, :cast => :cjoin
        end
      when 'node'
        if !info.all_realm_scope
          no = info.nodes.map { |id| ref_obj(id) }
          field 'node access', no, :cast => :cjoin
        end
      end

      permitted = {}
      denied = {}
      info.rights.each_pair do |perm, val|
        desc = perm_desc[scope]['rights'][perm] rescue ''
        desc.sub!(/^#{scope} permission to /, '')
        if val
          permitted[perm] = "user #{color('may', :green)} #{desc}"
        else
          denied[perm] = "user #{color('may not', :red)} #{desc}"
        end
      end

      if options.verbose
        # always print all
        permitted.each_pair { |p, d| field p, d }
        denied.each_pair { |p, d| field p, d }
      else
        if denied.size == 0
          field "may perform all #{color(scope, :green)} actions", ''
        elsif permitted.size == 0
          fs.hide = true
        else
          # only print permitted
          permitted.each_pair { |p, d| field p, d }
        end
      end
    end
  end

  if user.sessions.length > 0
    header 'Sessions'
    table do |t|
      t.cols("serial", "created", "last used", "addr")
      user.sessions.each do |s|
        t << [ s.serial,
               format_time(s.created_ms),
               format_time(s.last_ms),
               s.addr ]
      end
    end
  end
end
