# Copyright (c) 2015, Blockbridge Networks LLC.  All rights reserved.
# Use of this source code is governed by a BSD-style license, found
# in the LICENSE file.

if data.length == 0
  header "No virtual storage services found."
  return
end

data.each do |obj|
  fieldset("VSS: #{obj.label} (#{obj.serial})", heading: true) do
    partial(:obj_basics, obj)
    field "hostname", obj.hostname
    field "current time", obj.isotime
    field "software build version", obj.build_version, verbose: true
    field "software build time", obj.build_time, verbose: true
    partial(:xmd_refs, obj.xmd_refs)
  end

  partial_out(:sizing, obj.sizing)

  fieldset('Quota', verbose: true) do
    quota = obj.quota
    size = quota[:size]
    iops = quota.iops
    field 'size limit', size.limit, :nil_str => 'none', :cast => :bytes
    field 'size notify', size.notify, :nil_str => 'none', :cast => :bytes
    field 'size reserve', size.reserve, :cast => :bytes
    if iops
      field 'iops limit', iops.limit, :nil_str => 'none'
      field 'iops reserve', iops.reserve
      field 'iops burst', iops.burst, :nil_str => 'none'
      field 'iops burst credits', iops.burst_credits, :nil_str => 'none'
    end
  end

  partial_out :xmd, obj.xmd

  if (disks = obj.disks)
    header "Disks"
    if disks.length > 0
      table do |t|
        t.cols({label: 'label', lpad: 1}, 'serial', 'capacity', 'size', 'status')
        disks.each do |o|
          cap_str = format_value(o.capacity)
          if o.sizing && (sz = o.sizing[:size])
            size_str = format_bytes(sz)
          else
            size_str = "?"
          end
          t << [o.label, o.serial, cap_str, size_str, partial(:obj_status, o.status)]
        end
      end
    else
      empty_table
    end
  end

  if (targets = obj.targets)
    header "Targets"
    if targets.length > 0
      table do |t|
        t.cols({label: 'label', lpad: 1}, 'serial', 'status')
        targets.each { |o| t << [o.label, o.serial, partial(:obj_status, o.status)] }
      end
    else
      empty_table
    end
  end
end
