# encoding: utf-8
# frozen_string_literal: true

#
# WARNING: Do not edit by hand, this file was generated by Heroics:
#
#   https://github.com/interagent/heroics
#

require 'heroics'
require 'uri'

module BlockbridgeInternalClient
  # Get a Client configured to use HTTP Basic or header-based authentication.
  #
  # @param api_key [String] The API key to use when connecting.
  # @param options [Hash<Symbol,String>] Optionally, custom settings
  #   to use with the client.  Allowed options are `default_headers`,
  #   `cache`, `user` and `url`.
  # @return [Client] A client configured to use the API with HTTP Basic
  #   or header-based authentication.
  def self.connect(api_key, options=nil)
    options = custom_options(options)
    uri = URI.parse(options[:url])

    if options[:user]
      uri.user = URI.encode_www_form_component options[:user]
    end

    if api_key
      uri.user ||= 'user'
      uri.password = api_key
    end

    client = Heroics.client_from_schema(SCHEMA, uri.to_s, options)
    Client.new(client)
  end

  # Get a Client configured to use OAuth authentication.
  #
  # @param oauth_token [String] The OAuth token to use with the API.
  # @param options [Hash<Symbol,String>] Optionally, custom settings
  #   to use with the client.  Allowed options are `default_headers`,
  #   `cache` and `url`.
  # @return [Client] A client configured to use the API with OAuth
  #   authentication.
  def self.connect_oauth(oauth_token, options=nil)
    options = custom_options(options)
    url = options[:url]
    client = Heroics.oauth_client_from_schema(oauth_token, SCHEMA, url, options)
    Client.new(client)
  end

  # Get a Client configured to use Token authentication.
  #
  # @param token [String] The token to use with the API.
  # @param options [Hash<Symbol,String>] Optionally, custom settings
  #   to use with the client.  Allowed options are `default_headers`,
  #   `cache` and `url`.
  # @return [Client] A client configured to use the API with OAuth
  #   authentication.
  def self.connect_token(token, options=nil)
    options = custom_options(options)
    url = options[:url]
    client = Heroics.token_client_from_schema(token, SCHEMA, url, options)
    Client.new(client)
  end

  # Get customized options.
  def self.custom_options(options)
    return default_options if options.nil?

    final_options = default_options
    if options[:default_headers]
      final_options[:default_headers].merge!(options[:default_headers])
    end
    final_options[:cache] = options[:cache] || Moneta.new(:File, dir: "#{Dir.home}/.blockbridge-cli/cache")
    final_options[:url] = options[:url] if options[:url]
    final_options[:user] = options[:user] if options[:user]
    final_options
  end

  # Get the default options.
  def self.default_options
    default_headers = {"Accept"=>"application/vnd.blockbridge-3+json"}
    {
      default_headers: default_headers,
      url:             "https://localhost/api"
    }
  end

  private_class_method :default_options, :custom_options

  # Blockbridge REST API
  class Client
    def initialize(client)
      @client = client
    end

    # Blockbridge is a secure multi-tenant storage system.  Each tenant has an Account which is isolated from every other tenant Account.  All of the tenant's storage, configuration data, credentials, audit history, and statistics *- anything that could be considered private data -* is inaccessible to other Accounts. 

    # 

    # Accounts have one or more Users, who are each assigned a set of permissions that control the actions they may perform.  One user may be simply an observer: able to query state, but unable to change anything.  Another user may be able to provision services, but not remove any existing ones.  Another is permitted to manage crypto keys. 

    # 

    # Lastly, the Account object contains contact information for the primary account holder.
    #
    # @return [Account]
    def account
      @account_resource ||= Account.new(@client)
    end

    # An Account has one or more Users, who are permitted to administer and consume storage according to various defined roles.  Each User has a profile object that has the User's name, email address, password and two-factor authentication information for the API and web application.
    #
    # @return [UserProfile]
    def user_profile
      @user_profile_resource ||= UserProfile.new(@client)
    end

    # Submit a username and password to create a time-limited OAuth 2 API access token.  Include this token in the `Authorization` HTTP header in subsequent requests.  For example,:

    # 

    # ```

    # Authorization: Bearer 0/EYZPk2DHOQ+ep8NyFerJake9NCG+M3WSbsoj5cfn6L5xh0+TYMc6Hw

    # 

    # ```
    #
    # @return [Oauth2Token]
    def oauth2_token
      @oauth2_token_resource ||= Oauth2Token.new(@client)
    end

    # Manage secure application access to the API using revokable authorization tokens.  A user may have many authorization tokens, in support of many different applications.  Each token may be independently revoked with a `DELETE` request.
    #
    # @return [Authz]
    def authz
      @authz_resource ||= Authz.new(@client)
    end

    # A Blockbridge Node is an instance of Blockbridge node software running on physical or virtual hardware.  It can be a management node, a storage node, or a converged node. 

    # * A **management node** provides configuration, monitoring, and other administrative capabilities.  The management web application and API clients are terminated at the management node. 

    # * A **storage node** delivers secure storage services using direct-attached and iSCSI storage. Client iSCSI connections are terminated at a storage node. 

    # * A **converged node** contains both a management node and a storage node in one system.  For most management purposes (including in the management web application) converged nodes are treated as a distinct management node and storage node.
    #
    # @return [Node]
    def node
      @node_resource ||= Node.new(@client)
    end

    # Sites are groups of storage and management nodes.  When deploying a Blockbridge storage network, you can use sites to group nodes together that are co-located in the same data center.  Or, you can subdivide a datacenter into multiple sites, or align sites along business unit lines.  Every node in a site shares the same SMTP configuration.
    #
    # @return [Site]
    def site
      @site_resource ||= Site.new(@client)
    end

    # Blockbridge storage node software detects the Ethernet interfaces you have configured on your nodes.  Network Interface resources allow you to define how these interfaces are used for Blockbridge storage services. 

    # 

    # The Blockbridge system thinks of networking in terms of these interfaces. You have the full power of Linux networking at your disposal including channel bonding, VLANs, and tunnels.  You can have multiple interfaces for segregation, performance or high availability. 

    # 

    # When a storage node completes its initial rendezvous with the management node, it registers the first Ethernet interface it finds, along with its IP addresses.  If the node has additional interfaces, use this interface to register them.
    #
    # @return [Net]
    def net
      @net_resource ||= Net.new(@client)
    end

    # The Operating System Storage Device object has the configuration necessary for a Blockbridge storage node to integrate direct-attached (DAS) storage into a System Datastore.  The operating system has been configured with the proper drivers for the storage technology, and is responsible for providing a persistent device path.  You can use any storage device that's compatible with Linux, such as NVDIMM, NVMe, PCI Flash, direct-attached hardware RAID, or a Fibre Channel SAN.
    #
    # @return [OsDev]
    def os_dev
      @os_dev_resource ||= OsDev.new(@client)
    end

    # A System Datastore (or just Datastore) defines a pool of storage from which you, your users, and applications will provision secure virtual storage services.  You can aggregate direct-attached and iSCSI storage devices to create a single large pool of storage.
    #
    # @return [SysDs]
    def sys_ds
      @sys_ds_resource ||= SysDs.new(@client)
    end

    # Retrieve and change certain basic parameters of iSCSI Devices and Operating System Devices from this common resource.  For parameters that are device-specific, consult the individual iSCSI device and operating system device resources.
    #
    # @return [Dev]
    def dev
      @dev_resource ||= Dev.new(@client)
    end

    # The Product resource has the list of Product Tags offered by a Datastore that has been configured to support automatic service provisioning.
    #
    # @return [Product]
    def product
      @product_resource ||= Product.new(@client)
    end

    # A Secure virtual service delivers storage resources to applications, customers, developers and your cloud infrastructure, in a service-oriented fashion.  Virtual services can be manually or automatically provisioned. 

    # 

    # These virtual services are provisioned from the storage resources provided by a datastore.  Each virtual storage service provides an independent storage area network (SAN).  You can provision disks and iSCSI targets within a virtual storage service as needed. 

    # 

    # The Blockbridge management network makes it possible to manage multiple, distributed virtual storage services from the management application. This allows a single tenant account to operate multiple classes of storage, to scale, and to implement disaster tolerance using virtual disk level replication.
    #
    # @return [Vss]
    def vss
      @vss_resource ||= Vss.new(@client)
    end

    # Virtual disks provide isolated data resources. Each virtual disk has a unique set of encryption keys. Those keys are automatically disposed of when the disk is deleted. You can take the keys out of the infrastructure, and you can provide them in-line of access.  

    # 

    # Virtual disks are thinly provisioned.  They support no-I/O snapshots, which can be cloned. Virtual disks support limits on IOPS and quotas on storage consumption. Quotas allow you to dedicate storage resources to a disk. 

    # 

    # Virtual disks also support synchronous and asynchronous block-level replication, along with the ability to validate data integrity and authenticity.  They support SCSI SPC-3 persistent reservations and various emulation modes (including removable disks).
    #
    # @return [Vdisk]
    def vdisk
      @vdisk_resource ||= Vdisk.new(@client)
    end

    # Initiator profiles hold the authentication and transport encryption parameters for one or more iSCSI initiators.  From this resource, you may also create secure access tokens that use split key encryption to enable you to unlock access to your disks on demand.  And, you can define policies that restrict initiator access to certain times of day, or to certain IP address ranges.
    #
    # @return [InitiatorProfile]
    def initiator_profile
      @initiator_profile_resource ||= InitiatorProfile.new(@client)
    end

    # The iSCSI target defines how disks are mapped to the network, making them accessible to iSCSI clients.  In the Blockbridge System, the iSCSI target is virtual, so that a single storage node supports many targets. You're free to define them as needed.
    #
    # @return [Target]
    def target
      @target_resource ||= Target.new(@client)
    end

    # You can take a point-in-time snapshot of a disk's contents to make a backup image, or to create a reference from which cloned disks may be created.
    #
    # @return [Snapshot]
    def snapshot
      @snapshot_resource ||= Snapshot.new(@client)
    end

    # The Object Store is endpoint and authentication configuration to support data backup to an object store such as Amazon S3 or OpenStack Swift.
    #
    # @return [ObjStore]
    def obj_store
      @obj_store_resource ||= ObjStore.new(@client)
    end

    #
    # @return [Rule]
    def rule
      @rule_resource ||= Rule.new(@client)
    end

    # The Blockbridge system maintains an extensive audit history of administrative actions and status changes for each configuration object.  These events have a descriptive symbol, such as `TARGET_LOGIN` and several additional qualifiers, such as the ID and serial number of the affected objects, and in some cases the iSCSI initiator IQN, or the user's name. 

    # 

    # Requesting events from the REST API opens a distributed query to retrieve events from throughout the Blockbridge managment network.  If the response doesn't indicate end-of-file (`eof`), then increase the number of desired results with the `num` parameter, or shorten the specified time range.
    #
    # @return [Events]
    def events
      @events_resource ||= Events.new(@client)
    end

    # Blockbridge storage nodes keep a long history of how the node's storage resources have been used over time.  You can retrieve time-series information information such as block usage for virtual disks, IOPS, or write bandwidth for various types of resources. 

    # 

    # These statistics are grouped into snapshots of related data points called statistics blocks.  Available statistics block types include:

    # 

    #  * **vdisk_history:** read/write bandwidth, I/O size histograms, IOPS and storage consumption for virtual disks

    #  * **target_history:** read/write bandwidth and IOPS, iSCSI PDUs sent and received for iSCSI targets

    #  * **vss_history:** storage consumption and IOPS usage for virtual storage services

    #  * **sys_ds_history:** storage consumption, IOPS, and other performance metrics for system datastores

    #  * **node_usage_history:**  counters for devices, services, virtual disks, snapshots, etc. for a storage node 

    # 

    # Requesting statistics from the REST API opens a query internally to the appropriate storage node. The statistics are reuturned in reverse time order, starting from `tend`. If the response doesn't indicate end-of-file (`eof`), then increase the number of desired results with the `num` parameter, or shorten the specified time range.
    #
    # @return [Stats]
    def stats
      @stats_resource ||= Stats.new(@client)
    end

    # The Extensible Metadata Record provides a way for applications to store free-form data in the Blockbridge management node.  The data can include information of use to the client itself, to other clients, or to the storage administrator.  The data can be associated with another object such as a virtual disk or service, so that it is removed when the associated object is deleted.
    #
    # @return [Xmd]
    def xmd
      @xmd_resource ||= Xmd.new(@client)
    end

    # The Blockbridge management node may be configured with an embedded Certificate Authority that issues SSL certificates for clients to securely access to the API and the management web application.  Install its CA certificate on client machines that will use Blockbridge management services.  If no certificate authority is configured, SSL connections use self-signed certificates.
    #
    # @return [CaCert]
    def ca_cert
      @ca_cert_resource ||= CaCert.new(@client)
    end

    # Examine API, authorization, and internal system status details.
    #
    # @return [Status]
    def status
      @status_resource ||= Status.new(@client)
    end

    # Access and perform operations on objects of disparate types.
    #
    # @return [Objects]
    def objects
      @objects_resource ||= Objects.new(@client)
    end
  end

  private

  # Blockbridge is a secure multi-tenant storage system.  Each tenant has an Account which is isolated from every other tenant Account.  All of the tenant's storage, configuration data, credentials, audit history, and statistics *- anything that could be considered private data -* is inaccessible to other Accounts. 

  # 

  # Accounts have one or more Users, who are each assigned a set of permissions that control the actions they may perform.  One user may be simply an observer: able to query state, but unable to change anything.  Another user may be able to provision services, but not remove any existing ones.  Another is permitted to manage crypto keys. 

  # 

  # Lastly, the Account object contains contact information for the primary account holder.
  class Account
    def initialize(client)
      @client = client
    end

    # Retrieve an existing account.
    #
    # @param account_id_or_account_serial: object id or serial number
    def info(account_id_or_account_serial)
      @client.account.info(account_id_or_account_serial)
    end

    # Enumerate accounts.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.account.list(body)
    end

    # Create a new account.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.account.create(body)
    end

    # Remove an existing account.
    #
    # @param account_id_or_account_serial: object id or serial number
    def remove(account_id_or_account_serial)
      @client.account.remove(account_id_or_account_serial)
    end

    # Change the configuration of an existing account.
    #
    # @param account_id_or_account_serial: object id or serial number
    # @param body: the object to pass as the request payload
    def update(account_id_or_account_serial, body = {})
      @client.account.update(account_id_or_account_serial, body)
    end

    # Display usage for an existing account.
    #
    # @param account_id_or_account_serial: object id or serial number
    def usage(account_id_or_account_serial)
      @client.account.usage(account_id_or_account_serial)
    end
  end

  # An Account has one or more Users, who are permitted to administer and consume storage according to various defined roles.  Each User has a profile object that has the User's name, email address, password and two-factor authentication information for the API and web application.
  class UserProfile
    def initialize(client)
      @client = client
    end

    # Retrieve an existing user profile.
    #
    # @param user_profile_id_or_user_profile_serial: object id or user profile serial number
    def info(user_profile_id_or_user_profile_serial)
      @client.user_profile.info(user_profile_id_or_user_profile_serial)
    end

    # Enumerate user profiles.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.user_profile.list(body)
    end

    # Create a new user profile.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.user_profile.create(body)
    end

    # Remove an existing user profile.
    #
    # @param user_profile_id_or_user_profile_serial: object id or user profile serial number
    # @param body: the object to pass as the request payload
    def remove(user_profile_id_or_user_profile_serial, body = {})
      @client.user_profile.remove(user_profile_id_or_user_profile_serial, body)
    end

    # Change the configuration of an existing user profile.
    #
    # @param user_profile_id_or_user_profile_serial: object id or user profile serial number
    # @param body: the object to pass as the request payload
    def update(user_profile_id_or_user_profile_serial, body = {})
      @client.user_profile.update(user_profile_id_or_user_profile_serial, body)
    end

    # Enumerate the permissions of an existing user profile.
    def permissions()
      @client.user_profile.permissions()
    end
  end

  # Submit a username and password to create a time-limited OAuth 2 API access token.  Include this token in the `Authorization` HTTP header in subsequent requests.  For example,:

  # 

  # ```

  # Authorization: Bearer 0/EYZPk2DHOQ+ep8NyFerJake9NCG+M3WSbsoj5cfn6L5xh0+TYMc6Hw

  # 

  # ```
  class Oauth2Token
    def initialize(client)
      @client = client
    end

    # Exchange authorization of some sort for an access token.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.oauth2_token.create(body)
    end
  end

  # Manage secure application access to the API using revokable authorization tokens.  A user may have many authorization tokens, in support of many different applications.  Each token may be independently revoked with a `DELETE` request.
  class Authz
    def initialize(client)
      @client = client
    end

    # Retrieve existing authorizations.
    #
    # @param authz_id_or_authz_serial: object id or authorization serial number
    def info(authz_id_or_authz_serial)
      @client.authz.info(authz_id_or_authz_serial)
    end

    # Enumerate authorizations.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.authz.list(body)
    end

    # Create a persistent API authorization token.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.authz.create(body)
    end

    # Remove a persistent API authorization token.
    #
    # @param authz_id_or_authz_serial: object id or authorization serial number
    def remove(authz_id_or_authz_serial)
      @client.authz.remove(authz_id_or_authz_serial)
    end

    # Change a persistent API authorization token.
    #
    # @param authz_id_or_authz_serial: object id or authorization serial number
    # @param body: the object to pass as the request payload
    def update(authz_id_or_authz_serial, body = {})
      @client.authz.update(authz_id_or_authz_serial, body)
    end
  end

  # A Blockbridge Node is an instance of Blockbridge node software running on physical or virtual hardware.  It can be a management node, a storage node, or a converged node. 

  # * A **management node** provides configuration, monitoring, and other administrative capabilities.  The management web application and API clients are terminated at the management node. 

  # * A **storage node** delivers secure storage services using direct-attached and iSCSI storage. Client iSCSI connections are terminated at a storage node. 

  # * A **converged node** contains both a management node and a storage node in one system.  For most management purposes (including in the management web application) converged nodes are treated as a distinct management node and storage node.
  class Node
    def initialize(client)
      @client = client
    end

    # Retrieve an existing node.
    #
    # @param node_id_or_node_serial: object id or node serial number
    def info(node_id_or_node_serial)
      @client.node.info(node_id_or_node_serial)
    end

    # Enumerate nodes.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.node.list(body)
    end

    # Create a new storage node.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.node.create(body)
    end

    # Remove an existing storage node.
    #
    # @param node_id_or_node_serial: object id or node serial number
    def remove(node_id_or_node_serial)
      @client.node.remove(node_id_or_node_serial)
    end

    # Change the configuration of an existing management node or a storage node.
    #
    # @param node_id_or_node_serial: object id or node serial number
    # @param body: the object to pass as the request payload
    def update(node_id_or_node_serial, body = {})
      @client.node.update(node_id_or_node_serial, body)
    end

    # Retrieve a list of operating system storage devices that match the specified parameters.
    #
    # @param node_id_or_node_serial: object id or node serial number
    # @param body: the object to pass as the request payload
    def discover_devices(node_id_or_node_serial, body = {})
      @client.node.discover_devices(node_id_or_node_serial, body)
    end

    # Retrieve a list of network interfaces that match the specified parameters.
    #
    # @param node_id_or_node_serial: object id or node serial number
    def discover_interfaces(node_id_or_node_serial)
      @client.node.discover_interfaces(node_id_or_node_serial)
    end
  end

  # Sites are groups of storage and management nodes.  When deploying a Blockbridge storage network, you can use sites to group nodes together that are co-located in the same data center.  Or, you can subdivide a datacenter into multiple sites, or align sites along business unit lines.  Every node in a site shares the same SMTP configuration.
  class Site
    def initialize(client)
      @client = client
    end

    # Retrieve an existing site.
    #
    # @param site_id_or_site_serial: object id or site serial number
    def info(site_id_or_site_serial)
      @client.site.info(site_id_or_site_serial)
    end

    # Enumerate sites.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.site.list(body)
    end

    # Create a new site.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.site.create(body)
    end

    # Remove an existing site.
    #
    # @param site_id_or_site_serial: object id or site serial number
    def remove(site_id_or_site_serial)
      @client.site.remove(site_id_or_site_serial)
    end

    # Change the configuration of an existing site.
    #
    # @param site_id_or_site_serial: object id or site serial number
    # @param body: the object to pass as the request payload
    def update(site_id_or_site_serial, body = {})
      @client.site.update(site_id_or_site_serial, body)
    end
  end

  # Blockbridge storage node software detects the Ethernet interfaces you have configured on your nodes.  Network Interface resources allow you to define how these interfaces are used for Blockbridge storage services. 

  # 

  # The Blockbridge system thinks of networking in terms of these interfaces. You have the full power of Linux networking at your disposal including channel bonding, VLANs, and tunnels.  You can have multiple interfaces for segregation, performance or high availability. 

  # 

  # When a storage node completes its initial rendezvous with the management node, it registers the first Ethernet interface it finds, along with its IP addresses.  If the node has additional interfaces, use this interface to register them.
  class Net
    def initialize(client)
      @client = client
    end

    # Retrieve an existing network interface.
    #
    # @param net_id_or_net_serial: object id or network interface serial number
    def info(net_id_or_net_serial)
      @client.net.info(net_id_or_net_serial)
    end

    # Enumerate network interfaces.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.net.list(body)
    end

    # Register a new network interface.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.net.create(body)
    end

    # Remove the configuration for an existing network interface.
    #
    # @param net_id_or_net_serial: object id or network interface serial number
    def remove(net_id_or_net_serial)
      @client.net.remove(net_id_or_net_serial)
    end

    # Change the configuration of an existing network interface.
    #
    # @param net_id_or_net_serial: object id or network interface serial number
    # @param body: the object to pass as the request payload
    def update(net_id_or_net_serial, body = {})
      @client.net.update(net_id_or_net_serial, body)
    end
  end

  # The Operating System Storage Device object has the configuration necessary for a Blockbridge storage node to integrate direct-attached (DAS) storage into a System Datastore.  The operating system has been configured with the proper drivers for the storage technology, and is responsible for providing a persistent device path.  You can use any storage device that's compatible with Linux, such as NVDIMM, NVMe, PCI Flash, direct-attached hardware RAID, or a Fibre Channel SAN.
  class OsDev
    def initialize(client)
      @client = client
    end

    # Retrieve an existing operating system storage device.
    #
    # @param os_dev_id_or_os_dev_serial: object id or OS device serial number
    def info(os_dev_id_or_os_dev_serial)
      @client.os_dev.info(os_dev_id_or_os_dev_serial)
    end

    # Enumerate operating system storage devices.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.os_dev.list(body)
    end

    # Register a new operating system storage device, creating its configuration.  Once the device has been initialized, it may be incorporated into the storage pool of a system datastore.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.os_dev.create(body)
    end

    # Initialize an operating system storage device.  This action causes the storage node to write configuration data to the start and end of the storage device.  On completion, the device can be incorporated into the storage pool of a system datastore.
    #
    # @param os_dev_id_or_os_dev_serial: object id or OS device serial number
    # @param body: the object to pass as the request payload
    def init(os_dev_id_or_os_dev_serial, body = {})
      @client.os_dev.init(os_dev_id_or_os_dev_serial, body)
    end

    # Remove the configuration of an existing operating system storage device.
    #
    # @param os_dev_id_or_os_dev_serial: object id or OS device serial number
    def remove(os_dev_id_or_os_dev_serial)
      @client.os_dev.remove(os_dev_id_or_os_dev_serial)
    end

    # Change the configuration of an existing operating system storage device.
    #
    # @param os_dev_id_or_os_dev_serial: object id or OS device serial number
    # @param body: the object to pass as the request payload
    def update(os_dev_id_or_os_dev_serial, body = {})
      @client.os_dev.update(os_dev_id_or_os_dev_serial, body)
    end
  end

  # A System Datastore (or just Datastore) defines a pool of storage from which you, your users, and applications will provision secure virtual storage services.  You can aggregate direct-attached and iSCSI storage devices to create a single large pool of storage.
  class SysDs
    def initialize(client)
      @client = client
    end

    # Retrieve an existing system datastore.
    #
    # @param sys_ds_id_or_sys_ds_serial: object id or system datastore serial number
    def info(sys_ds_id_or_sys_ds_serial)
      @client.sys_ds.info(sys_ds_id_or_sys_ds_serial)
    end

    # Enumerate system datastores.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.sys_ds.list(body)
    end

    # Create a new system datastore.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.sys_ds.create(body)
    end

    # Remove an existing system datastore.  Its storage pool must be empty.
    #
    # @param sys_ds_id_or_sys_ds_serial: object id or system datastore serial number
    def remove(sys_ds_id_or_sys_ds_serial)
      @client.sys_ds.remove(sys_ds_id_or_sys_ds_serial)
    end

    # Retrieve historical usage data for a system datastore.
    #
    # @param sys_ds_id_or_sys_ds_serial: object id or system datastore serial number
    # @param body: the object to pass as the request payload
    def query_usage(sys_ds_id_or_sys_ds_serial, body = {})
      @client.sys_ds.query_usage(sys_ds_id_or_sys_ds_serial, body)
    end

    # Change the configuration of an existing system datastore.
    #
    # @param sys_ds_id_or_sys_ds_serial: object id or system datastore serial number
    # @param body: the object to pass as the request payload
    def update(sys_ds_id_or_sys_ds_serial, body = {})
      @client.sys_ds.update(sys_ds_id_or_sys_ds_serial, body)
    end

    # Add an iSCSI storage device or an OS storage device to the storage pool of a system datastore.
    #
    # @param sys_ds_id_or_sys_ds_serial: object id or system datastore serial number
    # @param body: the object to pass as the request payload
    def pool_add(sys_ds_id_or_sys_ds_serial, body = {})
      @client.sys_ds.pool_add(sys_ds_id_or_sys_ds_serial, body)
    end

    # Remove an iSCSI storage device or an OS storage device from the storage pool of a system datastore.  The device must not contain any user data.  Use the **pool destage** action to move user data away from the device prior to removing it from the pool.
    #
    # @param sys_ds_id_or_sys_ds_serial: object id or system datastore serial number
    # @param body: the object to pass as the request payload
    def pool_delete(sys_ds_id_or_sys_ds_serial, body = {})
      @client.sys_ds.pool_delete(sys_ds_id_or_sys_ds_serial, body)
    end

    # Move all user data off of an iSCSI or OS storage device to other devices in the system datastore storage pool.  There must be enough room on the remaining set of pool devices to hold the data.
    #
    # @param sys_ds_id_or_sys_ds_serial: object id or system datastore serial number
    # @param body: the object to pass as the request payload
    def pool_destage(sys_ds_id_or_sys_ds_serial, body = {})
      @client.sys_ds.pool_destage(sys_ds_id_or_sys_ds_serial, body)
    end

    # Initiate a benchmark test for the storage pool of a system datastore.
    #
    # @param sys_ds_id_or_sys_ds_serial: object id or system datastore serial number
    # @param body: the object to pass as the request payload
    def benchmark(sys_ds_id_or_sys_ds_serial, body = {})
      @client.sys_ds.benchmark(sys_ds_id_or_sys_ds_serial, body)
    end
  end

  # Retrieve and change certain basic parameters of iSCSI Devices and Operating System Devices from this common resource.  For parameters that are device-specific, consult the individual iSCSI device and operating system device resources.
  class Dev
    def initialize(client)
      @client = client
    end

    # Info for existing dev.
    #
    # @param dev_identity: 
    def info(dev_identity)
      @client.dev.info(dev_identity)
    end

    # List existing devs.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.dev.list(body)
    end
  end

  # The Product resource has the list of Product Tags offered by a Datastore that has been configured to support automatic service provisioning.
  class Product
    def initialize(client)
      @client = client
    end

    # Query the storage product catalog.
    #
    # @param body: the object to pass as the request payload
    def search_create(body = {})
      @client.product.search_create(body)
    end

    # Retrieve the available storage catalog parameters.
    def search_parameters()
      @client.product.search_parameters()
    end
  end

  # A Secure virtual service delivers storage resources to applications, customers, developers and your cloud infrastructure, in a service-oriented fashion.  Virtual services can be manually or automatically provisioned. 

  # 

  # These virtual services are provisioned from the storage resources provided by a datastore.  Each virtual storage service provides an independent storage area network (SAN).  You can provision disks and iSCSI targets within a virtual storage service as needed. 

  # 

  # The Blockbridge management network makes it possible to manage multiple, distributed virtual storage services from the management application. This allows a single tenant account to operate multiple classes of storage, to scale, and to implement disaster tolerance using virtual disk level replication.
  class Vss
    def initialize(client)
      @client = client
    end

    # Retrieve an existing virtual storage service.
    #
    # @param vss_id_or_vss_serial: object id or virtual storage service serial number
    def info(vss_id_or_vss_serial)
      @client.vss.info(vss_id_or_vss_serial)
    end

    # Enumerate virtual storage services.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.vss.list(body)
    end

    # Provision a new virtual storage service.  The system datastore is selected by conducting a storage product search.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.vss.create(body)
    end

    # Remove an existing virtual storage service, including its virtual disks, iSCSI targets, and initiator profiles.  User data that remains in the service will be irretrievable.
    #
    # @param vss_id_or_vss_serial: object id or virtual storage service serial number
    def remove(vss_id_or_vss_serial)
      @client.vss.remove(vss_id_or_vss_serial)
    end

    # Change the configuration of an existing virtual storage service.
    #
    # @param vss_id_or_vss_serial: object id or virtual storage service serial number
    # @param body: the object to pass as the request payload
    def update(vss_id_or_vss_serial, body = {})
      @client.vss.update(vss_id_or_vss_serial, body)
    end

    # Change the quota for a virtual storage service.
    #
    # @param vss_id_or_vss_serial: object id or virtual storage service serial number
    # @param body: the object to pass as the request payload
    def quota_update(vss_id_or_vss_serial, body = {})
      @client.vss.quota_update(vss_id_or_vss_serial, body)
    end
  end

  # Virtual disks provide isolated data resources. Each virtual disk has a unique set of encryption keys. Those keys are automatically disposed of when the disk is deleted. You can take the keys out of the infrastructure, and you can provide them in-line of access.  

  # 

  # Virtual disks are thinly provisioned.  They support no-I/O snapshots, which can be cloned. Virtual disks support limits on IOPS and quotas on storage consumption. Quotas allow you to dedicate storage resources to a disk. 

  # 

  # Virtual disks also support synchronous and asynchronous block-level replication, along with the ability to validate data integrity and authenticity.  They support SCSI SPC-3 persistent reservations and various emulation modes (including removable disks).
  class Vdisk
    def initialize(client)
      @client = client
    end

    # Retrieve an existing virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    def info(vdisk_id_or_vdisk_serial)
      @client.vdisk.info(vdisk_id_or_vdisk_serial)
    end

    # Enumerate virtual disks.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.vdisk.list(body)
    end

    # Create a new internal virtual disk.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.vdisk.create(body)
    end

    # Remove an existing virtual disk.  Once removed, the user data in a virtual disk is not retrievable.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    def remove(vdisk_id_or_vdisk_serial)
      @client.vdisk.remove(vdisk_id_or_vdisk_serial)
    end

    # Change the configuration of an existing internal virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def update(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.update(vdisk_id_or_vdisk_serial, body)
    end

    # Change the quota for a virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def quota_update(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.quota_update(vdisk_id_or_vdisk_serial, body)
    end

    # Add a replication master or slave virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def add_replication_master(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.add_replication_master(vdisk_id_or_vdisk_serial, body)
    end

    # Remove a replication master or slave virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param vdisk_master_id: master disk id
    def remove_replication_master(vdisk_id_or_vdisk_serial, vdisk_master_id)
      @client.vdisk.remove_replication_master(vdisk_id_or_vdisk_serial, vdisk_master_id)
    end

    # Add a replication master or slave virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def add_replication_slave(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.add_replication_slave(vdisk_id_or_vdisk_serial, body)
    end

    # Update the configuration of a replication master or slave virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param vdisk_slave_id: slave disk id
    # @param body: the object to pass as the request payload
    def update_replication_slave(vdisk_id_or_vdisk_serial, vdisk_slave_id, body = {})
      @client.vdisk.update_replication_slave(vdisk_id_or_vdisk_serial, vdisk_slave_id, body)
    end

    # Remove a replication master or slave virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param vdisk_slave_id: slave disk id
    def remove_replication_slave(vdisk_id_or_vdisk_serial, vdisk_slave_id)
      @client.vdisk.remove_replication_slave(vdisk_id_or_vdisk_serial, vdisk_slave_id)
    end

    # Create a replication relationship between a master virtual disk and a slave virtual disk.
    #
    # @param body: the object to pass as the request payload
    def attach_replication_peers(body = {})
      @client.vdisk.attach_replication_peers(body)
    end

    # Break the replication relationship between a master virtual disk and a slave virtual disk.
    #
    # @param body: the object to pass as the request payload
    def detach_replication_peers(body = {})
      @client.vdisk.detach_replication_peers(body)
    end

    # Rebuild a replication slave virtual disk.
    #
    # @param body: the object to pass as the request payload
    def rebuild_replication_slave(body = {})
      @client.vdisk.rebuild_replication_slave(body)
    end

    # Change the size of an internal virtual disk
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def resize(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.resize(vdisk_id_or_vdisk_serial, body)
    end

    # vdisk thicken
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def thicken(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.thicken(vdisk_id_or_vdisk_serial, body)
    end

    # vdisk compress
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def compress(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.compress(vdisk_id_or_vdisk_serial, body)
    end

    # Lock an internal virtual disk.  This action uses the supplied passphrase to encrypt the disk's encryption key.  Once locked, the disk cannot be decrypted without supplying the passphrase.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def lock(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.lock(vdisk_id_or_vdisk_serial, body)
    end

    # Unlock a locked virtual disk.  The correct passphrase must be supplied.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def unlock(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.unlock(vdisk_id_or_vdisk_serial, body)
    end

    # vdisk load
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def load_media(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.load_media(vdisk_id_or_vdisk_serial, body)
    end

    # Clone the specified snapshot and load the media into a new removable virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def load_cloned_media(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.load_cloned_media(vdisk_id_or_vdisk_serial, body)
    end

    # Eject the media for a removable virtual disk.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    def eject_media(vdisk_id_or_vdisk_serial)
      @client.vdisk.eject_media(vdisk_id_or_vdisk_serial)
    end

    # Initiate a backup.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def backup(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.backup(vdisk_id_or_vdisk_serial, body)
    end

    # Raise a time-limited I/O barrier.  Outstanding I/O operations will run to completion.  New operations will wait until the barrier expires or is removed.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def barrier_create(vdisk_id_or_vdisk_serial, body = {})
      @client.vdisk.barrier_create(vdisk_id_or_vdisk_serial, body)
    end

    # Remove a virtual disk I/O barrier.
    #
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param vdisk_uuid: object uuid
    # @param body: the object to pass as the request payload
    def barrier_remove(vdisk_id_or_vdisk_serial, vdisk_uuid, body = {})
      @client.vdisk.barrier_remove(vdisk_id_or_vdisk_serial, vdisk_uuid, body)
    end
  end

  # Initiator profiles hold the authentication and transport encryption parameters for one or more iSCSI initiators.  From this resource, you may also create secure access tokens that use split key encryption to enable you to unlock access to your disks on demand.  And, you can define policies that restrict initiator access to certain times of day, or to certain IP address ranges.
  class InitiatorProfile
    def initialize(client)
      @client = client
    end

    # Retrieve an existing iSCSI initiator profile.
    #
    # @param initiator_profile_id_or_initiator_profile_serial: object id or initiator profile serial number
    def info(initiator_profile_id_or_initiator_profile_serial)
      @client.initiator_profile.info(initiator_profile_id_or_initiator_profile_serial)
    end

    # Enumerate iSCSI initiator profiles.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.initiator_profile.list(body)
    end

    # Create a new iSCSI initiator profile.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.initiator_profile.create(body)
    end

    # Remove an existing iSCSI initiator profile.
    #
    # @param initiator_profile_id_or_initiator_profile_serial: object id or initiator profile serial number
    def remove(initiator_profile_id_or_initiator_profile_serial)
      @client.initiator_profile.remove(initiator_profile_id_or_initiator_profile_serial)
    end

    # Change the configuration of an existing iSCSI initiator profile.
    #
    # @param initiator_profile_id_or_initiator_profile_serial: object id or initiator profile serial number
    # @param body: the object to pass as the request payload
    def update(initiator_profile_id_or_initiator_profile_serial, body = {})
      @client.initiator_profile.update(initiator_profile_id_or_initiator_profile_serial, body)
    end

    # Prepare to create a secure access token for an initiator profile.
    #
    # @param initiator_profile_id_or_initiator_profile_serial: object id or initiator profile serial number
    def prepare_token(initiator_profile_id_or_initiator_profile_serial)
      @client.initiator_profile.prepare_token(initiator_profile_id_or_initiator_profile_serial)
    end

    # Create a secure access token for an iSCSI initiator profile.
    #
    # @param initiator_profile_id_or_initiator_profile_serial: object id or initiator profile serial number
    # @param body: the object to pass as the request payload
    def create_token(initiator_profile_id_or_initiator_profile_serial, body = {})
      @client.initiator_profile.create_token(initiator_profile_id_or_initiator_profile_serial, body)
    end

    # Remove a configured secure access token from an iSCSI initiator profile.
    #
    # @param initiator_profile_id_or_initiator_profile_serial: object id or initiator profile serial number
    def remove_token(initiator_profile_id_or_initiator_profile_serial)
      @client.initiator_profile.remove_token(initiator_profile_id_or_initiator_profile_serial)
    end
  end

  # The iSCSI target defines how disks are mapped to the network, making them accessible to iSCSI clients.  In the Blockbridge System, the iSCSI target is virtual, so that a single storage node supports many targets. You're free to define them as needed.
  class Target
    def initialize(client)
      @client = client
    end

    # Retrieve an existing iSCSI target.
    #
    # @param target_id_or_target_serial: object id or iSCSI target serial number
    def info(target_id_or_target_serial)
      @client.target.info(target_id_or_target_serial)
    end

    # Enumerate iSCSI targets.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.target.list(body)
    end

    # Create a new iSCSI target.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.target.create(body)
    end

    # Remove an existing iSCSI target.
    #
    # @param target_id_or_target_serial: object id or iSCSI target serial number
    def remove(target_id_or_target_serial)
      @client.target.remove(target_id_or_target_serial)
    end

    # Change the configuration of an existing iSCSI target.
    #
    # @param target_id_or_target_serial: object id or iSCSI target serial number
    # @param body: the object to pass as the request payload
    def update(target_id_or_target_serial, body = {})
      @client.target.update(target_id_or_target_serial, body)
    end

    # Map a virtual disk to an existing iSCSI target.
    #
    # @param target_id_or_target_serial: object id or iSCSI target serial number
    # @param target_lun: Logical Unit Number
    # @param body: the object to pass as the request payload
    def lun_map(target_id_or_target_serial, target_lun, body = {})
      @client.target.lun_map(target_id_or_target_serial, target_lun, body)
    end

    # Unmap a virtual disk from an existing iSCSI target.
    #
    # @param target_id_or_target_serial: object id or iSCSI target serial number
    # @param target_lun: Logical Unit Number
    def lun_unmap(target_id_or_target_serial, target_lun)
      @client.target.lun_unmap(target_id_or_target_serial, target_lun)
    end

    # Map a virtual disk to an existing iSCSI target.
    #
    # @param target_id_or_target_serial: object id or iSCSI target serial number
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    # @param body: the object to pass as the request payload
    def disk_map(target_id_or_target_serial, vdisk_id_or_vdisk_serial, body = {})
      @client.target.disk_map(target_id_or_target_serial, vdisk_id_or_vdisk_serial, body)
    end

    # Unmap a virtual disk from an existing iSCSI target.
    #
    # @param target_id_or_target_serial: object id or iSCSI target serial number
    # @param vdisk_id_or_vdisk_serial: object id or virtual disk serial number
    def disk_unmap(target_id_or_target_serial, vdisk_id_or_vdisk_serial)
      @client.target.disk_unmap(target_id_or_target_serial, vdisk_id_or_vdisk_serial)
    end
  end

  # You can take a point-in-time snapshot of a disk's contents to make a backup image, or to create a reference from which cloned disks may be created.
  class Snapshot
    def initialize(client)
      @client = client
    end

    # Retrieve an existing virtual disk snapshot.
    #
    # @param snapshot_id_or_snapshot_serial: object id or snapshot serial number
    def info(snapshot_id_or_snapshot_serial)
      @client.snapshot.info(snapshot_id_or_snapshot_serial)
    end

    # Enumerate virtual disk snapshots.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.snapshot.list(body)
    end

    # Create a new snapshot of the contents of an internal virtual disk.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.snapshot.create(body)
    end

    # Remove an existing virtual disk snapshot.  Once the snapshot has been removed, the storage node starts reclaiming user data blocks that are no longer needed for other snapshots or for the virtual disk itself.
    #
    # @param snapshot_id_or_snapshot_serial: object id or snapshot serial number
    def remove(snapshot_id_or_snapshot_serial)
      @client.snapshot.remove(snapshot_id_or_snapshot_serial)
    end

    # Change the configuration of an existing virtual disk snapshot.
    #
    # @param snapshot_id_or_snapshot_serial: object id or snapshot serial number
    # @param body: the object to pass as the request payload
    def update(snapshot_id_or_snapshot_serial, body = {})
      @client.snapshot.update(snapshot_id_or_snapshot_serial, body)
    end
  end

  # The Object Store is endpoint and authentication configuration to support data backup to an object store such as Amazon S3 or OpenStack Swift.
  class ObjStore
    def initialize(client)
      @client = client
    end

    # Retrieve an existing object store definition.
    #
    # @param obj_store_id_or_obj_store_serial: object id or object store serial number
    def info(obj_store_id_or_obj_store_serial)
      @client.obj_store.info(obj_store_id_or_obj_store_serial)
    end

    # Enumerate object stores.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.obj_store.list(body)
    end

    # Enumerate backups on an object-store.
    #
    # @param obj_store_id_or_obj_store_serial: object id or object store serial number
    # @param body: the object to pass as the request payload
    def list_backups(obj_store_id_or_obj_store_serial, body = {})
      @client.obj_store.list_backups(obj_store_id_or_obj_store_serial, body)
    end

    # Delete a backup from an object-store.
    #
    # @param obj_store_id_or_obj_store_serial: object id or object store serial number
    # @param obj_store_backup_id: backup identifier
    # @param body: the object to pass as the request payload
    def remove_backup(obj_store_id_or_obj_store_serial, obj_store_backup_id, body = {})
      @client.obj_store.remove_backup(obj_store_id_or_obj_store_serial, obj_store_backup_id, body)
    end

    # Create an object store definition.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.obj_store.create(body)
    end

    # Remove an obj_store definition.
    #
    # @param obj_store_id_or_obj_store_serial: object id or object store serial number
    def remove(obj_store_id_or_obj_store_serial)
      @client.obj_store.remove(obj_store_id_or_obj_store_serial)
    end

    # Change the configuration of an existing object store definition.
    #
    # @param obj_store_id_or_obj_store_serial: object id or object store serial number
    # @param body: the object to pass as the request payload
    def update(obj_store_id_or_obj_store_serial, body = {})
      @client.obj_store.update(obj_store_id_or_obj_store_serial, body)
    end
  end

  class Rule
    def initialize(client)
      @client = client
    end

    # Create a virtual disk rule.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.rule.create(body)
    end

    # Remove an existing virtual disk rule.
    #
    # @param rule_id_or_rule_serial: object id or rule serial number
    def remove(rule_id_or_rule_serial)
      @client.rule.remove(rule_id_or_rule_serial)
    end

    # Info for existing rule.
    #
    # @param rule_id_or_rule_serial: object id or rule serial number
    def info(rule_id_or_rule_serial)
      @client.rule.info(rule_id_or_rule_serial)
    end

    # List existing rules.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.rule.list(body)
    end

    # Change the configuration of a virtual disk rule.
    #
    # @param rule_id_or_rule_serial: object id or rule serial number
    # @param body: the object to pass as the request payload
    def update(rule_id_or_rule_serial, body = {})
      @client.rule.update(rule_id_or_rule_serial, body)
    end
  end

  # The Blockbridge system maintains an extensive audit history of administrative actions and status changes for each configuration object.  These events have a descriptive symbol, such as `TARGET_LOGIN` and several additional qualifiers, such as the ID and serial number of the affected objects, and in some cases the iSCSI initiator IQN, or the user's name. 

  # 

  # Requesting events from the REST API opens a distributed query to retrieve events from throughout the Blockbridge managment network.  If the response doesn't indicate end-of-file (`eof`), then increase the number of desired results with the `num` parameter, or shorten the specified time range.
  class Events
    def initialize(client)
      @client = client
    end

    # Retrieve all events for the requestor's account.
    #
    # @param body: the object to pass as the request payload
    def query_account(body = {})
      @client.events.query_account(body)
    end

    # Retrieve user and administrative events for the specified id or serial number.  Any type of id or serial number may be specified in place of `{events_identity}`.
    #
    # @param events_identity: 
    # @param body: the object to pass as the request payload
    def query(events_identity, body = {})
      @client.events.query(events_identity, body)
    end
  end

  # Blockbridge storage nodes keep a long history of how the node's storage resources have been used over time.  You can retrieve time-series information information such as block usage for virtual disks, IOPS, or write bandwidth for various types of resources. 

  # 

  # These statistics are grouped into snapshots of related data points called statistics blocks.  Available statistics block types include:

  # 

  #  * **vdisk_history:** read/write bandwidth, I/O size histograms, IOPS and storage consumption for virtual disks

  #  * **target_history:** read/write bandwidth and IOPS, iSCSI PDUs sent and received for iSCSI targets

  #  * **vss_history:** storage consumption and IOPS usage for virtual storage services

  #  * **sys_ds_history:** storage consumption, IOPS, and other performance metrics for system datastores

  #  * **node_usage_history:**  counters for devices, services, virtual disks, snapshots, etc. for a storage node 

  # 

  # Requesting statistics from the REST API opens a query internally to the appropriate storage node. The statistics are reuturned in reverse time order, starting from `tend`. If the response doesn't indicate end-of-file (`eof`), then increase the number of desired results with the `num` parameter, or shorten the specified time range.
  class Stats
    def initialize(client)
      @client = client
    end

    # Retrieve statistics for the specified id or serial number. Any type of id or serial number may be specified in place of `{stats_identity}`.
    #
    # @param stats_identity: 
    # @param body: the object to pass as the request payload
    def query(stats_identity, body = {})
      @client.stats.query(stats_identity, body)
    end
  end

  # The Extensible Metadata Record provides a way for applications to store free-form data in the Blockbridge management node.  The data can include information of use to the client itself, to other clients, or to the storage administrator.  The data can be associated with another object such as a virtual disk or service, so that it is removed when the associated object is deleted.
  class Xmd
    def initialize(client)
      @client = client
    end

    # Retrieve an existing external metadata object.
    #
    # @param xmd_id_or_xmd_serial_or_xmd_ref: object id or extensible metadata serial number or arbitrary string reference key
    def info(xmd_id_or_xmd_serial_or_xmd_ref)
      @client.xmd.info(xmd_id_or_xmd_serial_or_xmd_ref)
    end

    # Enumerate extensible metadata objects.
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.xmd.list(body)
    end

    # Create an extensible metadata object.
    #
    # @param body: the object to pass as the request payload
    def create(body = {})
      @client.xmd.create(body)
    end

    # Remove an extensible metadata object.
    #
    # @param xmd_id_or_xmd_serial_or_xmd_ref: object id or extensible metadata serial number or arbitrary string reference key
    def remove(xmd_id_or_xmd_serial_or_xmd_ref)
      @client.xmd.remove(xmd_id_or_xmd_serial_or_xmd_ref)
    end

    # Change an extensible metadata object.
    #
    # @param xmd_id_or_xmd_serial_or_xmd_ref: object id or extensible metadata serial number or arbitrary string reference key
    # @param body: the object to pass as the request payload
    def update(xmd_id_or_xmd_serial_or_xmd_ref, body = {})
      @client.xmd.update(xmd_id_or_xmd_serial_or_xmd_ref, body)
    end
  end

  # The Blockbridge management node may be configured with an embedded Certificate Authority that issues SSL certificates for clients to securely access to the API and the management web application.  Install its CA certificate on client machines that will use Blockbridge management services.  If no certificate authority is configured, SSL connections use self-signed certificates.
  class CaCert
    def initialize(client)
      @client = client
    end

    # Retrieve the certificate authority certificate.
    #
    # @param body: the object to pass as the request payload
    def info(body = {})
      @client.ca_cert.info(body)
    end
  end

  # Examine API, authorization, and internal system status details.
  class Status
    def initialize(client)
      @client = client
    end

    # Retrieve API high-level status information.
    def info()
      @client.status.info()
    end

    # Retrieve API authorization detail.
    def authorization()
      @client.status.authorization()
    end

    # Retrieve API adapter debug state.
    def debug()
      @client.status.debug()
    end

    # Retrieve API adapter and OS platform.
    def platform()
      @client.status.platform()
    end

    # Retrieve API platform process listing.
    #
    # @param body: the object to pass as the request payload
    def process_list(body = {})
      @client.status.process_list(body)
    end

    # Retrieve API platform process info
    #
    # @param status_process_id: process id
    def process_info(status_process_id)
      @client.status.process_info(status_process_id)
    end
  end

  # Access and perform operations on objects of disparate types.
  class Objects
    def initialize(client)
      @client = client
    end

    # Enumerate objects
    #
    # @param body: the object to pass as the request payload
    def list(body = {})
      @client.objects.list(body)
    end

    # Info for a single object.
    #
    # @param objects_identity: 
    def info(objects_identity)
      @client.objects.info(objects_identity)
    end

    # Enumerate objects by xref
    #
    # @param objects_xref: object external reference
    # @param body: the object to pass as the request payload
    def list_by_xref(objects_xref, body = {})
      @client.objects.list_by_xref(objects_xref, body)
    end

    # Remove objects by xref.
    #
    # @param objects_xref: object external reference
    # @param body: the object to pass as the request payload
    def remove_by_xref(objects_xref, body = {})
      @client.objects.remove_by_xref(objects_xref, body)
    end
  end

  SCHEMA = Heroics::Schema.new(MultiJson.load(<<-'HEROICS_SCHEMA'))
{
  "$schema": "http://json-schema.org/draft-04/hyper-schema#",
  "type": [
    "object"
  ],
  "definitions": {
    "account": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Account",
      "description": "Blockbridge is a secure multi-tenant storage system.  Each tenant has an Account which is isolated from every other tenant Account.  All of the tenant's storage, configuration data, credentials, audit history, and statistics *- anything that could be considered private data -* is inaccessible to other Accounts. \n\nAccounts have one or more Users, who are each assigned a set of permissions that control the actions they may perform.  One user may be simply an observer: able to query state, but unable to change anything.  Another user may be able to provision services, but not remove any existing ones.  Another is permitted to manage crypto keys. \n\nLastly, the Account object contains contact information for the primary account holder.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "name": {
          "type": [
            "string"
          ],
          "description": "account name"
        },
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/account/definitions/id"
            },
            {
              "$ref": "#/definitions/account/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "account create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "account last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "serial number"
        },
        "usage_id": {
          "type": [
            "string"
          ],
          "example": "account_usage:91:10",
          "description": "account_usage id"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string to display associated events"
        },
        "disabled": {
          "type": [
            "boolean"
          ],
          "description": "account is disabled"
        },
        "primary_contact": {
          "type": [
            "object"
          ],
          "description": "primary contact information",
          "properties": {
            "first_name": {
              "type": [
                "string"
              ],
              "description": "First Name",
              "default": ""
            },
            "last_name": {
              "type": [
                "string"
              ],
              "description": "Last Name",
              "default": ""
            },
            "company": {
              "type": [
                "string"
              ],
              "description": "company name"
            },
            "address": {
              "type": [
                "object"
              ],
              "description": "mailing address",
              "properties": {
                "addr": {
                  "type": [
                    "array"
                  ],
                  "items": {
                    "type": [
                      "string"
                    ],
                    "description": "address line"
                  },
                  "description": "physical address lines"
                },
                "city": {
                  "type": [
                    "string"
                  ],
                  "description": "city"
                },
                "state": {
                  "type": [
                    "string"
                  ],
                  "description": "state"
                },
                "zip": {
                  "type": [
                    "string"
                  ],
                  "description": "zip code"
                },
                "country": {
                  "type": [
                    "string"
                  ],
                  "description": "country",
                  "default": "US"
                }
              },
              "additionalProperties": false
            },
            "phone": {
              "type": [
                "object"
              ],
              "description": "phone number",
              "properties": {
                "number": {
                  "type": [
                    "string"
                  ],
                  "description": "Phone number"
                },
                "valid": {
                  "type": [
                    "boolean"
                  ],
                  "description": "phone number has been verified for SMS"
                },
                "token": {
                  "type": [
                    "string"
                  ],
                  "description": "SMS verification token"
                }
              },
              "additionalProperties": false
            },
            "email": {
              "type": [
                "object"
              ],
              "description": "email address",
              "properties": {
                "addr": {
                  "type": [
                    "string"
                  ],
                  "description": "email address"
                },
                "valid": {
                  "type": [
                    "boolean"
                  ],
                  "description": "address has been verified"
                },
                "token": {
                  "type": [
                    "string"
                  ],
                  "description": "address verification token"
                }
              },
              "additionalProperties": false
            }
          },
          "additionalProperties": false
        },
        "billing_contact": {
          "type": [
            "object",
            "null"
          ],
          "description": "billing contact information",
          "properties": {
            "first_name": {
              "type": [
                "string"
              ],
              "description": "First Name",
              "default": ""
            },
            "last_name": {
              "type": [
                "string"
              ],
              "description": "Last Name",
              "default": ""
            },
            "company": {
              "type": [
                "string"
              ],
              "description": "company name"
            },
            "address": {
              "type": [
                "object"
              ],
              "description": "mailing address",
              "properties": {
                "addr": {
                  "type": [
                    "array"
                  ],
                  "items": {
                    "type": [
                      "string"
                    ],
                    "description": "address line"
                  },
                  "description": "physical address lines"
                },
                "city": {
                  "type": [
                    "string"
                  ],
                  "description": "city"
                },
                "state": {
                  "type": [
                    "string"
                  ],
                  "description": "state"
                },
                "zip": {
                  "type": [
                    "string"
                  ],
                  "description": "zip code"
                },
                "country": {
                  "type": [
                    "string"
                  ],
                  "description": "country",
                  "default": "US"
                }
              },
              "additionalProperties": false
            },
            "phone": {
              "type": [
                "object"
              ],
              "description": "phone number",
              "properties": {
                "number": {
                  "type": [
                    "string"
                  ],
                  "description": "Phone number"
                },
                "valid": {
                  "type": [
                    "boolean"
                  ],
                  "description": "phone number has been verified for SMS"
                },
                "token": {
                  "type": [
                    "string"
                  ],
                  "description": "SMS verification token"
                }
              },
              "additionalProperties": false
            },
            "email": {
              "type": [
                "object"
              ],
              "description": "email address",
              "properties": {
                "addr": {
                  "type": [
                    "string"
                  ],
                  "description": "email address"
                },
                "valid": {
                  "type": [
                    "boolean"
                  ],
                  "description": "address has been verified"
                },
                "token": {
                  "type": [
                    "string"
                  ],
                  "description": "address verification token"
                }
              },
              "additionalProperties": false
            }
          },
          "additionalProperties": false
        },
        "admin_profile_id": {
          "type": [
            "string"
          ],
          "example": "user_profile:79:12",
          "description": "account administrative user"
        },
        "limits": {
          "type": [
            "object"
          ],
          "description": "account limits",
          "properties": {
            "vss_num": {
              "type": [
                "integer",
                "null"
              ],
              "description": "number of virtual storage services",
              "default": null
            },
            "size_reserve_total": {
              "type": [
                "integer",
                "null"
              ],
              "description": "maximum size of storage",
              "example": 1073741824,
              "default": null
            }
          },
          "additionalProperties": false
        },
        "provisioning": {
          "type": [
            "object"
          ],
          "description": "account provisioning settings",
          "properties": {
            "size_reserve_max": {
              "type": [
                "integer",
                "null"
              ],
              "description": "maximum size reserve of a single virtual storage service",
              "example": 1073741824,
              "default": null
            },
            "iops_reserve_max": {
              "type": [
                "integer",
                "null"
              ],
              "description": "maximum iops reserve of a single virtual storage service",
              "default": null
            },
            "tags_include": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "string"
                ],
                "description": "tag"
              },
              "description": "tags included",
              "default": [

              ]
            },
            "tags_exclude": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "string"
                ],
                "description": "tag"
              },
              "description": "tags excluded",
              "default": [

              ]
            },
            "tags_permit": {
              "type": [
                "array",
                "null"
              ],
              "items": {
                "type": [
                  "string"
                ],
                "description": "tag"
              },
              "description": "tags permitted",
              "default": null
            }
          },
          "additionalProperties": false
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "idp": {
          "type": [
            "object"
          ],
          "description": "idP information",
          "properties": {
            "id": {
              "type": [
                "string"
              ],
              "example": "idp:76:10",
              "description": "no documentation"
            },
            "label": {
              "type": [
                "string"
              ],
              "description": "no documentation"
            },
            "type": {
              "type": [
                "string"
              ],
              "example": "internal",
              "enum": [
                "internal",
                "openstack"
              ],
              "description": "identity provider type"
            }
          },
          "additionalProperties": false
        }
      },
      "links": [
        {
          "description": "Retrieve an existing account.",
          "href": "/account/{(%23%2Fdefinitions%2Faccount%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate accounts.",
          "href": "/account",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a new account.",
          "href": "/account",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "name": {
                "type": [
                  "string"
                ],
                "description": "account name"
              },
              "password": {
                "type": [
                  "string"
                ],
                "description": "password to set in primary user profile"
              },
              "permissions": {
                "type": [
                  "object"
                ],
                "description": "user permissions",
                "properties": {
                  "realm": {
                    "type": [
                      "object"
                    ],
                    "description": "realm permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "realm rights",
                        "properties": {
                          "can_switch_user": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can SU to lower level user"
                          },
                          "manage_node_membership": {
                            "type": [
                              "boolean"
                            ],
                            "description": "accept or delete nodes from the management network"
                          },
                          "manage_accounts": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can create or delete other accounts, users and their settings"
                          },
                          "view_logs": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view administrative logs"
                          },
                          "run_admin_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tasks"
                          },
                          "run_tests": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tests"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "node": {
                    "type": [
                      "object"
                    ],
                    "description": "node permissions",
                    "properties": {
                      "all_realm_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all nodes in the realm",
                        "default": true
                      },
                      "nodes": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "node:83:10",
                          "description": "node id"
                        },
                        "description": "scope permissions to specific nodes "
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "node rights",
                        "properties": {
                          "manage_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure OS devices, iSCSI devices, and system datastores"
                          },
                          "manage_networks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure networks"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manually provision virtual storage services"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove virtual storage services"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "vss": {
                    "type": [
                      "object"
                    ],
                    "description": "vss permissions",
                    "properties": {
                      "all_account_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all virtual storage services in the account",
                        "default": true
                      },
                      "vsses": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "vss:65:11",
                          "description": "virtual storage service id"
                        },
                        "description": "limit scope to specified vsses"
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "vss rights",
                        "properties": {
                          "dismiss_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "dismiss tasks"
                          },
                          "update_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "update vss configuration"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove vss"
                          },
                          "set_vss_quota": {
                            "type": [
                              "boolean"
                            ],
                            "description": "set vss quota"
                          },
                          "manage_internal_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage internal disks"
                          },
                          "manage_external_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage external disks"
                          },
                          "manage_removable_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage removable disks"
                          },
                          "manage_disk_cryptography": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk cryptography"
                          },
                          "remove_locked_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove locked disks"
                          },
                          "validate_data_integrity": {
                            "type": [
                              "boolean"
                            ],
                            "description": "validate data integrity"
                          },
                          "manage_targets": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage targets"
                          },
                          "manage_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage profiles"
                          },
                          "manage_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage secure access tokens"
                          },
                          "manage_rules": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage rules"
                          },
                          "replicate_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate disks"
                          },
                          "synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "synchronize disks"
                          },
                          "format_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "format disks"
                          },
                          "resize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "resize disks"
                          },
                          "manage_snapshots": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage snapshots"
                          },
                          "backup_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "backup disks"
                          },
                          "replicate_and_synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate and synchronize disks (DEPRECATED)"
                          },
                          "compress_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "compress disks"
                          },
                          "manage_disk_compression": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk "
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "user": {
                    "type": [
                      "object"
                    ],
                    "description": "user permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "user rights",
                        "properties": {
                          "manage_users": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete users in an account"
                          },
                          "modify_user_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify user contact info"
                          },
                          "reset_user_password": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset user password"
                          },
                          "reset_user_two_factor": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset two factor authentication"
                          },
                          "manage_authorizations": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete persistent authorizations"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "account": {
                    "type": [
                      "object"
                    ],
                    "description": "account permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "account rights",
                        "properties": {
                          "modify_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify account contact settings"
                          },
                          "view_events": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view events"
                          },
                          "view_statistics": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view statistics"
                          },
                          "manage_global_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global profiles"
                          },
                          "manage_global_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global secure access tokens"
                          },
                          "query_catalog": {
                            "type": [
                              "boolean"
                            ],
                            "description": "query product catalog"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "provision vss from catalog"
                          },
                          "manage_obj_stores": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage obj stores"
                          },
                          "read_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "read from object storage"
                          },
                          "write_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "write to object storage"
                          },
                          "delete_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "delete from object storage"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              },
              "level": {
                "type": [
                  "integer"
                ],
                "description": "privilege level"
              },
              "access": {
                "type": [
                  "object"
                ],
                "description": "api access configuration",
                "properties": {
                  "web": {
                    "type": [
                      "boolean"
                    ],
                    "description": "web access permitted",
                    "default": true
                  },
                  "api": {
                    "type": [
                      "boolean"
                    ],
                    "description": "api access permitted",
                    "default": false
                  }
                },
                "additionalProperties": false
              },
              "activated": {
                "type": [
                  "boolean"
                ],
                "description": "user profile activated"
              },
              "primary_contact": {
                "type": [
                  "object"
                ],
                "description": "administrative (primary) contact information",
                "properties": {
                  "first_name": {
                    "type": [
                      "string"
                    ],
                    "default": "",
                    "description": "First Name"
                  },
                  "last_name": {
                    "type": [
                      "string"
                    ],
                    "default": "",
                    "description": "Last Name"
                  },
                  "company": {
                    "type": [
                      "string"
                    ],
                    "description": "company name"
                  },
                  "address": {
                    "type": [
                      "object"
                    ],
                    "description": "mailing address",
                    "properties": {
                      "addr": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "address line"
                        },
                        "description": "physical address lines"
                      },
                      "city": {
                        "type": [
                          "string"
                        ],
                        "description": "city"
                      },
                      "state": {
                        "type": [
                          "string"
                        ],
                        "description": "state"
                      },
                      "zip": {
                        "type": [
                          "string"
                        ],
                        "description": "zip code"
                      },
                      "country": {
                        "type": [
                          "string"
                        ],
                        "default": "US",
                        "description": "country"
                      }
                    },
                    "additionalProperties": false
                  },
                  "phone": {
                    "type": [
                      "string"
                    ],
                    "description": "phone number"
                  },
                  "email": {
                    "type": [
                      "string"
                    ],
                    "example": "support@blockbridge.com",
                    "description": "email address",
                    "format": "email"
                  }
                },
                "additionalProperties": false
              },
              "billing_contact": {
                "type": [
                  "object",
                  "null"
                ],
                "description": "billing contact information",
                "properties": {
                  "first_name": {
                    "type": [
                      "string"
                    ],
                    "description": "First Name",
                    "default": ""
                  },
                  "last_name": {
                    "type": [
                      "string"
                    ],
                    "description": "Last Name",
                    "default": ""
                  },
                  "company": {
                    "type": [
                      "string"
                    ],
                    "description": "company name"
                  },
                  "address": {
                    "type": [
                      "object"
                    ],
                    "description": "mailing address",
                    "properties": {
                      "addr": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "address line"
                        },
                        "description": "physical address lines"
                      },
                      "city": {
                        "type": [
                          "string"
                        ],
                        "description": "city"
                      },
                      "state": {
                        "type": [
                          "string"
                        ],
                        "description": "state"
                      },
                      "zip": {
                        "type": [
                          "string"
                        ],
                        "description": "zip code"
                      },
                      "country": {
                        "type": [
                          "string"
                        ],
                        "default": "US",
                        "description": "country"
                      }
                    },
                    "additionalProperties": false
                  },
                  "phone": {
                    "type": [
                      "string"
                    ],
                    "description": "phone number"
                  },
                  "email": {
                    "type": [
                      "string"
                    ],
                    "description": "email address",
                    "example": "support@blockbridge.com",
                    "format": "email"
                  }
                },
                "additionalProperties": false
              },
              "limits": {
                "type": [
                  "object"
                ],
                "description": "account limits",
                "properties": {
                  "vss_num": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "description": "number of virtual storage services",
                    "default": null
                  },
                  "size_reserve_total": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "description": "maximum size of storage",
                    "example": 1073741824,
                    "default": null
                  }
                },
                "additionalProperties": false
              },
              "provisioning": {
                "type": [
                  "object"
                ],
                "description": "account provisioning settings",
                "properties": {
                  "size_reserve_max": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "description": "maximum size reserve of a single virtual storage service",
                    "example": 1073741824,
                    "default": null
                  },
                  "iops_reserve_max": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "description": "maximum iops reserve of a single virtual storage service",
                    "default": null
                  },
                  "tags_include": {
                    "type": [
                      "array"
                    ],
                    "default": [

                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "tag"
                    },
                    "description": "tags included"
                  },
                  "tags_exclude": {
                    "type": [
                      "array"
                    ],
                    "default": [

                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "tag"
                    },
                    "description": "tags excluded"
                  },
                  "tags_permit": {
                    "type": [
                      "array",
                      "null"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "tag"
                    },
                    "description": "tags permitted",
                    "default": null
                  }
                },
                "additionalProperties": false
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "account UUID"
              },
              "user_uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "user profile UUID"
              },
              "template": {
                "type": [
                  "string"
                ],
                "description": "accounte template"
              }
            },
            "description": "account create request arguments",
            "required": [
              "name"
            ],
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "account_create"
        },
        {
          "description": "Remove an existing account.",
          "href": "/account/{(%23%2Fdefinitions%2Faccount%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "account_remove"
        },
        {
          "description": "Change the configuration of an existing account.",
          "href": "/account/{(%23%2Fdefinitions%2Faccount%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "host": {
                "type": [
                  "string"
                ],
                "description": "server hostname originating request (for url)"
              },
              "primary_contact": {
                "type": [
                  "object"
                ],
                "description": "administrative (primary) contact information",
                "properties": {
                  "first_name": {
                    "type": [
                      "string"
                    ],
                    "description": "First Name"
                  },
                  "last_name": {
                    "type": [
                      "string"
                    ],
                    "description": "Last Name"
                  },
                  "company": {
                    "type": [
                      "string"
                    ],
                    "description": "company name"
                  },
                  "address": {
                    "type": [
                      "object"
                    ],
                    "description": "mailing address",
                    "properties": {
                      "addr": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "address line"
                        },
                        "description": "physical address lines"
                      },
                      "city": {
                        "type": [
                          "string"
                        ],
                        "description": "city"
                      },
                      "state": {
                        "type": [
                          "string"
                        ],
                        "description": "state"
                      },
                      "zip": {
                        "type": [
                          "string"
                        ],
                        "description": "zip code"
                      },
                      "country": {
                        "type": [
                          "string"
                        ],
                        "description": "country"
                      }
                    },
                    "additionalProperties": false
                  },
                  "phone": {
                    "type": [
                      "string"
                    ],
                    "description": "phone number"
                  },
                  "email": {
                    "type": [
                      "string"
                    ],
                    "description": "email address",
                    "example": "support@blockbridge.com",
                    "format": "email"
                  }
                },
                "additionalProperties": false
              },
              "billing_contact": {
                "type": [
                  "object",
                  "null"
                ],
                "description": "billing contact information",
                "properties": {
                  "first_name": {
                    "type": [
                      "string"
                    ],
                    "description": "First Name"
                  },
                  "last_name": {
                    "type": [
                      "string"
                    ],
                    "description": "Last Name"
                  },
                  "company": {
                    "type": [
                      "string"
                    ],
                    "description": "company name"
                  },
                  "address": {
                    "type": [
                      "object"
                    ],
                    "description": "mailing address",
                    "properties": {
                      "addr": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "address line"
                        },
                        "description": "physical address lines"
                      },
                      "city": {
                        "type": [
                          "string"
                        ],
                        "description": "city"
                      },
                      "state": {
                        "type": [
                          "string"
                        ],
                        "description": "state"
                      },
                      "zip": {
                        "type": [
                          "string"
                        ],
                        "description": "zip code"
                      },
                      "country": {
                        "type": [
                          "string"
                        ],
                        "description": "country"
                      }
                    },
                    "additionalProperties": false
                  },
                  "phone": {
                    "type": [
                      "string"
                    ],
                    "description": "phone number"
                  },
                  "email": {
                    "type": [
                      "string"
                    ],
                    "description": "email address",
                    "example": "support@blockbridge.com",
                    "format": "email"
                  }
                },
                "additionalProperties": false
              },
              "password": {
                "type": [
                  "string"
                ],
                "description": "password of primary user profile"
              },
              "limits": {
                "type": [
                  "object"
                ],
                "description": "account limits",
                "properties": {
                  "vss_num": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "description": "number of virtual storage services"
                  },
                  "size_reserve_total": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "description": "maximum size of storage",
                    "example": 1073741824
                  }
                },
                "additionalProperties": false
              },
              "provisioning": {
                "type": [
                  "object"
                ],
                "description": "account provisioning settings",
                "properties": {
                  "size_reserve_max": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "description": "maximum size reserve of a single virtual storage service",
                    "example": 1073741824
                  },
                  "iops_reserve_max": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "description": "maximum iops reserve of a single virtual storage service"
                  },
                  "tags_include": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "tag"
                    },
                    "description": "tags included"
                  },
                  "tags_exclude": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "tag"
                    },
                    "description": "tags excluded"
                  },
                  "tags_permit": {
                    "type": [
                      "array",
                      "null"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "tag"
                    },
                    "description": "tags permitted"
                  }
                },
                "additionalProperties": false
              }
            },
            "description": "account update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "account_update"
        },
        {
          "description": "Display usage for an existing account.",
          "href": "/account/{(%23%2Fdefinitions%2Faccount%2Fdefinitions%2Fidentity)}/usage",
          "method": "GET",
          "rel": "self",
          "title": "Usage"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/account/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/account/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/account/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/account/definitions/mtime"
        },
        "idp": {
          "$ref": "#/definitions/account/definitions/idp"
        },
        "serial": {
          "$ref": "#/definitions/account/definitions/serial"
        },
        "usage_id": {
          "$ref": "#/definitions/account/definitions/usage_id"
        },
        "disabled": {
          "$ref": "#/definitions/account/definitions/disabled"
        },
        "name": {
          "$ref": "#/definitions/account/definitions/name"
        },
        "primary_contact": {
          "$ref": "#/definitions/account/definitions/primary_contact"
        },
        "billing_contact": {
          "$ref": "#/definitions/account/definitions/billing_contact"
        },
        "admin_profile_id": {
          "$ref": "#/definitions/account/definitions/admin_profile_id"
        },
        "limits": {
          "$ref": "#/definitions/account/definitions/limits"
        },
        "provisioning": {
          "$ref": "#/definitions/account/definitions/provisioning"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "serial",
        "usage_id",
        "disabled",
        "name",
        "primary_contact",
        "billing_contact",
        "admin_profile_id",
        "limits",
        "provisioning"
      ],
      "additionalProperties": false
    },
    "user-profile": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "User Profile",
      "description": "An Account has one or more Users, who are permitted to administer and consume storage according to various defined roles.  Each User has a profile object that has the User's name, email address, password and two-factor authentication information for the API and web application.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/user-profile/definitions/id"
            },
            {
              "$ref": "#/definitions/user-profile/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "user profile create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "user profile last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string to display associated events"
        },
        "email_notify": {
          "type": [
            "boolean"
          ],
          "description": "email notifications enabled"
        },
        "email": {
          "type": [
            "string",
            "null"
          ],
          "format": "email",
          "example": "support@blockbridge.com",
          "description": "email address"
        },
        "email_verified": {
          "type": [
            "boolean"
          ],
          "description": "email address has been verified"
        },
        "sms_notify": {
          "type": [
            "boolean"
          ],
          "description": "SMS notifications enabled"
        },
        "sms": {
          "type": [
            "object",
            "null"
          ],
          "description": "notification number for SMS",
          "properties": {
            "number": {
              "type": [
                "string"
              ],
              "description": "Phone number"
            },
            "valid": {
              "type": [
                "boolean"
              ],
              "description": "phone number has been verified for SMS"
            },
            "token": {
              "type": [
                "string"
              ],
              "description": "SMS verification token"
            }
          },
          "required": [
            "number",
            "valid"
          ],
          "additionalProperties": false
        },
        "login": {
          "type": [
            "string"
          ],
          "description": "username"
        },
        "password_set": {
          "type": [
            "boolean"
          ],
          "description": "is password non-null?"
        },
        "allow_su": {
          "type": [
            "boolean"
          ],
          "description": "admin allowed to SU to this user"
        },
        "level": {
          "type": [
            "integer"
          ],
          "description": "user privilege level"
        },
        "timezone": {
          "type": [
            "string"
          ],
          "enum": [
            "local"
          ],
          "description": "timezone",
          "example": "local"
        },
        "activated": {
          "type": [
            "boolean"
          ],
          "description": "user profile activated"
        },
        "account_admin": {
          "type": [
            "boolean"
          ],
          "description": "user has account-wide administrative control"
        },
        "two_factor": {
          "type": [
            "object"
          ],
          "description": "two-factor authentication parameters",
          "properties": {
            "auth": {
              "type": [
                "string"
              ],
              "enum": [
                "none",
                "yubikey",
                "google"
              ],
              "description": "two-factor authentication type",
              "example": "google"
            },
            "yubikey_id": {
              "type": [
                "string"
              ],
              "description": "yubikey OTP for binding unique yubikey to profile"
            },
            "security_email": {
              "type": [
                "object",
                "null"
              ],
              "description": "security email address",
              "properties": {
                "addr": {
                  "type": [
                    "string"
                  ],
                  "format": "email",
                  "example": "support@blockbridge.com",
                  "description": "security email address"
                },
                "verified": {
                  "type": [
                    "boolean"
                  ],
                  "description": "security email address has been verified"
                },
                "bounce": {
                  "type": [
                    "boolean"
                  ],
                  "description": "email is bouncing to security_email_addr"
                }
              },
              "required": [
                "addr",
                "verified",
                "bounce"
              ],
              "additionalProperties": false
            }
          },
          "required": [
            "auth",
            "yubikey_id",
            "security_email"
          ],
          "additionalProperties": false,
          "dependencies": {
            "yubikey_id": {
              "properties": {
                "auth": {
                  "enum": [
                    "yubikey"
                  ]
                }
              }
            },
            "security_email": {
              "not": {
                "properties": {
                  "auth": {
                    "enum": [
                      "none"
                    ]
                  }
                }
              }
            }
          }
        },
        "permissions": {
          "type": [
            "object"
          ],
          "description": "user permissions",
          "properties": {
            "realm": {
              "type": [
                "object"
              ],
              "description": "realm permissions",
              "properties": {
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "realm rights",
                  "properties": {
                    "can_switch_user": {
                      "type": [
                        "boolean"
                      ],
                      "description": "can SU to lower level user"
                    },
                    "manage_node_membership": {
                      "type": [
                        "boolean"
                      ],
                      "description": "accept or delete nodes from the management network"
                    },
                    "manage_accounts": {
                      "type": [
                        "boolean"
                      ],
                      "description": "can create or delete other accounts, users and their settings"
                    },
                    "view_logs": {
                      "type": [
                        "boolean"
                      ],
                      "description": "view administrative logs"
                    },
                    "run_admin_tasks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "run realm administrative tasks"
                    },
                    "run_tests": {
                      "type": [
                        "boolean"
                      ],
                      "description": "run realm administrative tests"
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            },
            "node": {
              "type": [
                "object"
              ],
              "description": "node permissions",
              "properties": {
                "all_realm_scope": {
                  "type": [
                    "boolean"
                  ],
                  "description": "apply to all nodes in the realm"
                },
                "nodes": {
                  "type": [
                    "array"
                  ],
                  "items": {
                    "type": [
                      "string"
                    ],
                    "example": "node:26:12",
                    "description": "node id"
                  },
                  "description": "scope permissions to specific nodes "
                },
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "node rights",
                  "properties": {
                    "manage_storage": {
                      "type": [
                        "boolean"
                      ],
                      "description": "configure OS devices, iSCSI devices, and system datastores"
                    },
                    "manage_networks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "configure networks"
                    },
                    "provision_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manually provision virtual storage services"
                    },
                    "remove_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "remove virtual storage services"
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            },
            "vss": {
              "type": [
                "object"
              ],
              "description": "vss permissions",
              "properties": {
                "all_account_scope": {
                  "type": [
                    "boolean"
                  ],
                  "description": "apply to all virtual storage services in the account"
                },
                "vsses": {
                  "type": [
                    "array"
                  ],
                  "items": {
                    "type": [
                      "string"
                    ],
                    "example": "vss:53:5",
                    "description": "virtual storage service id"
                  },
                  "description": "limit scope to specified vsses"
                },
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "vss rights",
                  "properties": {
                    "dismiss_tasks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "dismiss tasks"
                    },
                    "update_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "update vss configuration"
                    },
                    "remove_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "remove vss"
                    },
                    "set_vss_quota": {
                      "type": [
                        "boolean"
                      ],
                      "description": "set vss quota"
                    },
                    "manage_internal_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage internal disks"
                    },
                    "manage_external_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage external disks"
                    },
                    "manage_removable_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage removable disks"
                    },
                    "manage_disk_cryptography": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage disk cryptography"
                    },
                    "remove_locked_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "remove locked disks"
                    },
                    "validate_data_integrity": {
                      "type": [
                        "boolean"
                      ],
                      "description": "validate data integrity"
                    },
                    "manage_targets": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage targets"
                    },
                    "manage_profiles": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage profiles"
                    },
                    "manage_secure_access_tokens": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage secure access tokens"
                    },
                    "manage_rules": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage rules"
                    },
                    "replicate_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "replicate disks"
                    },
                    "synchronize_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "synchronize disks"
                    },
                    "format_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "format disks"
                    },
                    "resize_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "resize disks"
                    },
                    "manage_snapshots": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage snapshots"
                    },
                    "backup_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "backup disks"
                    },
                    "replicate_and_synchronize_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "replicate and synchronize disks (DEPRECATED)"
                    },
                    "compress_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "compress disks"
                    },
                    "manage_disk_compression": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage disk "
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            },
            "user": {
              "type": [
                "object"
              ],
              "description": "user permissions",
              "properties": {
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "user rights",
                  "properties": {
                    "manage_users": {
                      "type": [
                        "boolean"
                      ],
                      "description": "create or delete users in an account"
                    },
                    "modify_user_contact_settings": {
                      "type": [
                        "boolean"
                      ],
                      "description": "modify user contact info"
                    },
                    "reset_user_password": {
                      "type": [
                        "boolean"
                      ],
                      "description": "reset user password"
                    },
                    "reset_user_two_factor": {
                      "type": [
                        "boolean"
                      ],
                      "description": "reset two factor authentication"
                    },
                    "manage_authorizations": {
                      "type": [
                        "boolean"
                      ],
                      "description": "create or delete persistent authorizations"
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            },
            "account": {
              "type": [
                "object"
              ],
              "description": "account permissions",
              "properties": {
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "account rights",
                  "properties": {
                    "modify_contact_settings": {
                      "type": [
                        "boolean"
                      ],
                      "description": "modify account contact settings"
                    },
                    "view_events": {
                      "type": [
                        "boolean"
                      ],
                      "description": "view events"
                    },
                    "view_statistics": {
                      "type": [
                        "boolean"
                      ],
                      "description": "view statistics"
                    },
                    "manage_global_profiles": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage global profiles"
                    },
                    "manage_global_secure_access_tokens": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage global secure access tokens"
                    },
                    "query_catalog": {
                      "type": [
                        "boolean"
                      ],
                      "description": "query product catalog"
                    },
                    "provision_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "provision vss from catalog"
                    },
                    "manage_obj_stores": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage obj stores"
                    },
                    "read_object_storage": {
                      "type": [
                        "boolean"
                      ],
                      "description": "read from object storage"
                    },
                    "write_object_storage": {
                      "type": [
                        "boolean"
                      ],
                      "description": "write to object storage"
                    },
                    "delete_object_storage": {
                      "type": [
                        "boolean"
                      ],
                      "description": "delete from object storage"
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            }
          },
          "additionalProperties": false
        },
        "access": {
          "type": [
            "object"
          ],
          "description": "access configuration",
          "properties": {
            "web": {
              "type": [
                "boolean"
              ],
              "description": "web access permitted"
            },
            "api": {
              "type": [
                "boolean"
              ],
              "description": "API access permitted"
            }
          },
          "required": [
            "web",
            "api"
          ],
          "additionalProperties": false
        },
        "app_default": {
          "type": [
            "string"
          ],
          "enum": [
            "storage",
            "infrastructure",
            "account",
            "securedrive"
          ],
          "description": "default web-ui application",
          "example": "account"
        },
        "ext_auth": {
          "type": [
            "object"
          ],
          "description": "user profile external authentication configuration",
          "properties": {
            "key": {
              "type": [
                "string",
                "null"
              ],
              "description": "key",
              "default": null
            },
            "provider": {
              "type": [
                "string",
                "null"
              ],
              "description": "name of external authentication provider",
              "default": null
            },
            "login": {
              "type": [
                "string",
                "null"
              ],
              "description": "mapped external login",
              "default": null
            },
            "domain": {
              "type": [
                "string",
                "null"
              ],
              "description": "mapped external domain",
              "default": null
            },
            "domain_function": {
              "type": [
                "string",
                "null"
              ],
              "description": "function of external domain",
              "default": null
            }
          },
          "additionalProperties": false
        },
        "account_id": {
          "type": [
            "string"
          ],
          "example": "account:64:6",
          "description": "account ref"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "user profile serial number"
        },
        "xmd_refs": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "arbitrary string reference key"
          },
          "description": "array of extensible metadata reference keys"
        },
        "xref": {
          "type": [
            "string"
          ],
          "description": "arbitrary string reference"
        },
        "label": {
          "type": [
            "string",
            "null"
          ],
          "description": "dynamic label, based on available login data"
        },
        "auth_user": {
          "type": [
            "string",
            "null"
          ],
          "description": "dynamic user, based on available login data"
        },
        "auth_domain": {
          "type": [
            "string",
            "null"
          ],
          "description": "dynamic domain, based on available data"
        },
        "auth_domain_function": {
          "type": [
            "string",
            "null"
          ],
          "description": "dynamic domain function, based on available data"
        },
        "auth_provider": {
          "type": [
            "string",
            "null"
          ],
          "description": "authentication provider (null for internal)"
        },
        "sessions": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "information about an API session",
            "properties": {
              "serial": {
                "type": [
                  "string"
                ],
                "description": "session serial number"
              },
              "id": {
                "type": [
                  "string"
                ],
                "description": "session id"
              },
              "created_ms": {
                "type": [
                  "integer"
                ],
                "description": "creation time, in milliseconds since epoch",
                "minimum": 0,
                "example": 1443200456094
              },
              "last_ms": {
                "type": [
                  "integer"
                ],
                "description": "time of last activity on session",
                "minimum": 0,
                "example": 1443200456094
              },
              "addr": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "source IP of last request on session"
              }
            },
            "required": [
              "serial",
              "id",
              "created_ms",
              "last_ms",
              "addr"
            ],
            "additionalProperties": false
          },
          "description": "array of session information"
        },
        "xmd": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "per-linked xmd data",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "example": "xmd:67:14",
                "description": "no documentation"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference key"
              },
              "mtime": {
                "type": [
                  "integer"
                ],
                "description": "last modified time of xmd",
                "minimum": 0,
                "example": 1443200456094
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "self": {
                "type": [
                  "boolean"
                ],
                "description": "no documentation"
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "no documentation",
                "properties": {
                }
              }
            },
            "additionalProperties": false,
            "required": [
              "id",
              "ref",
              "mtime",
              "tags",
              "data"
            ]
          },
          "description": "array of api xmd results"
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "idp": {
          "type": [
            "object"
          ],
          "description": "idP information",
          "properties": {
            "id": {
              "type": [
                "string"
              ],
              "example": "idp:62:6",
              "description": "no documentation"
            },
            "label": {
              "type": [
                "string"
              ],
              "description": "no documentation"
            },
            "type": {
              "type": [
                "string"
              ],
              "example": "openstack",
              "enum": [
                "internal",
                "openstack"
              ],
              "description": "identity provider type"
            }
          },
          "additionalProperties": false
        }
      },
      "links": [
        {
          "description": "Retrieve an existing user profile.",
          "href": "/user-profile/{(%23%2Fdefinitions%2Fuser-profile%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate user profiles.",
          "href": "/user-profile",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a new user profile.",
          "href": "/user-profile",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "xref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference"
              },
              "host": {
                "type": [
                  "string"
                ],
                "description": "server hostname originating request (for url)"
              },
              "username": {
                "type": [
                  "string"
                ],
                "description": "user-assigned portion of username (username@account)"
              },
              "password": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user-assigned password",
                "default": null
              },
              "two_factor": {
                "type": [
                  "object"
                ],
                "description": "two factor authentication parameters",
                "properties": {
                  "auth": {
                    "type": [
                      "string"
                    ],
                    "default": "none",
                    "enum": [
                      "none",
                      "yubikey",
                      "google"
                    ],
                    "description": "two-factor authentication type"
                  },
                  "otp": {
                    "type": [
                      "string"
                    ],
                    "description": "one-time-password from authentication device"
                  },
                  "secret": {
                    "type": [
                      "string"
                    ],
                    "pattern": "[a-fA-F0-9]*",
                    "description": "shared AES secret"
                  },
                  "private_id": {
                    "type": [
                      "string"
                    ],
                    "pattern": "[a-fA-F0-9]*",
                    "description": "yubikey private ID"
                  },
                  "security_email": {
                    "type": [
                      "string"
                    ],
                    "format": "email",
                    "example": "support@blockbridge.com",
                    "description": "security email for lost authenticator recovery"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "otp": {
                    "not": {
                      "properties": {
                        "auth": {
                          "enum": [
                            "none"
                          ]
                        }
                      }
                    }
                  },
                  "secret": {
                    "not": {
                      "properties": {
                        "auth": {
                          "enum": [
                            "none"
                          ]
                        }
                      }
                    }
                  },
                  "private_id": {
                    "properties": {
                      "auth": {
                        "enum": [
                          "yubikey"
                        ]
                      }
                    }
                  },
                  "security_email": {
                    "not": {
                      "properties": {
                        "auth": {
                          "enum": [
                            "none"
                          ]
                        }
                      }
                    }
                  }
                }
              },
              "permissions": {
                "type": [
                  "object"
                ],
                "description": "user permissions",
                "properties": {
                  "realm": {
                    "type": [
                      "object"
                    ],
                    "description": "realm permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "realm rights",
                        "properties": {
                          "can_switch_user": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can SU to lower level user"
                          },
                          "manage_node_membership": {
                            "type": [
                              "boolean"
                            ],
                            "description": "accept or delete nodes from the management network"
                          },
                          "manage_accounts": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can create or delete other accounts, users and their settings"
                          },
                          "view_logs": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view administrative logs"
                          },
                          "run_admin_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tasks"
                          },
                          "run_tests": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tests"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "node": {
                    "type": [
                      "object"
                    ],
                    "description": "node permissions",
                    "properties": {
                      "all_realm_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all nodes in the realm",
                        "default": true
                      },
                      "nodes": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "node:1:9",
                          "description": "node id"
                        },
                        "description": "scope permissions to specific nodes "
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "node rights",
                        "properties": {
                          "manage_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure OS devices, iSCSI devices, and system datastores"
                          },
                          "manage_networks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure networks"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manually provision virtual storage services"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove virtual storage services"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "vss": {
                    "type": [
                      "object"
                    ],
                    "description": "vss permissions",
                    "properties": {
                      "all_account_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all virtual storage services in the account",
                        "default": true
                      },
                      "vsses": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "vss:4:10",
                          "description": "virtual storage service id"
                        },
                        "description": "limit scope to specified vsses"
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "vss rights",
                        "properties": {
                          "dismiss_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "dismiss tasks"
                          },
                          "update_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "update vss configuration"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove vss"
                          },
                          "set_vss_quota": {
                            "type": [
                              "boolean"
                            ],
                            "description": "set vss quota"
                          },
                          "manage_internal_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage internal disks"
                          },
                          "manage_external_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage external disks"
                          },
                          "manage_removable_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage removable disks"
                          },
                          "manage_disk_cryptography": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk cryptography"
                          },
                          "remove_locked_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove locked disks"
                          },
                          "validate_data_integrity": {
                            "type": [
                              "boolean"
                            ],
                            "description": "validate data integrity"
                          },
                          "manage_targets": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage targets"
                          },
                          "manage_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage profiles"
                          },
                          "manage_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage secure access tokens"
                          },
                          "manage_rules": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage rules"
                          },
                          "replicate_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate disks"
                          },
                          "synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "synchronize disks"
                          },
                          "format_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "format disks"
                          },
                          "resize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "resize disks"
                          },
                          "manage_snapshots": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage snapshots"
                          },
                          "backup_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "backup disks"
                          },
                          "replicate_and_synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate and synchronize disks (DEPRECATED)"
                          },
                          "compress_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "compress disks"
                          },
                          "manage_disk_compression": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk "
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "user": {
                    "type": [
                      "object"
                    ],
                    "description": "user permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "user rights",
                        "properties": {
                          "manage_users": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete users in an account"
                          },
                          "modify_user_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify user contact info"
                          },
                          "reset_user_password": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset user password"
                          },
                          "reset_user_two_factor": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset two factor authentication"
                          },
                          "manage_authorizations": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete persistent authorizations"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "account": {
                    "type": [
                      "object"
                    ],
                    "description": "account permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "account rights",
                        "properties": {
                          "modify_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify account contact settings"
                          },
                          "view_events": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view events"
                          },
                          "view_statistics": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view statistics"
                          },
                          "manage_global_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global profiles"
                          },
                          "manage_global_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global secure access tokens"
                          },
                          "query_catalog": {
                            "type": [
                              "boolean"
                            ],
                            "description": "query product catalog"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "provision vss from catalog"
                          },
                          "manage_obj_stores": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage obj stores"
                          },
                          "read_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "read from object storage"
                          },
                          "write_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "write to object storage"
                          },
                          "delete_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "delete from object storage"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              },
              "access": {
                "type": [
                  "object"
                ],
                "description": "access configuration",
                "properties": {
                  "web": {
                    "type": [
                      "boolean"
                    ],
                    "default": true,
                    "description": "web access permitted"
                  },
                  "api": {
                    "type": [
                      "boolean"
                    ],
                    "default": true,
                    "description": "API access permitted"
                  }
                },
                "additionalProperties": false
              },
              "allow_su": {
                "type": [
                  "boolean"
                ],
                "default": false,
                "description": "admin allowed to SU to user"
              },
              "email_notify": {
                "type": [
                  "boolean"
                ],
                "default": false,
                "description": "email notifications enabled"
              },
              "email": {
                "type": [
                  "string",
                  "null"
                ],
                "format": "email",
                "example": "support@blockbridge.com",
                "description": "email address",
                "default": null
              },
              "email_verify": {
                "type": [
                  "boolean"
                ],
                "description": "require email address verification"
              },
              "sms_notify": {
                "type": [
                  "boolean"
                ],
                "default": false,
                "description": "SMS notifications enabled"
              },
              "sms": {
                "type": [
                  "string"
                ],
                "description": "notification number for SMS messages"
              },
              "sms_verify": {
                "type": [
                  "boolean"
                ],
                "description": "require SMS number verification"
              },
              "app_default": {
                "type": [
                  "string"
                ],
                "default": "storage",
                "enum": [
                  "storage",
                  "infrastructure",
                  "account",
                  "securedrive"
                ],
                "description": "default web-ui application"
              },
              "account_id": {
                "type": [
                  "string"
                ],
                "example": "account:18:11",
                "description": "account id"
              },
              "level": {
                "type": [
                  "integer"
                ],
                "description": "user privilege level"
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              }
            },
            "description": "web profile create request arguments",
            "required": [
              "username"
            ],
            "additionalProperties": false,
            "dependencies": {
              "sms": {
                "properties": {
                  "sms_notify": {
                    "enum": [
                      true
                    ]
                  }
                }
              },
              "sms_verify": {
                "properties": {
                  "sms_notify": {
                    "enum": [
                      true
                    ]
                  }
                }
              }
            }
          },
          "title": "Create",
          "x_bb_method": "user_profile_create"
        },
        {
          "description": "Remove an existing user profile.",
          "href": "/user-profile/{(%23%2Fdefinitions%2Fuser-profile%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "user_profile_remove",
          "schema": {
            "type": [
              "object"
            ],
            "description": "web profile remove request arguments",
            "properties": {
              "account_id": {
                "type": [
                  "string"
                ],
                "example": "account:57:12",
                "description": "account id"
              }
            },
            "additionalProperties": false
          }
        },
        {
          "description": "Change the configuration of an existing user profile.",
          "href": "/user-profile/{(%23%2Fdefinitions%2Fuser-profile%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "host": {
                "type": [
                  "string"
                ],
                "description": "server hostname originating request (for url)"
              },
              "new_password": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "new password"
              },
              "auth_password": {
                "type": [
                  "string"
                ],
                "description": "current password; required when changing password for non-admin users"
              },
              "two_factor": {
                "type": [
                  "object"
                ],
                "description": "two factor authentication parameters",
                "properties": {
                  "auth": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "none",
                      "yubikey",
                      "google"
                    ],
                    "description": "two-factor authentication type",
                    "example": "yubikey"
                  },
                  "otp": {
                    "type": [
                      "string"
                    ],
                    "description": "one-time-password from authentication device"
                  },
                  "secret": {
                    "type": [
                      "string"
                    ],
                    "pattern": "[a-fA-F0-9]*",
                    "description": "shared AES secret"
                  },
                  "private_id": {
                    "type": [
                      "string"
                    ],
                    "pattern": "[a-fA-F0-9]*",
                    "description": "yubikey private ID"
                  },
                  "security_email": {
                    "type": [
                      "string"
                    ],
                    "format": "email",
                    "example": "support@blockbridge.com",
                    "description": "security email for lost authenticator recovery"
                  },
                  "state": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "enable",
                      "disable"
                    ],
                    "description": "enable or disable two-factor authentication",
                    "example": "enable"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "otp": {
                    "not": {
                      "properties": {
                        "auth": {
                          "enum": [
                            "none"
                          ]
                        }
                      }
                    }
                  },
                  "secret": {
                    "not": {
                      "properties": {
                        "auth": {
                          "enum": [
                            "none"
                          ]
                        }
                      }
                    }
                  },
                  "private_id": {
                    "properties": {
                      "auth": {
                        "enum": [
                          "yubikey"
                        ]
                      }
                    }
                  }
                }
              },
              "email_notify": {
                "type": [
                  "boolean"
                ],
                "description": "email notifications are enabled"
              },
              "email": {
                "type": [
                  "string",
                  "null"
                ],
                "format": "email",
                "example": "support@blockbridge.com",
                "description": "notification email address"
              },
              "email_verify": {
                "type": [
                  "boolean"
                ],
                "description": "require email address verification"
              },
              "sms_notify": {
                "type": [
                  "boolean"
                ],
                "description": "SMS notifications enabled"
              },
              "sms": {
                "type": [
                  "string"
                ],
                "description": "notification number for SMS messages"
              },
              "sms_verify": {
                "type": [
                  "boolean"
                ],
                "description": "require SMS number verification"
              },
              "app_default": {
                "type": [
                  "string"
                ],
                "enum": [
                  "storage",
                  "infrastructure",
                  "account",
                  "securedrive"
                ],
                "description": "default web-ui application",
                "example": "storage"
              },
              "activated": {
                "type": [
                  "boolean"
                ],
                "description": "user profile activated"
              },
              "ext_auth": {
                "type": [
                  "object"
                ],
                "description": "external authentication configuration",
                "properties": {
                  "key": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "no documentation"
                  },
                  "scope": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "name of external authentication scope"
                  },
                  "login": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "mapped external login"
                  },
                  "domain": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "mapped external domain"
                  },
                  "domain_function": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "mapped external domain function"
                  }
                },
                "additionalProperties": false
              },
              "permissions": {
                "type": [
                  "object"
                ],
                "description": "user permissions",
                "properties": {
                  "realm": {
                    "type": [
                      "object"
                    ],
                    "description": "realm permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "realm rights",
                        "properties": {
                          "can_switch_user": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can SU to lower level user"
                          },
                          "manage_node_membership": {
                            "type": [
                              "boolean"
                            ],
                            "description": "accept or delete nodes from the management network"
                          },
                          "manage_accounts": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can create or delete other accounts, users and their settings"
                          },
                          "view_logs": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view administrative logs"
                          },
                          "run_admin_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tasks"
                          },
                          "run_tests": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tests"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "node": {
                    "type": [
                      "object"
                    ],
                    "description": "node permissions",
                    "properties": {
                      "all_realm_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all nodes in the realm",
                        "default": true
                      },
                      "nodes": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "node:66:12",
                          "description": "node id"
                        },
                        "description": "scope permissions to specific nodes "
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "node rights",
                        "properties": {
                          "manage_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure OS devices, iSCSI devices, and system datastores"
                          },
                          "manage_networks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure networks"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manually provision virtual storage services"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove virtual storage services"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "vss": {
                    "type": [
                      "object"
                    ],
                    "description": "vss permissions",
                    "properties": {
                      "all_account_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all virtual storage services in the account",
                        "default": true
                      },
                      "vsses": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "vss:33:5",
                          "description": "virtual storage service id"
                        },
                        "description": "limit scope to specified vsses"
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "vss rights",
                        "properties": {
                          "dismiss_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "dismiss tasks"
                          },
                          "update_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "update vss configuration"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove vss"
                          },
                          "set_vss_quota": {
                            "type": [
                              "boolean"
                            ],
                            "description": "set vss quota"
                          },
                          "manage_internal_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage internal disks"
                          },
                          "manage_external_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage external disks"
                          },
                          "manage_removable_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage removable disks"
                          },
                          "manage_disk_cryptography": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk cryptography"
                          },
                          "remove_locked_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove locked disks"
                          },
                          "validate_data_integrity": {
                            "type": [
                              "boolean"
                            ],
                            "description": "validate data integrity"
                          },
                          "manage_targets": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage targets"
                          },
                          "manage_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage profiles"
                          },
                          "manage_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage secure access tokens"
                          },
                          "manage_rules": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage rules"
                          },
                          "replicate_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate disks"
                          },
                          "synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "synchronize disks"
                          },
                          "format_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "format disks"
                          },
                          "resize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "resize disks"
                          },
                          "manage_snapshots": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage snapshots"
                          },
                          "backup_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "backup disks"
                          },
                          "replicate_and_synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate and synchronize disks (DEPRECATED)"
                          },
                          "compress_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "compress disks"
                          },
                          "manage_disk_compression": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk "
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "user": {
                    "type": [
                      "object"
                    ],
                    "description": "user permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "user rights",
                        "properties": {
                          "manage_users": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete users in an account"
                          },
                          "modify_user_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify user contact info"
                          },
                          "reset_user_password": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset user password"
                          },
                          "reset_user_two_factor": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset two factor authentication"
                          },
                          "manage_authorizations": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete persistent authorizations"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "account": {
                    "type": [
                      "object"
                    ],
                    "description": "account permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "account rights",
                        "properties": {
                          "modify_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify account contact settings"
                          },
                          "view_events": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view events"
                          },
                          "view_statistics": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view statistics"
                          },
                          "manage_global_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global profiles"
                          },
                          "manage_global_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global secure access tokens"
                          },
                          "query_catalog": {
                            "type": [
                              "boolean"
                            ],
                            "description": "query product catalog"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "provision vss from catalog"
                          },
                          "manage_obj_stores": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage obj stores"
                          },
                          "read_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "read from object storage"
                          },
                          "write_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "write to object storage"
                          },
                          "delete_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "delete from object storage"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              },
              "permissions_update_mode": {
                "type": [
                  "string"
                ],
                "default": "merge",
                "enum": [
                  "replace",
                  "merge"
                ],
                "description": "user permissions update mode"
              },
              "allow_su": {
                "type": [
                  "boolean"
                ],
                "description": "admin allowed to SU to user"
              },
              "account_id": {
                "type": [
                  "string"
                ],
                "example": "account:80:7",
                "description": "account id"
              }
            },
            "description": "web profile update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "user_profile_update"
        },
        {
          "description": "Enumerate the permissions of an existing user profile.",
          "href": "/user-profile/permissions",
          "method": "GET",
          "rel": "discover",
          "title": "Permissions",
          "x_bb_method": "user_profile_perms"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/user-profile/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/user-profile/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/user-profile/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/user-profile/definitions/mtime"
        },
        "email_notify": {
          "$ref": "#/definitions/user-profile/definitions/email_notify"
        },
        "email": {
          "$ref": "#/definitions/user-profile/definitions/email"
        },
        "email_verified": {
          "$ref": "#/definitions/user-profile/definitions/email_verified"
        },
        "sms_notify": {
          "$ref": "#/definitions/user-profile/definitions/sms_notify"
        },
        "sms": {
          "$ref": "#/definitions/user-profile/definitions/sms"
        },
        "login": {
          "$ref": "#/definitions/user-profile/definitions/login"
        },
        "password_set": {
          "$ref": "#/definitions/user-profile/definitions/password_set"
        },
        "allow_su": {
          "$ref": "#/definitions/user-profile/definitions/allow_su"
        },
        "level": {
          "$ref": "#/definitions/user-profile/definitions/level"
        },
        "timezone": {
          "$ref": "#/definitions/user-profile/definitions/timezone"
        },
        "activated": {
          "$ref": "#/definitions/user-profile/definitions/activated"
        },
        "idp": {
          "$ref": "#/definitions/user-profile/definitions/idp"
        },
        "account_admin": {
          "$ref": "#/definitions/user-profile/definitions/account_admin"
        },
        "two_factor": {
          "$ref": "#/definitions/user-profile/definitions/two_factor"
        },
        "permissions": {
          "$ref": "#/definitions/user-profile/definitions/permissions"
        },
        "access": {
          "$ref": "#/definitions/user-profile/definitions/access"
        },
        "app_default": {
          "$ref": "#/definitions/user-profile/definitions/app_default"
        },
        "account_id": {
          "$ref": "#/definitions/user-profile/definitions/account_id"
        },
        "serial": {
          "$ref": "#/definitions/user-profile/definitions/serial"
        },
        "xmd_refs": {
          "$ref": "#/definitions/user-profile/definitions/xmd_refs"
        },
        "xref": {
          "$ref": "#/definitions/user-profile/definitions/xref"
        },
        "sessions": {
          "$ref": "#/definitions/user-profile/definitions/sessions"
        },
        "xmd": {
          "$ref": "#/definitions/user-profile/definitions/xmd"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "email_notify",
        "email",
        "email_verified",
        "sms_notify",
        "sms",
        "login",
        "password_set",
        "allow_su",
        "level",
        "timezone",
        "activated",
        "account_admin",
        "two_factor",
        "permissions",
        "access",
        "app_default",
        "account_id",
        "serial",
        "xmd_refs",
        "sessions"
      ],
      "additionalProperties": false
    },
    "oauth2-token": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "OAuth 2 Access Token",
      "description": "Submit a username and password to create a time-limited OAuth 2 API access token.  Include this token in the `Authorization` HTTP header in subsequent requests.  For example,:\n\n```\nAuthorization: Bearer 0/EYZPk2DHOQ+ep8NyFerJake9NCG+M3WSbsoj5cfn6L5xh0+TYMc6Hw\n\n```",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "id": {
          "description": "unique identifier of OAuth access token",
          "type": [
            "string"
          ]
        },
        "scope": {
          "description": "The scope of access OAuth authorization allows",
          "example": [
            "global"
          ],
          "type": [
            "string"
          ]
        },
        "expires_in": {
          "description": "when access token will expire (in seconds)",
          "example": 3560,
          "type": [
            "integer"
          ]
        },
        "grant_type": {
          "description": "type of grant request",
          "example": "password",
          "type": [
            "string"
          ]
        },
        "client_id": {
          "description": "(optional) client id of request",
          "type": [
            "string"
          ]
        },
        "client_secret": {
          "description": "(optional) client supplied secret",
          "type": [
            "string"
          ]
        },
        "code": {
          "description": "(optional) code",
          "type": [
            "string"
          ]
        },
        "redirect_url": {
          "description": "(optional) redirect url",
          "type": [
            "string"
          ]
        },
        "username": {
          "description": "username to request token for",
          "type": [
            "string"
          ],
          "example": "username"
        },
        "password": {
          "description": "password for username",
          "type": [
            "string"
          ],
          "example": "password"
        },
        "method": {
          "description": "(optional) method of authorization",
          "type": [
            "string"
          ],
          "example": "keystone"
        },
        "identity": {
        }
      },
      "links": [
        {
          "description": "Exchange authorization of some sort for an access token.",
          "href": "/oauth2/token",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "grant_type": {
                "$ref": "#/definitions/oauth2-token/definitions/grant_type"
              },
              "client_id": {
                "$ref": "#/definitions/oauth2-token/definitions/client_id"
              },
              "client_secret": {
                "$ref": "#/definitions/oauth2-token/definitions/client_secret"
              },
              "code": {
                "$ref": "#/definitions/oauth2-token/definitions/code"
              },
              "redirect_url": {
                "$ref": "#/definitions/oauth2-token/definitions/redirect_url"
              },
              "username": {
                "$ref": "#/definitions/oauth2-token/definitions/username"
              },
              "password": {
                "$ref": "#/definitions/oauth2-token/definitions/password"
              },
              "method": {
                "$ref": "#/definitions/oauth2-token/definitions/method"
              },
              "expires_in": {
                "$ref": "#/definitions/oauth2-token/definitions/expires_in"
              }
            },
            "required": [
              "grant_type"
            ]
          },
          "title": "Create"
        }
      ],
      "properties": {
      },
      "additionalProperties": false
    },
    "authz": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Authorization",
      "description": "Manage secure application access to the API using revokable authorization tokens.  A user may have many authorization tokens, in support of many different applications.  Each token may be independently revoked with a `DELETE` request.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/authz/definitions/id"
            },
            {
              "$ref": "#/definitions/authz/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "authorization create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "authorization last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "authorization serial number"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "account_id": {
          "type": [
            "string"
          ],
          "example": "account:92:9",
          "description": "no documentation"
        },
        "user_id": {
          "type": [
            "string"
          ],
          "example": "user_profile:54:10",
          "description": "no documentation"
        },
        "fingerprint": {
          "type": [
            "string",
            "null"
          ],
          "description": "client-side differentiator to permit multiple authorizations per application/user",
          "default": null
        },
        "enabled": {
          "type": [
            "boolean"
          ],
          "description": "authorization is enabled",
          "default": true
        },
        "app_id": {
          "type": [
            "string",
            "null"
          ],
          "example": "app:45:13",
          "description": "associated client application (null = no/unspecified application)",
          "default": null
        },
        "scope": {
          "type": [
            "string",
            "null"
          ],
          "description": "authorization scope (null maps to referenced user permissions)",
          "default": null
        },
        "access_type": {
          "type": [
            "string"
          ],
          "enum": [
            "online",
            "offline"
          ],
          "description": "authorization access type (offline access includes a refresh token)",
          "default": "online"
        },
        "lifetime": {
          "type": [
            "integer",
            "null"
          ],
          "description": "access token lifetime, in seconds since created_at (null = eternal)"
        },
        "restrict": {
          "type": [
            "string"
          ],
          "enum": [
            "none",
            "auth"
          ],
          "description": "how to restrict user-profile permissions when calculating effective perms",
          "example": "none"
        },
        "created_at": {
          "type": [
            "string"
          ],
          "description": "authorization create time"
        },
        "updated_at": {
          "type": [
            "string"
          ],
          "description": "authorization last updated time"
        },
        "expires_in": {
          "type": [
            "integer",
            "null"
          ],
          "description": "authorization time remaining"
        },
        "access_token_digest": {
          "type": [
            "string"
          ],
          "description": "base64-encoded SHA256 digest of access token"
        },
        "access_token_suffix": {
          "type": [
            "string"
          ],
          "description": "access token suffix"
        },
        "refresh_token_digest": {
          "type": [
            "string",
            "null"
          ],
          "description": "base64-encoded SHA256 digest of refresh token (for offline token refresh)"
        },
        "permissions": {
          "type": [
            "object",
            "null"
          ],
          "description": "user permissions",
          "properties": {
            "realm": {
              "type": [
                "object"
              ],
              "description": "realm permissions",
              "properties": {
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "realm rights",
                  "properties": {
                    "can_switch_user": {
                      "type": [
                        "boolean"
                      ],
                      "description": "can SU to lower level user"
                    },
                    "manage_node_membership": {
                      "type": [
                        "boolean"
                      ],
                      "description": "accept or delete nodes from the management network"
                    },
                    "manage_accounts": {
                      "type": [
                        "boolean"
                      ],
                      "description": "can create or delete other accounts, users and their settings"
                    },
                    "view_logs": {
                      "type": [
                        "boolean"
                      ],
                      "description": "view administrative logs"
                    },
                    "run_admin_tasks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "run realm administrative tasks"
                    },
                    "run_tests": {
                      "type": [
                        "boolean"
                      ],
                      "description": "run realm administrative tests"
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            },
            "node": {
              "type": [
                "object"
              ],
              "description": "node permissions",
              "properties": {
                "all_realm_scope": {
                  "type": [
                    "boolean"
                  ],
                  "description": "apply to all nodes in the realm",
                  "default": true
                },
                "nodes": {
                  "type": [
                    "array"
                  ],
                  "items": {
                    "type": [
                      "string"
                    ],
                    "example": "node:83:5",
                    "description": "node id"
                  },
                  "description": "scope permissions to specific nodes "
                },
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "node rights",
                  "properties": {
                    "manage_storage": {
                      "type": [
                        "boolean"
                      ],
                      "description": "configure OS devices, iSCSI devices, and system datastores"
                    },
                    "manage_networks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "configure networks"
                    },
                    "provision_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manually provision virtual storage services"
                    },
                    "remove_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "remove virtual storage services"
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            },
            "vss": {
              "type": [
                "object"
              ],
              "description": "vss permissions",
              "properties": {
                "all_account_scope": {
                  "type": [
                    "boolean"
                  ],
                  "description": "apply to all virtual storage services in the account",
                  "default": true
                },
                "vsses": {
                  "type": [
                    "array"
                  ],
                  "items": {
                    "type": [
                      "string"
                    ],
                    "example": "vss:76:7",
                    "description": "virtual storage service id"
                  },
                  "description": "limit scope to specified vsses"
                },
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "vss rights",
                  "properties": {
                    "dismiss_tasks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "dismiss tasks"
                    },
                    "update_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "update vss configuration"
                    },
                    "remove_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "remove vss"
                    },
                    "set_vss_quota": {
                      "type": [
                        "boolean"
                      ],
                      "description": "set vss quota"
                    },
                    "manage_internal_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage internal disks"
                    },
                    "manage_external_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage external disks"
                    },
                    "manage_removable_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage removable disks"
                    },
                    "manage_disk_cryptography": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage disk cryptography"
                    },
                    "remove_locked_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "remove locked disks"
                    },
                    "validate_data_integrity": {
                      "type": [
                        "boolean"
                      ],
                      "description": "validate data integrity"
                    },
                    "manage_targets": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage targets"
                    },
                    "manage_profiles": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage profiles"
                    },
                    "manage_secure_access_tokens": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage secure access tokens"
                    },
                    "manage_rules": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage rules"
                    },
                    "replicate_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "replicate disks"
                    },
                    "synchronize_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "synchronize disks"
                    },
                    "format_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "format disks"
                    },
                    "resize_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "resize disks"
                    },
                    "manage_snapshots": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage snapshots"
                    },
                    "backup_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "backup disks"
                    },
                    "replicate_and_synchronize_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "replicate and synchronize disks (DEPRECATED)"
                    },
                    "compress_disks": {
                      "type": [
                        "boolean"
                      ],
                      "description": "compress disks"
                    },
                    "manage_disk_compression": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage disk "
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            },
            "user": {
              "type": [
                "object"
              ],
              "description": "user permissions",
              "properties": {
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "user rights",
                  "properties": {
                    "manage_users": {
                      "type": [
                        "boolean"
                      ],
                      "description": "create or delete users in an account"
                    },
                    "modify_user_contact_settings": {
                      "type": [
                        "boolean"
                      ],
                      "description": "modify user contact info"
                    },
                    "reset_user_password": {
                      "type": [
                        "boolean"
                      ],
                      "description": "reset user password"
                    },
                    "reset_user_two_factor": {
                      "type": [
                        "boolean"
                      ],
                      "description": "reset two factor authentication"
                    },
                    "manage_authorizations": {
                      "type": [
                        "boolean"
                      ],
                      "description": "create or delete persistent authorizations"
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            },
            "account": {
              "type": [
                "object"
              ],
              "description": "account permissions",
              "properties": {
                "rights": {
                  "type": [
                    "object"
                  ],
                  "description": "account rights",
                  "properties": {
                    "modify_contact_settings": {
                      "type": [
                        "boolean"
                      ],
                      "description": "modify account contact settings"
                    },
                    "view_events": {
                      "type": [
                        "boolean"
                      ],
                      "description": "view events"
                    },
                    "view_statistics": {
                      "type": [
                        "boolean"
                      ],
                      "description": "view statistics"
                    },
                    "manage_global_profiles": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage global profiles"
                    },
                    "manage_global_secure_access_tokens": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage global secure access tokens"
                    },
                    "query_catalog": {
                      "type": [
                        "boolean"
                      ],
                      "description": "query product catalog"
                    },
                    "provision_vss": {
                      "type": [
                        "boolean"
                      ],
                      "description": "provision vss from catalog"
                    },
                    "manage_obj_stores": {
                      "type": [
                        "boolean"
                      ],
                      "description": "manage obj stores"
                    },
                    "read_object_storage": {
                      "type": [
                        "boolean"
                      ],
                      "description": "read from object storage"
                    },
                    "write_object_storage": {
                      "type": [
                        "boolean"
                      ],
                      "description": "write to object storage"
                    },
                    "delete_object_storage": {
                      "type": [
                        "boolean"
                      ],
                      "description": "delete from object storage"
                    }
                  },
                  "additionalProperties": false
                }
              },
              "additionalProperties": false
            }
          },
          "additionalProperties": false
        },
        "effective_scope": {
          "type": [
            "string",
            "null"
          ],
          "description": "authorization effective scope"
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "enforce_two_factor": {
          "type": [
            "boolean"
          ],
          "default": false,
          "description": "enforce user two-factor auth (if configured)"
        },
        "xref": {
          "type": [
            "string"
          ],
          "description": "arbitrary string reference"
        },
        "access_token_type": {
          "type": [
            "string"
          ],
          "example": "Bearer",
          "enum": [
            "Bearer"
          ],
          "description": "no documentation"
        }
      },
      "links": [
        {
          "description": "Retrieve existing authorizations.",
          "href": "/authorization/{(%23%2Fdefinitions%2Fauthz%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate authorizations.",
          "href": "/authorization",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a persistent API authorization token.",
          "href": "/authorization",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "fingerprint": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "client-side differentiator to permit multiple authorizations per application/user",
                "default": null
              },
              "app_id": {
                "type": [
                  "string",
                  "null"
                ],
                "example": "app:27:11",
                "description": "associated client application (null = no/unspecified application)",
                "default": null
              },
              "notes": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned notes",
                "default": null
              },
              "scope": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "authorization scope (null maps to referenced user permissions)",
                "default": null
              },
              "enabled": {
                "type": [
                  "boolean"
                ],
                "default": true,
                "description": "authorization is enabled"
              },
              "access_type": {
                "type": [
                  "string"
                ],
                "default": "online",
                "enum": [
                  "online",
                  "offline"
                ],
                "description": "authorization access type (offline access includes a refresh token)"
              },
              "restrict": {
                "type": [
                  "string"
                ],
                "default": "auth",
                "enum": [
                  "none",
                  "auth"
                ],
                "description": "specify how the user permissions are mapped/filtered"
              },
              "permissions": {
                "type": [
                  "object"
                ],
                "description": "authorization scope is specified with the internal permissions structure",
                "properties": {
                  "realm": {
                    "type": [
                      "object"
                    ],
                    "description": "realm permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "realm rights",
                        "properties": {
                          "can_switch_user": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can SU to lower level user"
                          },
                          "manage_node_membership": {
                            "type": [
                              "boolean"
                            ],
                            "description": "accept or delete nodes from the management network"
                          },
                          "manage_accounts": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can create or delete other accounts, users and their settings"
                          },
                          "view_logs": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view administrative logs"
                          },
                          "run_admin_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tasks"
                          },
                          "run_tests": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tests"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "node": {
                    "type": [
                      "object"
                    ],
                    "description": "node permissions",
                    "properties": {
                      "all_realm_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all nodes in the realm",
                        "default": true
                      },
                      "nodes": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "node:50:11",
                          "description": "node id"
                        },
                        "description": "scope permissions to specific nodes "
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "node rights",
                        "properties": {
                          "manage_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure OS devices, iSCSI devices, and system datastores"
                          },
                          "manage_networks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure networks"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manually provision virtual storage services"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove virtual storage services"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "vss": {
                    "type": [
                      "object"
                    ],
                    "description": "vss permissions",
                    "properties": {
                      "all_account_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all virtual storage services in the account",
                        "default": true
                      },
                      "vsses": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "vss:87:8",
                          "description": "virtual storage service id"
                        },
                        "description": "limit scope to specified vsses"
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "vss rights",
                        "properties": {
                          "dismiss_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "dismiss tasks"
                          },
                          "update_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "update vss configuration"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove vss"
                          },
                          "set_vss_quota": {
                            "type": [
                              "boolean"
                            ],
                            "description": "set vss quota"
                          },
                          "manage_internal_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage internal disks"
                          },
                          "manage_external_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage external disks"
                          },
                          "manage_removable_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage removable disks"
                          },
                          "manage_disk_cryptography": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk cryptography"
                          },
                          "remove_locked_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove locked disks"
                          },
                          "validate_data_integrity": {
                            "type": [
                              "boolean"
                            ],
                            "description": "validate data integrity"
                          },
                          "manage_targets": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage targets"
                          },
                          "manage_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage profiles"
                          },
                          "manage_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage secure access tokens"
                          },
                          "manage_rules": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage rules"
                          },
                          "replicate_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate disks"
                          },
                          "synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "synchronize disks"
                          },
                          "format_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "format disks"
                          },
                          "resize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "resize disks"
                          },
                          "manage_snapshots": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage snapshots"
                          },
                          "backup_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "backup disks"
                          },
                          "replicate_and_synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate and synchronize disks (DEPRECATED)"
                          },
                          "compress_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "compress disks"
                          },
                          "manage_disk_compression": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk "
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "user": {
                    "type": [
                      "object"
                    ],
                    "description": "user permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "user rights",
                        "properties": {
                          "manage_users": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete users in an account"
                          },
                          "modify_user_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify user contact info"
                          },
                          "reset_user_password": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset user password"
                          },
                          "reset_user_two_factor": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset two factor authentication"
                          },
                          "manage_authorizations": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete persistent authorizations"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "account": {
                    "type": [
                      "object"
                    ],
                    "description": "account permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "account rights",
                        "properties": {
                          "modify_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify account contact settings"
                          },
                          "view_events": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view events"
                          },
                          "view_statistics": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view statistics"
                          },
                          "manage_global_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global profiles"
                          },
                          "manage_global_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global secure access tokens"
                          },
                          "query_catalog": {
                            "type": [
                              "boolean"
                            ],
                            "description": "query product catalog"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "provision vss from catalog"
                          },
                          "manage_obj_stores": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage obj stores"
                          },
                          "read_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "read from object storage"
                          },
                          "write_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "write to object storage"
                          },
                          "delete_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "delete from object storage"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              },
              "xref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference"
              },
              "enforce_two_factor": {
                "type": [
                  "boolean"
                ],
                "default": false,
                "description": "enforce user two-factor auth (if configured)"
              }
            },
            "description": "authz create request arguments",
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "authz_create"
        },
        {
          "description": "Remove a persistent API authorization token.",
          "href": "/authorization/{(%23%2Fdefinitions%2Fauthz%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "authz_remove"
        },
        {
          "description": "Change a persistent API authorization token.",
          "href": "/authorization/{(%23%2Fdefinitions%2Fauthz%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "enabled": {
                "type": [
                  "boolean"
                ],
                "default": true,
                "description": "authorization is enabled"
              },
              "notes": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned notes"
              },
              "scope": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "authorization scope (null maps to referenced user permissions)",
                "default": null
              },
              "permissions": {
                "type": [
                  "object"
                ],
                "description": "update authorization scope using internal permissions structure",
                "properties": {
                  "realm": {
                    "type": [
                      "object"
                    ],
                    "description": "realm permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "realm rights",
                        "properties": {
                          "can_switch_user": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can SU to lower level user"
                          },
                          "manage_node_membership": {
                            "type": [
                              "boolean"
                            ],
                            "description": "accept or delete nodes from the management network"
                          },
                          "manage_accounts": {
                            "type": [
                              "boolean"
                            ],
                            "description": "can create or delete other accounts, users and their settings"
                          },
                          "view_logs": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view administrative logs"
                          },
                          "run_admin_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tasks"
                          },
                          "run_tests": {
                            "type": [
                              "boolean"
                            ],
                            "description": "run realm administrative tests"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "node": {
                    "type": [
                      "object"
                    ],
                    "description": "node permissions",
                    "properties": {
                      "all_realm_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all nodes in the realm",
                        "default": true
                      },
                      "nodes": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "node:69:15",
                          "description": "node id"
                        },
                        "description": "scope permissions to specific nodes "
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "node rights",
                        "properties": {
                          "manage_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure OS devices, iSCSI devices, and system datastores"
                          },
                          "manage_networks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "configure networks"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manually provision virtual storage services"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove virtual storage services"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "vss": {
                    "type": [
                      "object"
                    ],
                    "description": "vss permissions",
                    "properties": {
                      "all_account_scope": {
                        "type": [
                          "boolean"
                        ],
                        "description": "apply to all virtual storage services in the account",
                        "default": true
                      },
                      "vsses": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "example": "vss:85:6",
                          "description": "virtual storage service id"
                        },
                        "description": "limit scope to specified vsses"
                      },
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "vss rights",
                        "properties": {
                          "dismiss_tasks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "dismiss tasks"
                          },
                          "update_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "update vss configuration"
                          },
                          "remove_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove vss"
                          },
                          "set_vss_quota": {
                            "type": [
                              "boolean"
                            ],
                            "description": "set vss quota"
                          },
                          "manage_internal_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage internal disks"
                          },
                          "manage_external_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage external disks"
                          },
                          "manage_removable_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage removable disks"
                          },
                          "manage_disk_cryptography": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk cryptography"
                          },
                          "remove_locked_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "remove locked disks"
                          },
                          "validate_data_integrity": {
                            "type": [
                              "boolean"
                            ],
                            "description": "validate data integrity"
                          },
                          "manage_targets": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage targets"
                          },
                          "manage_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage profiles"
                          },
                          "manage_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage secure access tokens"
                          },
                          "manage_rules": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage rules"
                          },
                          "replicate_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate disks"
                          },
                          "synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "synchronize disks"
                          },
                          "format_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "format disks"
                          },
                          "resize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "resize disks"
                          },
                          "manage_snapshots": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage snapshots"
                          },
                          "backup_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "backup disks"
                          },
                          "replicate_and_synchronize_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "replicate and synchronize disks (DEPRECATED)"
                          },
                          "compress_disks": {
                            "type": [
                              "boolean"
                            ],
                            "description": "compress disks"
                          },
                          "manage_disk_compression": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage disk "
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "user": {
                    "type": [
                      "object"
                    ],
                    "description": "user permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "user rights",
                        "properties": {
                          "manage_users": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete users in an account"
                          },
                          "modify_user_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify user contact info"
                          },
                          "reset_user_password": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset user password"
                          },
                          "reset_user_two_factor": {
                            "type": [
                              "boolean"
                            ],
                            "description": "reset two factor authentication"
                          },
                          "manage_authorizations": {
                            "type": [
                              "boolean"
                            ],
                            "description": "create or delete persistent authorizations"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "account": {
                    "type": [
                      "object"
                    ],
                    "description": "account permissions",
                    "properties": {
                      "rights": {
                        "type": [
                          "object"
                        ],
                        "description": "account rights",
                        "properties": {
                          "modify_contact_settings": {
                            "type": [
                              "boolean"
                            ],
                            "description": "modify account contact settings"
                          },
                          "view_events": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view events"
                          },
                          "view_statistics": {
                            "type": [
                              "boolean"
                            ],
                            "description": "view statistics"
                          },
                          "manage_global_profiles": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global profiles"
                          },
                          "manage_global_secure_access_tokens": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage global secure access tokens"
                          },
                          "query_catalog": {
                            "type": [
                              "boolean"
                            ],
                            "description": "query product catalog"
                          },
                          "provision_vss": {
                            "type": [
                              "boolean"
                            ],
                            "description": "provision vss from catalog"
                          },
                          "manage_obj_stores": {
                            "type": [
                              "boolean"
                            ],
                            "description": "manage obj stores"
                          },
                          "read_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "read from object storage"
                          },
                          "write_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "write to object storage"
                          },
                          "delete_object_storage": {
                            "type": [
                              "boolean"
                            ],
                            "description": "delete from object storage"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              },
              "enforce_two_factor": {
                "type": [
                  "boolean"
                ],
                "default": false,
                "description": "enforce user two-factor auth (if configured)"
              }
            },
            "description": "authz update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "authz_update"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/authz/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/authz/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/authz/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/authz/definitions/mtime"
        },
        "serial": {
          "$ref": "#/definitions/authz/definitions/serial"
        },
        "xref": {
          "$ref": "#/definitions/authz/definitions/xref"
        },
        "notes": {
          "$ref": "#/definitions/authz/definitions/notes"
        },
        "account_id": {
          "$ref": "#/definitions/authz/definitions/account_id"
        },
        "user_id": {
          "$ref": "#/definitions/authz/definitions/user_id"
        },
        "fingerprint": {
          "$ref": "#/definitions/authz/definitions/fingerprint"
        },
        "enabled": {
          "$ref": "#/definitions/authz/definitions/enabled"
        },
        "app_id": {
          "$ref": "#/definitions/authz/definitions/app_id"
        },
        "scope": {
          "$ref": "#/definitions/authz/definitions/scope"
        },
        "access_type": {
          "$ref": "#/definitions/authz/definitions/access_type"
        },
        "lifetime": {
          "$ref": "#/definitions/authz/definitions/lifetime"
        },
        "restrict": {
          "$ref": "#/definitions/authz/definitions/restrict"
        },
        "enforce_two_factor": {
          "$ref": "#/definitions/authz/definitions/enforce_two_factor"
        },
        "created_at": {
          "$ref": "#/definitions/authz/definitions/created_at"
        },
        "updated_at": {
          "$ref": "#/definitions/authz/definitions/updated_at"
        },
        "expires_in": {
          "$ref": "#/definitions/authz/definitions/expires_in"
        },
        "access_token_digest": {
          "$ref": "#/definitions/authz/definitions/access_token_digest"
        },
        "access_token_suffix": {
          "$ref": "#/definitions/authz/definitions/access_token_suffix"
        },
        "access_token_type": {
          "$ref": "#/definitions/authz/definitions/access_token_type"
        },
        "refresh_token_digest": {
          "$ref": "#/definitions/authz/definitions/refresh_token_digest"
        },
        "permissions": {
          "$ref": "#/definitions/authz/definitions/permissions"
        },
        "effective_scope": {
          "$ref": "#/definitions/authz/definitions/effective_scope"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "serial",
        "notes",
        "account_id",
        "user_id",
        "lifetime",
        "restrict",
        "created_at",
        "updated_at",
        "expires_in",
        "access_token_digest",
        "access_token_suffix",
        "access_token_type",
        "refresh_token_digest",
        "permissions",
        "effective_scope"
      ],
      "additionalProperties": false
    },
    "node": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Node",
      "description": "A Blockbridge Node is an instance of Blockbridge node software running on physical or virtual hardware.  It can be a management node, a storage node, or a converged node. \n* A **management node** provides configuration, monitoring, and other administrative capabilities.  The management web application and API clients are terminated at the management node. \n* A **storage node** delivers secure storage services using direct-attached and iSCSI storage. Client iSCSI connections are terminated at a storage node. \n* A **converged node** contains both a management node and a storage node in one system.  For most management purposes (including in the management web application) converged nodes are treated as a distinct management node and storage node.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/node/definitions/id"
            },
            {
              "$ref": "#/definitions/node/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "label": {
          "type": [
            "string"
          ],
          "description": "user assigned label"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "node serial number"
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string for event application to display associated events"
        },
        "install_token": {
          "type": [
            "string"
          ],
          "description": "generated installation token"
        },
        "install_mode": {
          "type": [
            "string"
          ],
          "description": "installation mode"
        },
        "activation_code": {
          "type": [
            "string"
          ],
          "description": "generated activation code"
        },
        "activation_state": {
          "type": [
            "string"
          ],
          "description": "activation state"
        },
        "license": {
          "type": [
            "object"
          ],
          "description": "node license",
          "properties": {
            "type": {
              "type": [
                "string"
              ],
              "enum": [
                "none",
                "development",
                "evaluation",
                "production",
                "subscription"
              ],
              "description": "license type",
              "example": "production"
            },
            "minutes_remaining": {
              "type": [
                "integer"
              ],
              "description": "license minutes remaining"
            },
            "token": {
              "type": [
                "string"
              ],
              "description": "license token"
            }
          },
          "required": [
            "type"
          ],
          "additionalProperties": false
        },
        "registration": {
          "type": [
            "object"
          ],
          "description": "node registration",
          "properties": {
            "allow": {
              "type": [
                "boolean"
              ],
              "description": "allow registrations for this node"
            }
          },
          "required": [
            "allow"
          ],
          "additionalProperties": false
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "node create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "node last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "site_id": {
          "type": [
            "string"
          ],
          "example": "site:34:9",
          "description": "site node is located in"
        },
        "type": {
          "type": [
            "string"
          ],
          "enum": [
            "management",
            "storage",
            "disk"
          ],
          "description": "node type",
          "example": "management"
        },
        "ip": {
          "type": [
            "object",
            "null"
          ],
          "description": "node ip address for management",
          "properties": {
            "pub_addr": {
              "type": [
                "string"
              ],
              "format": "ipv4",
              "description": "public address of service target interface"
            },
            "pub_desc": {
              "type": [
                "string"
              ],
              "description": "public address description"
            },
            "prv_addr": {
              "type": [
                "string"
              ],
              "format": "ipv4",
              "description": "private address of system interface"
            },
            "prv_desc": {
              "type": [
                "string"
              ],
              "description": "private address description"
            },
            "pub_addr_user_set": {
              "type": [
                "boolean"
              ],
              "description": "public address set by user"
            },
            "prv_addr_user_set": {
              "type": [
                "boolean"
              ],
              "description": "private address set by user"
            }
          },
          "required": [
            "pub_addr",
            "prv_addr"
          ],
          "additionalProperties": false
        },
        "infra": {
          "type": [
            "object"
          ],
          "description": "infrastructure information",
          "properties": {
            "last_archived": {
              "type": [
                "integer",
                "null"
              ],
              "description": "time infrastructure configuration was last archived",
              "minimum": 0,
              "example": 1443200456094
            }
          },
          "required": [
            "last_archived"
          ],
          "additionalProperties": false
        },
        "management": {
          "type": [
            "object"
          ],
          "description": "node management parameters (valid for management node only)",
          "properties": {
            "ca": {
              "type": [
                "string"
              ],
              "enum": [
                "none",
                "embedded"
              ],
              "description": "no documentation",
              "example": "none"
            },
            "hostname": {
              "type": [
                "string"
              ],
              "description": "no documentation"
            }
          },
          "required": [
            "ca",
            "hostname"
          ],
          "additionalProperties": false,
          "dependencies": {
            "hostname": {
              "properties": {
                "ca": {
                  "enum": [
                    "embedded"
                  ]
                }
              }
            }
          }
        },
        "params": {
          "type": [
            "object"
          ],
          "description": "node configuration parameters (valid for management node only)",
          "properties": {
            "scheduling_algorithms": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "scheduling algorithm",
                "properties": {
                  "type": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "ideal_usage"
                    ],
                    "description": "scheduling algorithm type",
                    "example": "ideal_usage"
                  },
                  "label": {
                    "type": [
                      "string",
                      "object",
                      "array",
                      "null"
                    ],
                    "description": "no documentation",
                    "properties": {
                    }
                  },
                  "ideal_usage_pct": {
                    "type": [
                      "string",
                      "object",
                      "array",
                      "null"
                    ],
                    "description": "no documentation",
                    "properties": {
                    }
                  },
                  "min_usage_pct": {
                    "type": [
                      "string",
                      "object",
                      "array",
                      "null"
                    ],
                    "description": "no documentation",
                    "properties": {
                    }
                  },
                  "capacity_weight_pct": {
                    "type": [
                      "string",
                      "object",
                      "array",
                      "null"
                    ],
                    "description": "no documentation",
                    "properties": {
                    }
                  },
                  "iops_weight_pct": {
                    "type": [
                      "string",
                      "object",
                      "array",
                      "null"
                    ],
                    "description": "no documentation",
                    "properties": {
                    }
                  },
                  "default": {
                    "type": [
                      "string",
                      "object",
                      "array",
                      "null"
                    ],
                    "description": "no documentation",
                    "properties": {
                    }
                  }
                },
                "required": [
                  "type",
                  "label",
                  "ideal_usage_pct",
                  "min_usage_pct",
                  "capacity_weight_pct",
                  "iops_weight_pct",
                  "default"
                ],
                "additionalProperties": false
              },
              "description": "scheduling algorithms for storage provisioning"
            },
            "service_templates": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "service_template",
                "properties": {
                  "type": {
                    "type": [
                      "string"
                    ],
                    "description": "service type name"
                  },
                  "description": {
                    "type": [
                      "string"
                    ],
                    "description": "service type description"
                  },
                  "default": {
                    "type": [
                      "boolean"
                    ],
                    "description": "default template"
                  },
                  "tags": {
                    "type": [
                      "object"
                    ],
                    "description": "tags appended to user's query",
                    "properties": {
                      "include": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "include value"
                        },
                        "description": "include array"
                      },
                      "exclude": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "exclude value"
                        },
                        "description": "exclude array"
                      }
                    },
                    "additionalProperties": false
                  },
                  "size": {
                    "type": [
                      "object"
                    ],
                    "description": "size",
                    "properties": {
                      "reserve_min": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "minimum size reserve"
                      },
                      "reserve_max": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "maximum size reserve"
                      },
                      "limit_percent": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "minimum": 100,
                        "description": "Set the hard limit on storage consumption to a percentage of the size reserved.  Must be at least 100% of the reserved size.  If null, it's unlimited."
                      }
                    },
                    "required": [
                      "reserve_min",
                      "reserve_max",
                      "limit_percent"
                    ],
                    "additionalProperties": false
                  },
                  "iops": {
                    "type": [
                      "object"
                    ],
                    "description": "iops",
                    "properties": {
                      "ratio": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "baseline IOPS ratio, specified as a ratio of IOPS to reserved size (in IOPS/GiB)"
                      },
                      "burst": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "IOPS burst limit (in IOPS)"
                      },
                      "burst_credit": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "maximum burst credits (in IOPS credits); not supported with provisioned IOPS"
                      },
                      "min": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "minimum IOPS"
                      },
                      "max": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "maximum IOPS"
                      }
                    },
                    "required": [
                      "ratio",
                      "burst",
                      "burst_credit",
                      "min",
                      "max"
                    ],
                    "additionalProperties": false
                  },
                  "piops": {
                    "type": [
                      "object"
                    ],
                    "description": "provisioned iops",
                    "properties": {
                      "type": {
                        "type": [
                          "string"
                        ],
                        "example": "disabled",
                        "enum": [
                          "disabled",
                          "admin-fixed",
                          "capacity-scaled",
                          "user-specified"
                        ],
                        "description": "how provisioned IOPS are specified"
                      },
                      "value": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "minimum": 1,
                        "description": "fixed IOPS value"
                      },
                      "ratio": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "baseline provisioned IOPS ratio, specified as a ratio of IOPS to reserved size (in IOPS/GiB)"
                      },
                      "min": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "minimum provisioned IOPS"
                      },
                      "max": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "maximum provisioned IOPS"
                      }
                    },
                    "required": [
                      "type",
                      "value",
                      "ratio",
                      "min",
                      "max"
                    ],
                    "additionalProperties": false
                  }
                },
                "required": [
                  "type",
                  "description",
                  "default",
                  "size",
                  "iops",
                  "piops"
                ],
                "additionalProperties": false
              },
              "description": "service templates array"
            },
            "account_templates": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "account template",
                "properties": {
                  "provisioning": {
                    "type": [
                      "object"
                    ],
                    "description": "account provisioning",
                    "properties": {
                      "size_reserve_max": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "example": 1073741824,
                        "description": "maximum size reserve of a single virtual storage service"
                      },
                      "iops_reserve_max": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "maximum iops reserve of a single virtual storage service"
                      },
                      "tags_include": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "tag"
                        },
                        "description": "tags included"
                      },
                      "tags_exclude": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "tag"
                        },
                        "description": "tags excluded"
                      },
                      "tags_permit": {
                        "type": [
                          "array",
                          "null"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "tag"
                        },
                        "description": "tags permitted"
                      }
                    },
                    "required": [
                      "size_reserve_max",
                      "iops_reserve_max",
                      "tags_include",
                      "tags_exclude",
                      "tags_permit"
                    ],
                    "additionalProperties": false
                  },
                  "limits": {
                    "type": [
                      "object"
                    ],
                    "description": "account limits",
                    "properties": {
                      "vss_num": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "number of virtual storage services"
                      },
                      "size_reserve_total": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "example": 1073741824,
                        "description": "maximum size of storage"
                      }
                    },
                    "required": [
                      "vss_num",
                      "size_reserve_total"
                    ],
                    "additionalProperties": false
                  },
                  "permissions": {
                    "type": [
                      "object"
                    ],
                    "description": "user permissions",
                    "properties": {
                      "realm": {
                        "type": [
                          "object"
                        ],
                        "description": "realm permissions",
                        "properties": {
                          "rights": {
                            "type": [
                              "object"
                            ],
                            "description": "realm rights",
                            "properties": {
                              "can_switch_user": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "can SU to lower level user"
                              },
                              "manage_node_membership": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "accept or delete nodes from the management network"
                              },
                              "manage_accounts": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "can create or delete other accounts, users and their settings"
                              },
                              "view_logs": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "view administrative logs"
                              },
                              "run_admin_tasks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "run realm administrative tasks"
                              },
                              "run_tests": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "run realm administrative tests"
                              }
                            },
                            "additionalProperties": false
                          }
                        },
                        "additionalProperties": false
                      },
                      "node": {
                        "type": [
                          "object"
                        ],
                        "description": "node permissions",
                        "properties": {
                          "all_realm_scope": {
                            "type": [
                              "boolean"
                            ],
                            "description": "apply to all nodes in the realm"
                          },
                          "nodes": {
                            "type": [
                              "array"
                            ],
                            "items": {
                              "type": [
                                "string"
                              ],
                              "example": "node:20:9",
                              "description": "node id"
                            },
                            "description": "scope permissions to specific nodes "
                          },
                          "rights": {
                            "type": [
                              "object"
                            ],
                            "description": "node rights",
                            "properties": {
                              "manage_storage": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "configure OS devices, iSCSI devices, and system datastores"
                              },
                              "manage_networks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "configure networks"
                              },
                              "provision_vss": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manually provision virtual storage services"
                              },
                              "remove_vss": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "remove virtual storage services"
                              }
                            },
                            "additionalProperties": false
                          }
                        },
                        "additionalProperties": false
                      },
                      "vss": {
                        "type": [
                          "object"
                        ],
                        "description": "vss permissions",
                        "properties": {
                          "all_account_scope": {
                            "type": [
                              "boolean"
                            ],
                            "description": "apply to all virtual storage services in the account"
                          },
                          "vsses": {
                            "type": [
                              "array"
                            ],
                            "items": {
                              "type": [
                                "string"
                              ],
                              "example": "vss:82:14",
                              "description": "virtual storage service id"
                            },
                            "description": "limit scope to specified vsses"
                          },
                          "rights": {
                            "type": [
                              "object"
                            ],
                            "description": "vss rights",
                            "properties": {
                              "dismiss_tasks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "dismiss tasks"
                              },
                              "update_vss": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "update vss configuration"
                              },
                              "remove_vss": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "remove vss"
                              },
                              "set_vss_quota": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "set vss quota"
                              },
                              "manage_internal_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage internal disks"
                              },
                              "manage_external_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage external disks"
                              },
                              "manage_removable_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage removable disks"
                              },
                              "manage_disk_cryptography": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage disk cryptography"
                              },
                              "remove_locked_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "remove locked disks"
                              },
                              "replicate_and_synchronize_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "replicate and synchronize disks"
                              },
                              "validate_data_integrity": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "validate data integrity"
                              },
                              "manage_targets": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage targets"
                              },
                              "manage_profiles": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage profiles"
                              },
                              "manage_secure_access_tokens": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage secure access tokens"
                              },
                              "manage_rules": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage rules"
                              },
                              "replicate_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "replicate disks"
                              },
                              "synchronize_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "synchronize disks"
                              },
                              "format_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "format disks"
                              },
                              "resize_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "resize disks"
                              },
                              "backup_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "backup disks"
                              },
                              "manage_snapshots": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage snapshots"
                              },
                              "compress_disks": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "compress disks"
                              },
                              "manage_disk_compression": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage disk "
                              }
                            },
                            "additionalProperties": false
                          }
                        },
                        "additionalProperties": false
                      },
                      "user": {
                        "type": [
                          "object"
                        ],
                        "description": "user permissions",
                        "properties": {
                          "rights": {
                            "type": [
                              "object"
                            ],
                            "description": "user rights",
                            "properties": {
                              "manage_users": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "create or delete users in an account"
                              },
                              "modify_user_contact_settings": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "modify user contact info"
                              },
                              "reset_user_password": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "reset user password"
                              },
                              "reset_user_two_factor": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "reset two factor authentication"
                              },
                              "manage_authorizations": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "create or delete persistent authorizations"
                              }
                            },
                            "additionalProperties": false
                          }
                        },
                        "additionalProperties": false
                      },
                      "account": {
                        "type": [
                          "object"
                        ],
                        "description": "account permissions",
                        "properties": {
                          "rights": {
                            "type": [
                              "object"
                            ],
                            "description": "account rights",
                            "properties": {
                              "modify_contact_settings": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "modify account contact settings"
                              },
                              "view_events": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "view events"
                              },
                              "view_statistics": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "view statistics"
                              },
                              "manage_global_profiles": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage global profiles"
                              },
                              "manage_global_secure_access_tokens": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage global secure access tokens"
                              },
                              "query_catalog": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "query product catalog"
                              },
                              "provision_vss": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "provision vss from catalog"
                              },
                              "manage_obj_stores": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "manage object stores"
                              },
                              "read_object_storage": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "read from object storage"
                              },
                              "write_object_storage": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "write to object storage"
                              },
                              "delete_object_storage": {
                                "type": [
                                  "boolean"
                                ],
                                "description": "delete from object storage"
                              }
                            },
                            "additionalProperties": false
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "type": {
                    "type": [
                      "string"
                    ],
                    "description": "account template name"
                  },
                  "description": {
                    "type": [
                      "string"
                    ],
                    "description": "account template description"
                  },
                  "default": {
                    "type": [
                      "boolean"
                    ],
                    "description": "default template"
                  }
                },
                "required": [
                  "type",
                  "description",
                  "default",
                  "provisioning",
                  "limits"
                ],
                "additionalProperties": false
              },
              "description": "account templates array"
            },
            "scheduling_workloads": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "scheduling workload",
                "properties": {
                  "workload": {
                    "type": [
                      "string"
                    ],
                    "example": "normal_iops",
                    "enum": [
                      "lower_iops",
                      "normal_iops",
                      "higher_iops"
                    ],
                    "description": "workload"
                  },
                  "iops": {
                    "type": [
                      "integer"
                    ],
                    "description": "workload IOPS"
                  }
                },
                "required": [
                  "workload",
                  "iops"
                ],
                "additionalProperties": false
              },
              "description": "scheduling workloads"
            }
          },
          "required": [
            "scheduling_algorithms",
            "service_templates",
            "account_templates"
          ],
          "additionalProperties": false
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "node status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "offline"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "pending"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "isotime": {
          "type": [
            "string",
            "null"
          ],
          "format": "date-time",
          "description": "local time on node"
        },
        "humantime": {
          "type": [
            "string",
            "null"
          ],
          "description": "human-readable time on node"
        },
        "build_version": {
          "type": [
            "string",
            "null"
          ],
          "description": "version of software running on node"
        },
        "build_time": {
          "type": [
            "string",
            "null"
          ],
          "description": "time and date that node software was built"
        },
        "version": {
          "type": [
            "object",
            "null"
          ],
          "description": "build version",
          "properties": {
            "hash": {
              "type": [
                "string"
              ],
              "description": "build hash"
            },
            "minor": {
              "type": [
                "integer"
              ],
              "description": "build minor version"
            },
            "major": {
              "type": [
                "integer"
              ],
              "description": "build major version"
            },
            "timestamp": {
              "type": [
                "integer"
              ],
              "description": "build timestamp"
            },
            "patch": {
              "type": [
                "integer"
              ],
              "description": "build patch version"
            },
            "tag": {
              "type": [
                "string"
              ],
              "description": "build tag"
            },
            "release": {
              "type": [
                "string"
              ],
              "description": "build release"
            }
          },
          "required": [
            "hash",
            "minor",
            "major",
            "release",
            "timestamp",
            "patch",
            "tag"
          ],
          "additionalProperties": false
        },
        "cpu_processors": {
          "type": [
            "integer",
            "null"
          ],
          "description": "number of processors on node"
        },
        "cpu_model": {
          "type": [
            "string",
            "null"
          ],
          "description": "vendor and model of first CPU on node"
        },
        "mem_total": {
          "type": [
            "integer",
            "null"
          ],
          "description": "system memory on node",
          "example": 1073741824
        },
        "sn": {
          "type": [
            "object"
          ],
          "description": "parameters related to storage nodes (valid for storage node only)",
          "properties": {
            "usage": {
              "type": [
                "object"
              ],
              "description": "node resource utilization",
              "properties": {
                "vdisk_int": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "internal virtual disks on node"
                },
                "rules": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "rules on node"
                },
                "vss": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "virtual storage services on node"
                },
                "targets": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "targets on node"
                },
                "removable": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "removable virtual disks on node"
                },
                "sds": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "datastores on node"
                },
                "clones": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "cloned disks on node"
                },
                "iscsi_dev": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "iSCSI devices on node"
                },
                "snapshots": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "snapshots on node"
                },
                "repl_slaves": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "replication slave virtual disks on node"
                },
                "vdisk_int_cap_mb": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "sum of internal virtual disk capacities in megabytes"
                },
                "conn_secure": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "secure iSCSI session connections to node targets"
                },
                "conn_insecure": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "insecure iSCSI session connections to node targets"
                },
                "vdisk_ext": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "external virtual disks on node"
                },
                "os_dev": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "OS devices on node"
                },
                "sessions": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "iSCSI sessions connected to node targets"
                },
                "accounts": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "accounts on node"
                },
                "profiles": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "initiator profiles on node"
                },
                "repl_masters": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "replication master virtual disks on node"
                },
                "vss_max": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "maximum number of virtual storage services on the node"
                },
                "session_max": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "maximum number of iSCSI sessions on the node"
                },
                "target_max": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "maximum number of iSCSI targets on the node"
                },
                "vdisk_max": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "maximum number of virtual disks on the node"
                },
                "os_dev_max": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "maximum number of configurable os devices on the node"
                },
                "profile_max": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "maximum number of initiator profiles on the node"
                },
                "rule_max": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "maximum number of rules on the node"
                },
                "dev": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "iSCSI and OS devices on node"
                },
                "vdisk": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "virtual disks on node"
                },
                "conn": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "iSCSI session connections to node targets"
                }
              },
              "additionalProperties": false
            },
            "cplx_num": {
              "type": [
                "integer",
                "null"
              ],
              "description": "number of processor complexes"
            },
            "cplx": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "runtime params reported by each sp complex",
                "properties": {
                  "id": {
                    "type": [
                      "string"
                    ],
                    "description": "processor complex id"
                  },
                  "status": {
                    "type": [
                      "object"
                    ],
                    "description": "processor complex status/health",
                    "properties": {
                      "indicator": {
                        "type": [
                          "string"
                        ],
                        "example": "degraded",
                        "enum": [
                          "online",
                          "degraded",
                          "offline",
                          "na"
                        ],
                        "description": "status indicator"
                      },
                      "value": {
                        "type": [
                          "string"
                        ],
                        "example": "online",
                        "enum": [
                          "online",
                          "degraded",
                          "offline",
                          "pending",
                          "payment"
                        ],
                        "description": "status value"
                      },
                      "detail": {
                        "type": [
                          "string",
                          "null"
                        ],
                        "description": "status detail"
                      }
                    },
                    "additionalProperties": false
                  },
                  "data_cache_size": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "example": 1073741824,
                    "description": "size of processor complex data cache"
                  },
                  "meta_cache_size_limit": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "example": 1073741824,
                    "description": "limit on total memory that may be reserved for metadata caching"
                  },
                  "max_data_log_size": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "example": 1073741824,
                    "description": "maximum data log size that may be created"
                  },
                  "max_meta_cache_size": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "example": 1073741824,
                    "description": "maximum metadata cache size that may be specified"
                  },
                  "available": {
                    "type": [
                      "boolean"
                    ],
                    "description": "available for datastore placement"
                  },
                  "label": {
                    "type": [
                      "string"
                    ],
                    "description": "customer-friendly textual label"
                  }
                },
                "additionalProperties": false
              },
              "description": "no documentation"
            }
          },
          "additionalProperties": false
        },
        "restore": {
          "type": [
            "object"
          ],
          "description": "node restore status",
          "properties": {
            "start_time": {
              "type": [
                "integer",
                "null"
              ],
              "description": "node restore start time",
              "minimum": 0,
              "example": 1443200456094
            },
            "end_time": {
              "type": [
                "integer",
                "null"
              ],
              "description": "node restore end time (success or failure)",
              "minimum": 0,
              "example": 1443200456094
            },
            "state": {
              "type": [
                "string",
                "null"
              ],
              "enum": [
                "starting",
                "running",
                "success",
                "failed"
              ],
              "description": "node restore job state",
              "example": "success"
            },
            "errors": {
              "type": [
                "integer",
                "null"
              ],
              "description": "count of errors during node restore, see event log for details"
            },
            "phase": {
              "type": [
                "string",
                "null"
              ],
              "description": "description of current node restore phase"
            },
            "failure": {
              "type": [
                "string",
                "null"
              ],
              "description": "on node restore failure, description of reason"
            }
          },
          "required": [
            "start_time",
            "end_time",
            "state",
            "errors",
            "phase",
            "failure"
          ],
          "additionalProperties": false
        },
        "cluster": {
          "type": [
            "object"
          ],
          "description": "cluster status",
          "properties": {
            "reports": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "cluster member report",
                "properties": {
                  "id": {
                    "type": [
                      "string"
                    ],
                    "description": "name of cluster member that generated this report"
                  },
                  "members": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "cluster member",
                      "properties": {
                        "active": {
                          "type": [
                            "boolean",
                            "null"
                          ],
                          "description": "cluster member is actively hosting services"
                        },
                        "cluster_ip": {
                          "type": [
                            "string",
                            "null"
                          ],
                          "format": "ipv4",
                          "description": "cluster network address of member"
                        },
                        "role": {
                          "type": [
                            "string",
                            "null"
                          ],
                          "enum": [
                            "active",
                            "passive",
                            "vote"
                          ],
                          "description": "cluster member role",
                          "example": "active"
                        },
                        "failover": {
                          "type": [
                            "boolean",
                            "null"
                          ],
                          "description": "this cluster member is passive and ready for accept failover"
                        },
                        "status": {
                          "type": [
                            "object"
                          ],
                          "description": "computed cluster member health",
                          "properties": {
                            "indicator": {
                              "type": [
                                "string"
                              ],
                              "enum": [
                                "online",
                                "degraded",
                                "offline",
                                "na"
                              ],
                              "description": "status indicator",
                              "example": "offline"
                            },
                            "value": {
                              "type": [
                                "string"
                              ],
                              "enum": [
                                "online",
                                "degraded",
                                "offline",
                                "pending",
                                "payment"
                              ],
                              "description": "status value",
                              "example": "degraded"
                            },
                            "detail": {
                              "type": [
                                "string",
                                "null"
                              ],
                              "description": "status detail"
                            }
                          },
                          "required": [
                            "indicator",
                            "value",
                            "detail"
                          ],
                          "additionalProperties": false
                        },
                        "status_ip": {
                          "type": [
                            "string",
                            "null"
                          ],
                          "format": "ipv4",
                          "description": "address of cluster member from which it reports status"
                        },
                        "id": {
                          "type": [
                            "string"
                          ],
                          "description": "cluster member name"
                        },
                        "state": {
                          "type": [
                            "string",
                            "null"
                          ],
                          "enum": [
                            "dirty",
                            "standby",
                            "maintenance",
                            "clean",
                            "offline"
                          ],
                          "description": "cluster member state",
                          "example": "maintenance"
                        },
                        "online": {
                          "type": [
                            "boolean",
                            "null"
                          ],
                          "description": "cluster member is online"
                        }
                      },
                      "required": [
                        "active",
                        "cluster_ip",
                        "role",
                        "failover",
                        "status",
                        "status_ip",
                        "id",
                        "state",
                        "online"
                      ],
                      "additionalProperties": false
                    },
                    "description": "array cluster members"
                  },
                  "failover": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "enum": [
                      "available",
                      "unavailable"
                    ],
                    "description": "cluster member failover capability",
                    "example": "available"
                  },
                  "status": {
                    "type": [
                      "object"
                    ],
                    "description": "computed cluster memeber health",
                    "properties": {
                      "indicator": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "online",
                          "degraded",
                          "offline",
                          "na"
                        ],
                        "description": "status indicator",
                        "example": "degraded"
                      },
                      "value": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "online",
                          "degraded",
                          "offline",
                          "pending",
                          "payment"
                        ],
                        "description": "status value",
                        "example": "payment"
                      },
                      "detail": {
                        "type": [
                          "string",
                          "null"
                        ],
                        "description": "status detail"
                      }
                    },
                    "required": [
                      "indicator",
                      "value",
                      "detail"
                    ],
                    "additionalProperties": false
                  }
                },
                "required": [
                  "id",
                  "members",
                  "failover",
                  "status"
                ],
                "additionalProperties": false
              },
              "description": "array of cluster state reported by each cluster member"
            },
            "members": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "cluster member",
                "properties": {
                  "active": {
                    "type": [
                      "boolean",
                      "null"
                    ],
                    "description": "cluster member is actively hosting services"
                  },
                  "cluster_ip": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "format": "ipv4",
                    "description": "cluster network address of member"
                  },
                  "role": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "enum": [
                      "active",
                      "passive",
                      "vote"
                    ],
                    "description": "cluster member role",
                    "example": "vote"
                  },
                  "failover": {
                    "type": [
                      "boolean",
                      "null"
                    ],
                    "description": "this cluster member is passive and ready for accept failover"
                  },
                  "status": {
                    "type": [
                      "object"
                    ],
                    "description": "computed cluster member health",
                    "properties": {
                      "indicator": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "online",
                          "degraded",
                          "offline",
                          "na"
                        ],
                        "description": "status indicator",
                        "example": "online"
                      },
                      "value": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "online",
                          "degraded",
                          "offline",
                          "pending",
                          "payment"
                        ],
                        "description": "status value",
                        "example": "degraded"
                      },
                      "detail": {
                        "type": [
                          "string",
                          "null"
                        ],
                        "description": "status detail"
                      }
                    },
                    "required": [
                      "indicator",
                      "value",
                      "detail"
                    ],
                    "additionalProperties": false
                  },
                  "status_ip": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "format": "ipv4",
                    "description": "address of cluster member from which it reports status"
                  },
                  "id": {
                    "type": [
                      "string"
                    ],
                    "description": "cluster member name"
                  },
                  "state": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "enum": [
                      "dirty",
                      "standby",
                      "maintenance",
                      "clean",
                      "offline"
                    ],
                    "description": "cluster member state",
                    "example": "maintenance"
                  },
                  "online": {
                    "type": [
                      "boolean",
                      "null"
                    ],
                    "description": "cluster member is online"
                  }
                },
                "required": [
                  "active",
                  "cluster_ip",
                  "role",
                  "failover",
                  "status",
                  "status_ip",
                  "id",
                  "state",
                  "online"
                ],
                "additionalProperties": false
              },
              "description": "array of cluster members"
            },
            "failover": {
              "type": [
                "string",
                "null"
              ],
              "enum": [
                "available",
                "unavailable"
              ],
              "description": "cluster failover capability",
              "example": "unavailable"
            },
            "status": {
              "type": [
                "object"
              ],
              "description": "computed cluster health",
              "properties": {
                "indicator": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "online",
                    "degraded",
                    "offline",
                    "na"
                  ],
                  "description": "status indicator",
                  "example": "degraded"
                },
                "value": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "online",
                    "degraded",
                    "offline",
                    "pending",
                    "payment"
                  ],
                  "description": "status value",
                  "example": "payment"
                },
                "detail": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "description": "status detail"
                }
              },
              "required": [
                "indicator",
                "value",
                "detail"
              ],
              "additionalProperties": false
            },
            "is_cluster": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "node is running in cluster mode"
            }
          },
          "required": [
            "reports",
            "members",
            "failover",
            "status",
            "is_cluster"
          ],
          "additionalProperties": false
        },
        "openstack_idp": {
          "type": [
            "object"
          ],
          "description": "identity provider configuration",
          "properties": {
            "id": {
              "type": [
                "string",
                "null"
              ],
              "example": "idp:63:15",
              "description": "no documentation"
            },
            "uuid": {
              "type": [
                "string",
                "null"
              ],
              "format": "uuid",
              "description": "no documentation"
            },
            "label": {
              "type": [
                "string"
              ],
              "description": "no documentation"
            },
            "type": {
              "type": [
                "string"
              ],
              "example": "openstack",
              "enum": [
                "internal",
                "openstack"
              ],
              "description": "identity provider type"
            },
            "enabled": {
              "type": [
                "boolean"
              ],
              "description": "identity provider enabled"
            },
            "url": {
              "type": [
                "string",
                "null"
              ],
              "description": "idP API endpoint"
            },
            "auth": {
              "type": [
                "object"
              ],
              "description": "admin auth configuration",
              "properties": {
                "user": {
                  "type": [
                    "object"
                  ],
                  "description": "specify identity user",
                  "properties": {
                    "id": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "look up user by idp-specific index"
                    },
                    "name": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "look up user by name/login"
                    },
                    "password": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "authenticate using supplied password"
                    }
                  },
                  "required": [
                    "id",
                    "name",
                    "password"
                  ],
                  "additionalProperties": false
                },
                "project": {
                  "type": [
                    "object"
                  ],
                  "description": "specify identity scope (e.g., account, project, tenant)",
                  "properties": {
                    "id": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "look up project by idp-specific index"
                    },
                    "name": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "look up project by name"
                    }
                  },
                  "required": [
                    "id",
                    "name"
                  ],
                  "additionalProperties": false
                },
                "domain": {
                  "type": [
                    "object"
                  ],
                  "description": "specify identity domain, if applicable",
                  "properties": {
                    "id": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "look up domain by idp-specific index"
                    },
                    "name": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "look up domain by name"
                    }
                  },
                  "required": [
                    "id",
                    "name"
                  ],
                  "additionalProperties": false
                }
              },
              "required": [
                "user",
                "project",
                "domain"
              ],
              "additionalProperties": false
            },
            "auto_create_account": {
              "type": [
                "boolean"
              ],
              "description": "automatically create mapped accounts"
            },
            "auto_create_user": {
              "type": [
                "boolean"
              ],
              "description": "automatically create mapped users"
            },
            "accepted_roles": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "string"
                ],
                "description": "no documentation"
              },
              "description": "accepted roles"
            },
            "recheck_interval": {
              "type": [
                "integer",
                "null"
              ],
              "description": "time after which a token must be re-validated (in seconds)"
            }
          },
          "required": [
            "id",
            "uuid",
            "label",
            "type",
            "enabled",
            "url",
            "auth",
            "auto_create_account",
            "auto_create_user",
            "accepted_roles",
            "recheck_interval"
          ],
          "additionalProperties": false
        },
        "eula": {
          "type": [
            "object"
          ],
          "description": "end user license",
          "properties": {
            "accepted": {
              "type": [
                "boolean"
              ],
              "description": "end user license accepted"
            },
            "accepted_at": {
              "type": [
                "integer",
                "null"
              ],
              "example": 1443200456094,
              "minimum": 0,
              "description": "end user license accepted at (time)"
            }
          },
          "required": [
            "accepted",
            "accepted_at"
          ],
          "additionalProperties": false
        },
        "tags": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "tag"
          },
          "description": "object tags"
        },
        "disk_nodes": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "tag"
          },
          "description": "object tags"
        },
        "visibility": {
          "type": [
            "string"
          ],
          "example": "default",
          "enum": [
            "show",
            "hide"
          ],
          "description": "object visibility status"
        },
        "visibility_ctl": {
          "type": [
            "string"
          ],
          "example": "hide",
          "enum": [
            "default",
            "show",
            "hide"
          ],
          "description": "object visibility control"
        },
        "default_visibility": {
          "type": [
            "string"
          ],
          "example": "show",
          "enum": [
            "show",
            "hide"
          ],
          "description": "object visibility default"
        },
        "enabled": {
          "type": [
            "boolean"
          ],
          "description": "node enabled for use"
        },
        "kernel_version": {
          "type": [
            "string",
            "null"
          ],
          "description": "kernel version on node"
        },
        "restricted": {
          "type": [
            "boolean"
          ],
          "description": "node present but restricted from use"
        },
        "converged_sn_id": {
          "type": [
            "string"
          ],
          "description": "id of converged storage node"
        },
        "converged_mn_id": {
          "type": [
            "string"
          ],
          "description": "id of converged management node"
        },
        "openstack_portal_filter": {
          "type": [
            "object",
            "null"
          ],
          "description": "IP filter rule",
          "properties": {
            "ip": {
              "type": [
                "string"
              ],
              "format": "ipv4",
              "description": "IP address"
            },
            "mask": {
              "type": [
                "string"
              ],
              "format": "ipv4",
              "description": "netmask"
            }
          },
          "required": [
            "ip",
            "mask"
          ],
          "additionalProperties": false
        },
        "enclosures": {
          "type": [
            "string",
            "object",
            "array",
            "null"
          ],
          "properties": {
          },
          "description": "enclosure data"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing node.",
          "href": "/node/{(%23%2Fdefinitions%2Fnode%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate nodes.",
          "href": "/node",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a new storage node.",
          "href": "/node",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "UUID to use for created object"
              },
              "label": {
                "type": [
                  "string"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "site_id": {
                "type": [
                  "string"
                ],
                "example": "site:67:13",
                "description": "site id"
              },
              "type": {
                "type": [
                  "string"
                ],
                "enum": [
                  "management",
                  "storage",
                  "disk"
                ],
                "description": "type of processing node",
                "example": "storage"
              },
              "license": {
                "type": [
                  "string"
                ],
                "description": "software license bundle"
              },
              "mode": {
                "type": [
                  "string"
                ],
                "default": "solo",
                "enum": [
                  "solo",
                  "cluster"
                ],
                "description": "node clustering mode"
              },
              "pub_ipaddr": {
                "type": [
                  "string"
                ],
                "format": "ipv4",
                "description": "node public IP address"
              },
              "pub_ipaddr_desc": {
                "type": [
                  "string"
                ],
                "description": "node public IP address description"
              },
              "prv_ipaddr": {
                "type": [
                  "string"
                ],
                "format": "ipv4",
                "description": "node private IP address"
              },
              "prv_ipaddr_desc": {
                "type": [
                  "string"
                ],
                "description": "node private IP address description"
              },
              "maintenance": {
                "type": [
                  "object"
                ],
                "description": "node maintenance mode",
                "properties": {
                  "mode": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "none",
                      "restrict",
                      "rendezvous"
                    ],
                    "description": "maintenance mode",
                    "example": "restrict"
                  },
                  "restrict": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "node maintenance restriction",
                      "properties": {
                        "type": {
                          "type": [
                            "string"
                          ],
                          "enum": [
                            "svc_purchase",
                            "pt_queue_user",
                            "pt_queue_admin",
                            "pt_queue_remote",
                            "pt_rpc_send",
                            "pt_rpc_recv",
                            "pt_sched_user",
                            "pt_sched_admin",
                            "rpc_send",
                            "rpc_recv",
                            "rc_task_add",
                            "rc_task_sched",
                            "rc_msg_send",
                            "rc_msg_recv",
                            "cp_proxy",
                            "slp_send_boot"
                          ],
                          "description": "restriction type",
                          "example": "pt_queue_admin"
                        },
                        "set": {
                          "type": [
                            "boolean"
                          ],
                          "description": "restriction set"
                        }
                      },
                      "additionalProperties": false
                    },
                    "description": "maintenance mode restricted operations"
                  },
                  "reason": {
                    "type": [
                      "string"
                    ],
                    "description": "reason for restriction"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "restrict": {
                    "not": {
                      "properties": {
                        "mode": {
                          "enum": [
                            "none"
                          ]
                        }
                      }
                    }
                  },
                  "reason": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "restrict"
                        ]
                      }
                    }
                  }
                }
              },
              "params": {
                "type": [
                  "object"
                ],
                "description": "node parameters",
                "properties": {
                  "scheduling_algorithms": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "scheduling algorithm",
                      "properties": {
                        "type": {
                          "type": [
                            "string"
                          ],
                          "enum": [
                            "ideal_usage"
                          ],
                          "description": "scheduling algorithm type",
                          "example": "ideal_usage"
                        },
                        "label": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "ideal_usage_pct": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "min_usage_pct": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "capacity_weight_pct": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "iops_weight_pct": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "default": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        }
                      },
                      "additionalProperties": false
                    },
                    "description": "scheduling algorithms for storage provisioning"
                  },
                  "service_templates": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "service_template",
                      "properties": {
                        "type": {
                          "type": [
                            "string"
                          ],
                          "description": "service type name"
                        },
                        "description": {
                          "type": [
                            "string"
                          ],
                          "description": "service type description"
                        },
                        "default": {
                          "type": [
                            "boolean"
                          ],
                          "description": "default template",
                          "default": false
                        },
                        "tags": {
                          "type": [
                            "object"
                          ],
                          "description": "tags appended to user's query",
                          "properties": {
                            "include": {
                              "type": [
                                "array"
                              ],
                              "items": {
                                "type": [
                                  "string"
                                ],
                                "description": "include value"
                              },
                              "description": "include array"
                            },
                            "exclude": {
                              "type": [
                                "array"
                              ],
                              "items": {
                                "type": [
                                  "string"
                                ],
                                "description": "exclude value"
                              },
                              "description": "exclude array"
                            }
                          },
                          "additionalProperties": false
                        },
                        "size": {
                          "type": [
                            "object"
                          ],
                          "description": "size",
                          "properties": {
                            "reserve_min": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "minimum size reserve",
                              "default": null
                            },
                            "reserve_max": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "maximum size reserve",
                              "default": null
                            },
                            "limit_percent": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "minimum": 100,
                              "description": "Set the hard limit on storage consumption to a percentage of the size reserved.  Must be at least 100% of the reserved size.  If null, it's unlimited.",
                              "default": null
                            }
                          },
                          "additionalProperties": false
                        },
                        "iops": {
                          "type": [
                            "object"
                          ],
                          "description": "iops",
                          "properties": {
                            "ratio": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "baseline IOPS ratio, specified as a ratio of IOPS to reserved size (in IOPS/GiB)",
                              "default": null
                            },
                            "burst": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "IOPS burst limit (in IOPS)",
                              "default": null
                            },
                            "burst_credit": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "maximum burst credits (in IOPS credits); not supported with provisioned IOPS",
                              "default": null
                            },
                            "min": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "minimum IOPS",
                              "default": null
                            },
                            "max": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "maximum IOPS",
                              "default": null
                            }
                          },
                          "additionalProperties": false
                        },
                        "piops": {
                          "type": [
                            "object"
                          ],
                          "description": "provisioned iops",
                          "properties": {
                            "type": {
                              "type": [
                                "string"
                              ],
                              "example": "admin-fixed",
                              "enum": [
                                "disabled",
                                "admin-fixed",
                                "capacity-scaled",
                                "user-specified"
                              ],
                              "description": "how provisioned IOPS are specified",
                              "default": "disabled"
                            },
                            "value": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "minimum": 1,
                              "description": "fixed IOPS value",
                              "default": null
                            },
                            "ratio": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "baseline provisioned IOPS ratio, specified as a ratio of IOPS to reserved size (in IOPS/GiB)",
                              "default": null
                            },
                            "min": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "minimum provisioned IOPS",
                              "default": null
                            },
                            "max": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "maximum provisioned IOPS",
                              "default": null
                            }
                          },
                          "additionalProperties": false
                        }
                      },
                      "additionalProperties": false
                    },
                    "description": "service templates array"
                  }
                },
                "additionalProperties": false
              },
              "cert_fingerprint": {
                "type": [
                  "string"
                ],
                "description": "TLS certificate fingerprint"
              },
              "openstack_idp": {
                "type": [
                  "object"
                ],
                "description": "identity provider configuration",
                "properties": {
                  "id": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "default": null,
                    "example": "idp:34:5",
                    "description": "no documentation"
                  },
                  "uuid": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "default": null,
                    "format": "uuid",
                    "description": "no documentation"
                  },
                  "label": {
                    "type": [
                      "string"
                    ],
                    "default": "openstack",
                    "description": "no documentation"
                  },
                  "type": {
                    "type": [
                      "string"
                    ],
                    "default": "openstack",
                    "enum": [
                      "internal",
                      "openstack"
                    ],
                    "description": "identity provider type"
                  },
                  "enabled": {
                    "type": [
                      "boolean"
                    ],
                    "default": false,
                    "description": "identity provider enabled"
                  },
                  "url": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "default": null,
                    "description": "idP API endpoint"
                  },
                  "auth": {
                    "type": [
                      "object"
                    ],
                    "description": "admin auth configuration",
                    "properties": {
                      "user": {
                        "type": [
                          "object"
                        ],
                        "description": "specify identity user",
                        "properties": {
                          "id": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "default": null,
                            "description": "look up user by idp-specific index"
                          },
                          "name": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "default": "admin",
                            "description": "look up user by name/login"
                          },
                          "password": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "default": null,
                            "description": "authenticate using supplied password"
                          }
                        },
                        "additionalProperties": false
                      },
                      "project": {
                        "type": [
                          "object"
                        ],
                        "description": "specify identity scope (e.g., account, project, tenant)",
                        "properties": {
                          "id": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "default": null,
                            "description": "look up project by idp-specific index"
                          },
                          "name": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "default": "admin",
                            "description": "look up project by name"
                          }
                        },
                        "additionalProperties": false
                      },
                      "domain": {
                        "type": [
                          "object"
                        ],
                        "description": "specify identity domain, if applicable",
                        "properties": {
                          "id": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "default": "default",
                            "description": "look up domain by idp-specific index"
                          },
                          "name": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "default": null,
                            "description": "look up domain by name"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "auto_create_account": {
                    "type": [
                      "boolean"
                    ],
                    "default": true,
                    "description": "automatically create mapped accounts"
                  },
                  "auto_create_user": {
                    "type": [
                      "boolean"
                    ],
                    "default": true,
                    "description": "automatically create mapped users"
                  },
                  "accepted_roles": {
                    "type": [
                      "array"
                    ],
                    "default": [

                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "no documentation"
                    },
                    "description": "accepted roles"
                  },
                  "recheck_interval": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "default": 60,
                    "description": "time after which a token must be re-validated (in seconds)"
                  }
                },
                "additionalProperties": false
              },
              "visibility_ctl": {
                "type": [
                  "string"
                ],
                "default": "default",
                "enum": [
                  "default",
                  "show",
                  "hide"
                ],
                "description": "object visibility control"
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              }
            },
            "description": "node create request arguments",
            "required": [
              "site_id",
              "type"
            ],
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "node_create"
        },
        {
          "description": "Remove an existing storage node.",
          "href": "/node/{(%23%2Fdefinitions%2Fnode%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "node_remove"
        },
        {
          "description": "Change the configuration of an existing management node or a storage node.",
          "href": "/node/{(%23%2Fdefinitions%2Fnode%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "label": {
                "type": [
                  "string"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "enabled": {
                "type": [
                  "boolean"
                ],
                "description": "node enabled for use"
              },
              "maintenance": {
                "type": [
                  "object"
                ],
                "description": "node maintenance mode",
                "properties": {
                  "mode": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "none",
                      "restrict",
                      "rendezvous"
                    ],
                    "description": "maintenance mode",
                    "example": "restrict"
                  },
                  "restrict": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "node maintenance restriction",
                      "properties": {
                        "type": {
                          "type": [
                            "string"
                          ],
                          "enum": [
                            "svc_purchase",
                            "pt_queue_user",
                            "pt_queue_admin",
                            "pt_queue_remote",
                            "pt_rpc_send",
                            "pt_rpc_recv",
                            "pt_sched_user",
                            "pt_sched_admin",
                            "rpc_send",
                            "rpc_recv",
                            "rc_task_add",
                            "rc_task_sched",
                            "rc_msg_send",
                            "rc_msg_recv",
                            "cp_proxy",
                            "slp_send_boot"
                          ],
                          "description": "restriction type",
                          "example": "pt_rpc_send"
                        },
                        "set": {
                          "type": [
                            "boolean"
                          ],
                          "description": "restriction set"
                        }
                      },
                      "additionalProperties": false
                    },
                    "description": "maintenance mode restricted operations"
                  },
                  "reason": {
                    "type": [
                      "string"
                    ],
                    "description": "reason for restriction"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "restrict": {
                    "not": {
                      "properties": {
                        "mode": {
                          "enum": [
                            "none"
                          ]
                        }
                      }
                    }
                  },
                  "reason": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "restrict"
                        ]
                      }
                    }
                  }
                }
              },
              "management": {
                "type": [
                  "object"
                ],
                "description": "no documentation",
                "properties": {
                  "ca": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "none",
                      "embedded"
                    ],
                    "description": "no documentation",
                    "example": "none"
                  },
                  "hostname": {
                    "type": [
                      "string"
                    ],
                    "description": "no documentation"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "hostname": {
                    "properties": {
                      "ca": {
                        "enum": [
                          "embedded"
                        ]
                      }
                    }
                  }
                }
              },
              "pub_ipaddr": {
                "type": [
                  "string"
                ],
                "format": "ipv4",
                "description": "node public IP address"
              },
              "pub_ipaddr_desc": {
                "type": [
                  "string"
                ],
                "description": "node public IP address description"
              },
              "prv_ipaddr": {
                "type": [
                  "string"
                ],
                "format": "ipv4",
                "description": "node private IP address"
              },
              "prv_ipaddr_desc": {
                "type": [
                  "string"
                ],
                "description": "node private IP address description"
              },
              "params": {
                "type": [
                  "object"
                ],
                "description": "node parameters",
                "properties": {
                  "scheduling_algorithms": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "scheduling algorithm",
                      "properties": {
                        "type": {
                          "type": [
                            "string"
                          ],
                          "enum": [
                            "ideal_usage"
                          ],
                          "description": "scheduling algorithm type",
                          "example": "ideal_usage"
                        },
                        "label": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "ideal_usage_pct": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "min_usage_pct": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "capacity_weight_pct": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "iops_weight_pct": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        },
                        "default": {
                          "type": [
                            "string",
                            "object",
                            "array",
                            "null"
                          ],
                          "description": "no documentation",
                          "properties": {
                          }
                        }
                      },
                      "additionalProperties": false
                    },
                    "description": "scheduling algorithms for storage provisioning"
                  },
                  "service_templates": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "service_template",
                      "properties": {
                        "type": {
                          "type": [
                            "string"
                          ],
                          "description": "service type name"
                        },
                        "description": {
                          "type": [
                            "string"
                          ],
                          "description": "service type description"
                        },
                        "default": {
                          "type": [
                            "boolean"
                          ],
                          "description": "default template",
                          "default": false
                        },
                        "tags": {
                          "type": [
                            "object"
                          ],
                          "description": "tags appended to user's query",
                          "properties": {
                            "include": {
                              "type": [
                                "array"
                              ],
                              "items": {
                                "type": [
                                  "string"
                                ],
                                "description": "include value"
                              },
                              "description": "include array"
                            },
                            "exclude": {
                              "type": [
                                "array"
                              ],
                              "items": {
                                "type": [
                                  "string"
                                ],
                                "description": "exclude value"
                              },
                              "description": "exclude array"
                            }
                          },
                          "additionalProperties": false
                        },
                        "size": {
                          "type": [
                            "object"
                          ],
                          "description": "size",
                          "properties": {
                            "reserve_min": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "minimum size reserve",
                              "default": null
                            },
                            "reserve_max": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "maximum size reserve",
                              "default": null
                            },
                            "limit_percent": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "minimum": 100,
                              "description": "Set the hard limit on storage consumption to a percentage of the size reserved.  Must be at least 100% of the reserved size.  If null, it's unlimited.",
                              "default": null
                            }
                          },
                          "additionalProperties": false
                        },
                        "iops": {
                          "type": [
                            "object"
                          ],
                          "description": "iops",
                          "properties": {
                            "ratio": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "baseline IOPS ratio, specified as a ratio of IOPS to reserved size (in IOPS/GiB)",
                              "default": null
                            },
                            "burst": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "IOPS burst limit (in IOPS)",
                              "default": null
                            },
                            "burst_credit": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "maximum burst credits (in IOPS credits); not supported with provisioned IOPS",
                              "default": null
                            },
                            "min": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "minimum IOPS",
                              "default": null
                            },
                            "max": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "maximum IOPS",
                              "default": null
                            }
                          },
                          "additionalProperties": false
                        },
                        "piops": {
                          "type": [
                            "object"
                          ],
                          "description": "provisioned iops",
                          "properties": {
                            "type": {
                              "type": [
                                "string"
                              ],
                              "example": "user-specified",
                              "enum": [
                                "disabled",
                                "admin-fixed",
                                "capacity-scaled",
                                "user-specified"
                              ],
                              "description": "how provisioned IOPS are specified",
                              "default": "disabled"
                            },
                            "value": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "minimum": 1,
                              "description": "fixed IOPS value",
                              "default": null
                            },
                            "ratio": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "baseline provisioned IOPS ratio, specified as a ratio of IOPS to reserved size (in IOPS/GiB)",
                              "default": null
                            },
                            "min": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "minimum provisioned IOPS",
                              "default": null
                            },
                            "max": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "description": "maximum provisioned IOPS",
                              "default": null
                            }
                          },
                          "additionalProperties": false
                        }
                      },
                      "additionalProperties": false
                    },
                    "description": "service templates array"
                  },
                  "account_templates": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "account template arg",
                      "properties": {
                        "type": {
                          "type": [
                            "string"
                          ],
                          "description": "account template name"
                        },
                        "description": {
                          "type": [
                            "string"
                          ],
                          "description": "account template description"
                        },
                        "default": {
                          "type": [
                            "boolean"
                          ],
                          "default": false,
                          "description": "default template"
                        },
                        "provisioning": {
                          "type": [
                            "object"
                          ],
                          "description": "account provisioning",
                          "properties": {
                            "size_reserve_max": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "default": null,
                              "example": 1073741824,
                              "description": "maximum size reserve of a single virtual storage service"
                            },
                            "iops_reserve_max": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "default": null,
                              "description": "maximum iops reserve of a single virtual storage service"
                            },
                            "tags_include": {
                              "type": [
                                "array"
                              ],
                              "default": [

                              ],
                              "items": {
                                "type": [
                                  "string"
                                ],
                                "description": "tag"
                              },
                              "description": "tags included"
                            },
                            "tags_exclude": {
                              "type": [
                                "array"
                              ],
                              "default": [

                              ],
                              "items": {
                                "type": [
                                  "string"
                                ],
                                "description": "tag"
                              },
                              "description": "tags excluded"
                            },
                            "tags_permit": {
                              "type": [
                                "array",
                                "null"
                              ],
                              "default": null,
                              "items": {
                                "type": [
                                  "string"
                                ],
                                "description": "tag"
                              },
                              "description": "tags permitted"
                            }
                          },
                          "additionalProperties": false
                        },
                        "limits": {
                          "type": [
                            "object"
                          ],
                          "description": "account limits",
                          "properties": {
                            "vss_num": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "default": null,
                              "description": "number of virtual storage services"
                            },
                            "size_reserve_total": {
                              "type": [
                                "integer",
                                "null"
                              ],
                              "default": null,
                              "example": 1073741824,
                              "description": "maximum size of storage"
                            }
                          },
                          "additionalProperties": false
                        },
                        "permissions": {
                          "type": [
                            "object"
                          ],
                          "description": "user permissions",
                          "properties": {
                            "realm": {
                              "type": [
                                "object"
                              ],
                              "description": "realm permissions",
                              "properties": {
                                "rights": {
                                  "type": [
                                    "object"
                                  ],
                                  "description": "realm rights",
                                  "properties": {
                                    "can_switch_user": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "can SU to lower level user"
                                    },
                                    "manage_node_membership": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "accept or delete nodes from the management network"
                                    },
                                    "manage_accounts": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "can create or delete other accounts, users and their settings"
                                    },
                                    "view_logs": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "view administrative logs"
                                    },
                                    "run_admin_tasks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "run realm administrative tasks"
                                    },
                                    "run_tests": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "run realm administrative tests"
                                    }
                                  },
                                  "additionalProperties": false
                                }
                              },
                              "additionalProperties": false
                            },
                            "node": {
                              "type": [
                                "object"
                              ],
                              "description": "node permissions",
                              "properties": {
                                "all_realm_scope": {
                                  "type": [
                                    "boolean"
                                  ],
                                  "default": true,
                                  "description": "apply to all nodes in the realm"
                                },
                                "nodes": {
                                  "type": [
                                    "array"
                                  ],
                                  "items": {
                                    "type": [
                                      "string"
                                    ],
                                    "example": "node:38:11",
                                    "description": "node id"
                                  },
                                  "description": "scope permissions to specific nodes "
                                },
                                "rights": {
                                  "type": [
                                    "object"
                                  ],
                                  "description": "node rights",
                                  "properties": {
                                    "manage_storage": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "configure OS devices, iSCSI devices, and system datastores"
                                    },
                                    "manage_networks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "configure networks"
                                    },
                                    "provision_vss": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manually provision virtual storage services"
                                    },
                                    "remove_vss": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "remove virtual storage services"
                                    }
                                  },
                                  "additionalProperties": false
                                }
                              },
                              "additionalProperties": false
                            },
                            "vss": {
                              "type": [
                                "object"
                              ],
                              "description": "vss permissions",
                              "properties": {
                                "all_account_scope": {
                                  "type": [
                                    "boolean"
                                  ],
                                  "default": true,
                                  "description": "apply to all virtual storage services in the account"
                                },
                                "vsses": {
                                  "type": [
                                    "array"
                                  ],
                                  "items": {
                                    "type": [
                                      "string"
                                    ],
                                    "example": "vss:91:8",
                                    "description": "virtual storage service id"
                                  },
                                  "description": "limit scope to specified vsses"
                                },
                                "rights": {
                                  "type": [
                                    "object"
                                  ],
                                  "description": "vss rights",
                                  "properties": {
                                    "dismiss_tasks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "dismiss tasks"
                                    },
                                    "update_vss": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "update vss configuration"
                                    },
                                    "remove_vss": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "remove vss"
                                    },
                                    "set_vss_quota": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "set vss quota"
                                    },
                                    "manage_internal_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage internal disks"
                                    },
                                    "manage_external_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage external disks"
                                    },
                                    "manage_removable_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage removable disks"
                                    },
                                    "manage_disk_cryptography": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage disk cryptography"
                                    },
                                    "remove_locked_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "remove locked disks"
                                    },
                                    "replicate_and_synchronize_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "replicate and synchronize disks"
                                    },
                                    "validate_data_integrity": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "validate data integrity"
                                    },
                                    "manage_targets": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage targets"
                                    },
                                    "manage_profiles": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage profiles"
                                    },
                                    "manage_secure_access_tokens": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage secure access tokens"
                                    },
                                    "manage_rules": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage rules"
                                    },
                                    "replicate_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "replicate disks"
                                    },
                                    "synchronize_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "synchronize disks"
                                    },
                                    "format_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "format disks"
                                    },
                                    "resize_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "resize disks"
                                    },
                                    "backup_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "backup disks"
                                    },
                                    "manage_snapshots": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage snapshots"
                                    },
                                    "compress_disks": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "compress disks"
                                    },
                                    "manage_disk_compression": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage disk "
                                    }
                                  },
                                  "additionalProperties": false
                                }
                              },
                              "additionalProperties": false
                            },
                            "user": {
                              "type": [
                                "object"
                              ],
                              "description": "user permissions",
                              "properties": {
                                "rights": {
                                  "type": [
                                    "object"
                                  ],
                                  "description": "user rights",
                                  "properties": {
                                    "manage_users": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "create or delete users in an account"
                                    },
                                    "modify_user_contact_settings": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "modify user contact info"
                                    },
                                    "reset_user_password": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "reset user password"
                                    },
                                    "reset_user_two_factor": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "reset two factor authentication"
                                    },
                                    "manage_authorizations": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "create or delete persistent authorizations"
                                    }
                                  },
                                  "additionalProperties": false
                                }
                              },
                              "additionalProperties": false
                            },
                            "account": {
                              "type": [
                                "object"
                              ],
                              "description": "account permissions",
                              "properties": {
                                "rights": {
                                  "type": [
                                    "object"
                                  ],
                                  "description": "account rights",
                                  "properties": {
                                    "modify_contact_settings": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "modify account contact settings"
                                    },
                                    "view_events": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "view events"
                                    },
                                    "view_statistics": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "view statistics"
                                    },
                                    "manage_global_profiles": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage global profiles"
                                    },
                                    "manage_global_secure_access_tokens": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage global secure access tokens"
                                    },
                                    "query_catalog": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "query product catalog"
                                    },
                                    "provision_vss": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "provision vss from catalog"
                                    },
                                    "manage_obj_stores": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "manage object stores"
                                    },
                                    "read_object_storage": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "read from object storage"
                                    },
                                    "write_object_storage": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "write to object storage"
                                    },
                                    "delete_object_storage": {
                                      "type": [
                                        "boolean"
                                      ],
                                      "description": "delete from object storage"
                                    }
                                  },
                                  "additionalProperties": false
                                }
                              },
                              "additionalProperties": false
                            }
                          },
                          "additionalProperties": false
                        }
                      },
                      "additionalProperties": false
                    },
                    "description": "account templates args array"
                  }
                },
                "additionalProperties": false
              },
              "cert_fingerprint": {
                "type": [
                  "string"
                ],
                "description": "TLS certificate fingerprint"
              },
              "license": {
                "type": [
                  "string"
                ],
                "description": "software license bundle"
              },
              "registration": {
                "type": [
                  "object"
                ],
                "description": "node registration",
                "properties": {
                  "allow": {
                    "type": [
                      "boolean"
                    ],
                    "description": "allow registrations for this node"
                  }
                },
                "additionalProperties": false
              },
              "openstack_idp": {
                "type": [
                  "object"
                ],
                "description": "no documentation",
                "properties": {
                  "label": {
                    "type": [
                      "string"
                    ],
                    "description": "no documentation"
                  },
                  "enabled": {
                    "type": [
                      "boolean"
                    ],
                    "description": "identity provider enabled"
                  },
                  "auto_create_account": {
                    "type": [
                      "boolean"
                    ],
                    "description": "automatically create mapped accounts"
                  },
                  "auto_create_user": {
                    "type": [
                      "boolean"
                    ],
                    "description": "automatically create mapped users"
                  },
                  "url": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "idP API endpoint"
                  },
                  "auth": {
                    "type": [
                      "object"
                    ],
                    "description": "admin auth configuration",
                    "properties": {
                      "user": {
                        "type": [
                          "object"
                        ],
                        "description": "specify identity user",
                        "properties": {
                          "id": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "description": "look up user by idp-specific index"
                          },
                          "name": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "description": "look up user by name/login"
                          },
                          "password": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "description": "authenticate using supplied password"
                          }
                        },
                        "additionalProperties": false
                      },
                      "project": {
                        "type": [
                          "object"
                        ],
                        "description": "specify identity scope (e.g., account, project, tenant)",
                        "properties": {
                          "id": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "description": "look up project by idp-specific index"
                          },
                          "name": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "description": "look up project by name"
                          }
                        },
                        "additionalProperties": false
                      },
                      "domain": {
                        "type": [
                          "object"
                        ],
                        "description": "specify identity domain, if applicable",
                        "properties": {
                          "id": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "description": "look up domain by idp-specific index"
                          },
                          "name": {
                            "type": [
                              "string",
                              "null"
                            ],
                            "description": "look up domain by name"
                          }
                        },
                        "additionalProperties": false
                      }
                    },
                    "additionalProperties": false
                  },
                  "accepted_roles": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "no documentation"
                    },
                    "description": "accepted roles"
                  }
                },
                "additionalProperties": false
              },
              "eula": {
                "type": [
                  "object"
                ],
                "description": "end user license agreement",
                "properties": {
                  "accepted": {
                    "type": [
                      "boolean"
                    ],
                    "description": "eula accepted"
                  }
                },
                "additionalProperties": false
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "disk_nodes": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "visibility_ctl": {
                "type": [
                  "string"
                ],
                "example": "default",
                "enum": [
                  "default",
                  "show",
                  "hide"
                ],
                "description": "object visibility control"
              },
              "openstack_portal_filter": {
                "type": [
                  "object",
                  "null"
                ],
                "description": "IP filter rule",
                "properties": {
                  "ip": {
                    "type": [
                      "string"
                    ],
                    "format": "ipv4",
                    "description": "IP address"
                  },
                  "mask": {
                    "type": [
                      "string"
                    ],
                    "format": "ipv4",
                    "description": "netmask"
                  }
                },
                "additionalProperties": false
              }
            },
            "description": "node update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "node_update"
        },
        {
          "description": "Retrieve a list of operating system storage devices that match the specified parameters.",
          "href": "/node/{(%23%2Fdefinitions%2Fnode%2Fdefinitions%2Fidentity)}/devices",
          "method": "GET",
          "rel": "discover",
          "title": "Discover Devices",
          "x_bb_method": "device_discover",
          "schema": {
            "type": [
              "object"
            ],
            "description": "retrieve listing of devices on node",
            "properties": {
              "type": {
                "type": [
                  "string"
                ],
                "default": "block",
                "enum": [
                  "block"
                ],
                "description": "device type"
              },
              "subsystem": {
                "type": [
                  "string",
                  "null"
                ],
                "enum": [
                  "scsi",
                  "xen"
                ],
                "description": "device subsystem",
                "example": "scsi",
                "default": null
              }
            },
            "additionalProperties": false
          }
        },
        {
          "description": "Retrieve a list of network interfaces that match the specified parameters.",
          "href": "/node/{(%23%2Fdefinitions%2Fnode%2Fdefinitions%2Fidentity)}/interfaces",
          "method": "GET",
          "rel": "discover",
          "title": "Discover Interfaces",
          "x_bb_method": "network_discover"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/node/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/node/definitions/uuid"
        },
        "label": {
          "$ref": "#/definitions/node/definitions/label"
        },
        "serial": {
          "$ref": "#/definitions/node/definitions/serial"
        },
        "install_token": {
          "$ref": "#/definitions/node/definitions/install_token"
        },
        "install_mode": {
          "$ref": "#/definitions/node/definitions/install_mode"
        },
        "activation_code": {
          "$ref": "#/definitions/node/definitions/activation_code"
        },
        "activation_state": {
          "$ref": "#/definitions/node/definitions/activation_state"
        },
        "license": {
          "$ref": "#/definitions/node/definitions/license"
        },
        "eula": {
          "$ref": "#/definitions/node/definitions/eula"
        },
        "registration": {
          "$ref": "#/definitions/node/definitions/registration"
        },
        "notes": {
          "$ref": "#/definitions/node/definitions/notes"
        },
        "ctime": {
          "$ref": "#/definitions/node/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/node/definitions/mtime"
        },
        "site_id": {
          "$ref": "#/definitions/node/definitions/site_id"
        },
        "type": {
          "$ref": "#/definitions/node/definitions/type"
        },
        "ip": {
          "$ref": "#/definitions/node/definitions/ip"
        },
        "management": {
          "$ref": "#/definitions/node/definitions/management"
        },
        "enabled": {
          "$ref": "#/definitions/node/definitions/enabled"
        },
        "openstack_idp": {
          "$ref": "#/definitions/node/definitions/openstack_idp"
        },
        "openstack_portal_filter": {
          "$ref": "#/definitions/node/definitions/openstack_portal_filter"
        },
        "tags": {
          "$ref": "#/definitions/node/definitions/tags"
        },
        "visibility_ctl": {
          "$ref": "#/definitions/node/definitions/visibility_ctl"
        },
        "restricted": {
          "$ref": "#/definitions/node/definitions/restricted"
        },
        "converged_sn_id": {
          "$ref": "#/definitions/node/definitions/converged_sn_id"
        },
        "converged_mn_id": {
          "$ref": "#/definitions/node/definitions/converged_mn_id"
        },
        "disk_nodes": {
          "$ref": "#/definitions/node/definitions/disk_nodes"
        },
        "params": {
          "$ref": "#/definitions/node/definitions/params"
        },
        "status": {
          "$ref": "#/definitions/node/definitions/status"
        },
        "default_visibility": {
          "$ref": "#/definitions/node/definitions/default_visibility"
        },
        "visibility": {
          "$ref": "#/definitions/node/definitions/visibility"
        },
        "isotime": {
          "$ref": "#/definitions/node/definitions/isotime"
        },
        "humantime": {
          "$ref": "#/definitions/node/definitions/humantime"
        },
        "build_version": {
          "$ref": "#/definitions/node/definitions/build_version"
        },
        "build_time": {
          "$ref": "#/definitions/node/definitions/build_time"
        },
        "version": {
          "$ref": "#/definitions/node/definitions/version"
        },
        "cpu_processors": {
          "$ref": "#/definitions/node/definitions/cpu_processors"
        },
        "cpu_model": {
          "$ref": "#/definitions/node/definitions/cpu_model"
        },
        "mem_total": {
          "$ref": "#/definitions/node/definitions/mem_total"
        },
        "kernel_version": {
          "$ref": "#/definitions/node/definitions/kernel_version"
        },
        "enclosures": {
          "$ref": "#/definitions/node/definitions/enclosures"
        },
        "sn": {
          "$ref": "#/definitions/node/definitions/sn"
        },
        "restore": {
          "$ref": "#/definitions/node/definitions/restore"
        },
        "cluster": {
          "$ref": "#/definitions/node/definitions/cluster"
        }
      },
      "required": [
        "id",
        "label",
        "serial",
        "activation_state",
        "license",
        "eula",
        "registration",
        "notes",
        "ctime",
        "mtime",
        "site_id",
        "type",
        "ip",
        "management",
        "enabled",
        "openstack_idp",
        "openstack_portal_filter",
        "tags",
        "visibility_ctl",
        "disk_nodes",
        "params",
        "status",
        "default_visibility",
        "visibility",
        "isotime",
        "humantime",
        "build_version",
        "build_time",
        "version",
        "cpu_processors",
        "cpu_model",
        "mem_total",
        "kernel_version",
        "restore",
        "cluster"
      ],
      "additionalProperties": false
    },
    "site": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Site",
      "description": "Sites are groups of storage and management nodes.  When deploying a Blockbridge storage network, you can use sites to group nodes together that are co-located in the same data center.  Or, you can subdivide a datacenter into multiple sites, or align sites along business unit lines.  Every node in a site shares the same SMTP configuration.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/site/definitions/id"
            },
            {
              "$ref": "#/definitions/site/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "site create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "site last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "site serial number"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string for event application to display associated events"
        },
        "label": {
          "type": [
            "string"
          ],
          "description": "user assigned label"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "location": {
          "type": [
            "object"
          ],
          "description": "site location",
          "properties": {
            "country": {
              "type": [
                "string"
              ],
              "default": "",
              "description": "ISO 3166-1 alpha-3 country code"
            },
            "lat": {
              "type": [
                "number"
              ],
              "default": 0,
              "description": "latitude"
            },
            "long": {
              "type": [
                "number"
              ],
              "default": 0,
              "description": "longitude"
            },
            "city": {
              "type": [
                "string"
              ],
              "default": "",
              "description": "city"
            },
            "state": {
              "type": [
                "string"
              ],
              "default": "",
              "description": "state as two-character USPS abbreviation"
            }
          },
          "additionalProperties": false
        },
        "zip_code": {
          "type": [
            "string"
          ],
          "description": "site zip code"
        },
        "tier": {
          "type": [
            "string"
          ],
          "enum": [
            "I",
            "II",
            "III",
            "IV"
          ],
          "description": "datacenter infrastructure tier",
          "example": "II"
        },
        "email": {
          "type": [
            "object"
          ],
          "description": "site email configuration",
          "properties": {
            "type": {
              "type": [
                "string"
              ],
              "enum": [
                "none",
                "smtp",
                "mailgun"
              ],
              "description": "email type",
              "example": "mailgun"
            },
            "smtp": {
              "type": [
                "object"
              ],
              "description": "SMTP server configuration",
              "properties": {
                "server_ssl": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "none",
                    "required",
                    "optional"
                  ],
                  "description": "SMTP server SSL/TLS",
                  "example": "none"
                },
                "server_addr": {
                  "type": [
                    "string"
                  ],
                  "format": "hostname",
                  "description": "SMTP server hostname"
                },
                "mail_from": {
                  "type": [
                    "string"
                  ],
                  "format": "email",
                  "example": "support@blockbridge.com",
                  "description": "mail from email address"
                },
                "server_username": {
                  "type": [
                    "string"
                  ],
                  "description": "SMTP authentication username"
                },
                "server_auth": {
                  "type": [
                    "boolean"
                  ],
                  "description": "SMTP authentication enabled"
                },
                "server_port": {
                  "type": [
                    "integer"
                  ],
                  "minimum": 1,
                  "maximum": 65535,
                  "description": "SMTP server port",
                  "default": 587
                }
              },
              "additionalProperties": false
            },
            "mailgun": {
              "type": [
                "object"
              ],
              "description": "mailgun server configuration",
              "properties": {
              },
              "additionalProperties": false
            }
          },
          "additionalProperties": false,
          "dependencies": {
            "smtp": {
              "properties": {
                "type": {
                  "enum": [
                    "smtp"
                  ]
                }
              }
            },
            "mailgun": {
              "properties": {
                "type": {
                  "enum": [
                    "mailgun"
                  ]
                }
              }
            }
          }
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "site runtime status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "online"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "online"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "isotime": {
          "type": [
            "string",
            "null"
          ],
          "format": "date-time",
          "description": "local time on node"
        },
        "humantime": {
          "type": [
            "string",
            "null"
          ],
          "description": "human-readable time on node"
        },
        "build_version": {
          "type": [
            "string",
            "null"
          ],
          "description": "version of software running on node"
        },
        "build_time": {
          "type": [
            "string",
            "null"
          ],
          "description": "time and date that node software was built"
        },
        "version": {
          "type": [
            "object",
            "null"
          ],
          "description": "build version",
          "properties": {
            "hash": {
              "type": [
                "string"
              ],
              "description": "build hash"
            },
            "minor": {
              "type": [
                "integer"
              ],
              "description": "build minor version"
            },
            "major": {
              "type": [
                "integer"
              ],
              "description": "build major version"
            },
            "timestamp": {
              "type": [
                "integer"
              ],
              "description": "build timestamp"
            },
            "patch": {
              "type": [
                "integer"
              ],
              "description": "build patch version"
            },
            "tag": {
              "type": [
                "string"
              ],
              "description": "build tag"
            }
          },
          "required": [
            "hash",
            "minor",
            "major",
            "timestamp",
            "patch",
            "tag"
          ],
          "additionalProperties": false
        },
        "cpu_processors": {
          "type": [
            "integer",
            "null"
          ],
          "description": "number of processors on node"
        },
        "cpu_model": {
          "type": [
            "integer",
            "null"
          ],
          "description": "vendor and model of first CPU on node"
        },
        "mem_total": {
          "type": [
            "integer",
            "null"
          ],
          "description": "system memory on node",
          "example": 1073741824
        },
        "sn": {
          "type": [
            "object"
          ],
          "description": "parameters related to storage nodes (valid for storage node only)",
          "properties": {
            "data_cache_size": {
              "type": [
                "integer",
                "null"
              ],
              "description": "size of storage node data cache",
              "example": 1073741824
            },
            "meta_cache_size_limit": {
              "type": [
                "integer",
                "null"
              ],
              "description": "limit on total memory that may be reserved for metadata caching",
              "example": 1073741824
            },
            "max_data_log_size": {
              "type": [
                "integer",
                "null"
              ],
              "description": "maximum data log size that may be created",
              "example": 1073741824
            },
            "max_meta_cache_size": {
              "type": [
                "integer",
                "null"
              ],
              "description": "maximum metadata cache size that may be specified",
              "example": 1073741824
            },
            "usage": {
              "type": [
                "object"
              ],
              "description": "node resource utilization",
              "properties": {
                "vdisk_int": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "internal virtual disks on node"
                },
                "rules": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "rules on node"
                },
                "vss": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "virtual storage services on node"
                },
                "targets": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "targets on node"
                },
                "removable": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "removable virtual disks on node"
                },
                "sds": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "datastores on node"
                },
                "clones": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "cloned disks on node"
                },
                "iscsi_dev": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "iSCSI devices on node"
                },
                "snapshots": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "snapshots on node"
                },
                "repl_slaves": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "replication slave virtual disks on node"
                },
                "vdisk_int_cap_mb": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "sum of internal virtual disk capacities in megabytes"
                },
                "conn_secure": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "secure iSCSI session connections to node targets"
                },
                "conn_insecure": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "insecure iSCSI session connections to node targets"
                },
                "vdisk_ext": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "external virtual disks on node"
                },
                "os_dev": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "OS devices on node"
                },
                "sessions": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "iSCSI sessions connected to node targets"
                },
                "accounts": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "accounts on node"
                },
                "profiles": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "initiator profiles on node"
                },
                "repl_masters": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "replication master virtual disks on node"
                }
              },
              "required": [
                "vdisk_int",
                "rules",
                "vss",
                "targets",
                "removable",
                "sds",
                "clones",
                "iscsi_dev",
                "snapshots",
                "repl_slaves",
                "vdisk_int_cap_mb",
                "conn_secure",
                "conn_insecure",
                "vdisk_ext",
                "os_dev",
                "sessions",
                "accounts",
                "profiles",
                "repl_masters"
              ],
              "additionalProperties": false
            }
          },
          "required": [
            "data_cache_size",
            "meta_cache_size_limit",
            "max_data_log_size",
            "max_meta_cache_size",
            "usage"
          ],
          "additionalProperties": false
        },
        "restore": {
          "type": [
            "object"
          ],
          "description": "node restore status",
          "properties": {
            "start_time": {
              "type": [
                "integer",
                "null"
              ],
              "description": "node restore start time",
              "minimum": 0,
              "example": 1443200456094
            },
            "end_time": {
              "type": [
                "integer",
                "null"
              ],
              "description": "node restore end time (success or failure)",
              "minimum": 0,
              "example": 1443200456094
            },
            "state": {
              "type": [
                "string",
                "null"
              ],
              "enum": [
                "starting",
                "running",
                "success",
                "failed"
              ],
              "description": "node restore job state",
              "example": "success"
            },
            "errors": {
              "type": [
                "integer",
                "null"
              ],
              "description": "count of errors during node restore, see event log for details"
            },
            "phase": {
              "type": [
                "string",
                "null"
              ],
              "description": "description of current node restore phase"
            },
            "failure": {
              "type": [
                "string",
                "null"
              ],
              "description": "on node restore failure, description of reason"
            }
          },
          "required": [
            "start_time",
            "end_time",
            "state",
            "errors",
            "phase",
            "failure"
          ],
          "additionalProperties": false
        },
        "cluster": {
          "type": [
            "object"
          ],
          "description": "cluster status",
          "properties": {
            "reports": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "cluster member report",
                "properties": {
                  "id": {
                    "type": [
                      "string"
                    ],
                    "description": "name of cluster member that generated this report"
                  },
                  "members": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "cluster member",
                      "properties": {
                        "active": {
                          "type": [
                            "boolean",
                            "null"
                          ],
                          "description": "cluster member is actively hosting services"
                        },
                        "cluster_ip": {
                          "type": [
                            "string",
                            "null"
                          ],
                          "format": "ipv4",
                          "description": "cluster network address of member"
                        },
                        "role": {
                          "type": [
                            "string",
                            "null"
                          ],
                          "enum": [
                            "active",
                            "passive",
                            "vote"
                          ],
                          "description": "cluster member role",
                          "example": "active"
                        },
                        "failover": {
                          "type": [
                            "boolean",
                            "null"
                          ],
                          "description": "this cluster member is passive and ready for accept failover"
                        },
                        "status": {
                          "type": [
                            "object"
                          ],
                          "description": "computed cluster member health",
                          "properties": {
                            "indicator": {
                              "type": [
                                "string"
                              ],
                              "enum": [
                                "online",
                                "degraded",
                                "offline"
                              ],
                              "description": "status indicator",
                              "example": "offline"
                            },
                            "value": {
                              "type": [
                                "string"
                              ],
                              "enum": [
                                "online",
                                "degraded",
                                "offline",
                                "pending",
                                "payment"
                              ],
                              "description": "status value",
                              "example": "offline"
                            },
                            "detail": {
                              "type": [
                                "string",
                                "null"
                              ],
                              "description": "status detail"
                            }
                          },
                          "required": [
                            "indicator",
                            "value",
                            "detail"
                          ],
                          "additionalProperties": false
                        },
                        "status_ip": {
                          "type": [
                            "string",
                            "null"
                          ],
                          "format": "ipv4",
                          "description": "address of cluster member from which it reports status"
                        },
                        "id": {
                          "type": [
                            "string"
                          ],
                          "description": "cluster member name"
                        },
                        "state": {
                          "type": [
                            "string",
                            "null"
                          ],
                          "enum": [
                            "dirty",
                            "standby",
                            "maintenance",
                            "clean",
                            "offline"
                          ],
                          "description": "cluster member state",
                          "example": "standby"
                        },
                        "online": {
                          "type": [
                            "boolean",
                            "null"
                          ],
                          "description": "cluster member is online"
                        }
                      },
                      "required": [
                        "active",
                        "cluster_ip",
                        "role",
                        "failover",
                        "status",
                        "status_ip",
                        "id",
                        "state",
                        "online"
                      ],
                      "additionalProperties": false
                    },
                    "description": "array cluster members"
                  },
                  "failover": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "enum": [
                      "available",
                      "unavailable"
                    ],
                    "description": "cluster member failover capability",
                    "example": "available"
                  },
                  "status": {
                    "type": [
                      "object"
                    ],
                    "description": "computed cluster memeber health",
                    "properties": {
                      "indicator": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "online",
                          "degraded",
                          "offline"
                        ],
                        "description": "status indicator",
                        "example": "online"
                      },
                      "value": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "online",
                          "degraded",
                          "offline",
                          "pending",
                          "payment"
                        ],
                        "description": "status value",
                        "example": "online"
                      },
                      "detail": {
                        "type": [
                          "string",
                          "null"
                        ],
                        "description": "status detail"
                      }
                    },
                    "required": [
                      "indicator",
                      "value",
                      "detail"
                    ],
                    "additionalProperties": false
                  }
                },
                "required": [
                  "id",
                  "members",
                  "failover",
                  "status"
                ],
                "additionalProperties": false
              },
              "description": "array of cluster state reported by each cluster member"
            },
            "members": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "cluster member",
                "properties": {
                  "active": {
                    "type": [
                      "boolean",
                      "null"
                    ],
                    "description": "cluster member is actively hosting services"
                  },
                  "cluster_ip": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "format": "ipv4",
                    "description": "cluster network address of member"
                  },
                  "role": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "enum": [
                      "active",
                      "passive",
                      "vote"
                    ],
                    "description": "cluster member role",
                    "example": "passive"
                  },
                  "failover": {
                    "type": [
                      "boolean",
                      "null"
                    ],
                    "description": "this cluster member is passive and ready for accept failover"
                  },
                  "status": {
                    "type": [
                      "object"
                    ],
                    "description": "computed cluster member health",
                    "properties": {
                      "indicator": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "online",
                          "degraded",
                          "offline"
                        ],
                        "description": "status indicator",
                        "example": "degraded"
                      },
                      "value": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "online",
                          "degraded",
                          "offline",
                          "pending",
                          "payment"
                        ],
                        "description": "status value",
                        "example": "degraded"
                      },
                      "detail": {
                        "type": [
                          "string",
                          "null"
                        ],
                        "description": "status detail"
                      }
                    },
                    "required": [
                      "indicator",
                      "value",
                      "detail"
                    ],
                    "additionalProperties": false
                  },
                  "status_ip": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "format": "ipv4",
                    "description": "address of cluster member from which it reports status"
                  },
                  "id": {
                    "type": [
                      "string"
                    ],
                    "description": "cluster member name"
                  },
                  "state": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "enum": [
                      "dirty",
                      "standby",
                      "maintenance",
                      "clean",
                      "offline"
                    ],
                    "description": "cluster member state",
                    "example": "offline"
                  },
                  "online": {
                    "type": [
                      "boolean",
                      "null"
                    ],
                    "description": "cluster member is online"
                  }
                },
                "required": [
                  "active",
                  "cluster_ip",
                  "role",
                  "failover",
                  "status",
                  "status_ip",
                  "id",
                  "state",
                  "online"
                ],
                "additionalProperties": false
              },
              "description": "array of cluster members"
            },
            "failover": {
              "type": [
                "string",
                "null"
              ],
              "enum": [
                "available",
                "unavailable"
              ],
              "description": "cluster failover capability",
              "example": "available"
            },
            "status": {
              "type": [
                "object"
              ],
              "description": "computed cluster health",
              "properties": {
                "indicator": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "online",
                    "degraded",
                    "offline"
                  ],
                  "description": "status indicator",
                  "example": "online"
                },
                "value": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "online",
                    "degraded",
                    "offline",
                    "pending",
                    "payment"
                  ],
                  "description": "status value",
                  "example": "pending"
                },
                "detail": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "description": "status detail"
                }
              },
              "required": [
                "indicator",
                "value",
                "detail"
              ],
              "additionalProperties": false
            },
            "is_cluster": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "node is running in cluster mode"
            }
          },
          "required": [
            "reports",
            "members",
            "failover",
            "status",
            "is_cluster"
          ],
          "additionalProperties": false
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing site.",
          "href": "/site/{(%23%2Fdefinitions%2Fsite%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate sites.",
          "href": "/site",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a new site.",
          "href": "/site",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "label": {
                "type": [
                  "string"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "location": {
                "type": [
                  "object"
                ],
                "description": "location information",
                "properties": {
                  "country": {
                    "type": [
                      "string"
                    ],
                    "description": "ISO 3166-1 alpha-3 country code",
                    "default": ""
                  },
                  "lat": {
                    "type": [
                      "number"
                    ],
                    "description": "latitude",
                    "default": 0
                  },
                  "long": {
                    "type": [
                      "number"
                    ],
                    "description": "longitude",
                    "default": 0
                  },
                  "city": {
                    "type": [
                      "string"
                    ],
                    "description": "city",
                    "default": ""
                  },
                  "state": {
                    "type": [
                      "string"
                    ],
                    "description": "state as two-character USPS abbreviation",
                    "default": ""
                  }
                },
                "additionalProperties": false
              },
              "tier": {
                "type": [
                  "string"
                ],
                "enum": [
                  "I",
                  "II",
                  "III",
                  "IV"
                ],
                "description": "datacenter infrastructure tier",
                "example": "II",
                "default": "IV"
              },
              "email": {
                "type": [
                  "object"
                ],
                "description": "email configuration",
                "properties": {
                  "type": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "none",
                      "smtp",
                      "mailgun"
                    ],
                    "description": "email type",
                    "example": "mailgun"
                  },
                  "smtp": {
                    "type": [
                      "object"
                    ],
                    "description": "smtp server configuration",
                    "properties": {
                      "mail_from": {
                        "type": [
                          "string"
                        ],
                        "format": "email",
                        "example": "support@blockbridge.com",
                        "description": "mail from email address"
                      },
                      "server_ssl": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "none",
                          "required",
                          "optional"
                        ],
                        "description": "smtp server ssl",
                        "example": "optional"
                      },
                      "server_addr": {
                        "type": [
                          "string"
                        ],
                        "format": "hostname",
                        "description": "smtp server name"
                      },
                      "server_password": {
                        "type": [
                          "string"
                        ],
                        "description": "smtp auth password"
                      },
                      "server_username": {
                        "type": [
                          "string"
                        ],
                        "description": "smtp auth username"
                      },
                      "server_auth": {
                        "type": [
                          "boolean"
                        ],
                        "description": "smtp auth enabled"
                      },
                      "server_port": {
                        "type": [
                          "integer"
                        ],
                        "default": 587,
                        "minimum": 1,
                        "maximum": 65535,
                        "description": "smtp server port"
                      }
                    },
                    "additionalProperties": false,
                    "dependencies": {
                      "server_password": {
                        "properties": {
                          "server_auth": {
                            "enum": [
                              true
                            ]
                          }
                        }
                      },
                      "server_username": {
                        "properties": {
                          "server_auth": {
                            "enum": [
                              true
                            ]
                          }
                        }
                      }
                    }
                  },
                  "mailgun": {
                    "type": [
                      "object"
                    ],
                    "description": "mailgun server configuration",
                    "properties": {
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "smtp": {
                    "properties": {
                      "type": {
                        "enum": [
                          "smtp"
                        ]
                      }
                    }
                  },
                  "mailgun": {
                    "properties": {
                      "type": {
                        "enum": [
                          "mailgun"
                        ]
                      }
                    }
                  }
                }
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              }
            },
            "description": "site create request arguments",
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "site_create"
        },
        {
          "description": "Remove an existing site.",
          "href": "/site/{(%23%2Fdefinitions%2Fsite%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "site_remove"
        },
        {
          "description": "Change the configuration of an existing site.",
          "href": "/site/{(%23%2Fdefinitions%2Fsite%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "label": {
                "type": [
                  "string"
                ],
                "description": "user assigned label"
              },
              "location": {
                "type": [
                  "object"
                ],
                "description": "no documentation",
                "properties": {
                  "country": {
                    "type": [
                      "string"
                    ],
                    "description": "ISO 3166-1 alpha-3 country code",
                    "default": ""
                  },
                  "lat": {
                    "type": [
                      "number"
                    ],
                    "description": "latitude",
                    "default": 0
                  },
                  "long": {
                    "type": [
                      "number"
                    ],
                    "description": "longitude",
                    "default": 0
                  },
                  "city": {
                    "type": [
                      "string"
                    ],
                    "description": "city",
                    "default": ""
                  },
                  "state": {
                    "type": [
                      "string"
                    ],
                    "description": "state as two-character USPS abbreviation",
                    "default": ""
                  }
                },
                "additionalProperties": false
              },
              "zip_code": {
                "type": [
                  "string"
                ],
                "description": "ZIP code"
              },
              "tier": {
                "type": [
                  "string"
                ],
                "enum": [
                  "I",
                  "II",
                  "III",
                  "IV"
                ],
                "description": "datacenter infrastructure tier",
                "example": "III"
              },
              "email": {
                "type": [
                  "object"
                ],
                "description": "email configuration",
                "properties": {
                  "type": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "none",
                      "smtp",
                      "mailgun"
                    ],
                    "description": "email type",
                    "example": "none"
                  },
                  "smtp": {
                    "type": [
                      "object"
                    ],
                    "description": "SMTP server configuration",
                    "properties": {
                      "server_port": {
                        "type": [
                          "integer"
                        ],
                        "default": 587,
                        "minimum": 1,
                        "maximum": 65535,
                        "description": "SMTP server port"
                      },
                      "mail_from": {
                        "type": [
                          "string"
                        ],
                        "format": "email",
                        "example": "support@blockbridge.com",
                        "description": "alternative mail-from email address"
                      },
                      "server_ssl": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "none",
                          "required",
                          "optional"
                        ],
                        "description": "SMTP server SSL/TLS",
                        "example": "optional"
                      },
                      "server_addr": {
                        "type": [
                          "string"
                        ],
                        "format": "hostname",
                        "description": "SMTP server name"
                      },
                      "server_password": {
                        "type": [
                          "string"
                        ],
                        "description": "SMTP authentication password"
                      },
                      "server_username": {
                        "type": [
                          "string"
                        ],
                        "description": "SMTP authentication username"
                      },
                      "server_auth": {
                        "type": [
                          "boolean"
                        ],
                        "description": "SMTP authentication is enabled"
                      }
                    },
                    "additionalProperties": false
                  },
                  "mailgun": {
                    "type": [
                      "object"
                    ],
                    "description": "mailgun server configuration",
                    "properties": {
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              }
            },
            "description": "site update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "site_update"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/site/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/site/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/site/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/site/definitions/mtime"
        },
        "serial": {
          "$ref": "#/definitions/site/definitions/serial"
        },
        "label": {
          "$ref": "#/definitions/site/definitions/label"
        },
        "notes": {
          "$ref": "#/definitions/site/definitions/notes"
        },
        "location": {
          "$ref": "#/definitions/site/definitions/location"
        },
        "zip_code": {
          "$ref": "#/definitions/site/definitions/zip_code"
        },
        "tier": {
          "$ref": "#/definitions/site/definitions/tier"
        },
        "email": {
          "$ref": "#/definitions/site/definitions/email"
        },
        "status": {
          "$ref": "#/definitions/site/definitions/status"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "serial",
        "label",
        "notes",
        "status"
      ],
      "additionalProperties": false
    },
    "net": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Network Interface",
      "description": "Blockbridge storage node software detects the Ethernet interfaces you have configured on your nodes.  Network Interface resources allow you to define how these interfaces are used for Blockbridge storage services. \n\nThe Blockbridge system thinks of networking in terms of these interfaces. You have the full power of Linux networking at your disposal including channel bonding, VLANs, and tunnels.  You can have multiple interfaces for segregation, performance or high availability. \n\nWhen a storage node completes its initial rendezvous with the management node, it registers the first Ethernet interface it finds, along with its IP addresses.  If the node has additional interfaces, use this interface to register them.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/net/definitions/id"
            },
            {
              "$ref": "#/definitions/net/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "label": {
          "type": [
            "string"
          ],
          "description": "user assigned label"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "network interface serial number"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string for event application to display associated events"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "network interface create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "network interface last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "node_id": {
          "type": [
            "string"
          ],
          "example": "node:30:7",
          "description": "storage node id"
        },
        "enabled": {
          "type": [
            "boolean"
          ],
          "description": "service is enabled on this network interface"
        },
        "interface": {
          "type": [
            "string"
          ],
          "description": "network interface device name"
        },
        "nat_addr": {
          "type": [
            "string",
            "null"
          ],
          "format": "ipv4",
          "description": "NAT address assigned to interface"
        },
        "hostname": {
          "type": [
            "string",
            "null"
          ],
          "format": "hostname",
          "description": "hostname assigned to interface"
        },
        "service": {
          "type": [
            "object"
          ],
          "description": "network interface services",
          "properties": {
            "application": {
              "type": [
                "object"
              ],
              "description": "application service",
              "properties": {
                "enabled": {
                  "type": [
                    "boolean"
                  ],
                  "description": "application service enabled"
                }
              },
              "required": [
                "enabled"
              ],
              "additionalProperties": false
            },
            "management": {
              "type": [
                "object"
              ],
              "description": "management service",
              "properties": {
                "enabled": {
                  "type": [
                    "boolean"
                  ],
                  "description": "management service enabled"
                }
              },
              "required": [
                "enabled"
              ],
              "additionalProperties": false
            },
            "storage": {
              "type": [
                "object"
              ],
              "description": "storage service",
              "properties": {
                "enabled": {
                  "type": [
                    "boolean"
                  ],
                  "description": "storage service enabled"
                },
                "shared": {
                  "type": [
                    "boolean"
                  ],
                  "description": "service is shared"
                }
              },
              "required": [
                "enabled",
                "shared"
              ],
              "additionalProperties": false
            },
            "replication": {
              "type": [
                "object"
              ],
              "description": "replication service",
              "properties": {
                "enabled": {
                  "type": [
                    "boolean"
                  ],
                  "description": "replication service enabled"
                }
              },
              "required": [
                "enabled"
              ],
              "additionalProperties": false
            },
            "infrastructure": {
              "type": [
                "object"
              ],
              "description": "infrastructure service",
              "properties": {
                "enabled": {
                  "type": [
                    "boolean"
                  ],
                  "description": "infrastructure service enabled"
                }
              },
              "required": [
                "enabled"
              ],
              "additionalProperties": false
            },
            "external": {
              "type": [
                "object"
              ],
              "description": "external service",
              "properties": {
                "enabled": {
                  "type": [
                    "boolean"
                  ],
                  "description": "external service enabled"
                }
              },
              "required": [
                "enabled"
              ],
              "additionalProperties": false
            }
          },
          "additionalProperties": false,
          "required": [
            "application",
            "management",
            "storage",
            "replication",
            "infrastructure",
            "external"
          ]
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "network interface status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "offline"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "offline"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "network": {
          "type": [
            "object",
            "null"
          ],
          "description": "network interface description",
          "properties": {
            "interface": {
              "type": [
                "string"
              ],
              "description": "interface name"
            },
            "hwaddr": {
              "type": [
                "string"
              ],
              "description": "hardware address (MAC)"
            },
            "mtu": {
              "type": [
                "integer"
              ],
              "description": "MTU"
            },
            "flags": {
              "type": [
                "object"
              ],
              "description": "interface flags",
              "properties": {
                "up": {
                  "type": [
                    "boolean"
                  ],
                  "description": "up"
                },
                "broadcast": {
                  "type": [
                    "boolean"
                  ],
                  "description": "broadcast"
                },
                "debug": {
                  "type": [
                    "boolean"
                  ],
                  "description": "debug"
                },
                "loopback": {
                  "type": [
                    "boolean"
                  ],
                  "description": "loopback"
                },
                "pointopoint": {
                  "type": [
                    "boolean"
                  ],
                  "description": "pointopoint"
                },
                "notrailers": {
                  "type": [
                    "boolean"
                  ],
                  "description": "notrailers"
                },
                "running": {
                  "type": [
                    "boolean"
                  ],
                  "description": "running"
                },
                "noarp": {
                  "type": [
                    "boolean"
                  ],
                  "description": "noarp"
                },
                "promisc": {
                  "type": [
                    "boolean"
                  ],
                  "description": "promisc"
                },
                "master": {
                  "type": [
                    "boolean"
                  ],
                  "description": "master"
                },
                "slave": {
                  "type": [
                    "boolean"
                  ],
                  "description": "slave"
                },
                "multicast": {
                  "type": [
                    "boolean"
                  ],
                  "description": "multicast"
                }
              },
              "required": [
                "up",
                "broadcast",
                "debug",
                "loopback",
                "pointopoint",
                "notrailers",
                "running",
                "noarp",
                "promisc",
                "master",
                "slave",
                "multicast"
              ],
              "additionalProperties": false
            },
            "link": {
              "type": [
                "object"
              ],
              "description": "link information",
              "properties": {
                "detected": {
                  "type": [
                    "boolean",
                    "null"
                  ],
                  "description": "media link detected"
                },
                "speed": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "enum": [
                    "10",
                    "100",
                    "1000",
                    "2500",
                    "10000",
                    "25000",
                    "40000",
                    "50000",
                    "56000",
                    "100000",
                    "unknown"
                  ],
                  "description": "network interface speed in Mb/s",
                  "example": "100"
                },
                "duplex": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "enum": [
                    "half",
                    "full",
                    "unknown"
                  ],
                  "description": "network interface duplex",
                  "example": "half"
                },
                "port": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "enum": [
                    "twisted-pair",
                    "AUI",
                    "BNC",
                    "MII",
                    "FIBRE",
                    "direct-attach-copper",
                    "none",
                    "other",
                    "unknown"
                  ],
                  "description": "network interface port",
                  "example": "unknown"
                }
              },
              "required": [
                "detected",
                "speed",
                "duplex",
                "port"
              ],
              "additionalProperties": false
            },
            "driver": {
              "type": [
                "object"
              ],
              "description": "driver information",
              "properties": {
                "name": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "description": "driver name"
                },
                "version": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "description": "driver version"
                },
                "fw_version": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "description": "driver firmware version"
                },
                "bus": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "description": "driver bus"
                }
              },
              "required": [
                "name",
                "version",
                "fw_version",
                "bus"
              ],
              "additionalProperties": false
            },
            "stats": {
              "type": [
                "object"
              ],
              "description": "stats",
              "properties": {
                "tx_packets": {
                  "type": [
                    "integer"
                  ],
                  "description": "tx packets"
                },
                "tx_bytes": {
                  "type": [
                    "integer"
                  ],
                  "description": "tx bytes"
                },
                "tx_errors": {
                  "type": [
                    "integer"
                  ],
                  "description": "tx errors"
                },
                "tx_dropped": {
                  "type": [
                    "integer"
                  ],
                  "description": "tx dropped"
                },
                "rx_packets": {
                  "type": [
                    "integer"
                  ],
                  "description": "rx packets"
                },
                "rx_bytes": {
                  "type": [
                    "integer"
                  ],
                  "description": "rx bytes"
                },
                "rx_errors": {
                  "type": [
                    "integer"
                  ],
                  "description": "rx errors"
                },
                "rx_dropped": {
                  "type": [
                    "integer"
                  ],
                  "description": "rx dropped"
                }
              },
              "required": [
                "tx_packets",
                "tx_bytes",
                "tx_errors",
                "tx_dropped",
                "rx_packets",
                "rx_bytes",
                "rx_errors",
                "rx_dropped"
              ],
              "additionalProperties": false
            },
            "ipaddrs": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "network ip",
                "properties": {
                  "addr": {
                    "type": [
                      "string"
                    ],
                    "description": "ip address"
                  },
                  "family": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "IPv4",
                      "IPv6",
                      "unknown"
                    ],
                    "description": "address family",
                    "example": "IPv4"
                  }
                },
                "required": [
                  "addr",
                  "family"
                ],
                "additionalProperties": false
              },
              "description": "IP addresses"
            },
            "inuse": {
              "type": [
                "boolean"
              ],
              "description": "network interface configured"
            },
            "config": {
              "type": [
                "object"
              ],
              "description": "configuration reference",
              "properties": {
                "net_id": {
                  "type": [
                    "string"
                  ],
                  "example": "net:5:7",
                  "description": "network interface id"
                },
                "service": {
                  "type": [
                    "object"
                  ],
                  "description": "service",
                  "properties": {
                    "application": {
                      "type": [
                        "object"
                      ],
                      "description": "application service",
                      "properties": {
                        "enabled": {
                          "type": [
                            "boolean"
                          ],
                          "description": "service enabled"
                        }
                      },
                      "additionalProperties": false
                    },
                    "management": {
                      "type": [
                        "object"
                      ],
                      "description": "management service",
                      "properties": {
                        "enabled": {
                          "type": [
                            "boolean"
                          ],
                          "description": "service enabled"
                        }
                      },
                      "additionalProperties": false
                    },
                    "storage": {
                      "type": [
                        "object"
                      ],
                      "description": "storage service",
                      "properties": {
                        "enabled": {
                          "type": [
                            "boolean"
                          ],
                          "description": "service enabled"
                        },
                        "shared": {
                          "type": [
                            "boolean"
                          ],
                          "description": "service shared"
                        }
                      },
                      "additionalProperties": false
                    },
                    "replication": {
                      "type": [
                        "object"
                      ],
                      "description": "replication service",
                      "properties": {
                        "enabled": {
                          "type": [
                            "boolean"
                          ],
                          "description": "service enabled"
                        }
                      },
                      "additionalProperties": false
                    },
                    "infrastructure": {
                      "type": [
                        "object"
                      ],
                      "description": "infrastructure service",
                      "properties": {
                        "enabled": {
                          "type": [
                            "boolean"
                          ],
                          "description": "service enabled"
                        }
                      },
                      "additionalProperties": false
                    },
                    "external": {
                      "type": [
                        "object"
                      ],
                      "description": "external service",
                      "properties": {
                        "enabled": {
                          "type": [
                            "boolean"
                          ],
                          "description": "service enabled"
                        }
                      },
                      "additionalProperties": false
                    }
                  },
                  "additionalProperties": false
                },
                "nat_addr": {
                  "type": [
                    "string"
                  ],
                  "description": "NAT address"
                },
                "enabled": {
                  "type": [
                    "boolean"
                  ],
                  "description": "net administratively enabled/disabled"
                }
              },
              "additionalProperties": false
            },
            "parent": {
              "type": [
                "object",
                "null"
              ],
              "description": "parent interface",
              "properties": {
                "name": {
                  "type": [
                    "string"
                  ],
                  "description": "parent interface name"
                },
                "net_id": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "example": "net:10:9",
                  "description": "parent net"
                }
              },
              "required": [
                "name",
                "net_id"
              ],
              "additionalProperties": false
            }
          },
          "required": [
            "interface",
            "hwaddr",
            "mtu",
            "flags",
            "link",
            "driver",
            "stats",
            "ipaddrs",
            "parent"
          ],
          "additionalProperties": false,
          "dependencies": {
            "config": {
              "properties": {
                "inuse": {
                  "enum": [
                    true
                  ]
                }
              }
            }
          }
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "portals": {
          "type": [
            "array",
            "null"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "published portal"
          },
          "description": "published portals"
        },
        "parent": {
          "type": [
            "object",
            "null"
          ],
          "description": "one-to-one resource identifier",
          "properties": {
            "type": {
              "type": [
                "string"
              ],
              "description": "type of identified resource"
            },
            "meta": {
              "type": [
                "object"
              ],
              "description": "optional custom metadata related to the resource relationship",
              "properties": {
              }
            }
          },
          "required": [
            "type"
          ]
        },
        "pcid": {
          "type": [
            "string"
          ],
          "example": "node:86:6",
          "description": "storage node id"
        },
        "cplx_id": {
          "type": [
            "integer",
            "null"
          ],
          "description": "processor complex assignment; null indicates shared between all complexes"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing network interface.",
          "href": "/net/{(%23%2Fdefinitions%2Fnet%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate network interfaces.",
          "href": "/net",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Register a new network interface.",
          "href": "/net",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "label": {
                "type": [
                  "string"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "node_id": {
                "type": [
                  "string"
                ],
                "example": "node:19:9",
                "description": "node id"
              },
              "enabled": {
                "type": [
                  "boolean"
                ],
                "default": true,
                "description": "service is enabled on this network interface"
              },
              "interface": {
                "type": [
                  "string"
                ],
                "description": "interface name"
              },
              "nat_addr": {
                "type": [
                  "string",
                  "null"
                ],
                "format": "ipv4",
                "description": "NAT IP address",
                "default": null
              },
              "hostname": {
                "type": [
                  "string",
                  "null"
                ],
                "format": "hostname",
                "description": "hostname",
                "default": null
              },
              "service": {
                "type": [
                  "object"
                ],
                "description": "services and service parameters",
                "properties": {
                  "application": {
                    "type": [
                      "object"
                    ],
                    "description": "application service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "default": false,
                        "description": "application service enabled"
                      }
                    },
                    "additionalProperties": false
                  },
                  "management": {
                    "type": [
                      "object"
                    ],
                    "description": "management service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "default": false,
                        "description": "management service enabled"
                      }
                    },
                    "additionalProperties": false
                  },
                  "storage": {
                    "type": [
                      "object"
                    ],
                    "description": "storage service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "default": true,
                        "description": "storage service enabled"
                      },
                      "shared": {
                        "type": [
                          "boolean"
                        ],
                        "default": true,
                        "description": "storage service shared"
                      }
                    },
                    "additionalProperties": false
                  },
                  "replication": {
                    "type": [
                      "object"
                    ],
                    "description": "replication service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "default": true,
                        "description": "replication service enabled"
                      }
                    },
                    "additionalProperties": false
                  },
                  "infrastructure": {
                    "type": [
                      "object"
                    ],
                    "description": "infrastructure service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "default": true,
                        "description": "infrastructure service enabled"
                      }
                    },
                    "additionalProperties": false
                  },
                  "external": {
                    "type": [
                      "object"
                    ],
                    "description": "external service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "default": true,
                        "description": "external service enabled"
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              },
              "portals": {
                "type": [
                  "array",
                  "null"
                ],
                "default": null,
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "portal ip"
                },
                "description": "published portals"
              },
              "cplx_id": {
                "type": [
                  "integer",
                  "null"
                ],
                "default": null,
                "description": "processor complex assignment"
              }
            },
            "description": "network create request arguments",
            "required": [
              "interface",
              "node_id"
            ],
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "net_create"
        },
        {
          "description": "Remove the configuration for an existing network interface.",
          "href": "/net/{(%23%2Fdefinitions%2Fnet%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "net_remove"
        },
        {
          "description": "Change the configuration of an existing network interface.",
          "href": "/net/{(%23%2Fdefinitions%2Fnet%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "label": {
                "type": [
                  "string"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "enabled": {
                "type": [
                  "boolean"
                ],
                "description": "service is enabled on this network interface"
              },
              "interface": {
                "type": [
                  "string"
                ],
                "description": "interface name"
              },
              "nat_addr": {
                "type": [
                  "string",
                  "null"
                ],
                "format": "ipv4",
                "description": "NAT IP address"
              },
              "hostname": {
                "type": [
                  "string",
                  "null"
                ],
                "format": "hostname",
                "description": "hostname"
              },
              "service": {
                "type": [
                  "object"
                ],
                "description": "services and service parameters",
                "properties": {
                  "application": {
                    "type": [
                      "object"
                    ],
                    "description": "application service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "description": "application service enabled"
                      }
                    },
                    "additionalProperties": false
                  },
                  "management": {
                    "type": [
                      "object"
                    ],
                    "description": "management service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "description": "management service enabled"
                      }
                    },
                    "additionalProperties": false
                  },
                  "storage": {
                    "type": [
                      "object"
                    ],
                    "description": "storage service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "description": "storage service enabled"
                      },
                      "shared": {
                        "type": [
                          "boolean"
                        ],
                        "description": "storage service shared"
                      }
                    },
                    "additionalProperties": false
                  },
                  "replication": {
                    "type": [
                      "object"
                    ],
                    "description": "replication service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "description": "replication service enabled"
                      }
                    },
                    "additionalProperties": false
                  },
                  "infrastructure": {
                    "type": [
                      "object"
                    ],
                    "description": "infrastructure service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "description": "infrastructure service enabled"
                      }
                    },
                    "additionalProperties": false
                  },
                  "external": {
                    "type": [
                      "object"
                    ],
                    "description": "external service",
                    "properties": {
                      "enabled": {
                        "type": [
                          "boolean"
                        ],
                        "description": "external service enabled"
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              },
              "portals": {
                "type": [
                  "array",
                  "null"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "portal ip"
                },
                "description": "published portals"
              },
              "cplx_id": {
                "type": [
                  "integer",
                  "null"
                ],
                "description": "processor complex assignment"
              }
            },
            "description": "network update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "net_update"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/net/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/net/definitions/uuid"
        },
        "label": {
          "$ref": "#/definitions/net/definitions/label"
        },
        "serial": {
          "$ref": "#/definitions/net/definitions/serial"
        },
        "ctime": {
          "$ref": "#/definitions/net/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/net/definitions/mtime"
        },
        "notes": {
          "$ref": "#/definitions/net/definitions/notes"
        },
        "node_id": {
          "$ref": "#/definitions/net/definitions/node_id"
        },
        "cplx_id": {
          "$ref": "#/definitions/net/definitions/cplx_id"
        },
        "pcid": {
          "$ref": "#/definitions/net/definitions/pcid"
        },
        "enabled": {
          "$ref": "#/definitions/net/definitions/enabled"
        },
        "interface": {
          "$ref": "#/definitions/net/definitions/interface"
        },
        "nat_addr": {
          "$ref": "#/definitions/net/definitions/nat_addr"
        },
        "hostname": {
          "$ref": "#/definitions/net/definitions/hostname"
        },
        "portals": {
          "$ref": "#/definitions/net/definitions/portals"
        },
        "parent": {
          "$ref": "#/definitions/net/definitions/parent"
        },
        "service": {
          "$ref": "#/definitions/net/definitions/service"
        },
        "status": {
          "$ref": "#/definitions/net/definitions/status"
        },
        "network": {
          "$ref": "#/definitions/net/definitions/network"
        }
      },
      "required": [
        "id",
        "label",
        "serial",
        "ctime",
        "mtime",
        "notes",
        "node_id",
        "cplx_id",
        "pcid",
        "enabled",
        "interface",
        "nat_addr",
        "hostname",
        "portals",
        "parent",
        "service",
        "status",
        "network"
      ],
      "additionalProperties": false
    },
    "os-dev": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Operating System Device",
      "description": "The Operating System Storage Device object has the configuration necessary for a Blockbridge storage node to integrate direct-attached (DAS) storage into a System Datastore.  The operating system has been configured with the proper drivers for the storage technology, and is responsible for providing a persistent device path.  You can use any storage device that's compatible with Linux, such as NVDIMM, NVMe, PCI Flash, direct-attached hardware RAID, or a Fibre Channel SAN.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/os-dev/definitions/id"
            },
            {
              "$ref": "#/definitions/os-dev/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "label": {
          "type": [
            "string"
          ],
          "description": "user assigned label"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "OS device serial number"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string for event application to display associated events"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "OS device create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "OS device last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "node_id": {
          "type": [
            "string"
          ],
          "example": "node:73:9",
          "description": "storage node id"
        },
        "initialized": {
          "type": [
            "boolean"
          ],
          "description": "device is initialized"
        },
        "enabled": {
          "type": [
            "boolean"
          ],
          "description": "device is enabled"
        },
        "align_writes_4k": {
          "type": [
            "boolean",
            "null"
          ],
          "description": "align all writes to 4KiB boundaries, executing read requests as necessary"
        },
        "size": {
          "type": [
            "integer",
            "null"
          ],
          "description": "raw device size"
        },
        "path": {
          "type": [
            "string",
            "null"
          ],
          "description": "device path"
        },
        "sds_id": {
          "type": [
            "string",
            "null"
          ],
          "example": "sys_ds:98:5",
          "description": "system datastore id"
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "OS device status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline"
              ],
              "description": "status indicator",
              "example": "offline"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "payment"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "usable": {
          "type": [
            "integer",
            "null"
          ],
          "description": "usable device size (in bytes)"
        },
        "used": {
          "type": [
            "integer",
            "null"
          ],
          "description": "number of bytes of device that have been consumed",
          "example": 1073741824
        },
        "vendor_id": {
          "type": [
            "string"
          ],
          "description": "device vendor id"
        },
        "prod_id": {
          "type": [
            "string"
          ],
          "description": "device product id"
        },
        "prod_rev": {
          "type": [
            "string"
          ],
          "description": "device product revision"
        },
        "usn": {
          "type": [
            "string"
          ],
          "description": "device unit serial number"
        },
        "t10_vendor_specific_id": {
          "type": [
            "string"
          ],
          "description": "device t10 vendor specific device id"
        },
        "naa_id": {
          "type": [
            "string"
          ],
          "description": "device naa id"
        },
        "eui64_id": {
          "type": [
            "string"
          ],
          "description": "device eui64 id"
        },
        "logical_block_size": {
          "type": [
            "integer",
            "null"
          ],
          "description": "device logical block size",
          "example": 1073741824
        },
        "physical_block_size": {
          "type": [
            "integer",
            "null"
          ],
          "description": "device physical block size",
          "example": 1073741824
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "owner": {
          "type": [
            "string",
            "null"
          ],
          "example": "disk_agent",
          "enum": [
            "disk_agent",
            "sp"
          ],
          "description": "subsystem owning raw device"
        },
        "meta": {
          "type": [
            "object"
          ],
          "description": "device metadata",
          "properties": {
          }
        },
        "parent": {
          "type": [
            "object",
            "null"
          ],
          "description": "parent device reference",
          "properties": {
            "type": {
              "type": [
                "string"
              ],
              "description": "type of identified resource"
            },
            "meta": {
              "type": [
                "object"
              ],
              "description": "optional custom metadata related to the resource relationship",
              "properties": {
              }
            }
          },
          "required": [
            "type"
          ]
        },
        "rebalance_delta": {
          "type": [
            "integer",
            "null"
          ],
          "description": "remainder of rebalancing goal, bytes (negative: moving extents away)"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing operating system storage device.",
          "href": "/os-dev/{(%23%2Fdefinitions%2Fos-dev%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate operating system storage devices.",
          "href": "/os-dev",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Register a new operating system storage device, creating its configuration.  Once the device has been initialized, it may be incorporated into the storage pool of a system datastore.",
          "href": "/os-dev",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "path": {
                "type": [
                  "string"
                ],
                "description": "device path string"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "align_writes_4k": {
                "type": [
                  "boolean"
                ],
                "description": "align all writes to 4KiB boundaries, executing read requests as necessary",
                "default": false
              },
              "node_id": {
                "type": [
                  "string"
                ],
                "description": "storage node id"
              },
              "raw_size": {
                "type": [
                  "integer"
                ],
                "example": 1073741824,
                "minimum": 1000000000,
                "description": "raw device size in bytes"
              },
              "uuid": {
                "type": [
                  "string",
                  "null"
                ],
                "format": "uuid",
                "description": "object UUID"
              },
              "meta": {
                "type": [
                  "object"
                ],
                "description": "device metadata",
                "properties": {
                }
              },
              "parent": {
                "type": [
                  "object",
                  "null"
                ],
                "description": "parent device reference",
                "properties": {
                  "type": {
                    "type": [
                      "string"
                    ],
                    "description": "type of identified resource"
                  },
                  "meta": {
                    "type": [
                      "object"
                    ],
                    "description": "optional custom metadata related to the resource relationship",
                    "properties": {
                    }
                  }
                },
                "required": [
                  "type"
                ]
              }
            },
            "description": "OS dev create request arguments",
            "additionalProperties": false,
            "required": [
              "node_id",
              "path",
              "raw_size",
              "parent"
            ]
          },
          "title": "Create",
          "x_bb_method": "os_dev_create"
        },
        {
          "description": "Initialize an operating system storage device.  This action causes the storage node to write configuration data to the start and end of the storage device.  On completion, the device can be incorporated into the storage pool of a system datastore.",
          "href": "/os-dev/{(%23%2Fdefinitions%2Fos-dev%2Fdefinitions%2Fidentity)}/actions/initialize",
          "method": "POST",
          "rel": "initialize",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "mrdb_size": {
                "type": [
                  "integer"
                ],
                "description": "metadata region database size in bytes",
                "example": 1073741824
              }
            },
            "description": "OS dev initialize request arguments",
            "additionalProperties": false
          },
          "title": "Initialize",
          "x_bb_method": "os_dev_initialize"
        },
        {
          "description": "Remove the configuration of an existing operating system storage device.",
          "href": "/os-dev/{(%23%2Fdefinitions%2Fos-dev%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "os_dev_remove"
        },
        {
          "description": "Change the configuration of an existing operating system storage device.",
          "href": "/os-dev/{(%23%2Fdefinitions%2Fos-dev%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "path": {
                "type": [
                  "string"
                ],
                "description": "device path"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "align_writes_4k": {
                "type": [
                  "boolean"
                ],
                "description": "align all writes to 4KiB boundaries, executing read requests as necessary"
              },
              "meta": {
                "type": [
                  "object",
                  "null"
                ],
                "description": "device metadata",
                "properties": {
                }
              },
              "parent": {
                "type": [
                  "object",
                  "null"
                ],
                "description": "parent device reference",
                "properties": {
                  "type": {
                    "type": [
                      "string"
                    ],
                    "description": "type of identified resource"
                  },
                  "meta": {
                    "type": [
                      "object"
                    ],
                    "description": "optional custom metadata related to the resource relationship",
                    "properties": {
                    }
                  }
                }
              }
            },
            "description": "OS dev update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "os_dev_update"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/os-dev/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/os-dev/definitions/uuid"
        },
        "label": {
          "$ref": "#/definitions/os-dev/definitions/label"
        },
        "notes": {
          "$ref": "#/definitions/os-dev/definitions/notes"
        },
        "serial": {
          "$ref": "#/definitions/os-dev/definitions/serial"
        },
        "ctime": {
          "$ref": "#/definitions/os-dev/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/os-dev/definitions/mtime"
        },
        "node_id": {
          "$ref": "#/definitions/os-dev/definitions/node_id"
        },
        "initialized": {
          "$ref": "#/definitions/os-dev/definitions/initialized"
        },
        "enabled": {
          "$ref": "#/definitions/os-dev/definitions/enabled"
        },
        "align_writes_4k": {
          "$ref": "#/definitions/os-dev/definitions/align_writes_4k"
        },
        "size": {
          "$ref": "#/definitions/os-dev/definitions/size"
        },
        "path": {
          "$ref": "#/definitions/os-dev/definitions/path"
        },
        "sds_id": {
          "$ref": "#/definitions/os-dev/definitions/sds_id"
        },
        "parent": {
          "$ref": "#/definitions/os-dev/definitions/parent"
        },
        "meta": {
          "$ref": "#/definitions/os-dev/definitions/meta"
        },
        "status": {
          "$ref": "#/definitions/os-dev/definitions/status"
        },
        "usable": {
          "$ref": "#/definitions/os-dev/definitions/usable"
        },
        "used": {
          "$ref": "#/definitions/os-dev/definitions/used"
        },
        "rebalance_delta": {
          "$ref": "#/definitions/os-dev/definitions/rebalance_delta"
        },
        "vendor_id": {
          "$ref": "#/definitions/os-dev/definitions/vendor_id"
        },
        "prod_id": {
          "$ref": "#/definitions/os-dev/definitions/prod_id"
        },
        "prod_rev": {
          "$ref": "#/definitions/os-dev/definitions/prod_rev"
        },
        "usn": {
          "$ref": "#/definitions/os-dev/definitions/usn"
        },
        "t10_vendor_specific_id": {
          "$ref": "#/definitions/os-dev/definitions/t10_vendor_specific_id"
        },
        "naa_id": {
          "$ref": "#/definitions/os-dev/definitions/naa_id"
        },
        "eui64_id": {
          "$ref": "#/definitions/os-dev/definitions/eui64_id"
        },
        "logical_block_size": {
          "$ref": "#/definitions/os-dev/definitions/logical_block_size"
        },
        "physical_block_size": {
          "$ref": "#/definitions/os-dev/definitions/physical_block_size"
        }
      },
      "required": [
        "id",
        "label",
        "notes",
        "serial",
        "ctime",
        "mtime",
        "node_id",
        "initialized",
        "enabled",
        "align_writes_4k",
        "size",
        "path",
        "sds_id",
        "parent",
        "status",
        "usable",
        "used",
        "rebalance_delta",
        "vendor_id",
        "prod_id",
        "prod_rev",
        "usn",
        "t10_vendor_specific_id",
        "naa_id",
        "eui64_id",
        "logical_block_size",
        "physical_block_size"
      ],
      "additionalProperties": false
    },
    "sys-ds": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "System Datastore",
      "description": "A System Datastore (or just Datastore) defines a pool of storage from which you, your users, and applications will provision secure virtual storage services.  You can aggregate direct-attached and iSCSI storage devices to create a single large pool of storage.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/sys-ds/definitions/id"
            },
            {
              "$ref": "#/definitions/sys-ds/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "label": {
          "type": [
            "string"
          ],
          "description": "user assigned label"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "system datastore serial number"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string for event application to display associated events"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "system datastore create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "system datastore last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "site_id": {
          "type": [
            "string"
          ],
          "example": "site:62:10",
          "description": "site id"
        },
        "product_id": {
          "type": [
            "string"
          ],
          "example": "product:90:15",
          "description": "product id"
        },
        "node_id": {
          "type": [
            "string"
          ],
          "example": "node:40:15",
          "description": "node id"
        },
        "size_reservable": {
          "type": [
            "integer",
            "null"
          ],
          "description": "size of system datastore storage that is reservable"
        },
        "size_reserve_hard_threshold": {
          "type": [
            "integer",
            "null"
          ],
          "description": "When the available size is less than this threshold, the data plane denies write allocations for volumes that exceed their reserve.  This is the amount of storage held for use only by reservation holders."
        },
        "size_reserve_soft_threshold": {
          "type": [
            "integer",
            "null"
          ],
          "description": "When the available size is less than this threshold, the data plane marks the datastore degraded."
        },
        "iops_rating": {
          "type": [
            "integer",
            "null"
          ],
          "description": "system datastore IOPS rating"
        },
        "iops_scheduling": {
          "type": [
            "boolean",
            "null"
          ],
          "description": "system datastore supports provisioned IOPS"
        },
        "iops_reserve_pct": {
          "type": [
            "integer",
            "null"
          ],
          "description": "percent of IOPS reserved"
        },
        "vss_provisioning": {
          "type": [
            "boolean"
          ],
          "description": "virtual storage services are allowed to provision out of this system datastore"
        },
        "label_tag": {
          "type": [
            "boolean",
            "null"
          ],
          "description": "automatically use the system datastore label as a provisioning tag"
        },
        "vdisk_capacity_max": {
          "type": [
            "integer",
            "null"
          ],
          "description": "maximum provisioned capacity of a virtual disk"
        },
        "vdisk_capacity_min": {
          "type": [
            "integer",
            "null"
          ],
          "description": "minimum provisioned capacity of a virtual disk"
        },
        "mode": {
          "type": [
            "string"
          ],
          "enum": [
            "pool"
          ],
          "description": "system datastore provisioning mode",
          "example": "pool"
        },
        "blk_encode_default": {
          "type": [
            "string",
            "null"
          ],
          "enum": [
            "aes256-gcm-4k",
            "aes128-xts-4k"
          ],
          "description": "default block format for virtual disks",
          "example": "aes256-gcm-4k"
        },
        "pool": {
          "type": [
            "object",
            "null"
          ],
          "description": "system datastore pool configuration",
          "properties": {
            "strategy": {
              "type": [
                "string"
              ],
              "enum": [
                "weighted",
                "ranked",
                "ranked_weighted",
                "balanced_unused_percentage",
                "balanced_unused"
              ],
              "description": "pool allocation strategy",
              "example": "balanced_unused"
            },
            "devs": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "device tracking information",
                "properties": {
                  "dev_id": {
                    "type": [
                      "string"
                    ],
                    "example": "iscsi_dev:69:12",
                    "description": "device id"
                  },
                  "allocation": {
                    "type": [
                      "boolean"
                    ],
                    "description": "data allocation is permitted"
                  },
                  "rank": {
                    "type": [
                      "integer"
                    ],
                    "minimum": 1,
                    "maximum": 255,
                    "description": "allocation rank"
                  },
                  "weight": {
                    "type": [
                      "integer"
                    ],
                    "minimum": 1,
                    "maximum": 255,
                    "description": "allocation weight"
                  }
                },
                "required": [
                  "dev_id",
                  "allocation",
                  "rank",
                  "weight"
                ],
                "additionalProperties": false
              },
              "description": "list of devices in the storage pool"
            }
          },
          "required": [
            "strategy",
            "devs"
          ],
          "additionalProperties": false
        },
        "data": {
          "type": [
            "object"
          ],
          "description": "system datastore data parameters",
          "properties": {
            "log_dev_id": {
              "type": [
                "string"
              ],
              "example": "iscsi_dev:96:7",
              "description": "system datastore log device"
            },
            "log_compress": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "enable data log compression"
            }
          },
          "required": [
            "log_dev_id",
            "log_compress"
          ],
          "additionalProperties": false
        },
        "meta": {
          "type": [
            "object"
          ],
          "description": "system datastore metasystem parameters",
          "properties": {
            "dev_id": {
              "type": [
                "string"
              ],
              "example": "iscsi_dev:19:7",
              "description": "device to use for metasystem"
            },
            "cache_size": {
              "type": [
                "integer"
              ],
              "description": "metasystem cache size"
            }
          },
          "required": [
            "dev_id",
            "cache_size"
          ],
          "additionalProperties": false
        },
        "product": {
          "type": [
            "object"
          ],
          "description": "product",
          "properties": {
            "notes": {
              "type": [
                "string"
              ],
              "description": "user assigned notes"
            },
            "tags": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "string"
                ],
                "description": "product tag"
              },
              "description": "provisioning tags"
            }
          },
          "required": [
            "tags"
          ],
          "additionalProperties": false
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "system datastore status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline"
              ],
              "description": "status indicator",
              "example": "degraded"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "payment"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "size": {
          "type": [
            "integer",
            "null"
          ],
          "description": "total size of system datastore (in bytes)"
        },
        "used": {
          "type": [
            "integer",
            "null"
          ],
          "description": "used size of system datastore (in bytes)"
        },
        "reserve_size": {
          "type": [
            "integer",
            "null"
          ],
          "description": "total reserve size of system datastore (in bytes)"
        },
        "reserve_used": {
          "type": [
            "integer",
            "null"
          ],
          "description": "used reserve size of system datastore (in bytes)"
        },
        "reserve_iops": {
          "type": [
            "integer",
            "null"
          ],
          "description": "total reserved IOPS of system datastore"
        },
        "iops_read": {
          "type": [
            "integer",
            "null"
          ],
          "description": "Read operations per second, normalized to 4K"
        },
        "iops_write": {
          "type": [
            "integer",
            "null"
          ],
          "description": "Write operations per second, normalized to 4K"
        },
        "iosz": {
          "type": [
            "integer",
            "null"
          ],
          "description": "I/O size in bytes"
        },
        "data_rts": {
          "type": [
            "object"
          ],
          "description": "system datastore data state",
          "properties": {
            "log_size": {
              "type": [
                "integer",
                "null"
              ],
              "description": "runtime system datastore log size (in bytes)",
              "example": 1073741824
            },
            "log_compress_ratio": {
              "type": [
                "number",
                "null"
              ],
              "description": "data log compression ratio"
            }
          },
          "required": [
            "log_size",
            "log_compress_ratio"
          ],
          "additionalProperties": false
        },
        "meta_rts": {
          "type": [
            "object"
          ],
          "description": "system datastore metasystem parameters",
          "properties": {
            "size": {
              "type": [
                "integer",
                "null"
              ],
              "description": "runtime system datastore metasystem size (in bytes)"
            },
            "log_size": {
              "type": [
                "integer",
                "null"
              ],
              "description": "runtime system datastore metasystem log size (in bytes)"
            },
            "page_size": {
              "type": [
                "integer",
                "null"
              ],
              "description": "metasystem page size (in bytes)",
              "example": 1073741824
            },
            "pages": {
              "type": [
                "integer",
                "null"
              ],
              "description": "total number of pages in metasystem"
            },
            "pages_used": {
              "type": [
                "integer",
                "null"
              ],
              "description": "number of pages consumed in metasystem"
            },
            "pages_cached": {
              "type": [
                "integer",
                "null"
              ],
              "description": "number of pages in cache in metasystem"
            },
            "pages_dirty": {
              "type": [
                "integer",
                "null"
              ],
              "description": "number of dirty pages in cache in metasystem"
            },
            "pages_pinned": {
              "type": [
                "integer",
                "null"
              ],
              "description": "number of pages pinned into cache in metasystem"
            },
            "pages_compressed": {
              "type": [
                "integer",
                "null"
              ],
              "description": "of total, number of pages that are compressed in cache"
            }
          },
          "required": [
            "size",
            "log_size",
            "page_size",
            "pages",
            "pages_used",
            "pages_cached",
            "pages_dirty",
            "pages_pinned",
            "pages_compressed"
          ],
          "additionalProperties": false
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing system datastore.",
          "href": "/sys-ds/{(%23%2Fdefinitions%2Fsys-ds%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate system datastores.",
          "href": "/sys-ds",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a new system datastore.",
          "href": "/sys-ds",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "label": {
                "type": [
                  "string"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "strategy": {
                "type": [
                  "string"
                ],
                "default": "weighted",
                "enum": [
                  "weighted",
                  "ranked",
                  "ranked_weighted",
                  "balanced_unused_percentage",
                  "balanced_unused"
                ],
                "description": "pool allocation strategy"
              },
              "size_reservable": {
                "type": [
                  "integer",
                  "null"
                ],
                "default": null,
                "minimum": 0,
                "description": "size of storage that may be reserved by disks and services"
              },
              "size_reserve_hard_threshold": {
                "type": [
                  "integer",
                  "null"
                ],
                "default": null,
                "minimum": 0,
                "description": "the amount of storage held for use only by reservation holders"
              },
              "size_reserve_soft_threshold": {
                "type": [
                  "integer",
                  "null"
                ],
                "default": null,
                "minimum": 0,
                "description": "when there is less storage than this available, the datastore is marked degraded"
              },
              "iops_reserve_pct": {
                "type": [
                  "integer"
                ],
                "default": 100,
                "minimum": 0,
                "maximum": 100,
                "description": "percent of storage IOPS that may be reserved by services"
              },
              "iops_rating": {
                "type": [
                  "integer"
                ],
                "default": 50000,
                "minimum": 100,
                "maximum": 1000000,
                "description": "administrator assigned storage subsystem rating in I/O operations per second"
              },
              "iops_scheduling": {
                "type": [
                  "boolean"
                ],
                "default": false,
                "description": "IOPS scheduling is enabled"
              },
              "vss_provisioning": {
                "type": [
                  "boolean"
                ],
                "default": true,
                "description": "virtual storage service provisioning is enabled"
              },
              "vdisk_capacity_max": {
                "type": [
                  "integer"
                ],
                "default": 1099511627776,
                "description": "maximum virtual disk capacity",
                "minimum": 1048576,
                "maximum": 1125899906842624
              },
              "vdisk_capacity_min": {
                "type": [
                  "integer"
                ],
                "default": 33554432,
                "description": "minimum virtual disk capacity",
                "minimum": 1048576,
                "maximum": 1125899906842624
              },
              "label_tag": {
                "type": [
                  "boolean"
                ],
                "default": true,
                "description": "system datastore label automatically entered as a provisioning tag"
              },
              "product": {
                "type": [
                  "object"
                ],
                "description": "product parameters",
                "properties": {
                  "tags": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "product tag"
                    },
                    "description": "array of product tags"
                  }
                },
                "additionalProperties": false
              },
              "blk_encode_default": {
                "type": [
                  "string"
                ],
                "enum": [
                  "aes256-gcm-4k",
                  "aes128-xts-4k"
                ],
                "description": "default block encoding for user data",
                "example": "aes256-gcm-4k"
              },
              "backup_mrdb_size": {
                "type": [
                  "integer"
                ],
                "default": 4194304,
                "description": "configuration backup database size on metadata device",
                "example": 1073741824,
                "minimum": 1048576,
                "maximum": 16777216
              },
              "data": {
                "type": [
                  "object"
                ],
                "description": "data parameters",
                "properties": {
                  "log_dev_id": {
                    "type": [
                      "string"
                    ],
                    "example": "iscsi_dev:53:6",
                    "description": "data journal device id"
                  },
                  "log_size": {
                    "type": [
                      "integer"
                    ],
                    "default": 8388608,
                    "minimum": 2097152,
                    "description": "data journal size in bytes",
                    "maximum": 17179869184
                  },
                  "log_compress": {
                    "type": [
                      "boolean"
                    ],
                    "default": false,
                    "description": "enable data log compression"
                  }
                },
                "required": [
                  "log_dev_id"
                ],
                "additionalProperties": false
              },
              "meta": {
                "type": [
                  "object"
                ],
                "description": "meta parameters",
                "properties": {
                  "dev_id": {
                    "type": [
                      "string"
                    ],
                    "example": "iscsi_dev:41:7",
                    "description": "thin-provisioning metadata device id"
                  },
                  "size": {
                    "type": [
                      "integer"
                    ],
                    "default": 16777216,
                    "minimum": 16777216,
                    "description": "thin-provisioning metadata size in bytes"
                  },
                  "log_size": {
                    "type": [
                      "integer"
                    ],
                    "default": 8388608,
                    "minimum": 4194304,
                    "description": "thin-provisioning metadata journal size in bytes (encapsulated inside metadata)"
                  },
                  "cache_size": {
                    "type": [
                      "integer"
                    ],
                    "default": 16777216,
                    "minimum": 4194304,
                    "description": "thin-provisioning metadata cache size"
                  }
                },
                "required": [
                  "dev_id"
                ],
                "additionalProperties": false
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              },
              "node_id": {
                "type": [
                  "string"
                ],
                "description": "node id"
              }
            },
            "description": "system datastore create request arguments",
            "required": [
              "node_id",
              "data",
              "meta"
            ],
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "sys_ds_create"
        },
        {
          "description": "Remove an existing system datastore.  Its storage pool must be empty.",
          "href": "/sys-ds/{(%23%2Fdefinitions%2Fsys-ds%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "sys_ds_remove"
        },
        {
          "description": "Retrieve historical usage data for a system datastore.",
          "href": "/sys-ds/{(%23%2Fdefinitions%2Fsys-ds%2Fdefinitions%2Fidentity)}/usage",
          "method": "GET",
          "rel": "usage",
          "title": "Query Usage",
          "x_bb_method": "sys_ds_usage_query",
          "schema": {
            "type": [
              "object"
            ]
          }
        },
        {
          "description": "Change the configuration of an existing system datastore.",
          "href": "/sys-ds/{(%23%2Fdefinitions%2Fsys-ds%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "label": {
                "type": [
                  "string"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "data": {
                "type": [
                  "object"
                ],
                "description": "data parameters",
                "properties": {
                  "cache_size": {
                    "type": [
                      "integer"
                    ],
                    "description": "data cache size in bytes"
                  },
                  "log_compress": {
                    "type": [
                      "boolean"
                    ],
                    "description": "enable data log compression"
                  }
                },
                "additionalProperties": false
              },
              "meta": {
                "type": [
                  "object"
                ],
                "description": "meta parameters",
                "properties": {
                  "cache_size": {
                    "type": [
                      "integer"
                    ],
                    "description": "thin-provisioning metadata cache size in bytes"
                  }
                },
                "additionalProperties": false
              },
              "pool": {
                "type": [
                  "object"
                ],
                "description": "system datastore pool settings",
                "properties": {
                  "strategy": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "weighted",
                      "ranked",
                      "ranked_weighted",
                      "balanced_unused_percentage",
                      "balanced_unused"
                    ],
                    "description": "pool allocation strategy",
                    "example": "weighted"
                  },
                  "devs": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "object"
                      ],
                      "description": "device tracking information",
                      "properties": {
                        "dev_id": {
                          "type": [
                            "string"
                          ],
                          "example": "os_dev:73:15",
                          "description": "device id"
                        },
                        "allocation": {
                          "type": [
                            "boolean"
                          ],
                          "description": "data allocation is permitted"
                        },
                        "rank": {
                          "type": [
                            "integer"
                          ],
                          "minimum": 1,
                          "maximum": 255,
                          "description": "allocation rank"
                        },
                        "weight": {
                          "type": [
                            "integer"
                          ],
                          "minimum": 1,
                          "maximum": 255,
                          "description": "allocation weight"
                        }
                      },
                      "additionalProperties": false
                    },
                    "description": "list of devices in the storage pool"
                  }
                },
                "additionalProperties": false
              },
              "iops_reserve_pct": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "maximum": 100,
                "description": "percent of storage IOPS that may be reserved by services"
              },
              "size_reservable": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "size of storage that may be reserved by disks and services"
              },
              "size_reserve_hard_threshold": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "the amount of storage held for use only by reservation holders"
              },
              "size_reserve_soft_threshold": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "when there is less storage than this available, the datastore is marked degraded"
              },
              "iops_rating": {
                "type": [
                  "integer"
                ],
                "minimum": 100,
                "maximum": 1000000,
                "description": "administrator assigned storage subsystem rating in I/O operations per second"
              },
              "iops_scheduling": {
                "type": [
                  "boolean"
                ],
                "description": "IOPS scheduling is enabled"
              },
              "vss_provisioning": {
                "type": [
                  "boolean"
                ],
                "description": "virtual storage service provisioning is enabled"
              },
              "vdisk_capacity_max": {
                "type": [
                  "integer"
                ],
                "description": "maximum virtual disk capacity",
                "minimum": 1048576,
                "maximum": 1125899906842624
              },
              "vdisk_capacity_min": {
                "type": [
                  "integer"
                ],
                "description": "minimum virtual disk capacity",
                "minimum": 1048576,
                "maximum": 1125899906842624
              },
              "label_tag": {
                "type": [
                  "boolean"
                ],
                "description": "system datastore label automatically entered as a provisioning tag"
              },
              "product": {
                "type": [
                  "object"
                ],
                "description": "product parameters",
                "properties": {
                  "tags": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "product tag"
                    },
                    "description": "array of product tags"
                  },
                  "notes": {
                    "type": [
                      "string"
                    ],
                    "description": "user assigned notes"
                  }
                },
                "additionalProperties": false
              }
            },
            "description": "system datastore udpate request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "sys_ds_update"
        },
        {
          "description": "Add an iSCSI storage device or an OS storage device to the storage pool of a system datastore.",
          "href": "/sys-ds/{(%23%2Fdefinitions%2Fsys-ds%2Fdefinitions%2Fidentity)}/actions/pool-add",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "dev_id": {
                "type": [
                  "string"
                ],
                "example": "iscsi_dev:68:5",
                "description": "device id"
              },
              "allocation": {
                "type": [
                  "boolean"
                ],
                "default": true,
                "description": "data allocation is enabled"
              },
              "rank": {
                "type": [
                  "integer"
                ],
                "default": 1,
                "minimum": 1,
                "maximum": 255,
                "description": "allocation rank"
              },
              "weight": {
                "type": [
                  "integer"
                ],
                "default": 1,
                "minimum": 1,
                "maximum": 255,
                "description": "allocation weight"
              }
            },
            "description": "system datastore pool add request arguments",
            "required": [
              "dev_id"
            ],
            "additionalProperties": false
          },
          "title": "Pool Add",
          "x_bb_method": "sys_ds_pool_add"
        },
        {
          "description": "Remove an iSCSI storage device or an OS storage device from the storage pool of a system datastore.  The device must not contain any user data.  Use the **pool destage** action to move user data away from the device prior to removing it from the pool.",
          "href": "/sys-ds/{(%23%2Fdefinitions%2Fsys-ds%2Fdefinitions%2Fidentity)}/actions/pool-del",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "dev_id": {
                "type": [
                  "string"
                ],
                "example": "iscsi_dev:59:13",
                "description": "device id"
              }
            },
            "description": "system datastore pool delete request arguments",
            "required": [
              "dev_id"
            ],
            "additionalProperties": false
          },
          "title": "Pool Delete",
          "x_bb_method": "sys_ds_pool_del"
        },
        {
          "description": "Move all user data off of an iSCSI or OS storage device to other devices in the system datastore storage pool.  There must be enough room on the remaining set of pool devices to hold the data.",
          "href": "/sys-ds/{(%23%2Fdefinitions%2Fsys-ds%2Fdefinitions%2Fidentity)}/actions/pool-destage",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "dev_id": {
                "type": [
                  "string"
                ],
                "example": "os_dev:73:5",
                "description": "device id"
              },
              "limit_bandwidth": {
                "type": [
                  "boolean"
                ],
                "description": "limit bandwidth usage"
              },
              "bandwidth": {
                "type": [
                  "integer"
                ],
                "description": "bandwidth limit in bytes/sec"
              }
            },
            "description": "system datastore pool destage request arguments",
            "required": [
              "dev_id"
            ],
            "additionalProperties": false,
            "dependencies": {
              "bandwidth": {
                "properties": {
                  "limit_bandwidth": {
                    "enum": [
                      true
                    ]
                  }
                }
              }
            }
          },
          "title": "Pool Destage",
          "x_bb_method": "sys_ds_pool_destage"
        },
        {
          "description": "Initiate a benchmark test for the storage pool of a system datastore.",
          "href": "/sys-ds/{(%23%2Fdefinitions%2Fsys-ds%2Fdefinitions%2Fidentity)}/actions/benchmark",
          "method": "POST",
          "rel": "benchmark",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "read_percent": {
                "type": [
                  "integer"
                ],
                "default": 50,
                "minimum": 0,
                "maximum": 100,
                "description": "percentage of read I/Os"
              },
              "encoding": {
                "type": [
                  "string"
                ],
                "enum": [
                  "aes256-gcm-4k",
                  "aes128-xts-4k"
                ],
                "description": "block encoding",
                "example": "aes256-gcm-4k"
              },
              "duration": {
                "type": [
                  "integer"
                ],
                "default": 300,
                "description": "time in seconds to run test"
              },
              "range": {
                "type": [
                  "integer"
                ],
                "minimum": 1048576,
                "description": "byte range of test",
                "example": 1073741824
              },
              "iosize_min": {
                "type": [
                  "integer"
                ],
                "default": 4096,
                "minimum": 512,
                "maximum": 1048576,
                "description": "minimum I/O size",
                "example": 1073741824
              },
              "workload": {
                "type": [
                  "string"
                ],
                "enum": [
                  "sequential",
                  "random"
                ],
                "description": "benchmark workload type",
                "example": "sequential"
              },
              "iosize_max": {
                "type": [
                  "integer"
                ],
                "default": 4096,
                "minimum": 512,
                "maximum": 1048576,
                "description": "maximum I/O size",
                "example": 1073741824
              },
              "align": {
                "type": [
                  "integer"
                ],
                "default": 4096,
                "minimum": 512,
                "maximum": 1048576,
                "description": "I/O offset alignment"
              },
              "preformat": {
                "type": [
                  "boolean"
                ],
                "description": "write entire range prior to test"
              },
              "queue_depth": {
                "type": [
                  "integer"
                ],
                "default": 64,
                "minimum": 1,
                "maximum": 1024,
                "description": "maximum number of I/O's outstanding"
              },
              "compressibility": {
                "type": [
                  "integer"
                ],
                "default": 0,
                "minimum": 0,
                "maximum": 100,
                "description": "percentage that written data should compress, assuming ideal compression"
              }
            },
            "description": "system datastore benchmark request arguments",
            "required": [
              "range",
              "workload",
              "preformat"
            ],
            "additionalProperties": false
          },
          "title": "Benchmark",
          "x_bb_method": "sys_ds_benchmark"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/sys-ds/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/sys-ds/definitions/uuid"
        },
        "label": {
          "$ref": "#/definitions/sys-ds/definitions/label"
        },
        "notes": {
          "$ref": "#/definitions/sys-ds/definitions/notes"
        },
        "serial": {
          "$ref": "#/definitions/sys-ds/definitions/serial"
        },
        "ctime": {
          "$ref": "#/definitions/sys-ds/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/sys-ds/definitions/mtime"
        },
        "site_id": {
          "$ref": "#/definitions/sys-ds/definitions/site_id"
        },
        "product_id": {
          "$ref": "#/definitions/sys-ds/definitions/product_id"
        },
        "node_id": {
          "$ref": "#/definitions/sys-ds/definitions/node_id"
        },
        "size_reservable": {
          "$ref": "#/definitions/sys-ds/definitions/size_reservable"
        },
        "size_reserve_hard_threshold": {
          "$ref": "#/definitions/sys-ds/definitions/size_reserve_hard_threshold"
        },
        "size_reserve_soft_threshold": {
          "$ref": "#/definitions/sys-ds/definitions/size_reserve_soft_threshold"
        },
        "iops_rating": {
          "$ref": "#/definitions/sys-ds/definitions/iops_rating"
        },
        "iops_scheduling": {
          "$ref": "#/definitions/sys-ds/definitions/iops_scheduling"
        },
        "iops_reserve_pct": {
          "$ref": "#/definitions/sys-ds/definitions/iops_reserve_pct"
        },
        "vss_provisioning": {
          "$ref": "#/definitions/sys-ds/definitions/vss_provisioning"
        },
        "label_tag": {
          "$ref": "#/definitions/sys-ds/definitions/label_tag"
        },
        "vdisk_capacity_max": {
          "$ref": "#/definitions/sys-ds/definitions/vdisk_capacity_max"
        },
        "vdisk_capacity_min": {
          "$ref": "#/definitions/sys-ds/definitions/vdisk_capacity_min"
        },
        "blk_encode_default": {
          "$ref": "#/definitions/sys-ds/definitions/blk_encode_default"
        },
        "pool": {
          "$ref": "#/definitions/sys-ds/definitions/pool"
        },
        "data": {
          "$ref": "#/definitions/sys-ds/definitions/data"
        },
        "meta": {
          "$ref": "#/definitions/sys-ds/definitions/meta"
        },
        "product": {
          "$ref": "#/definitions/sys-ds/definitions/product"
        },
        "status": {
          "$ref": "#/definitions/sys-ds/definitions/status"
        },
        "size": {
          "$ref": "#/definitions/sys-ds/definitions/size"
        },
        "used": {
          "$ref": "#/definitions/sys-ds/definitions/used"
        },
        "reserve_size": {
          "$ref": "#/definitions/sys-ds/definitions/reserve_size"
        },
        "reserve_used": {
          "$ref": "#/definitions/sys-ds/definitions/reserve_used"
        },
        "reserve_iops": {
          "$ref": "#/definitions/sys-ds/definitions/reserve_iops"
        },
        "iops_read": {
          "$ref": "#/definitions/sys-ds/definitions/iops_read"
        },
        "iops_write": {
          "$ref": "#/definitions/sys-ds/definitions/iops_write"
        },
        "iosz": {
          "$ref": "#/definitions/sys-ds/definitions/iosz"
        },
        "data_rts": {
          "$ref": "#/definitions/sys-ds/definitions/data_rts"
        },
        "meta_rts": {
          "$ref": "#/definitions/sys-ds/definitions/meta_rts"
        }
      },
      "required": [
        "id",
        "label",
        "notes",
        "serial",
        "ctime",
        "mtime",
        "site_id",
        "product_id",
        "size_reservable",
        "size_reserve_hard_threshold",
        "size_reserve_soft_threshold",
        "iops_rating",
        "iops_scheduling",
        "iops_reserve_pct",
        "vss_provisioning",
        "label_tag",
        "vdisk_capacity_max",
        "vdisk_capacity_min",
        "blk_encode_default",
        "pool",
        "data",
        "meta",
        "product",
        "status",
        "size",
        "used",
        "reserve_size",
        "reserve_used",
        "reserve_iops",
        "iops_read",
        "iops_write",
        "iosz",
        "data_rts",
        "meta_rts"
      ],
      "additionalProperties": false
    },
    "dev": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "System Datastore Device",
      "description": "Retrieve and change certain basic parameters of iSCSI Devices and Operating System Devices from this common resource.  For parameters that are device-specific, consult the individual iSCSI device and operating system device resources.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
        }
      },
      "links": [
        {
          "description": "Info for existing dev.",
          "href": "/dev/{(%23%2Fdefinitions%2Fdev%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "List existing devs.",
          "href": "/dev",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        }
      ],
      "properties": {
      },
      "additionalProperties": false
    },
    "product": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Product",
      "description": "The Product resource has the list of Product Tags offered by a Datastore that has been configured to support automatic service provisioning.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/product/definitions/id"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "product create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "product last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "site_id": {
          "type": [
            "string"
          ],
          "example": "site:85:8",
          "description": "site product is located in"
        },
        "description": {
          "type": [
            "string"
          ],
          "description": "product description"
        },
        "tags": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "product tag"
          },
          "description": "array of product tags"
        },
        "search_token": {
          "description": "saved search token",
          "example": "5ba631ac93baa31ccc57ee358c97f97bc6754f98f90fa2d6c01bfd3dcdaaa1ce",
          "type": [
            "string"
          ]
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        }
      },
      "links": [
        {
          "description": "Query the storage product catalog.",
          "href": "/product/search",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "capacity": {
                "type": [
                  "integer"
                ],
                "example": 1073741824,
                "description": "capacity to reserve"
              },
              "iops": {
                "type": [
                  "integer"
                ],
                "description": "IOPS to reserve"
              },
              "scheduling_algorithm": {
                "type": [
                  "string"
                ],
                "description": "scheduling algorithm label"
              },
              "tags": {
                "type": [
                  "object"
                ],
                "description": "product query tag",
                "properties": {
                  "include": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "include value"
                    },
                    "description": "include array"
                  },
                  "exclude": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "exclude value"
                    },
                    "description": "exclude array"
                  }
                },
                "additionalProperties": false
              },
              "count": {
                "type": [
                  "integer"
                ],
                "default": 3,
                "description": "number of results"
              },
              "template": {
                "type": [
                  "string"
                ],
                "description": "service template"
              }
            },
            "description": "catalog query arguments",
            "required": [
              "capacity"
            ],
            "additionalProperties": false
          },
          "title": "Search Create",
          "x_bb_method": "catalog_query"
        },
        {
          "description": "Retrieve the available storage catalog parameters.",
          "href": "/product/search/params",
          "method": "GET",
          "rel": "self",
          "title": "Search Parameters",
          "x_bb_method": "catalog_params"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/product/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/product/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/product/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/product/definitions/mtime"
        },
        "site_id": {
          "$ref": "#/definitions/product/definitions/site_id"
        },
        "description": {
          "$ref": "#/definitions/product/definitions/description"
        },
        "tags": {
          "$ref": "#/definitions/product/definitions/tags"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "site_id",
        "description",
        "tags"
      ],
      "additionalProperties": false
    },
    "vss": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Virtual Storage Service",
      "description": "A Secure virtual service delivers storage resources to applications, customers, developers and your cloud infrastructure, in a service-oriented fashion.  Virtual services can be manually or automatically provisioned. \n\nThese virtual services are provisioned from the storage resources provided by a datastore.  Each virtual storage service provides an independent storage area network (SAN).  You can provision disks and iSCSI targets within a virtual storage service as needed. \n\nThe Blockbridge management network makes it possible to manage multiple, distributed virtual storage services from the management application. This allows a single tenant account to operate multiple classes of storage, to scale, and to implement disaster tolerance using virtual disk level replication.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/vss/definitions/id"
            },
            {
              "$ref": "#/definitions/vss/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "virtual stroage service create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "virtual storage service last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "label": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned label"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "node_id": {
          "type": [
            "string"
          ],
          "example": "node:57:14",
          "description": "storage node id"
        },
        "account_id": {
          "type": [
            "string"
          ],
          "example": "account:23:11",
          "description": "account id"
        },
        "product_id": {
          "type": [
            "string"
          ],
          "example": "product:83:15",
          "description": "product id"
        },
        "location": {
          "type": [
            "object"
          ],
          "description": "location information",
          "properties": {
            "country": {
              "type": [
                "string"
              ],
              "description": "ISO 3166-1 alpha-3 country code",
              "default": ""
            },
            "lat": {
              "type": [
                "number"
              ],
              "description": "latitude",
              "default": 0
            },
            "long": {
              "type": [
                "number"
              ],
              "description": "longitude",
              "default": 0
            },
            "city": {
              "type": [
                "string"
              ],
              "description": "city",
              "default": ""
            },
            "state": {
              "type": [
                "string"
              ],
              "description": "state as two-character USPS abbreviation",
              "default": ""
            }
          },
          "additionalProperties": false
        },
        "location_str": {
          "type": [
            "string"
          ],
          "description": "location short string"
        },
        "tier": {
          "type": [
            "string"
          ],
          "enum": [
            "I",
            "II",
            "III",
            "IV"
          ],
          "description": "datacenter infrastructure tier",
          "example": "I"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "virtual storage service serial number"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string for event application to display associated events"
        },
        "cap_size_ratio": {
          "type": [
            "number",
            "null"
          ],
          "description": "ratio of user addressable capacity to size"
        },
        "quota": {
          "type": [
            "object",
            "null"
          ],
          "description": "restrictions on virtual storage service size and IOPS",
          "properties": {
            "size": {
              "type": [
                "object"
              ],
              "description": "storage consumption quota",
              "properties": {
                "limit": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "upper hard limit on size",
                  "example": 1073741824
                },
                "notify": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "notification threshold for size",
                  "example": 1073741824
                },
                "reserve": {
                  "type": [
                    "integer"
                  ],
                  "description": "guaranteed storage resources",
                  "example": 1073741824
                }
              },
              "required": [
                "limit",
                "notify",
                "reserve"
              ],
              "additionalProperties": false
            },
            "iops": {
              "type": [
                "object"
              ],
              "description": "I/O operations per second quota",
              "properties": {
                "limit": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "limit on sustained I/O operations per second"
                },
                "reserve": {
                  "type": [
                    "integer"
                  ],
                  "description": "reserve I/O operations per second"
                },
                "burst": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "upper limit for rate that burst credits can be spent"
                },
                "burst_credits": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "upper limit on the number bursting credits that may be accumulated"
                }
              },
              "required": [
                "limit",
                "reserve",
                "burst",
                "burst_credits"
              ],
              "additionalProperties": false
            }
          },
          "additionalProperties": false,
          "required": [
            "size",
            "iops"
          ]
        },
        "trashed": {
          "type": [
            "boolean"
          ],
          "description": "waiting for garbage collection"
        },
        "xmd_refs": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "arbitrary string reference key"
          },
          "description": "array of extensible metadata reference keys"
        },
        "xref": {
          "type": [
            "string"
          ],
          "description": "arbitrary string reference"
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "virtual storage service status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "online"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "online"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "isotime": {
          "type": [
            "string",
            "null"
          ],
          "format": "date-time",
          "description": "local time on node"
        },
        "humantime": {
          "type": [
            "string",
            "null"
          ],
          "description": "human-readable time on node"
        },
        "build_version": {
          "type": [
            "string",
            "null"
          ],
          "description": "version of software running on node"
        },
        "build_time": {
          "type": [
            "string",
            "null"
          ],
          "description": "time and date that node software was built"
        },
        "version": {
          "type": [
            "object",
            "null"
          ],
          "description": "build version",
          "properties": {
            "hash": {
              "type": [
                "string"
              ],
              "description": "build hash"
            },
            "minor": {
              "type": [
                "integer"
              ],
              "description": "build minor version"
            },
            "major": {
              "type": [
                "integer"
              ],
              "description": "build major version"
            },
            "timestamp": {
              "type": [
                "integer"
              ],
              "description": "build timestamp"
            },
            "patch": {
              "type": [
                "integer"
              ],
              "description": "build patch version"
            },
            "tag": {
              "type": [
                "string"
              ],
              "description": "build tag"
            },
            "release": {
              "type": [
                "string"
              ],
              "description": "build release"
            }
          },
          "required": [
            "hash",
            "minor",
            "major",
            "release",
            "timestamp",
            "patch",
            "tag"
          ],
          "additionalProperties": false
        },
        "sizing": {
          "type": [
            "object",
            "null"
          ],
          "description": "virtual storage service sizing information",
          "properties": {
            "size": {
              "type": [
                "integer",
                "null"
              ],
              "description": "size of virtual storage service (in bytes)",
              "example": 1073741824
            },
            "snapshot": {
              "type": [
                "integer",
                "null"
              ],
              "description": "snapshot size (in bytes)",
              "example": 1073741824
            },
            "reserve_total": {
              "type": [
                "integer",
                "null"
              ],
              "description": "reserved size of all disks or the virtual storage service reserve, whichever is greater (in bytes)",
              "example": 1073741824
            }
          },
          "required": [
            "size",
            "snapshot",
            "reserve_total"
          ],
          "additionalProperties": false
        },
        "xmd": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "per-linked xmd data",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "example": "xmd:42:8",
                "description": "no documentation"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference key"
              },
              "mtime": {
                "type": [
                  "integer"
                ],
                "description": "last modified time of xmd",
                "minimum": 0,
                "example": 1443200456094
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "self": {
                "type": [
                  "boolean"
                ],
                "description": "no documentation"
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "no documentation",
                "properties": {
                }
              }
            },
            "additionalProperties": false,
            "required": [
              "id",
              "ref",
              "mtime",
              "tags",
              "data"
            ]
          },
          "description": "array of api xmd results"
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "node_serial": {
          "type": [
            "string"
          ],
          "description": "storage node serial"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing virtual storage service.",
          "href": "/vss/{(%23%2Fdefinitions%2Fvss%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate virtual storage services.",
          "href": "/vss",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Provision a new virtual storage service.  The system datastore is selected by conducting a storage product search.",
          "href": "/vss",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "token": {
                "type": [
                  "string"
                ],
                "pattern": "[a-fA-F0-9]*",
                "description": "provision token"
              },
              "vss": {
                "type": [
                  "object"
                ],
                "description": "virtual service params",
                "properties": {
                  "label": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "label"
                  },
                  "xmd_refs": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "arbitrary string reference key"
                    },
                    "description": "array of extensible metadata reference keys"
                  },
                  "xref": {
                    "type": [
                      "string"
                    ],
                    "description": "arbitrary string reference"
                  },
                  "notes": {
                    "type": [
                      "string"
                    ],
                    "description": "user assigned notes"
                  }
                },
                "additionalProperties": false
              },
              "disk": {
                "type": [
                  "object"
                ],
                "description": "disk params",
                "properties": {
                  "create": {
                    "type": [
                      "boolean"
                    ],
                    "default": false,
                    "description": "create disk"
                  },
                  "label": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "label"
                  },
                  "tags": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "tag"
                    },
                    "description": "disk tags"
                  },
                  "xmd_refs": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "arbitrary string reference key"
                    },
                    "description": "array of extensible metadata reference keys"
                  },
                  "xref": {
                    "type": [
                      "string"
                    ],
                    "description": "arbitrary string reference"
                  },
                  "obj_store_id": {
                    "type": [
                      "string"
                    ],
                    "description": "object store id from which virtual disk is cloned"
                  },
                  "backup_id": {
                    "type": [
                      "string"
                    ],
                    "description": "backup ID from which virtual disk is cloned"
                  },
                  "src": {
                    "type": [
                      "string"
                    ],
                    "example": "object",
                    "enum": [
                      "vdisk",
                      "snapshot",
                      "object",
                      "block"
                    ],
                    "description": "clone source"
                  },
                  "snapshot_id": {
                    "type": [
                      "string"
                    ],
                    "description": "snapshot id from which virtual disk is cloned"
                  },
                  "vdisk_id": {
                    "type": [
                      "string"
                    ],
                    "description": "virtual disk id from which virtual disk is cloned"
                  },
                  "block_id": {
                    "type": [
                      "string"
                    ],
                    "description": "block device id from which virtual disk is cloned"
                  },
                  "thicken": {
                    "type": [
                      "boolean"
                    ],
                    "description": "thicken clone from source"
                  },
                  "bandwidth": {
                    "type": [
                      "integer"
                    ],
                    "description": "thicken bandwidth limit in bytes/sec"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "label": {
                    "properties": {
                      "create": {
                        "enum": [
                          true
                        ]
                      }
                    }
                  },
                  "tags": {
                    "properties": {
                      "create": {
                        "enum": [
                          true
                        ]
                      }
                    }
                  },
                  "snapshot_id": {
                    "properties": {
                      "src": {
                        "enum": [
                          "snapshot"
                        ]
                      }
                    }
                  },
                  "vdisk_id": {
                    "properties": {
                      "src": {
                        "enum": [
                          "vdisk"
                        ]
                      }
                    }
                  },
                  "block_id": {
                    "properties": {
                      "src": {
                        "enum": [
                          "block"
                        ]
                      }
                    }
                  },
                  "thicken": {
                    "properties": {
                      "src": {
                      }
                    }
                  },
                  "bandwidth": {
                    "properties": {
                      "thicken": {
                      }
                    }
                  }
                }
              },
              "profile": {
                "type": [
                  "object"
                ],
                "description": "profile params",
                "properties": {
                  "create": {
                    "type": [
                      "boolean"
                    ],
                    "default": false,
                    "description": "create profile"
                  },
                  "label": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "label"
                  },
                  "xmd_refs": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "arbitrary string reference key"
                    },
                    "description": "array of extensible metadata reference keys"
                  },
                  "xref": {
                    "type": [
                      "string"
                    ],
                    "description": "arbitrary string reference"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "label": {
                    "properties": {
                      "create": {
                        "enum": [
                          true
                        ]
                      }
                    }
                  }
                }
              },
              "target": {
                "type": [
                  "object"
                ],
                "description": "target params",
                "properties": {
                  "create": {
                    "type": [
                      "boolean"
                    ],
                    "default": false,
                    "description": "create target"
                  },
                  "label": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "label"
                  },
                  "xmd_refs": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "arbitrary string reference key"
                    },
                    "description": "array of extensible metadata reference keys"
                  },
                  "xref": {
                    "type": [
                      "string"
                    ],
                    "description": "arbitrary string reference"
                  },
                  "map_disk": {
                    "type": [
                      "boolean"
                    ],
                    "default": true,
                    "description": "map created disk into target"
                  },
                  "allow_profile": {
                    "type": [
                      "boolean"
                    ],
                    "default": true,
                    "description": "add profile to access control list"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "label": {
                    "properties": {
                      "create": {
                        "enum": [
                          true
                        ]
                      }
                    }
                  },
                  "map_disk": {
                    "properties": {
                      "create": {
                        "enum": [
                          true
                        ]
                      }
                    }
                  },
                  "allow_profile": {
                    "properties": {
                      "create": {
                        "enum": [
                          true
                        ]
                      }
                    }
                  }
                }
              },
              "xmd": {
                "type": [
                  "object"
                ],
                "description": "xmd params",
                "properties": {
                  "create": {
                    "type": [
                      "boolean"
                    ],
                    "default": false,
                    "description": "create xmd"
                  },
                  "ref": {
                    "type": [
                      "string"
                    ],
                    "description": "arbitrary string reference key"
                  },
                  "label": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "label",
                    "default": null
                  },
                  "notes": {
                    "type": [
                      "string"
                    ],
                    "description": "user assigned notes"
                  },
                  "tags": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "tag"
                    },
                    "description": "tags"
                  },
                  "xmd_refs": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "arbitrary string reference key"
                    },
                    "description": "array of extensible metadata reference keys"
                  },
                  "xref": {
                    "type": [
                      "string"
                    ],
                    "description": "arbitrary string reference"
                  },
                  "data": {
                    "type": [
                      "string",
                      "object",
                      "array",
                      "null"
                    ],
                    "description": "no documentation",
                    "properties": {
                    }
                  },
                  "publish": {
                    "type": [
                      "boolean"
                    ],
                    "description": "publish xmd"
                  },
                  "reservation": {
                    "type": [
                      "boolean"
                    ],
                    "description": "reserve xmd grouping"
                  },
                  "exists_ok": {
                    "type": [
                      "boolean"
                    ],
                    "default": false,
                    "description": "create is idempotent"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "label": {
                    "properties": {
                      "create": {
                        "enum": [
                          true
                        ]
                      }
                    }
                  }
                }
              },
              "account_id": {
                "type": [
                  "string"
                ],
                "example": "account:39:8",
                "description": "account id"
              },
              "query": {
                "type": [
                  "object"
                ],
                "description": "optional query params",
                "properties": {
                  "capacity": {
                    "type": [
                      "integer"
                    ],
                    "example": 1073741824,
                    "description": "capacity to reserve"
                  },
                  "iops": {
                    "type": [
                      "integer"
                    ],
                    "description": "IOPS to reserve"
                  },
                  "scheduling_algorithm": {
                    "type": [
                      "string"
                    ],
                    "description": "scheduling algorithm label"
                  },
                  "tags": {
                    "type": [
                      "object"
                    ],
                    "description": "product query tag",
                    "properties": {
                      "include": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "include value"
                        },
                        "description": "include array"
                      },
                      "exclude": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "string"
                          ],
                          "description": "exclude value"
                        },
                        "description": "exclude array"
                      }
                    },
                    "additionalProperties": false
                  },
                  "count": {
                    "type": [
                      "integer"
                    ],
                    "default": 1,
                    "description": "number of results"
                  },
                  "template": {
                    "type": [
                      "string"
                    ],
                    "description": "service template"
                  }
                },
                "additionalProperties": false
              }
            },
            "description": "vss provision request arguments",
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "vss_provision"
        },
        {
          "description": "Remove an existing virtual storage service, including its virtual disks, iSCSI targets, and initiator profiles.  User data that remains in the service will be irretrievable.",
          "href": "/vss/{(%23%2Fdefinitions%2Fvss%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "vss_remove"
        },
        {
          "description": "Change the configuration of an existing virtual storage service.",
          "href": "/vss/{(%23%2Fdefinitions%2Fvss%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              }
            },
            "description": "vss update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "vss_update"
        },
        {
          "description": "Change the quota for a virtual storage service.",
          "href": "/vss/{(%23%2Fdefinitions%2Fvss%2Fdefinitions%2Fidentity)}/quota",
          "method": "PUT",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "size": {
                "type": [
                  "object"
                ],
                "description": "storage consumption quota",
                "properties": {
                  "limit": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "default": null,
                    "example": 1073741824,
                    "description": "upper hard limit on size"
                  },
                  "notify": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "default": null,
                    "example": 1073741824,
                    "description": "notification threshold for size"
                  },
                  "reserve": {
                    "type": [
                      "integer"
                    ],
                    "default": 0,
                    "example": 1073741824,
                    "description": "guaranteed storage resources"
                  }
                },
                "additionalProperties": false
              },
              "iops": {
                "type": [
                  "object"
                ],
                "description": "I/O operations per second quota",
                "properties": {
                  "limit": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "default": null,
                    "description": "limit on sustained I/O operations per second"
                  },
                  "reserve": {
                    "type": [
                      "integer"
                    ],
                    "default": 0,
                    "description": "reserve I/O operations per second"
                  },
                  "burst": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "default": null,
                    "description": "upper limit for rate that burst credits can be spent"
                  },
                  "burst_credits": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "default": null,
                    "description": "upper limit on the number bursting credits that may be accumulated"
                  }
                },
                "additionalProperties": false
              }
            },
            "description": "place restrictions on virtual storage service size and IOPS",
            "additionalProperties": false
          },
          "title": "Quota Update",
          "x_bb_method": "vss_quota_set_rest"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/vss/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/vss/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/vss/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/vss/definitions/mtime"
        },
        "label": {
          "$ref": "#/definitions/vss/definitions/label"
        },
        "notes": {
          "$ref": "#/definitions/vss/definitions/notes"
        },
        "node_id": {
          "$ref": "#/definitions/vss/definitions/node_id"
        },
        "node_serial": {
          "$ref": "#/definitions/vss/definitions/node_serial"
        },
        "account_id": {
          "$ref": "#/definitions/vss/definitions/account_id"
        },
        "product_id": {
          "$ref": "#/definitions/vss/definitions/product_id"
        },
        "location": {
          "$ref": "#/definitions/vss/definitions/location"
        },
        "location_str": {
          "$ref": "#/definitions/vss/definitions/location_str"
        },
        "tier": {
          "$ref": "#/definitions/vss/definitions/tier"
        },
        "serial": {
          "$ref": "#/definitions/vss/definitions/serial"
        },
        "cap_size_ratio": {
          "$ref": "#/definitions/vss/definitions/cap_size_ratio"
        },
        "quota": {
          "$ref": "#/definitions/vss/definitions/quota"
        },
        "trashed": {
          "$ref": "#/definitions/vss/definitions/trashed"
        },
        "xmd_refs": {
          "$ref": "#/definitions/vss/definitions/xmd_refs"
        },
        "xref": {
          "$ref": "#/definitions/vss/definitions/xref"
        },
        "status": {
          "$ref": "#/definitions/vss/definitions/status"
        },
        "isotime": {
          "$ref": "#/definitions/vss/definitions/isotime"
        },
        "humantime": {
          "$ref": "#/definitions/vss/definitions/humantime"
        },
        "build_version": {
          "$ref": "#/definitions/vss/definitions/build_version"
        },
        "build_time": {
          "$ref": "#/definitions/vss/definitions/build_time"
        },
        "version": {
          "$ref": "#/definitions/vss/definitions/version"
        },
        "sizing": {
          "$ref": "#/definitions/vss/definitions/sizing"
        },
        "xmd": {
          "$ref": "#/definitions/vss/definitions/xmd"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "label",
        "notes",
        "node_id",
        "node_serial",
        "account_id",
        "product_id",
        "location",
        "location_str",
        "tier",
        "serial",
        "cap_size_ratio",
        "quota",
        "xmd_refs",
        "status",
        "isotime",
        "humantime",
        "build_version",
        "build_time",
        "version",
        "sizing"
      ],
      "additionalProperties": false
    },
    "vdisk": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Virtual Disk",
      "description": "Virtual disks provide isolated data resources. Each virtual disk has a unique set of encryption keys. Those keys are automatically disposed of when the disk is deleted. You can take the keys out of the infrastructure, and you can provide them in-line of access.  \n\nVirtual disks are thinly provisioned.  They support no-I/O snapshots, which can be cloned. Virtual disks support limits on IOPS and quotas on storage consumption. Quotas allow you to dedicate storage resources to a disk. \n\nVirtual disks also support synchronous and asynchronous block-level replication, along with the ability to validate data integrity and authenticity.  They support SCSI SPC-3 persistent reservations and various emulation modes (including removable disks).",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/vdisk/definitions/id"
            },
            {
              "$ref": "#/definitions/vdisk/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "master_id": {
          "type": [
            "string"
          ],
          "description": "master disk id"
        },
        "slave_id": {
          "type": [
            "string"
          ],
          "description": "slave disk id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "virtual disk create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "virtual disk last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "type": {
          "type": [
            "string"
          ],
          "enum": [
            "internal",
            "external"
          ],
          "description": "vdisk type",
          "example": "external"
        },
        "label": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned label"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "tags": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "tag"
          },
          "description": "object tags"
        },
        "vss_id": {
          "type": [
            "string"
          ],
          "description": "virtual storage service id",
          "example": "vss:57:15"
        },
        "node_id": {
          "type": [
            "string"
          ],
          "description": "storage node id",
          "example": "node:99:11"
        },
        "account_id": {
          "type": [
            "string"
          ],
          "description": "account id",
          "example": "account:18:13"
        },
        "basis_id": {
          "type": [
            "string",
            "null"
          ],
          "description": "snapshot id from which disk is cloned (if clone)",
          "example": "snapshot:99:13"
        },
        "transient": {
          "type": [
            "boolean"
          ],
          "description": "disk is transient"
        },
        "capacity": {
          "type": [
            "integer",
            "null"
          ],
          "description": "user addressable capacity in bytes",
          "example": 1073741824
        },
        "blk_encoding": {
          "type": [
            "string",
            "null"
          ],
          "enum": [
            "aes256-gcm-4k",
            "aes128-xts-4k"
          ],
          "description": "encryption type and format of virtual blocks",
          "example": "aes256-gcm-4k"
        },
        "cap_size_ratio": {
          "type": [
            "number",
            "null"
          ],
          "description": "ratio of user addressable capacity to size"
        },
        "quota": {
          "type": [
            "object",
            "null"
          ],
          "description": "restrictions on virtual disk size and IOPS",
          "properties": {
            "size": {
              "type": [
                "object"
              ],
              "description": "storage consumption quota",
              "properties": {
                "limit": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "upper hard limit on size",
                  "example": 1073741824
                },
                "notify": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "notification threshold for size",
                  "example": 1073741824
                },
                "reserve": {
                  "type": [
                    "integer"
                  ],
                  "description": "guaranteed storage resources",
                  "example": 1073741824
                }
              },
              "additionalProperties": false
            },
            "iops": {
              "type": [
                "object"
              ],
              "description": "I/O operations per second quota",
              "properties": {
                "limit": {
                  "type": [
                    "integer",
                    "null"
                  ],
                  "description": "limit on sustained I/O operations per second"
                }
              },
              "additionalProperties": false
            },
            "workload": {
              "type": [
                "string",
                "null"
              ],
              "enum": [
                "lower_iops",
                "normal_iops",
                "higher_iops"
              ],
              "description": "workload hint",
              "example": "higher_iops"
            }
          },
          "additionalProperties": false
        },
        "locked": {
          "type": [
            "boolean"
          ],
          "description": "virtual disk is locked"
        },
        "caps": {
          "type": [
            "object"
          ],
          "description": "virtual disk capabilities",
          "properties": {
            "encryption": {
              "type": [
                "string",
                "null"
              ],
              "description": "encryption technique for stored data blocks"
            },
            "eval": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "disk is non-persistent, for demonstration use only"
            }
          },
          "required": [
            "encryption",
            "eval"
          ],
          "additionalProperties": false
        },
        "scsi": {
          "type": [
            "object"
          ],
          "description": "virtual disk SCSI parameters",
          "properties": {
            "protocol": {
              "type": [
                "string"
              ],
              "description": "SCSI protocol compatibility set"
            },
            "tagged_queuing": {
              "type": [
                "boolean"
              ],
              "description": "tagged queuing",
              "default": true
            },
            "reservations": {
              "type": [
                "boolean"
              ],
              "description": "persistent reservations",
              "default": true
            },
            "lu_serial": {
              "type": [
                "string"
              ],
              "description": "logical unit serial number"
            },
            "vendor_id": {
              "type": [
                "string",
                "null"
              ],
              "description": "SCSI vendor id string"
            },
            "eui64_id": {
              "type": [
                "string",
                "null"
              ],
              "description": "EUI-64 id string"
            },
            "t10_id": {
              "type": [
                "string",
                "null"
              ],
              "description": "T10 id string"
            },
            "naa_id": {
              "type": [
                "string",
                "null"
              ],
              "description": "Network Address Authority id string"
            },
            "ua_interlock": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "unit attention interlock"
            },
            "aca": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "auto-contingent alliegance"
            },
            "vendor_ext": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "vendor extensions"
            },
            "dif": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "data integrity field"
            },
            "multi_map": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "multi-map permitted"
            },
            "read_only": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "read-only disk"
            },
            "removable": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "removable disk emulation"
            },
            "advise_lbp": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "advisory logical block provisioning"
            },
            "features": {
              "type": [
                "string"
              ],
              "description": "SCSI features summary"
            },
            "write_once": {
              "type": [
                "boolean",
                "null"
              ],
              "description": "Write-once disk"
            }
          },
          "required": [
            "protocol",
            "lu_serial",
            "vendor_id",
            "eui64_id",
            "t10_id",
            "naa_id",
            "ua_interlock",
            "aca",
            "vendor_ext",
            "dif",
            "multi_map",
            "read_only",
            "write_once",
            "removable",
            "advise_lbp",
            "features"
          ],
          "additionalProperties": false
        },
        "replication": {
          "type": [
            "object",
            "null"
          ],
          "description": "virtual disk replication parameters",
          "properties": {
            "master": {
              "type": [
                "object",
                "null"
              ],
              "description": "replication master parameters",
              "properties": {
                "disk_id": {
                  "type": [
                    "string"
                  ],
                  "description": "master virtual disk id",
                  "example": "vdisk:48:7"
                },
                "disk_serial": {
                  "type": [
                    "string"
                  ],
                  "description": "master virtual disk serial number"
                }
              },
              "required": [
                "disk_id",
                "disk_serial"
              ],
              "additionalProperties": false
            },
            "slaves": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "virtual disk replication slave",
                "properties": {
                  "state": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "disabled",
                      "enabled",
                      "suspended"
                    ],
                    "description": "slave state",
                    "example": "disabled"
                  },
                  "disk_id": {
                    "type": [
                      "string"
                    ],
                    "description": "slave virtual disk id",
                    "example": "vdisk:42:8"
                  },
                  "disk_serial": {
                    "type": [
                      "string"
                    ],
                    "description": "slave virtual disk serial number"
                  },
                  "config": {
                    "type": [
                      "object"
                    ],
                    "description": "replication slave configuration",
                    "properties": {
                      "mode": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "async",
                          "sync",
                          "async-ordered"
                        ],
                        "description": "replication mode",
                        "example": "sync"
                      },
                      "max_lag_cmds": {
                        "type": [
                          "integer"
                        ],
                        "description": "maximum commands to lag behind during async replication"
                      },
                      "max_lag_bytes": {
                        "type": [
                          "integer"
                        ],
                        "description": "maximum bytes to lag behind during async replication",
                        "example": 1073741824
                      },
                      "recovery": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "none",
                          "drl"
                        ],
                        "description": "recovery options",
                        "example": "drl"
                      },
                      "rebuild_bandwidth": {
                        "type": [
                          "integer"
                        ],
                        "description": "rebuild bandwidth limit in bytes/sec",
                        "default": 0
                      },
                      "rebuild_hash": {
                        "type": [
                          "boolean"
                        ],
                        "description": "use a hashing optimization to reduce network traffic during rebuild",
                        "default": true
                      },
                      "timeout": {
                        "type": [
                          "integer"
                        ],
                        "minimum": 100,
                        "description": "time to wait (in milliseconds) before stopping an unresponsive slave",
                        "default": 20000
                      }
                    },
                    "required": [
                      "mode",
                      "max_lag_cmds",
                      "max_lag_bytes",
                      "recovery"
                    ],
                    "additionalProperties": false,
                    "dependencies": {
                      "max_lag_cmds": {
                        "properties": {
                          "mode": {
                            "enum": [
                              "async"
                            ]
                          }
                        }
                      },
                      "max_lag_bytes": {
                        "properties": {
                          "mode": {
                            "enum": [
                              "async"
                            ]
                          }
                        }
                      }
                    }
                  },
                  "policy": {
                    "type": [
                      "string",
                      "object",
                      "array",
                      "null"
                    ],
                    "description": "replication policy",
                    "properties": {
                    }
                  }
                },
                "required": [
                  "state",
                  "disk_id",
                  "disk_serial",
                  "config",
                  "policy"
                ],
                "additionalProperties": false
              },
              "description": "list of configured replication slave virtual disks"
            }
          },
          "required": [
            "master",
            "slaves"
          ],
          "additionalProperties": false
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "virtual disk serial number"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string to display associated events"
        },
        "task": {
          "type": [
            "object"
          ],
          "description": "long-running task state",
          "properties": {
            "id": {
              "type": [
                "string"
              ],
              "description": "running task id",
              "example": "ptask:89:9"
            },
            "op": {
              "type": [
                "string"
              ],
              "enum": [
                "none",
                "backup",
                "format",
                "verify",
                "synchronize",
                "resize"
              ],
              "description": "task state",
              "example": "backup"
            }
          },
          "required": [
            "op"
          ],
          "additionalProperties": false
        },
        "trashed": {
          "type": [
            "boolean"
          ],
          "description": "object is awaiting garbage collection"
        },
        "xmd_refs": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "arbitrary string reference key"
          },
          "description": "array of extensible metadata reference keys"
        },
        "xref": {
          "type": [
            "string"
          ],
          "description": "arbitrary string reference"
        },
        "readahead": {
          "type": [
            "object"
          ],
          "description": "readahead parameters",
          "properties": {
            "mode": {
              "type": [
                "string",
                "null"
              ],
              "enum": [
                "none",
                "constant"
              ],
              "description": "readahead mode control",
              "example": "constant"
            },
            "size": {
              "type": [
                "integer"
              ],
              "maximum": 4194304,
              "description": "readahead size"
            }
          },
          "required": [
            "mode",
            "size"
          ],
          "additionalProperties": false,
          "dependencies": {
            "size": {
              "properties": {
                "mode": {
                  "enum": [
                    "constant"
                  ]
                }
              }
            }
          }
        },
        "encryption": {
          "type": [
            "object",
            "null"
          ],
          "description": "virtual disk encryption details",
          "properties": {
            "method": {
              "type": [
                "string"
              ],
              "description": "encryption method keyword"
            },
            "method_desc": {
              "type": [
                "string"
              ],
              "description": "human-readable encryption method description"
            },
            "cipher": {
              "type": [
                "string"
              ],
              "description": "encryption cipher keyword"
            },
            "cipher_desc": {
              "type": [
                "string"
              ],
              "description": "human-readable encryption cipher description"
            },
            "mode": {
              "type": [
                "string"
              ],
              "description": "encryption mode keyword"
            },
            "mode_desc": {
              "type": [
                "string"
              ],
              "description": "human-readable encryption mode description"
            },
            "key_desc": {
              "type": [
                "string"
              ],
              "description": "human-readable encryption key description"
            }
          },
          "required": [
            "method",
            "method_desc",
            "cipher",
            "cipher_desc",
            "mode",
            "mode_desc",
            "key_desc"
          ],
          "additionalProperties": false
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "virtual disk status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "offline"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "offline"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "scsi_reservations": {
          "type": [
            "object",
            "null"
          ],
          "description": "virtual disk scsi reservations",
          "properties": {
            "generation": {
              "type": [
                "integer"
              ],
              "description": "SCSI reservation generation"
            },
            "persist": {
              "type": [
                "boolean"
              ],
              "description": "persist through power loss"
            },
            "reserve6": {
              "type": [
                "object"
              ],
              "description": "SCSI RESERVE(6) Reservation",
              "properties": {
                "ini_id": {
                  "type": [
                    "string"
                  ],
                  "description": "reservation initiator id",
                  "example": "initiator:30:6"
                },
                "isid": {
                  "type": [
                    "integer"
                  ],
                  "maximum": 281474976710660,
                  "description": "reservation iSCSI session id"
                }
              },
              "additionalProperties": false
            },
            "reservations": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "virtual disk SCSI SPC-3 reservation",
                "properties": {
                  "holder": {
                    "type": [
                      "boolean"
                    ],
                    "description": "reservation holder"
                  },
                  "ini_id": {
                    "type": [
                      "string"
                    ],
                    "description": "reservation initiator id",
                    "example": "initiator:96:8"
                  },
                  "isid": {
                    "type": [
                      "integer"
                    ],
                    "maximum": 281474976710660,
                    "description": "reservation iSCSI session id"
                  },
                  "key": {
                    "type": [
                      "integer"
                    ],
                    "description": "reservation key"
                  },
                  "type": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "wr_ex",
                      "ex_ac",
                      "wr_ex_reg_only",
                      "ex_ac_reg_only",
                      "wr_ex_all_reg",
                      "ex_ac_all_reg"
                    ],
                    "description": "reservation type",
                    "example": "wr_ex_all_reg"
                  }
                },
                "required": [
                  "holder",
                  "ini_id",
                  "isid",
                  "key",
                  "type"
                ],
                "additionalProperties": false,
                "dependencies": {
                  "type": {
                    "properties": {
                      "holder": {
                        "enum": [
                          true
                        ]
                      }
                    }
                  }
                }
              },
              "description": "list of SCSI SPC-3 Persistent Reservations"
            }
          },
          "required": [
            "generation",
            "persist",
            "reservations"
          ],
          "additionalProperties": false
        },
        "media_loaded": {
          "type": [
            "boolean",
            "null"
          ],
          "description": "removable media loaded (if removable)"
        },
        "loaded_profile_id": {
          "type": [
            "string",
            "null"
          ],
          "description": "loaded initiator profile (if removable)",
          "example": "initiator_profile:78:8"
        },
        "loaded_profile_serial": {
          "type": [
            "string",
            "null"
          ],
          "description": "loaded initiator profile serial number (if removable)"
        },
        "sizing": {
          "type": [
            "object"
          ],
          "description": "disk sizing attributes (internal virtual disk)",
          "properties": {
            "size": {
              "type": [
                "integer",
                "null"
              ],
              "description": "size in bytes",
              "example": 1073741824
            },
            "snapshot": {
              "type": [
                "integer",
                "null"
              ],
              "description": "total snapshot size in bytes",
              "example": 1073741824
            }
          },
          "additionalProperties": false
        },
        "iops": {
          "type": [
            "integer",
            "null"
          ],
          "description": "normalized 4K I/O operations per second"
        },
        "xmd": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "per-linked xmd data",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "description": "no documentation",
                "example": "xmd:65:15"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference key"
              },
              "mtime": {
                "type": [
                  "integer"
                ],
                "description": "last modified time of xmd",
                "minimum": 0,
                "example": 1443200456094
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "self": {
                "type": [
                  "boolean"
                ],
                "description": "no documentation"
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "no documentation",
                "properties": {
                }
              }
            },
            "additionalProperties": false,
            "required": [
              "id",
              "ref",
              "mtime",
              "tags",
              "data"
            ]
          },
          "description": "array of api xmd results"
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "replication_rts": {
          "type": [
            "object",
            "null"
          ],
          "description": "virtual disk replication run-time state",
          "properties": {
            "master": {
              "type": [
                "object",
                "null"
              ],
              "description": "replication master status, from slave",
              "properties": {
                "state": {
                  "type": [
                    "string",
                    "null"
                  ],
                  "enum": [
                    "initializing",
                    "attached",
                    "detaching",
                    "rendezvous"
                  ],
                  "description": "virtual disk slave-side replication state",
                  "example": "attached"
                },
                "consistency": {
                  "type": [
                    "object"
                  ],
                  "description": "statistics for a replication slave, from the perspective of the slave node",
                  "properties": {
                    "master_serial": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "slave consistency reported with respect to specified master virtual disk serial number"
                    },
                    "master": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "slave consistency reported with respect to specified master virtual disk ID",
                      "example": "vdisk:17:10"
                    },
                    "time": {
                      "type": [
                        "integer",
                        "null"
                      ],
                      "minimum": 0,
                      "description": "slave is consistent with master as of this time",
                      "example": 1443200456094
                    },
                    "repl_id": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "description": "virtual disk SCSI id"
                    }
                  },
                  "required": [
                    "master_serial",
                    "master",
                    "time",
                    "repl_id"
                  ],
                  "additionalProperties": false
                }
              },
              "required": [
                "state",
                "consistency"
              ],
              "additionalProperties": false
            },
            "slaves": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "object"
                ],
                "description": "master-side replication statistics",
                "properties": {
                  "disk_id": {
                    "type": [
                      "string"
                    ],
                    "description": "replication slave virtual disk id",
                    "example": "vdisk:77:5"
                  },
                  "syndromes": {
                    "type": [
                      "array"
                    ],
                    "items": {
                      "type": [
                        "string"
                      ],
                      "description": "master-side slave state syndrome"
                    },
                    "description": "master-side slave state syndrome list, if available"
                  },
                  "state": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "enum": [
                      "active",
                      "attached",
                      "detached",
                      "detaching",
                      "disabled",
                      "disabling",
                      "enabling",
                      "initializing",
                      "halted",
                      "rebuild",
                      "rendezvous",
                      "resuming",
                      "suspended",
                      "suspending"
                    ],
                    "description": "virtual disk master-side slave replication state",
                    "example": "initializing"
                  },
                  "rebuild": {
                    "type": [
                      "object",
                      "null"
                    ],
                    "description": "statistics for the replication rebuild phase",
                    "properties": {
                      "elapsed": {
                        "type": [
                          "integer"
                        ],
                        "description": "elapsed time of rebuild in milliseconds"
                      },
                      "bandwidth": {
                        "type": [
                          "integer"
                        ],
                        "description": "interval SCSI end-to-end bandwidth in bytes/second"
                      },
                      "goal": {
                        "type": [
                          "integer"
                        ],
                        "description": "estimated total SCSI transfer bytes"
                      },
                      "mode": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "unknown",
                          "initial",
                          "recovery"
                        ],
                        "description": "replication rebuild mode",
                        "example": "unknown"
                      },
                      "evaluated": {
                        "type": [
                          "integer"
                        ],
                        "description": "of estimated transfer bytes, number evaluated"
                      },
                      "transfer": {
                        "type": [
                          "integer"
                        ],
                        "description": "total number of bytes written to destination"
                      },
                      "progress": {
                        "type": [
                          "integer"
                        ],
                        "minimum": 0,
                        "maximum": 100,
                        "description": "percent complete"
                      },
                      "ettc": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "minimum": 0,
                        "maximum": 2147483647000,
                        "description": "estimated time to completion in milliseconds"
                      },
                      "start_time": {
                        "type": [
                          "integer"
                        ],
                        "minimum": 0,
                        "description": "start time of this rebuild in milliseconds since epoch",
                        "example": 1443200456094
                      }
                    },
                    "required": [
                      "elapsed",
                      "bandwidth",
                      "goal",
                      "mode",
                      "evaluated",
                      "transfer",
                      "progress",
                      "ettc",
                      "start_time"
                    ],
                    "additionalProperties": false
                  },
                  "active": {
                    "type": [
                      "object",
                      "null"
                    ],
                    "description": "stats for the replication rebuild phase",
                    "properties": {
                      "bandwidth": {
                        "type": [
                          "integer"
                        ],
                        "description": "average network bandwidth in bytes/second"
                      },
                      "cmd_lag": {
                        "type": [
                          "integer"
                        ],
                        "description": "command lag"
                      },
                      "byte_lag": {
                        "type": [
                          "integer"
                        ],
                        "description": "transfer lag"
                      },
                      "latency": {
                        "type": [
                          "integer"
                        ],
                        "description": "write latency in milliseconds"
                      },
                      "history": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "object"
                          ],
                          "description": "data point",
                          "properties": {
                            "bandwidth": {
                              "type": [
                                "integer"
                              ],
                              "description": "average network bandwidth in bytes/second"
                            },
                            "cmd_lag": {
                              "type": [
                                "integer"
                              ],
                              "description": "command lag"
                            },
                            "byte_lag": {
                              "type": [
                                "integer"
                              ],
                              "description": "transfer lag"
                            },
                            "latency": {
                              "type": [
                                "integer"
                              ],
                              "description": "write latency in milliseconds"
                            },
                            "timestamp": {
                              "type": [
                                "integer"
                              ],
                              "minimum": 0,
                              "description": "timestamp of this snapshot",
                              "example": 1443200456094
                            }
                          },
                          "required": [
                            "bandwidth",
                            "cmd_lag",
                            "byte_lag",
                            "latency",
                            "timestamp"
                          ],
                          "additionalProperties": false
                        },
                        "description": "historical snapshots of active replication statistics"
                      },
                      "transfer": {
                        "type": [
                          "integer"
                        ],
                        "description": "bytes transferred"
                      }
                    },
                    "required": [
                      "bandwidth",
                      "cmd_lag",
                      "byte_lag",
                      "latency",
                      "history",
                      "transfer"
                    ],
                    "additionalProperties": false
                  },
                  "repair": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "enum": [
                      "repair",
                      "synchronize"
                    ],
                    "description": "replication slave repair method",
                    "example": "synchronize"
                  }
                },
                "required": [
                  "disk_id",
                  "syndromes",
                  "state",
                  "rebuild",
                  "active",
                  "repair"
                ],
                "additionalProperties": false
              },
              "description": "list of the run-time states of each replication slave virtual disk"
            }
          },
          "required": [
            "master",
            "slaves"
          ],
          "additionalProperties": false
        },
        "data_cache": {
          "type": [
            "boolean",
            "null"
          ],
          "description": "data read from disk will be cached"
        },
        "object_basis": {
          "type": [
            "object",
            "null"
          ],
          "description": "object basis for clone",
          "properties": {
            "obj_store_id": {
              "type": [
                "string"
              ],
              "description": "object store id from which virtual disk is cloned"
            },
            "object_key": {
              "type": [
                "string"
              ],
              "description": "object key from which virtual disk is cloned"
            }
          },
          "required": [
            "obj_store_id",
            "object_key"
          ],
          "additionalProperties": false
        },
        "basis": {
          "type": [
            "object",
            "null"
          ],
          "description": "disk basis",
          "properties": {
            "id": {
              "type": [
                "string"
              ],
              "description": "object id from which virtual disk is cloned"
            },
            "object_key": {
              "type": [
                "string"
              ],
              "description": "backup id from which virtual disk is cloned"
            },
            "src_id": {
              "type": [
                "string"
              ],
              "description": "basis src across attachment"
            },
            "requires_faultin": {
              "type": [
                "boolean"
              ],
              "description": "not thickened from basis"
            },
            "protocol": {
              "type": [
                "string"
              ],
              "example": "block",
              "enum": [
                "block",
                "object"
              ],
              "description": "protocol: block or object"
            },
            "locality": {
              "type": [
                "string"
              ],
              "example": "local",
              "enum": [
                "local",
                "remote"
              ],
              "description": "locality: local or remote"
            },
            "mode": {
              "type": [
                "string"
              ],
              "example": "read-through",
              "enum": [
                "read-through",
                "read-copy"
              ],
              "description": "mode: read-through or read-copy"
            },
            "gc": {
              "type": [
                "boolean"
              ],
              "description": "delete / detach basis objects when basis is unset"
            },
            "xref": {
              "type": [
                "string"
              ],
              "description": "basis xref"
            },
            "vss_id": {
              "type": [
                "string"
              ],
              "description": "basis vss"
            }
          },
          "required": [
            "id"
          ],
          "additionalProperties": false
        },
        "block_basis": {
          "type": [
            "object",
            "null"
          ],
          "description": "remote basis for clone",
          "properties": {
            "id": {
              "type": [
                "string"
              ],
              "description": "object id from which virtual disk is cloned"
            }
          },
          "required": [
            "id"
          ],
          "additionalProperties": false
        },
        "system": {
          "type": [
            "boolean"
          ],
          "description": "system target"
        },
        "compression": {
          "type": [
            "string",
            "null"
          ],
          "example": "economy",
          "enum": [
            "none",
            "inherit",
            "economy",
            "adaptive",
            "adaptive_economy",
            "adaptive_performance",
            "performance"
          ],
          "description": "compression codec"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate virtual disks.",
          "href": "/vdisk",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a new internal virtual disk.",
          "href": "/vdisk",
          "method": "POST",
          "rel": "create",
          "schema": {
            "example": {
              "vss_id": "vss:1:2",
              "capacity": 1024000,
              "label": "my-first-disk"
            },
            "type": [
              "object"
            ],
            "properties": {
              "vss_id": {
                "type": [
                  "string"
                ],
                "description": "virtual storage service id",
                "example": "vss:27:5"
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "virtual disk UUID"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "xref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference"
              },
              "multi_map": {
                "type": [
                  "boolean"
                ],
                "description": "virtual disk can be mapped into multiple targets"
              },
              "read_only": {
                "type": [
                  "boolean"
                ],
                "description": "virtual disk is read-only"
              },
              "removable": {
                "type": [
                  "boolean"
                ],
                "description": "virtual disk is removable"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "scsi_advise_lbp": {
                "type": [
                  "boolean"
                ],
                "description": "advisory SCSI logical block provisioning (internal use only)"
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "capacity": {
                "type": [
                  "integer"
                ],
                "minimum": 1048576,
                "maximum": 1125899906842624,
                "description": "capacity in bytes",
                "example": 1073741824
              },
              "quota": {
                "type": [
                  "object"
                ],
                "description": "restrictions on virtual disk size and IOPS",
                "properties": {
                  "size": {
                    "type": [
                      "object"
                    ],
                    "description": "storage consumption quota",
                    "properties": {
                      "limit": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "upper hard limit on size",
                        "example": 1073741824,
                        "default": null
                      },
                      "notify": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "notification threshold for size",
                        "example": 1073741824,
                        "default": null
                      },
                      "reserve": {
                        "type": [
                          "integer"
                        ],
                        "default": 0,
                        "description": "guaranteed storage resources",
                        "example": 1073741824
                      }
                    },
                    "additionalProperties": false
                  },
                  "iops": {
                    "type": [
                      "object"
                    ],
                    "description": "I/O operations per second quota",
                    "properties": {
                      "limit": {
                        "type": [
                          "integer",
                          "null"
                        ],
                        "description": "limit on sustained I/O operations per second",
                        "default": null
                      }
                    },
                    "additionalProperties": false
                  },
                  "workload": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "default": "normal_iops",
                    "enum": [
                      "lower_iops",
                      "normal_iops",
                      "higher_iops"
                    ],
                    "description": "workload hint"
                  }
                },
                "additionalProperties": false
              },
              "fs_type": {
                "type": [
                  "string"
                ],
                "enum": [
                  "ntfs",
                  "ext4",
                  "hfsplus"
                ],
                "description": "filesystem formatting type",
                "example": "ntfs"
              },
              "fs_options": {
                "type": [
                  "object"
                ],
                "description": "filesystem format options",
                "properties": {
                  "fs_type": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "ntfs",
                      "ext4",
                      "hfsplus"
                    ],
                    "description": "filesystem formatting type",
                    "example": "ntfs"
                  }
                },
                "additionalProperties": false
              },
              "readahead": {
                "type": [
                  "object"
                ],
                "description": "virtual disk readahead configuration",
                "properties": {
                  "mode": {
                    "type": [
                      "string"
                    ],
                    "default": "constant",
                    "enum": [
                      "none",
                      "constant"
                    ],
                    "description": "readahead mode control"
                  },
                  "size": {
                    "type": [
                      "integer"
                    ],
                    "default": 131072,
                    "maximum": 4194304,
                    "description": "readahead size in bytes (rounded internally to 512-byte blocks)",
                    "minimum": 4096
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "size": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "constant"
                        ]
                      }
                    }
                  }
                }
              },
              "write_once": {
                "type": [
                  "boolean"
                ],
                "description": "disk is write-once (block can not be re-written)"
              },
              "data_cache": {
                "type": [
                  "boolean"
                ],
                "description": "data read from disk will be cached",
                "default": true
              },
              "compression": {
                "type": [
                  "string"
                ],
                "example": "none",
                "enum": [
                  "none",
                  "inherit",
                  "economy",
                  "adaptive",
                  "adaptive_economy",
                  "adaptive_performance",
                  "performance"
                ],
                "description": "compression codec"
              }
            },
            "description": "internal virtual disk create request arguments",
            "required": [
              "vss_id",
              "capacity"
            ],
            "additionalProperties": false,
            "dependencies": {
              "fs_options": {
                "properties": {
                  "fs_type": {
                  }
                }
              }
            }
          },
          "title": "Create",
          "x_bb_method": "vdisk_create_internal"
        },
        {
          "description": "Remove an existing virtual disk.  Once removed, the user data in a virtual disk is not retrievable.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "vdisk_remove"
        },
        {
          "description": "Change the configuration of an existing internal virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "multi_map": {
                "type": [
                  "boolean"
                ],
                "description": "virtual disk can be mapped in multiple targets"
              },
              "read_only": {
                "type": [
                  "boolean"
                ],
                "description": "virtual disk is read-only"
              },
              "removable": {
                "type": [
                  "boolean"
                ],
                "description": "virtual disk is removable"
              },
              "ua_interlock": {
                "type": [
                  "boolean"
                ],
                "description": "support for SCSI unit attention interlock"
              },
              "dif": {
                "type": [
                  "boolean"
                ],
                "description": "support for SCSI data integrity field"
              },
              "scsi_advise_lbp": {
                "type": [
                  "boolean"
                ],
                "description": "advisory SCSI logical block provisioning (internal use only)"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "readahead": {
                "type": [
                  "object"
                ],
                "description": "virtual disk readahead configuration",
                "properties": {
                  "mode": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "none",
                      "constant"
                    ],
                    "description": "readahead mode control",
                    "example": "constant"
                  },
                  "size": {
                    "type": [
                      "integer"
                    ],
                    "maximum": 4194304,
                    "description": "readahead size in bytes (rounded internally to 512-byte blocks)",
                    "minimum": 4096
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "size": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "constant"
                        ]
                      }
                    }
                  }
                }
              },
              "write_once": {
                "type": [
                  "boolean"
                ],
                "description": "disk is write-once (blocks can not be re-written)"
              },
              "data_cache": {
                "type": [
                  "boolean"
                ],
                "description": "data read from disk will be cached"
              },
              "compression": {
                "type": [
                  "string"
                ],
                "example": "economy",
                "enum": [
                  "none",
                  "inherit",
                  "economy",
                  "adaptive",
                  "adaptive_economy",
                  "adaptive_performance",
                  "performance"
                ],
                "description": "compression codec"
              }
            },
            "description": "internal virtual disk update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "vdisk_update_internal"
        },
        {
          "description": "Change the quota for a virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/quota",
          "method": "PUT",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "size": {
                "type": [
                  "object"
                ],
                "description": "storage consumption quota",
                "properties": {
                  "limit": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "example": 1073741824,
                    "description": "upper hard limit on size",
                    "default": null
                  },
                  "notify": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "example": 1073741824,
                    "description": "notification threshold for size",
                    "default": null
                  },
                  "reserve": {
                    "type": [
                      "integer"
                    ],
                    "default": 0,
                    "example": 1073741824,
                    "description": "guaranteed storage resources"
                  }
                },
                "additionalProperties": false
              },
              "iops": {
                "type": [
                  "object"
                ],
                "description": "I/O operations per second quota",
                "properties": {
                  "limit": {
                    "type": [
                      "integer",
                      "null"
                    ],
                    "description": "limit on sustained I/O operations per second",
                    "default": null
                  }
                },
                "additionalProperties": false
              },
              "workload": {
                "type": [
                  "string",
                  "null"
                ],
                "default": "normal_iops",
                "enum": [
                  "lower_iops",
                  "normal_iops",
                  "higher_iops"
                ],
                "description": "workload hint"
              }
            },
            "additionalProperties": false,
            "description": "restrictions on virtual disk size and IOPS"
          },
          "title": "Quota Update",
          "x_bb_method": "vdisk_quota_set_rest"
        },
        {
          "description": "Add a replication master or slave virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/replication/master",
          "method": "POST",
          "rel": "update",
          "title": "Add Replication Master",
          "x_bb_method": "vdisk_replica_add",
          "schema": {
            "type": [
              "object"
            ],
            "description": "virtual disk replica add request arguments",
            "properties": {
              "vdisk_id": {
                "type": [
                  "string"
                ],
                "description": "virtual disk id to add as replica"
              }
            },
            "required": [
              "vdisk_id"
            ],
            "additionalProperties": false
          }
        },
        {
          "description": "Remove a replication master or slave virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/replication/master/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fmaster_id)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove Replication Master",
          "x_bb_method": "vdisk_replica_remove"
        },
        {
          "description": "Add a replication master or slave virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/replication/slaves",
          "method": "POST",
          "rel": "update",
          "title": "Add Replication Slave",
          "x_bb_method": "vdisk_replica_add",
          "schema": {
            "type": [
              "object"
            ],
            "description": "virtual disk replica add request arguments",
            "properties": {
              "vdisk_id": {
                "type": [
                  "string"
                ],
                "description": "virtual disk id to add as replica"
              }
            },
            "required": [
              "vdisk_id"
            ],
            "additionalProperties": false
          }
        },
        {
          "description": "Update the configuration of a replication master or slave virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/replication/slaves/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fslave_id)}",
          "method": "PUT",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "state": {
                "type": [
                  "string"
                ],
                "enum": [
                  "enable",
                  "disable",
                  "suspend",
                  "resume"
                ],
                "description": "state transition to perform",
                "example": "enable"
              },
              "config": {
                "type": [
                  "object"
                ],
                "description": "replica configuration",
                "properties": {
                  "mode": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "async",
                      "sync",
                      "async-ordered"
                    ],
                    "description": "replication mode",
                    "example": "async-ordered"
                  },
                  "max_lag_cmds": {
                    "type": [
                      "integer"
                    ],
                    "default": 0,
                    "description": "maximum commands to lag behind during async replication"
                  },
                  "max_lag_bytes": {
                    "type": [
                      "integer"
                    ],
                    "default": 0,
                    "description": "maximum bytes to lag behind during async replication",
                    "example": 1073741824
                  },
                  "recovery": {
                    "type": [
                      "string"
                    ],
                    "default": "drl",
                    "enum": [
                      "none",
                      "drl"
                    ],
                    "description": "recovery options"
                  },
                  "rebuild_bandwidth": {
                    "type": [
                      "integer"
                    ],
                    "default": 0,
                    "description": "rebuild bandwidth limit in bytes/sec"
                  },
                  "rebuild_hash": {
                    "type": [
                      "boolean"
                    ],
                    "default": true,
                    "description": "use a hashing optimization to reduce network traffic during rebuild"
                  },
                  "timeout": {
                    "type": [
                      "integer"
                    ],
                    "default": 20000,
                    "minimum": 100,
                    "description": "time to wait (in milliseconds) before stopping an unresponsive slave"
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "max_lag_cmds": {
                    "not": {
                      "properties": {
                        "mode": {
                          "enum": [
                            "sync"
                          ]
                        }
                      }
                    }
                  },
                  "max_lag_bytes": {
                    "not": {
                      "properties": {
                        "mode": {
                          "enum": [
                            "sync"
                          ]
                        }
                      }
                    }
                  }
                }
              },
              "policy": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "replication policy",
                "properties": {
                }
              }
            },
            "description": "virtual disk replica update request arguments",
            "additionalProperties": false
          },
          "title": "Update Replication Slave",
          "x_bb_method": "vdisk_replica_update"
        },
        {
          "description": "Remove a replication master or slave virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/replication/slaves/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fslave_id)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove Replication Slave",
          "x_bb_method": "vdisk_replica_remove"
        },
        {
          "description": "Create a replication relationship between a master virtual disk and a slave virtual disk.",
          "href": "/vdisk/actions/replication/attach",
          "method": "POST",
          "rel": "update",
          "title": "Attach Replication Peers",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "master_id": {
                "type": [
                  "string"
                ],
                "description": "virtual disk id of replica master"
              },
              "slave_id": {
                "type": [
                  "string"
                ],
                "description": "virtual disk id of replica slave"
              }
            },
            "description": "virtual disk replica attach request arguments",
            "required": [
              "master_id",
              "slave_id"
            ],
            "additionalProperties": false
          },
          "x_bb_method": "vdisk_replica_attach"
        },
        {
          "description": "Break the replication relationship between a master virtual disk and a slave virtual disk.",
          "href": "/vdisk/actions/replication/detach",
          "method": "POST",
          "rel": "update",
          "title": "Detach Replication Peers",
          "x_bb_method": "vdisk_replica_detach",
          "schema": {
            "type": [
              "object"
            ],
            "description": "virtual disk replica detach request arguments",
            "properties": {
              "master_id": {
                "type": [
                  "string"
                ],
                "description": "virtual disk id of replica master"
              },
              "slave_id": {
                "type": [
                  "string"
                ],
                "description": "virtual disk id of replica slave"
              }
            },
            "required": [
              "master_id",
              "slave_id"
            ],
            "additionalProperties": false
          }
        },
        {
          "description": "Rebuild a replication slave virtual disk.",
          "href": "/vdisk/actions/replication/rebuild",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "master_id": {
                "type": [
                  "string"
                ],
                "description": "virtual disk id of replica master",
                "example": "vdisk:8:15"
              },
              "slave_id": {
                "type": [
                  "string"
                ],
                "description": "virtual disk id of replica slave",
                "example": "vdisk:50:11"
              }
            },
            "description": "virtual disk replica rebuild arguments",
            "required": [
              "master_id",
              "slave_id"
            ],
            "additionalProperties": false
          },
          "title": "Rebuild Replication Slave",
          "x_bb_method": "vdisk_replica_rebuild"
        },
        {
          "description": "Change the size of an internal virtual disk",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/actions/resize",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "capacity": {
                "type": [
                  "integer"
                ],
                "minimum": 1048576,
                "maximum": 1125899906842624,
                "description": "new user addressable capacity in bytes",
                "example": 1073741824
              }
            },
            "description": "virtual disk resize request arguments",
            "required": [
              "capacity"
            ],
            "additionalProperties": false
          },
          "title": "Resize",
          "x_bb_method": "vdisk_resize"
        },
        {
          "description": "vdisk thicken",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/actions/thicken",
          "method": "POST",
          "rel": "update",
          "title": "Thicken",
          "x_bb_method": "vdisk_thicken",
          "schema": {
            "type": [
              "object"
            ],
            "description": "virtual disk thicken request arguments",
            "properties": {
              "limit_bandwidth": {
                "type": [
                  "boolean"
                ],
                "description": "limit bandwidth usage"
              },
              "bandwidth": {
                "type": [
                  "integer"
                ],
                "description": "verification bandwidth limit in bytes/sec"
              }
            },
            "dependencies": {
              "bandwidth": {
                "properties": {
                  "limit_bandwidth": {
                    "enum": [
                      true
                    ]
                  }
                }
              }
            },
            "additionalProperties": false
          }
        },
        {
          "description": "vdisk compress",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/actions/compress",
          "method": "POST",
          "rel": "update",
          "title": "Compress",
          "x_bb_method": "vdisk_compress",
          "schema": {
            "type": [
              "object"
            ],
            "description": "virtual disk compress request arguments",
            "properties": {
              "limit_bandwidth": {
                "type": [
                  "boolean"
                ],
                "description": "limit bandwidth usage"
              },
              "bandwidth": {
                "type": [
                  "integer"
                ],
                "description": "verification bandwidth limit in bytes/sec"
              }
            },
            "dependencies": {
              "bandwidth": {
                "properties": {
                  "limit_bandwidth": {
                    "enum": [
                      true
                    ]
                  }
                }
              }
            },
            "additionalProperties": false
          }
        },
        {
          "description": "Lock an internal virtual disk.  This action uses the supplied passphrase to encrypt the disk's encryption key.  Once locked, the disk cannot be decrypted without supplying the passphrase.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/actions/lock",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "passphrase": {
                "type": [
                  "string"
                ],
                "description": "passphrase"
              }
            },
            "description": "virtual disk lock request arguments",
            "required": [
              "passphrase"
            ],
            "additionalProperties": false
          },
          "title": "Lock",
          "x_bb_method": "vdisk_lock"
        },
        {
          "description": "Unlock a locked virtual disk.  The correct passphrase must be supplied.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/actions/unlock",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "passphrase": {
                "type": [
                  "string"
                ],
                "description": "passphrase"
              }
            },
            "description": "virtual disk unlock request arguments",
            "required": [
              "passphrase"
            ],
            "additionalProperties": false
          },
          "title": "Unlock",
          "x_bb_method": "vdisk_unlock"
        },
        {
          "description": "vdisk load",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/actions/load",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "profile_id": {
                "type": [
                  "string"
                ],
                "description": "initiator profile id (for which virtual disk is loaded)",
                "example": "initiator_profile:43:9"
              }
            },
            "description": "virtual disk load removable",
            "required": [
              "profile_id"
            ],
            "additionalProperties": false
          },
          "title": "Load Media",
          "x_bb_method": "vdisk_load"
        },
        {
          "description": "Clone the specified snapshot and load the media into a new removable virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/actions/load-clone",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "profile_id": {
                "type": [
                  "string"
                ],
                "description": "initiator profile id (for which virtual disk is loaded)",
                "example": "initiator_profile:68:9"
              },
              "label": {
                "type": [
                  "string"
                ],
                "description": "user assigned label"
              }
            },
            "description": "virtual disk load removable clone",
            "required": [
              "profile_id"
            ],
            "additionalProperties": false
          },
          "title": "Load Cloned Media",
          "x_bb_method": "vdisk_load_clone"
        },
        {
          "description": "Eject the media for a removable virtual disk.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/actions/eject",
          "method": "POST",
          "rel": "update",
          "title": "Eject Media",
          "x_bb_method": "vdisk_eject"
        },
        {
          "description": "Initiate a backup.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/actions/backup",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "backup UUID"
              },
              "snapshot_id": {
                "type": [
                  "string"
                ],
                "description": "snapshot id",
                "example": "snapshot:61:15"
              },
              "obj_store_id": {
                "type": [
                  "string"
                ],
                "description": "object store id",
                "example": "obj_store:67:14"
              },
              "object_key": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "object store base key string"
              }
            },
            "description": "virtual disk backup request arguments",
            "required": [
              "snapshot_id",
              "obj_store_id"
            ],
            "additionalProperties": false
          },
          "title": "Backup"
        },
        {
          "description": "Raise a time-limited I/O barrier.  Outstanding I/O operations will run to completion.  New operations will wait until the barrier expires or is removed.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/barrier",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "barrier UUID"
              },
              "expires": {
                "type": [
                  "integer"
                ],
                "description": "relative expiration time (in ms)",
                "example": "5000"
              },
              "vdisk_id": {
                "type": [
                  "string"
                ],
                "example": "vdisk:28:11",
                "description": "virtual disk ID"
              }
            },
            "description": "virtual disk barrier request arguments",
            "required": [
              "uuid",
              "vdisk_id",
              "expires"
            ],
            "additionalProperties": false
          },
          "title": "Barrier Create",
          "x_bb_method": "vdisk_barrier_create"
        },
        {
          "description": "Remove a virtual disk I/O barrier.",
          "href": "/vdisk/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}/barrier/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fuuid)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Barrier Remove",
          "x_bb_method": "vdisk_barrier_remove",
          "schema": {
            "type": [
              "object"
            ],
            "description": "virtual disk barrier remove request arguments",
            "properties": {
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object uuid"
              },
              "vdisk_id": {
                "type": [
                  "string"
                ],
                "example": "vdisk:70:14",
                "description": "virtual disk ID"
              }
            },
            "required": [
              "uuid",
              "vdisk_id"
            ],
            "additionalProperties": false
          }
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/vdisk/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/vdisk/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/vdisk/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/vdisk/definitions/mtime"
        },
        "type": {
          "$ref": "#/definitions/vdisk/definitions/type"
        },
        "label": {
          "$ref": "#/definitions/vdisk/definitions/label"
        },
        "notes": {
          "$ref": "#/definitions/vdisk/definitions/notes"
        },
        "tags": {
          "$ref": "#/definitions/vdisk/definitions/tags"
        },
        "vss_id": {
          "$ref": "#/definitions/vdisk/definitions/vss_id"
        },
        "node_id": {
          "$ref": "#/definitions/vdisk/definitions/node_id"
        },
        "account_id": {
          "$ref": "#/definitions/vdisk/definitions/account_id"
        },
        "basis": {
          "$ref": "#/definitions/vdisk/definitions/basis"
        },
        "transient": {
          "$ref": "#/definitions/vdisk/definitions/transient"
        },
        "capacity": {
          "$ref": "#/definitions/vdisk/definitions/capacity"
        },
        "blk_encoding": {
          "$ref": "#/definitions/vdisk/definitions/blk_encoding"
        },
        "cap_size_ratio": {
          "$ref": "#/definitions/vdisk/definitions/cap_size_ratio"
        },
        "quota": {
          "$ref": "#/definitions/vdisk/definitions/quota"
        },
        "locked": {
          "$ref": "#/definitions/vdisk/definitions/locked"
        },
        "caps": {
          "$ref": "#/definitions/vdisk/definitions/caps"
        },
        "scsi": {
          "$ref": "#/definitions/vdisk/definitions/scsi"
        },
        "replication": {
          "$ref": "#/definitions/vdisk/definitions/replication"
        },
        "serial": {
          "$ref": "#/definitions/vdisk/definitions/serial"
        },
        "task": {
          "$ref": "#/definitions/vdisk/definitions/task"
        },
        "trashed": {
          "$ref": "#/definitions/vdisk/definitions/trashed"
        },
        "system": {
          "$ref": "#/definitions/vdisk/definitions/system"
        },
        "xmd_refs": {
          "$ref": "#/definitions/vdisk/definitions/xmd_refs"
        },
        "xref": {
          "$ref": "#/definitions/vdisk/definitions/xref"
        },
        "readahead": {
          "$ref": "#/definitions/vdisk/definitions/readahead"
        },
        "encryption": {
          "$ref": "#/definitions/vdisk/definitions/encryption"
        },
        "data_cache": {
          "$ref": "#/definitions/vdisk/definitions/data_cache"
        },
        "compression": {
          "$ref": "#/definitions/vdisk/definitions/compression"
        },
        "status": {
          "$ref": "#/definitions/vdisk/definitions/status"
        },
        "scsi_reservations": {
          "$ref": "#/definitions/vdisk/definitions/scsi_reservations"
        },
        "media_loaded": {
          "$ref": "#/definitions/vdisk/definitions/media_loaded"
        },
        "loaded_profile_id": {
          "$ref": "#/definitions/vdisk/definitions/loaded_profile_id"
        },
        "loaded_profile_serial": {
          "$ref": "#/definitions/vdisk/definitions/loaded_profile_serial"
        },
        "sizing": {
          "$ref": "#/definitions/vdisk/definitions/sizing"
        },
        "replication_rts": {
          "$ref": "#/definitions/vdisk/definitions/replication_rts"
        },
        "iops": {
          "$ref": "#/definitions/vdisk/definitions/iops"
        },
        "xmd": {
          "$ref": "#/definitions/vdisk/definitions/xmd"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "type",
        "label",
        "notes",
        "tags",
        "vss_id",
        "node_id",
        "account_id",
        "basis",
        "locked",
        "caps",
        "scsi",
        "replication",
        "serial",
        "task",
        "xmd_refs",
        "readahead",
        "encryption",
        "data_cache",
        "compression",
        "status",
        "scsi_reservations",
        "media_loaded",
        "loaded_profile_id",
        "loaded_profile_serial",
        "replication_rts",
        "iops"
      ],
      "additionalProperties": false
    },
    "initiator-profile": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "iSCSI Initiator Profile",
      "description": "Initiator profiles hold the authentication and transport encryption parameters for one or more iSCSI initiators.  From this resource, you may also create secure access tokens that use split key encryption to enable you to unlock access to your disks on demand.  And, you can define policies that restrict initiator access to certain times of day, or to certain IP address ranges.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/initiator-profile/definitions/id"
            },
            {
              "$ref": "#/definitions/initiator-profile/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "initiator profile create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "initiator profile last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "label": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned label"
        },
        "access_token": {
          "type": [
            "object"
          ],
          "description": "access token parameters",
          "properties": {
            "valid": {
              "type": [
                "boolean"
              ],
              "description": "access token is valid"
            },
            "created_stamp": {
              "type": [
                "integer"
              ],
              "description": "token created timestamp",
              "minimum": 0,
              "example": 1443200456094
            },
            "id": {
              "type": [
                "string"
              ],
              "description": "access token id"
            }
          },
          "required": [
            "valid",
            "created_stamp",
            "id"
          ],
          "additionalProperties": false,
          "dependencies": {
            "created_stamp": {
              "properties": {
                "valid": {
                  "enum": [
                    true
                  ]
                }
              }
            },
            "id": {
              "properties": {
                "valid": {
                  "enum": [
                    true
                  ]
                }
              }
            }
          }
        },
        "iscsi": {
          "type": [
            "object"
          ],
          "description": "iscsi settings",
          "properties": {
            "auth_method": {
              "type": [
                "string"
              ],
              "description": "authentication method string"
            },
            "initiator_login": {
              "type": [
                "string"
              ],
              "description": "initator CHAP username"
            },
            "initiator_login_suffix": {
              "type": [
                "string"
              ],
              "description": "initiator CHAP username suffix (account name)"
            },
            "initiator_pass_set": {
              "type": [
                "boolean"
              ],
              "description": "password is set"
            },
            "suggested_base_iqn": {
              "type": [
                "string"
              ],
              "description": "suggested IQN string for this profile"
            },
            "initiator_list": {
              "type": [
                "array"
              ],
              "items": {
                "type": [
                  "string"
                ],
                "description": "initiator IQN"
              },
              "description": "initiator access list"
            },
            "initiator_chap_mode": {
              "type": [
                "string"
              ],
              "enum": [
                "username",
                "token"
              ],
              "description": "initiator CHAP mode",
              "example": "username"
            },
            "mutual_auth": {
              "type": [
                "string"
              ],
              "enum": [
                "disabled",
                "optional",
                "required"
              ],
              "description": "mutual authentication administrative state",
              "example": "optional"
            },
            "target_login": {
              "type": [
                "string"
              ],
              "description": "mutual authentication target CHAP username"
            }
          },
          "required": [
            "auth_method",
            "initiator_login",
            "initiator_login_suffix",
            "initiator_pass_set",
            "suggested_base_iqn",
            "initiator_list",
            "initiator_chap_mode",
            "mutual_auth",
            "target_login"
          ],
          "additionalProperties": false,
          "dependencies": {
            "target_login": {
              "not": {
                "properties": {
                  "mutual_auth": {
                    "enum": [
                      "disabled"
                    ]
                  }
                }
              }
            }
          }
        },
        "transport": {
          "type": [
            "object"
          ],
          "description": "transport security settings",
          "properties": {
            "mode": {
              "type": [
                "string"
              ],
              "enum": [
                "tls",
                "ikev2",
                "ikev1",
                "insecure"
              ],
              "description": "secure transport mode",
              "example": "tls"
            },
            "encryption_policy": {
              "type": [
                "string"
              ],
              "enum": [
                "disallowed",
                "optional",
                "required"
              ],
              "description": "transport encryption policy",
              "default": "disallowed"
            },
            "ikev1": {
              "type": [
                "object"
              ],
              "description": "IKEv1-related parameters",
              "properties": {
                "mode": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "transport"
                  ],
                  "description": "no documentation",
                  "example": "transport"
                },
                "auth": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "psk"
                  ],
                  "description": "client authentication mode",
                  "example": "psk"
                }
              },
              "required": [
                "mode",
                "auth"
              ],
              "additionalProperties": false
            },
            "ikev2": {
              "type": [
                "object"
              ],
              "description": "IKEv2-related parameters",
              "properties": {
                "mode": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "transport",
                    "tunnel"
                  ],
                  "description": "no documentation",
                  "example": "tunnel"
                },
                "subnet": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "172_31",
                    "172_30",
                    "10_1"
                  ],
                  "description": "private subnet designation",
                  "default": "172_31"
                },
                "auth": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "mschapv2"
                  ],
                  "description": "client authentication mode",
                  "example": "mschapv2"
                },
                "mschapv2_user": {
                  "type": [
                    "string"
                  ],
                  "description": "MSCHAPv2 username"
                }
              },
              "required": [
                "mode",
                "auth",
                "mschapv2_user"
              ],
              "additionalProperties": false,
              "dependencies": {
                "subnet": {
                  "properties": {
                    "mode": {
                      "enum": [
                        "tunnel"
                      ]
                    }
                  }
                },
                "mschapv2_user": {
                  "properties": {
                    "auth": {
                      "enum": [
                        "mschapv2"
                      ]
                    }
                  }
                }
              }
            },
            "tls": {
              "type": [
                "object"
              ],
              "description": "tls related parameters",
              "properties": {
                "portal_ipaddr": {
                  "type": [
                    "string"
                  ],
                  "format": "ipv4",
                  "description": "virtual target portal ip address"
                },
                "portal_ipport": {
                  "type": [
                    "integer"
                  ],
                  "description": "virtual target portal ip port"
                }
              },
              "required": [
                "portal_ipaddr",
                "portal_ipport"
              ],
              "additionalProperties": false
            }
          },
          "required": [
            "mode",
            "ikev1",
            "ikev2",
            "tls"
          ],
          "additionalProperties": false,
          "dependencies": {
            "ikev1": {
              "properties": {
                "mode": {
                  "enum": [
                    "ikev1"
                  ]
                }
              }
            },
            "ikev2": {
              "properties": {
                "mode": {
                  "enum": [
                    "ikev2"
                  ]
                }
              }
            },
            "tls": {
              "properties": {
                "mode": {
                  "enum": [
                    "tls"
                  ]
                }
              }
            }
          }
        },
        "account_id": {
          "type": [
            "string"
          ],
          "example": "account:75:9",
          "description": "account ref"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "initiator profile serial number"
        },
        "vss_id": {
          "type": [
            "string",
            "null"
          ],
          "example": "vss:31:10",
          "description": "virtual storage service id (if not global)"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string to display associated events"
        },
        "replication": {
          "type": [
            "boolean"
          ],
          "description": "is profile for replication"
        },
        "xmd_refs": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "arbitrary string reference key"
          },
          "description": "array of extensible metadata reference keys"
        },
        "xref": {
          "type": [
            "string",
            "null"
          ],
          "description": "arbitrary string reference"
        },
        "rules": {
          "type": [
            "object"
          ],
          "description": "profile rules",
          "properties": {
            "options": {
              "type": [
                "object"
              ],
              "description": "options for all rules",
              "properties": {
                "timezone": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "local"
                  ],
                  "description": "timezone",
                  "example": "local"
                }
              },
              "required": [
                "timezone"
              ],
              "additionalProperties": false
            },
            "access": {
              "type": [
                "object"
              ],
              "description": "access rules",
              "properties": {
                "options": {
                  "type": [
                    "object"
                  ],
                  "description": "options for access rules",
                  "properties": {
                  },
                  "additionalProperties": false
                },
                "ip": {
                  "type": [
                    "array"
                  ],
                  "items": {
                    "type": [
                      "object"
                    ],
                    "description": "IP access rule",
                    "properties": {
                      "type": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "allow",
                          "deny"
                        ],
                        "description": "access type",
                        "example": "deny"
                      },
                      "ip": {
                        "type": [
                          "string"
                        ],
                        "format": "ipv4",
                        "description": "IP address"
                      },
                      "mask": {
                        "type": [
                          "string"
                        ],
                        "format": "ipv4",
                        "description": "netmask"
                      }
                    },
                    "required": [
                      "type",
                      "ip",
                      "mask"
                    ],
                    "additionalProperties": false
                  },
                  "description": "IP-based access rules"
                },
                "weekly": {
                  "type": [
                    "array"
                  ],
                  "items": {
                    "type": [
                      "object"
                    ],
                    "description": "time of week access rule",
                    "properties": {
                      "type": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "allow",
                          "deny"
                        ],
                        "description": "access type",
                        "example": "allow"
                      },
                      "start": {
                        "type": [
                          "integer"
                        ],
                        "minimum": 0,
                        "maximum": 604799000,
                        "description": "start time in milliseconds since the start of the week (Monday 00:00:00.000)"
                      },
                      "end": {
                        "type": [
                          "integer"
                        ],
                        "minimum": 0,
                        "maximum": 604799000,
                        "description": "end time in milliseconds since the start of the week (Monday 00:00:00.000)"
                      }
                    },
                    "required": [
                      "type",
                      "start",
                      "end"
                    ],
                    "additionalProperties": false
                  },
                  "description": "weekly-based access rules"
                }
              },
              "required": [
                "ip",
                "weekly"
              ],
              "additionalProperties": false
            },
            "throttle": {
              "type": [
                "object"
              ],
              "description": "throttle rules",
              "properties": {
                "options": {
                  "type": [
                    "object"
                  ],
                  "description": "options for throttle rules",
                  "properties": {
                  },
                  "additionalProperties": false
                },
                "weekly": {
                  "type": [
                    "array"
                  ],
                  "items": {
                    "type": [
                      "object"
                    ],
                    "description": "time of week throttle rule",
                    "properties": {
                      "bandwidth": {
                        "type": [
                          "integer"
                        ],
                        "description": "bandwidth limit"
                      },
                      "start": {
                        "type": [
                          "integer"
                        ],
                        "minimum": 0,
                        "maximum": 604799000,
                        "description": "start time in milliseconds since the start of the week (Monday 00:00:00.000)"
                      },
                      "end": {
                        "type": [
                          "integer"
                        ],
                        "minimum": 0,
                        "maximum": 604799000,
                        "description": "end time in milliseconds since the start of the week (Monday 00:00:00.000)"
                      }
                    },
                    "required": [
                      "bandwidth",
                      "start",
                      "end"
                    ],
                    "additionalProperties": false
                  },
                  "description": "weekly-based throttle rules"
                }
              },
              "required": [
                "weekly"
              ],
              "additionalProperties": false
            },
            "disk": {
              "type": [
                "object"
              ],
              "description": "disk policies",
              "properties": {
                "commands": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "read-write",
                    "read-only",
                    "write-only"
                  ],
                  "description": "data commands",
                  "example": "read-write"
                }
              },
              "required": [
                "commands"
              ],
              "additionalProperties": false
            }
          },
          "additionalProperties": false,
          "required": [
            "options",
            "disk",
            "access",
            "throttle"
          ]
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "initiator profile status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "offline"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "degraded"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "xmd": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "per-linked xmd data",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "example": "xmd:70:15",
                "description": "no documentation"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference key"
              },
              "mtime": {
                "type": [
                  "integer"
                ],
                "description": "last modified time of xmd",
                "minimum": 0,
                "example": 1443200456094
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "self": {
                "type": [
                  "boolean"
                ],
                "description": "no documentation"
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "no documentation",
                "properties": {
                }
              }
            },
            "additionalProperties": false,
            "required": [
              "id",
              "ref",
              "mtime",
              "tags",
              "data"
            ]
          },
          "description": "array of api xmd results"
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "system": {
          "type": [
            "boolean"
          ],
          "description": "system target"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing iSCSI initiator profile.",
          "href": "/initiator-profile/{(%23%2Fdefinitions%2Finitiator-profile%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate iSCSI initiator profiles.",
          "href": "/initiator-profile",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a new iSCSI initiator profile.",
          "href": "/initiator-profile",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "xref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "enabled": {
                "type": [
                  "boolean"
                ],
                "default": true,
                "description": "initiator profile enabled for access"
              },
              "initiator_login": {
                "type": [
                  "string"
                ],
                "description": "initiator CHAP username"
              },
              "initiator_pass": {
                "type": [
                  "string"
                ],
                "description": "initiator CHAP password"
              },
              "vss_id": {
                "type": [
                  "string"
                ],
                "example": "vss:73:7",
                "description": "profile is local to specified virtual storage service"
              },
              "initiator_list": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "builtin iSCSI-name-value type for arguments"
                },
                "description": "initiator access list"
              },
              "initiator_chap_mode": {
                "type": [
                  "string"
                ],
                "enum": [
                  "username",
                  "token"
                ],
                "description": "initiator CHAP mode",
                "example": "token"
              },
              "mutual_auth": {
                "type": [
                  "string"
                ],
                "default": "disabled",
                "enum": [
                  "disabled",
                  "optional",
                  "required"
                ],
                "description": "mutual authentication"
              },
              "target_login": {
                "type": [
                  "string"
                ],
                "description": "mutual authentication target CHAP username"
              },
              "target_pass": {
                "type": [
                  "string"
                ],
                "description": "mutual authentication target CHAP password"
              },
              "transport": {
                "type": [
                  "object"
                ],
                "description": "transport security settings",
                "properties": {
                  "mode": {
                    "type": [
                      "string"
                    ],
                    "default": "insecure",
                    "enum": [
                      "tls",
                      "ikev2",
                      "ikev1",
                      "insecure"
                    ],
                    "description": "secure transport mode"
                  },
                  "encryption_policy": {
                    "type": [
                      "string"
                    ],
                    "default": "disallowed",
                    "enum": [
                      "disallowed",
                      "optional",
                      "required"
                    ],
                    "description": "transport encryption policy"
                  },
                  "ikev1": {
                    "type": [
                      "object"
                    ],
                    "description": "no documentation",
                    "properties": {
                      "mode": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "transport"
                        ],
                        "description": "no documentation",
                        "example": "transport"
                      },
                      "auth": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "psk"
                        ],
                        "description": "client authentication mode",
                        "example": "psk"
                      },
                      "psk": {
                        "type": [
                          "string"
                        ],
                        "description": "pre-shared secret key"
                      },
                      "psk_confirm": {
                        "type": [
                          "string"
                        ],
                        "description": "no documentation"
                      }
                    },
                    "additionalProperties": false,
                    "dependencies": {
                      "psk": {
                        "properties": {
                          "auth": {
                            "enum": [
                              "psk"
                            ]
                          }
                        }
                      }
                    }
                  },
                  "ikev2": {
                    "type": [
                      "object"
                    ],
                    "description": "no documentation",
                    "properties": {
                      "mode": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "transport",
                          "tunnel"
                        ],
                        "description": "no documentation",
                        "example": "tunnel"
                      },
                      "subnet": {
                        "type": [
                          "string"
                        ],
                        "default": "172_31",
                        "enum": [
                          "172_31",
                          "172_30",
                          "10_1"
                        ],
                        "description": "private subnet designation"
                      },
                      "auth": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "mschapv2"
                        ],
                        "description": "client authentication mode",
                        "example": "mschapv2"
                      },
                      "mschapv2_user": {
                        "type": [
                          "string"
                        ],
                        "description": "MSCHAPv2 username"
                      },
                      "mschapv2_pass": {
                        "type": [
                          "string"
                        ],
                        "description": "MSCHAPv2 password"
                      },
                      "mschapv2_pass_confirm": {
                        "type": [
                          "string"
                        ],
                        "description": "mschapv2 password (confirmation)"
                      }
                    },
                    "additionalProperties": false,
                    "dependencies": {
                      "subnet": {
                        "properties": {
                          "mode": {
                            "enum": [
                              "tunnel"
                            ]
                          }
                        }
                      },
                      "mschapv2_user": {
                        "properties": {
                          "auth": {
                            "enum": [
                              "mschapv2"
                            ]
                          }
                        }
                      },
                      "mschapv2_pass": {
                        "properties": {
                          "auth": {
                            "enum": [
                              "mschapv2"
                            ]
                          }
                        }
                      }
                    }
                  },
                  "tls": {
                    "type": [
                      "object"
                    ],
                    "description": "tls related parameters",
                    "properties": {
                      "portal_ipaddr": {
                        "type": [
                          "string"
                        ],
                        "default": "127.0.0.1",
                        "format": "ipv4",
                        "description": "virtual target portal ip address"
                      },
                      "portal_ipport": {
                        "type": [
                          "integer"
                        ],
                        "default": 3260,
                        "description": "virtual target portal ip port"
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "ikev1": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "ikev1"
                        ]
                      }
                    }
                  },
                  "ikev2": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "ikev2"
                        ]
                      }
                    }
                  },
                  "tls": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "tls"
                        ]
                      }
                    }
                  }
                }
              },
              "rules": {
                "type": [
                  "object"
                ],
                "description": "profile rules",
                "properties": {
                  "options": {
                    "type": [
                      "object"
                    ],
                    "description": "options for all rules",
                    "properties": {
                      "timezone": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "local"
                        ],
                        "description": "timezone",
                        "example": "local"
                      }
                    },
                    "additionalProperties": false
                  },
                  "disk": {
                    "type": [
                      "object"
                    ],
                    "description": "disk policies",
                    "properties": {
                      "commands": {
                        "type": [
                          "string"
                        ],
                        "default": "read-write",
                        "enum": [
                          "read-write",
                          "read-only",
                          "write-only"
                        ],
                        "description": "data commands"
                      }
                    },
                    "additionalProperties": false
                  },
                  "access": {
                    "type": [
                      "object"
                    ],
                    "description": "access rules",
                    "properties": {
                      "options": {
                        "type": [
                          "object"
                        ],
                        "description": "options for access rules",
                        "properties": {
                        },
                        "additionalProperties": false
                      },
                      "ip": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "object"
                          ],
                          "description": "IP access rule",
                          "properties": {
                            "type": {
                              "type": [
                                "string"
                              ],
                              "enum": [
                                "allow",
                                "deny"
                              ],
                              "description": "access type",
                              "example": "allow"
                            },
                            "ip": {
                              "type": [
                                "string"
                              ],
                              "format": "ipv4",
                              "description": "IP address"
                            },
                            "mask": {
                              "type": [
                                "string"
                              ],
                              "format": "ipv4",
                              "description": "netmask"
                            }
                          },
                          "additionalProperties": false
                        },
                        "description": "IP-based access rules"
                      },
                      "weekly": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "object"
                          ],
                          "description": "time of week access rule",
                          "properties": {
                            "type": {
                              "type": [
                                "string"
                              ],
                              "enum": [
                                "allow",
                                "deny"
                              ],
                              "description": "access type",
                              "example": "allow"
                            },
                            "start": {
                              "type": [
                                "integer"
                              ],
                              "minimum": 0,
                              "maximum": 604799000,
                              "description": "start time in milliseconds since the start of the week (Monday 00:00:00.000)"
                            },
                            "end": {
                              "type": [
                                "integer"
                              ],
                              "minimum": 0,
                              "maximum": 604799000,
                              "description": "end time in milliseconds since the start of the week (Monday 00:00:00.000)"
                            }
                          },
                          "additionalProperties": false
                        },
                        "description": "weekly-based access rules"
                      }
                    },
                    "additionalProperties": false
                  },
                  "throttle": {
                    "type": [
                      "object"
                    ],
                    "description": "throttle rules",
                    "properties": {
                      "options": {
                        "type": [
                          "object"
                        ],
                        "description": "options for throttle rules",
                        "properties": {
                        },
                        "additionalProperties": false
                      },
                      "weekly": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "object"
                          ],
                          "description": "time of week throttle rule",
                          "properties": {
                            "bandwidth": {
                              "type": [
                                "integer"
                              ],
                              "description": "bandwidth limit"
                            },
                            "start": {
                              "type": [
                                "integer"
                              ],
                              "minimum": 0,
                              "maximum": 604799000,
                              "description": "start time in milliseconds since the start of the week (Monday 00:00:00.000)"
                            },
                            "end": {
                              "type": [
                                "integer"
                              ],
                              "minimum": 0,
                              "maximum": 604799000,
                              "description": "end time in milliseconds since the start of the week (Monday 00:00:00.000)"
                            }
                          },
                          "additionalProperties": false
                        },
                        "description": "weekly based throttle rules"
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              }
            },
            "description": "initiator profile create request arguments",
            "additionalProperties": false,
            "dependencies": {
              "target_login": {
                "not": {
                  "properties": {
                    "mutual_auth": {
                      "enum": [
                        "disabled"
                      ]
                    }
                  }
                }
              },
              "target_pass": {
                "properties": {
                  "target_login": {
                  }
                }
              }
            }
          },
          "title": "Create",
          "x_bb_method": "initiator_profile_create"
        },
        {
          "description": "Remove an existing iSCSI initiator profile.",
          "href": "/initiator-profile/{(%23%2Fdefinitions%2Finitiator-profile%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "initiator_profile_remove"
        },
        {
          "description": "Change the configuration of an existing iSCSI initiator profile.",
          "href": "/initiator-profile/{(%23%2Fdefinitions%2Finitiator-profile%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "enabled": {
                "type": [
                  "boolean"
                ],
                "description": "initiator profile enabled for access"
              },
              "initiator_login": {
                "type": [
                  "string"
                ],
                "description": "initiator CHAP username"
              },
              "initiator_pass": {
                "type": [
                  "string"
                ],
                "description": "initiator CHAP password"
              },
              "initiator_list": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "builtin iSCSI-name-value type for arguments"
                },
                "description": "initiator access list"
              },
              "initiator_chap_mode": {
                "type": [
                  "string"
                ],
                "enum": [
                  "username",
                  "token"
                ],
                "description": "initiator CHAP mode",
                "example": "username"
              },
              "mutual_auth": {
                "type": [
                  "string"
                ],
                "enum": [
                  "disabled",
                  "optional",
                  "required"
                ],
                "description": "mutual authentication",
                "example": "disabled"
              },
              "target_login": {
                "type": [
                  "string"
                ],
                "description": "mutual authentication target CHAP username"
              },
              "target_pass": {
                "type": [
                  "string"
                ],
                "description": "mutual authentication target CHAP password"
              },
              "transport": {
                "type": [
                  "object"
                ],
                "description": "transport security settings",
                "properties": {
                  "mode": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "tls",
                      "ikev2",
                      "ikev1",
                      "insecure"
                    ],
                    "description": "secure transport mode",
                    "example": "tls"
                  },
                  "encryption_policy": {
                    "type": [
                      "string"
                    ],
                    "default": "disallowed",
                    "enum": [
                      "disallowed",
                      "optional",
                      "required"
                    ],
                    "description": "transport encryption policy"
                  },
                  "ikev1": {
                    "type": [
                      "object"
                    ],
                    "description": "no documentation",
                    "properties": {
                      "mode": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "transport"
                        ],
                        "description": "no documentation",
                        "example": "transport"
                      },
                      "auth": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "psk"
                        ],
                        "description": "client authentication mode",
                        "example": "psk"
                      },
                      "psk": {
                        "type": [
                          "string"
                        ],
                        "description": "pre-shared secret key"
                      },
                      "psk_confirm": {
                        "type": [
                          "string"
                        ],
                        "description": "no documentation"
                      }
                    },
                    "additionalProperties": false,
                    "dependencies": {
                      "psk": {
                        "properties": {
                          "auth": {
                            "enum": [
                              "psk"
                            ]
                          }
                        }
                      }
                    }
                  },
                  "ikev2": {
                    "type": [
                      "object"
                    ],
                    "description": "no documentation",
                    "properties": {
                      "mode": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "transport",
                          "tunnel"
                        ],
                        "description": "no documentation",
                        "example": "tunnel"
                      },
                      "subnet": {
                        "type": [
                          "string"
                        ],
                        "default": "172_31",
                        "enum": [
                          "172_31",
                          "172_30",
                          "10_1"
                        ],
                        "description": "private subnet designation"
                      },
                      "auth": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "mschapv2"
                        ],
                        "description": "client authentication mode",
                        "example": "mschapv2"
                      },
                      "mschapv2_user": {
                        "type": [
                          "string"
                        ],
                        "description": "MSCHAPv2 username"
                      },
                      "mschapv2_pass": {
                        "type": [
                          "string"
                        ],
                        "description": "MSCHAPv2 password"
                      },
                      "mschapv2_pass_confirm": {
                        "type": [
                          "string"
                        ],
                        "description": "mschapv2 password (confirmation)"
                      }
                    },
                    "additionalProperties": false,
                    "dependencies": {
                      "subnet": {
                        "properties": {
                          "mode": {
                            "enum": [
                              "tunnel"
                            ]
                          }
                        }
                      },
                      "mschapv2_user": {
                        "properties": {
                          "auth": {
                            "enum": [
                              "mschapv2"
                            ]
                          }
                        }
                      },
                      "mschapv2_pass": {
                        "properties": {
                          "mschapv2_user": {
                          }
                        }
                      }
                    }
                  },
                  "tls": {
                    "type": [
                      "object"
                    ],
                    "description": "tls related parameters",
                    "properties": {
                      "portal_ipaddr": {
                        "type": [
                          "string"
                        ],
                        "default": "127.0.0.1",
                        "format": "ipv4",
                        "description": "virtual target portal ip address"
                      },
                      "portal_ipport": {
                        "type": [
                          "integer"
                        ],
                        "default": 3260,
                        "description": "virtual target portal ip port"
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false,
                "dependencies": {
                  "ikev1": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "ikev1"
                        ]
                      }
                    }
                  },
                  "ikev2": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "ikev2"
                        ]
                      }
                    }
                  },
                  "tls": {
                    "properties": {
                      "mode": {
                        "enum": [
                          "tls"
                        ]
                      }
                    }
                  }
                }
              },
              "rules": {
                "type": [
                  "object"
                ],
                "description": "profile rules",
                "properties": {
                  "options": {
                    "type": [
                      "object"
                    ],
                    "description": "options for all rules",
                    "properties": {
                      "timezone": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "local"
                        ],
                        "description": "timezone",
                        "example": "local"
                      }
                    },
                    "additionalProperties": false
                  },
                  "disk": {
                    "type": [
                      "object"
                    ],
                    "description": "disk policies",
                    "properties": {
                      "commands": {
                        "type": [
                          "string"
                        ],
                        "enum": [
                          "read-write",
                          "read-only",
                          "write-only"
                        ],
                        "description": "data commands",
                        "example": "read-write"
                      }
                    },
                    "additionalProperties": false
                  },
                  "access": {
                    "type": [
                      "object"
                    ],
                    "description": "access rules",
                    "properties": {
                      "options": {
                        "type": [
                          "object"
                        ],
                        "description": "options for access rules",
                        "properties": {
                        },
                        "additionalProperties": false
                      },
                      "ip": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "object"
                          ],
                          "description": "IP access rule",
                          "properties": {
                            "type": {
                              "type": [
                                "string"
                              ],
                              "enum": [
                                "allow",
                                "deny"
                              ],
                              "description": "access type",
                              "example": "deny"
                            },
                            "ip": {
                              "type": [
                                "string"
                              ],
                              "format": "ipv4",
                              "description": "IP address"
                            },
                            "mask": {
                              "type": [
                                "string"
                              ],
                              "format": "ipv4",
                              "description": "netmask"
                            }
                          },
                          "additionalProperties": false
                        },
                        "description": "IP-based access rules"
                      },
                      "weekly": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "object"
                          ],
                          "description": "time of week access rule",
                          "properties": {
                            "type": {
                              "type": [
                                "string"
                              ],
                              "enum": [
                                "allow",
                                "deny"
                              ],
                              "description": "access type",
                              "example": "allow"
                            },
                            "start": {
                              "type": [
                                "integer"
                              ],
                              "minimum": 0,
                              "maximum": 604799000,
                              "description": "start time in milliseconds since the start of the week (Monday 00:00:00.000)"
                            },
                            "end": {
                              "type": [
                                "integer"
                              ],
                              "minimum": 0,
                              "maximum": 604799000,
                              "description": "end time in milliseconds since the start of the week (Monday 00:00:00.000)"
                            }
                          },
                          "additionalProperties": false
                        },
                        "description": "weekly-based access rules"
                      }
                    },
                    "additionalProperties": false
                  },
                  "throttle": {
                    "type": [
                      "object"
                    ],
                    "description": "throttle rules",
                    "properties": {
                      "options": {
                        "type": [
                          "object"
                        ],
                        "description": "options for throttle rules",
                        "properties": {
                        },
                        "additionalProperties": false
                      },
                      "weekly": {
                        "type": [
                          "array"
                        ],
                        "items": {
                          "type": [
                            "object"
                          ],
                          "description": "time of week throttle rule",
                          "properties": {
                            "bandwidth": {
                              "type": [
                                "integer"
                              ],
                              "description": "bandwidth limit"
                            },
                            "start": {
                              "type": [
                                "integer"
                              ],
                              "minimum": 0,
                              "maximum": 604799000,
                              "description": "start time in milliseconds since the start of the week (Monday 00:00:00.000)"
                            },
                            "end": {
                              "type": [
                                "integer"
                              ],
                              "minimum": 0,
                              "maximum": 604799000,
                              "description": "end time in milliseconds since the start of the week (Monday 00:00:00.000)"
                            }
                          },
                          "additionalProperties": false
                        },
                        "description": "weekly-based throttle rules"
                      }
                    },
                    "additionalProperties": false
                  }
                },
                "additionalProperties": false
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              }
            },
            "description": "initiator profile update request arguments",
            "additionalProperties": false,
            "dependencies": {
              "target_login": {
                "not": {
                  "properties": {
                    "mutual_auth": {
                      "enum": [
                        "disabled"
                      ]
                    }
                  }
                }
              },
              "target_pass": {
                "properties": {
                  "target_login": {
                  }
                }
              }
            }
          },
          "title": "Update",
          "x_bb_method": "initiator_profile_update"
        },
        {
          "description": "Prepare to create a secure access token for an initiator profile.",
          "href": "/initiator-profile/{(%23%2Fdefinitions%2Finitiator-profile%2Fdefinitions%2Fidentity)}/token",
          "method": "GET",
          "rel": "prepare",
          "title": "Prepare Token",
          "x_bb_method": "initiator_profile_token_create_prepare"
        },
        {
          "description": "Create a secure access token for an iSCSI initiator profile.",
          "href": "/initiator-profile/{(%23%2Fdefinitions%2Finitiator-profile%2Fdefinitions%2Fidentity)}/token",
          "method": "POST",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "tok_hash": {
                "type": [
                  "string"
                ],
                "description": "cryptographic hash of access token (sha-256)"
              },
              "pad": {
                "type": [
                  "string"
                ],
                "description": "random pad used during access token creation"
              }
            },
            "description": "initiator profile create token request arguments",
            "required": [
              "tok_hash",
              "pad"
            ],
            "additionalProperties": false
          },
          "title": "Create Token",
          "x_bb_method": "initiator_profile_token_create"
        },
        {
          "description": "Remove a configured secure access token from an iSCSI initiator profile.",
          "href": "/initiator-profile/{(%23%2Fdefinitions%2Finitiator-profile%2Fdefinitions%2Fidentity)}/token",
          "method": "DELETE",
          "rel": "update",
          "title": "Remove Token",
          "x_bb_method": "initiator_profile_token_remove"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/initiator-profile/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/initiator-profile/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/initiator-profile/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/initiator-profile/definitions/mtime"
        },
        "label": {
          "$ref": "#/definitions/initiator-profile/definitions/label"
        },
        "access_token": {
          "$ref": "#/definitions/initiator-profile/definitions/access_token"
        },
        "iscsi": {
          "$ref": "#/definitions/initiator-profile/definitions/iscsi"
        },
        "transport": {
          "$ref": "#/definitions/initiator-profile/definitions/transport"
        },
        "account_id": {
          "$ref": "#/definitions/initiator-profile/definitions/account_id"
        },
        "serial": {
          "$ref": "#/definitions/initiator-profile/definitions/serial"
        },
        "vss_id": {
          "$ref": "#/definitions/initiator-profile/definitions/vss_id"
        },
        "notes": {
          "$ref": "#/definitions/initiator-profile/definitions/notes"
        },
        "replication": {
          "$ref": "#/definitions/initiator-profile/definitions/replication"
        },
        "system": {
          "$ref": "#/definitions/initiator-profile/definitions/system"
        },
        "xmd_refs": {
          "$ref": "#/definitions/initiator-profile/definitions/xmd_refs"
        },
        "xref": {
          "$ref": "#/definitions/initiator-profile/definitions/xref"
        },
        "rules": {
          "$ref": "#/definitions/initiator-profile/definitions/rules"
        },
        "status": {
          "$ref": "#/definitions/initiator-profile/definitions/status"
        },
        "xmd": {
          "$ref": "#/definitions/initiator-profile/definitions/xmd"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "label",
        "access_token",
        "iscsi",
        "transport",
        "account_id",
        "serial",
        "vss_id",
        "notes",
        "replication",
        "xmd_refs",
        "xref",
        "rules",
        "status"
      ],
      "additionalProperties": false
    },
    "target": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "iSCSI Target",
      "description": "The iSCSI target defines how disks are mapped to the network, making them accessible to iSCSI clients.  In the Blockbridge System, the iSCSI target is virtual, so that a single storage node supports many targets. You're free to define them as needed.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/target/definitions/id"
            },
            {
              "$ref": "#/definitions/target/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "iSCSI target create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "iSCSI target last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "iqn": {
          "type": [
            "string"
          ],
          "pattern": "^iqn\\.\\d{4}-\\d{2}((?<!-)\\.(?!-)[a-zA-Z0-9\\-]+){1,63}(?<!-)(?<!\\.)(:[^:]+)?}$",
          "description": "iSCSI target IQN"
        },
        "iqn_base": {
          "type": [
            "string"
          ],
          "pattern": "^iqn\\.\\d{4}-\\d{2}((?<!-)\\.(?!-)[a-zA-Z0-9\\-]+){1,63}(?<!-)(?<!\\.)(:[^:]+)?}$",
          "description": "base of iSCSI target IQN"
        },
        "iqn_suffix": {
          "type": [
            "string"
          ],
          "pattern": "^[a-z0-9.-]*$",
          "description": "suffix of iSCSI target IQN"
        },
        "label": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned label"
        },
        "alias": {
          "type": [
            "string"
          ],
          "description": "iSCSI target alias"
        },
        "account_id": {
          "type": [
            "string"
          ],
          "example": "account:74:14",
          "description": "account id"
        },
        "node_id": {
          "type": [
            "string"
          ],
          "example": "node:89:13",
          "description": "storage node id"
        },
        "vss_id": {
          "type": [
            "string"
          ],
          "example": "vss:15:15",
          "description": "virtual storage service id"
        },
        "acl": {
          "type": [
            "array"
          ],
          "description": "access control list",
          "items": {
            "type": [
              "object"
            ],
            "description": "acl entry",
            "properties": {
              "profile_id": {
                "type": [
                  "string"
                ],
                "example": "initiator_profile:3:15",
                "description": "profile ref"
              },
              "privacy": {
                "type": [
                  "string"
                ],
                "default": "no",
                "enum": [
                  "yes",
                  "no"
                ],
                "description": "privacy permission level"
              },
              "discover": {
                "type": [
                  "string"
                ],
                "default": "no",
                "enum": [
                  "yes",
                  "no"
                ],
                "description": "discovery permission level"
              },
              "access": {
                "type": [
                  "string"
                ],
                "default": "no",
                "enum": [
                  "yes",
                  "no"
                ],
                "description": "access permission level"
              }
            },
            "required": [
              "profile_id"
            ],
            "additionalProperties": false
          }
        },
        "luns": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "LUN",
            "properties": {
              "lun": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "maximum": 16384,
                "description": "SCSI logical unit number"
              },
              "vdisk_id": {
                "type": [
                  "string"
                ],
                "example": "vdisk:22:13",
                "description": "no documentation"
              }
            },
            "required": [
              "lun",
              "vdisk_id"
            ],
            "additionalProperties": false
          },
          "description": "iSCSI target LUN mapping table"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "iSCSI target serial number"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string for event application to display associated events"
        },
        "automap": {
          "type": [
            "boolean"
          ],
          "description": "iSCSI target supports automapped LUNS"
        },
        "replication": {
          "type": [
            "boolean"
          ],
          "description": "iSCSI target is the virtual storage service replication target"
        },
        "xmd_refs": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "arbitrary string reference key"
          },
          "description": "array of extensible metadata reference keys"
        },
        "xref": {
          "type": [
            "string"
          ],
          "description": "arbitrary string reference"
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "iSCSI target status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "online"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "pending"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "sessions": {
          "type": [
            "array",
            "null"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "active iSCSI target session",
            "properties": {
              "profile_id": {
                "type": [
                  "string"
                ],
                "example": "initiator_profile:25:11",
                "description": "initiator profile ID"
              },
              "ini_id": {
                "type": [
                  "string"
                ],
                "example": "initiator:34:7",
                "description": "initiator id"
              },
              "isid": {
                "type": [
                  "integer"
                ],
                "maximum": 281474976710660,
                "description": "iSCSI session ID"
              },
              "ini_alias": {
                "type": [
                  "string"
                ],
                "description": "initiator alias"
              },
              "tsih": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "maximum": 65535,
                "description": "target session identifying handle"
              },
              "age": {
                "type": [
                  "integer"
                ],
                "description": "session age (in milliseconds)"
              },
              "prm": {
                "type": [
                  "object"
                ],
                "description": "iSCSI negotiated parameters",
                "properties": {
                  "max_conn": {
                    "type": [
                      "integer"
                    ],
                    "minimum": 0,
                    "maximum": 65535,
                    "description": "max connections"
                  },
                  "erlvl": {
                    "type": [
                      "integer"
                    ],
                    "minimum": 0,
                    "maximum": 2,
                    "description": "error recovery level"
                  },
                  "immed": {
                    "type": [
                      "boolean"
                    ],
                    "description": "immediate data"
                  },
                  "init_r2t": {
                    "type": [
                      "boolean"
                    ],
                    "description": "initial R2T"
                  },
                  "inrd_data": {
                    "type": [
                      "boolean"
                    ],
                    "description": "In Order Data"
                  },
                  "inrd_seq": {
                    "type": [
                      "boolean"
                    ],
                    "description": "In Order Sequence"
                  },
                  "fbl": {
                    "type": [
                      "integer"
                    ],
                    "description": "first burst length",
                    "minimum": 0,
                    "maximum": 16777215,
                    "example": 1073741824
                  },
                  "mbl": {
                    "type": [
                      "integer"
                    ],
                    "description": "maximum burst length",
                    "minimum": 0,
                    "maximum": 16777215,
                    "example": 1073741824
                  }
                },
                "required": [
                  "max_conn",
                  "erlvl",
                  "immed",
                  "init_r2t",
                  "inrd_data",
                  "inrd_seq",
                  "fbl",
                  "mbl"
                ],
                "additionalProperties": false
              },
              "conns": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "connection on session",
                  "properties": {
                    "cid": {
                      "type": [
                        "integer"
                      ],
                      "minimum": 0,
                      "maximum": 65535,
                      "description": "connection ID"
                    },
                    "port": {
                      "type": [
                        "integer"
                      ],
                      "description": "initiator TCP port"
                    },
                    "hdr_dig": {
                      "type": [
                        "boolean"
                      ],
                      "description": "Header Digest"
                    },
                    "dat_dig": {
                      "type": [
                        "boolean"
                      ],
                      "description": "Data Digest"
                    },
                    "rcv_win": {
                      "type": [
                        "integer"
                      ],
                      "description": "TCP Receive Window",
                      "example": 1073741824
                    },
                    "latency": {
                      "type": [
                        "integer"
                      ],
                      "description": "latency in milliseconds"
                    },
                    "sec_mode": {
                      "type": [
                        "string"
                      ],
                      "enum": [
                        "insecure",
                        "ssl",
                        "ipsec"
                      ],
                      "description": "security mode",
                      "example": "ssl"
                    },
                    "ipsec": {
                      "type": [
                        "object"
                      ],
                      "description": "IPSec connection parameters",
                      "properties": {
                        "crypt_alg": {
                          "type": [
                            "string"
                          ],
                          "description": "crypto algorithm"
                        },
                        "auth_mode": {
                          "type": [
                            "string"
                          ],
                          "description": "authentication cipher mode"
                        },
                        "tunnel": {
                          "type": [
                            "boolean"
                          ],
                          "description": "tunnel mode"
                        },
                        "auth_len": {
                          "type": [
                            "integer"
                          ],
                          "description": "authentication key length"
                        },
                        "auth_alg": {
                          "type": [
                            "string"
                          ],
                          "description": "authentication algorithm"
                        },
                        "crypt_len": {
                          "type": [
                            "integer"
                          ],
                          "description": "crypto key length"
                        },
                        "crypt_mode": {
                          "type": [
                            "string"
                          ],
                          "description": "crypto cipher mode"
                        }
                      },
                      "required": [
                        "crypt_alg",
                        "auth_mode",
                        "tunnel",
                        "auth_len",
                        "auth_alg",
                        "crypt_len",
                        "crypt_mode"
                      ],
                      "additionalProperties": false
                    },
                    "ssl": {
                      "type": [
                        "object"
                      ],
                      "description": "SSL/TLS connection parameters",
                      "properties": {
                        "comp": {
                          "type": [
                            "boolean"
                          ],
                          "description": "is compressed"
                        },
                        "comp_alg": {
                          "type": [
                            "string"
                          ],
                          "description": "compression algorithm"
                        },
                        "version": {
                          "type": [
                            "string"
                          ],
                          "description": "SSL version"
                        }
                      },
                      "required": [
                        "comp",
                        "comp_alg",
                        "version"
                      ],
                      "additionalProperties": false,
                      "dependencies": {
                        "comp_alg": {
                          "properties": {
                            "comp": {
                              "enum": [
                                true
                              ]
                            }
                          }
                        }
                      }
                    },
                    "peer_inner": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "format": "ipv4",
                      "description": "initiator IP address, tunnel mode inner"
                    },
                    "peer_outer": {
                      "type": [
                        "string"
                      ],
                      "format": "ipv4",
                      "description": "initiator IP address, public"
                    },
                    "host_inner": {
                      "type": [
                        "string",
                        "null"
                      ],
                      "format": "ipv4",
                      "description": "target IP address, tunnel mode inner"
                    },
                    "host_outer": {
                      "type": [
                        "string"
                      ],
                      "format": "ipv4",
                      "description": "target IP address, public"
                    }
                  },
                  "required": [
                    "cid",
                    "port",
                    "hdr_dig",
                    "dat_dig",
                    "rcv_win",
                    "latency",
                    "sec_mode",
                    "ipsec",
                    "ssl",
                    "peer_inner",
                    "peer_outer",
                    "host_inner",
                    "host_outer"
                  ],
                  "additionalProperties": false,
                  "dependencies": {
                    "ipsec": {
                      "properties": {
                        "sec_mode": {
                          "enum": [
                            "ipsec"
                          ]
                        }
                      }
                    },
                    "ssl": {
                      "properties": {
                        "sec_mode": {
                          "enum": [
                            "ssl"
                          ]
                        }
                      }
                    }
                  }
                },
                "description": "array of connections on session"
              }
            },
            "required": [
              "profile_id",
              "ini_id",
              "isid",
              "ini_alias",
              "tsih",
              "age",
              "prm",
              "conns"
            ],
            "additionalProperties": false
          },
          "description": "array of active iSCSI target sessions"
        },
        "portals": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "iSCSI target portal",
            "properties": {
              "hostname": {
                "type": [
                  "string",
                  "null"
                ],
                "format": "hostname",
                "description": "iSCSI target portal DNS hostname"
              },
              "interface": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "iSCSI target portal network interface"
              },
              "up": {
                "type": [
                  "boolean",
                  "null"
                ],
                "description": "iSCSI target portal network interface is up"
              },
              "speed": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "iSCSI target portal network interface link speed",
                "example": "40000",
                "enum": [
                  "10",
                  "100",
                  "1000",
                  "2500",
                  "10000",
                  "25000",
                  "40000",
                  "50000",
                  "56000",
                  "100000",
                  "unknown"
                ]
              },
              "duplex": {
                "type": [
                  "string",
                  "null"
                ],
                "enum": [
                  "half",
                  "full",
                  "unknown"
                ],
                "description": "network interface duplex",
                "example": "unknown"
              },
              "ipaddrs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "iSCSI target portal ip",
                  "properties": {
                    "addr": {
                      "type": [
                        "string"
                      ],
                      "format": "ipv4",
                      "description": "iSCSI target portal ip address"
                    },
                    "port": {
                      "type": [
                        "integer"
                      ],
                      "description": "iSCSI target portal ip port"
                    },
                    "family": {
                      "type": [
                        "string"
                      ],
                      "enum": [
                        "IPv4",
                        "IPv6",
                        "unknown"
                      ],
                      "description": "network interface family",
                      "example": "IPv6"
                    },
                    "detail": {
                      "type": [
                        "string"
                      ],
                      "description": "iSCSI target portal ip detail"
                    }
                  },
                  "required": [
                    "addr",
                    "port",
                    "family"
                  ],
                  "additionalProperties": false
                },
                "description": "iSCSI target portal array of ip addresses"
              }
            },
            "required": [
              "hostname",
              "interface",
              "up",
              "speed",
              "duplex",
              "ipaddrs"
            ],
            "additionalProperties": false
          },
          "description": "iSCSI target portals"
        },
        "pps": {
          "type": [
            "integer",
            "null"
          ],
          "description": "iSCSI PDUs per second"
        },
        "xmd": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "per-linked xmd data",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "example": "xmd:5:9",
                "description": "no documentation"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference key"
              },
              "mtime": {
                "type": [
                  "integer"
                ],
                "description": "last modified time of xmd",
                "minimum": 0,
                "example": 1443200456094
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "self": {
                "type": [
                  "boolean"
                ],
                "description": "no documentation"
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "no documentation",
                "properties": {
                }
              }
            },
            "additionalProperties": false,
            "required": [
              "id",
              "ref",
              "mtime",
              "tags",
              "data"
            ]
          },
          "description": "array of api xmd results"
        },
        "lun": {
          "description": "Logical Unit Number",
          "example": 4,
          "type": [
            "integer"
          ]
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "system": {
          "type": [
            "boolean"
          ],
          "description": "system target"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing iSCSI target.",
          "href": "/target/{(%23%2Fdefinitions%2Ftarget%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate iSCSI targets.",
          "href": "/target",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a new iSCSI target.",
          "href": "/target",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "vss_id": {
                "type": [
                  "string"
                ],
                "example": "vss:10:9",
                "description": "virtual storage service id"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "xref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference"
              },
              "iqn_suffix": {
                "type": [
                  "string"
                ],
                "pattern": "^[a-z0-9.-]*$",
                "description": "suffix for generated iSCSI target IQN"
              },
              "alias": {
                "type": [
                  "string"
                ],
                "description": "iSCSI target alias"
              },
              "acl": {
                "type": [
                  "array"
                ],
                "description": "access control list",
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "acl entry",
                  "properties": {
                    "profile_id": {
                      "type": [
                        "string"
                      ],
                      "example": "initiator_profile:31:12",
                      "description": "profile ref"
                    },
                    "privacy": {
                      "type": [
                        "string"
                      ],
                      "default": "no",
                      "enum": [
                        "yes",
                        "no"
                      ],
                      "description": "privacy permission level"
                    },
                    "discover": {
                      "type": [
                        "string"
                      ],
                      "default": "no",
                      "enum": [
                        "yes",
                        "no"
                      ],
                      "description": "discovery permission level"
                    },
                    "access": {
                      "type": [
                        "string"
                      ],
                      "default": "no",
                      "enum": [
                        "yes",
                        "no"
                      ],
                      "description": "access permission level"
                    }
                  },
                  "required": [
                    "profile_id"
                  ],
                  "additionalProperties": false
                }
              },
              "luns": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "LUN",
                  "properties": {
                    "lun": {
                      "type": [
                        "integer"
                      ],
                      "minimum": 0,
                      "maximum": 16384,
                      "description": "SCSI logical unit number"
                    },
                    "vdisk_id": {
                      "type": [
                        "string"
                      ],
                      "example": "vdisk:23:14",
                      "description": "no documentation"
                    }
                  },
                  "additionalProperties": false,
                  "required": [
                    "lun",
                    "vdisk_id"
                  ]
                },
                "description": "list of SCSI logical units"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "automap": {
                "type": [
                  "boolean"
                ],
                "description": "target allows automap"
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              }
            },
            "description": "iSCSI target create request arguments",
            "required": [
              "vss_id"
            ],
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "target_create"
        },
        {
          "description": "Remove an existing iSCSI target.",
          "href": "/target/{(%23%2Fdefinitions%2Ftarget%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "target_remove"
        },
        {
          "description": "Change the configuration of an existing iSCSI target.",
          "href": "/target/{(%23%2Fdefinitions%2Ftarget%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "acl": {
                "type": [
                  "array"
                ],
                "description": "access control list",
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "acl entry",
                  "properties": {
                    "profile_id": {
                      "type": [
                        "string"
                      ],
                      "example": "initiator_profile:42:7",
                      "description": "profile ref"
                    },
                    "privacy": {
                      "type": [
                        "string"
                      ],
                      "default": "no",
                      "enum": [
                        "yes",
                        "no"
                      ],
                      "description": "privacy permission level"
                    },
                    "discover": {
                      "type": [
                        "string"
                      ],
                      "default": "no",
                      "enum": [
                        "yes",
                        "no"
                      ],
                      "description": "discovery permission level"
                    },
                    "access": {
                      "type": [
                        "string"
                      ],
                      "default": "no",
                      "enum": [
                        "yes",
                        "no"
                      ],
                      "description": "access permission level"
                    }
                  },
                  "required": [
                    "profile_id"
                  ],
                  "additionalProperties": false
                }
              },
              "luns": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "LUN",
                  "properties": {
                    "lun": {
                      "type": [
                        "integer"
                      ],
                      "minimum": 0,
                      "maximum": 16384,
                      "description": "SCSI logical unit number"
                    },
                    "vdisk_id": {
                      "type": [
                        "string"
                      ],
                      "example": "vdisk:63:6",
                      "description": "no documentation"
                    }
                  },
                  "additionalProperties": false,
                  "required": [
                    "lun",
                    "vdisk_id"
                  ]
                },
                "description": "list of SCSI logical units"
              },
              "iqn_suffix": {
                "type": [
                  "string"
                ],
                "pattern": "^[a-z0-9.-]*$",
                "description": "suffix for generated iSCSI target IQN"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "alias": {
                "type": [
                  "string"
                ],
                "description": "iSCSI target alias"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "automap": {
                "type": [
                  "boolean"
                ],
                "description": "target allows automap"
              }
            },
            "description": "iSCSI target update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "target_update"
        },
        {
          "description": "Map a virtual disk to an existing iSCSI target.",
          "href": "/target/{(%23%2Fdefinitions%2Ftarget%2Fdefinitions%2Fidentity)}/luns/{(%23%2Fdefinitions%2Ftarget%2Fdefinitions%2Flun)}",
          "method": "PUT",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "vdisk_id": {
                "type": [
                  "string"
                ],
                "example": "vdisk:78:9",
                "description": "virtual disk id"
              }
            },
            "description": "map disk to target",
            "required": [
              "vdisk_id"
            ],
            "additionalProperties": false
          },
          "title": "LUN Map",
          "x_bb_method": "target_map_lun_rest"
        },
        {
          "description": "Unmap a virtual disk from an existing iSCSI target.",
          "href": "/target/{(%23%2Fdefinitions%2Ftarget%2Fdefinitions%2Fidentity)}/luns/{(%23%2Fdefinitions%2Ftarget%2Fdefinitions%2Flun)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "LUN Unmap",
          "x_bb_method": "target_unmap"
        },
        {
          "description": "Map a virtual disk to an existing iSCSI target.",
          "href": "/target/{(%23%2Fdefinitions%2Ftarget%2Fdefinitions%2Fidentity)}/disks/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}",
          "method": "PUT",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "lun": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "maximum": 16384,
                "description": "SCSI LUN assignment (automatic if unspecified)"
              },
              "lun_max": {
                "type": [
                  "integer"
                ],
                "description": "maximum LUN value for automatic assignment"
              }
            },
            "description": "map disk to target",
            "required": [
              "lun",
              "lun_max"
            ],
            "additionalProperties": false
          },
          "title": "Disk Map",
          "x_bb_method": "target_map_disk_rest"
        },
        {
          "description": "Unmap a virtual disk from an existing iSCSI target.",
          "href": "/target/{(%23%2Fdefinitions%2Ftarget%2Fdefinitions%2Fidentity)}/disks/{(%23%2Fdefinitions%2Fvdisk%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Disk Unmap",
          "x_bb_method": "target_unmap"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/target/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/target/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/target/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/target/definitions/mtime"
        },
        "iqn_base": {
          "$ref": "#/definitions/target/definitions/iqn_base"
        },
        "iqn_suffix": {
          "$ref": "#/definitions/target/definitions/iqn_suffix"
        },
        "iqn": {
          "$ref": "#/definitions/target/definitions/iqn"
        },
        "label": {
          "$ref": "#/definitions/target/definitions/label"
        },
        "alias": {
          "$ref": "#/definitions/target/definitions/alias"
        },
        "account_id": {
          "$ref": "#/definitions/target/definitions/account_id"
        },
        "node_id": {
          "$ref": "#/definitions/target/definitions/node_id"
        },
        "vss_id": {
          "$ref": "#/definitions/target/definitions/vss_id"
        },
        "acl": {
          "$ref": "#/definitions/target/definitions/acl"
        },
        "luns": {
          "$ref": "#/definitions/target/definitions/luns"
        },
        "notes": {
          "$ref": "#/definitions/target/definitions/notes"
        },
        "serial": {
          "$ref": "#/definitions/target/definitions/serial"
        },
        "automap": {
          "$ref": "#/definitions/target/definitions/automap"
        },
        "replication": {
          "$ref": "#/definitions/target/definitions/replication"
        },
        "system": {
          "$ref": "#/definitions/target/definitions/system"
        },
        "xmd_refs": {
          "$ref": "#/definitions/target/definitions/xmd_refs"
        },
        "xref": {
          "$ref": "#/definitions/target/definitions/xref"
        },
        "status": {
          "$ref": "#/definitions/target/definitions/status"
        },
        "sessions": {
          "$ref": "#/definitions/target/definitions/sessions"
        },
        "portals": {
          "$ref": "#/definitions/target/definitions/portals"
        },
        "pps": {
          "$ref": "#/definitions/target/definitions/pps"
        },
        "xmd": {
          "$ref": "#/definitions/target/definitions/xmd"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "iqn_base",
        "iqn_suffix",
        "iqn",
        "label",
        "alias",
        "account_id",
        "node_id",
        "vss_id",
        "acl",
        "luns",
        "notes",
        "serial",
        "automap",
        "xmd_refs",
        "status",
        "sessions",
        "portals",
        "pps"
      ],
      "additionalProperties": false
    },
    "snapshot": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Snapshot",
      "description": "You can take a point-in-time snapshot of a disk's contents to make a backup image, or to create a reference from which cloned disks may be created.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/snapshot/definitions/id"
            },
            {
              "$ref": "#/definitions/snapshot/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "snapshot create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "snapshot last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "label": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned label"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "tags": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "tag"
          },
          "description": "object tags"
        },
        "vss_id": {
          "type": [
            "string"
          ],
          "example": "vss:64:15",
          "description": "virtual storage service id"
        },
        "node_id": {
          "type": [
            "string"
          ],
          "example": "node:34:15",
          "description": "storage node id"
        },
        "account_id": {
          "type": [
            "string"
          ],
          "example": "account:53:10",
          "description": "account id"
        },
        "vdisk_id": {
          "type": [
            "string"
          ],
          "example": "vdisk:34:9",
          "description": "virtual disk id"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "snapshot serial number"
        },
        "evt_qry": {
          "type": [
            "string"
          ],
          "description": "query string for event application to display associated events"
        },
        "capacity": {
          "type": [
            "integer",
            "null"
          ],
          "description": "snapshot capacity (in bytes)"
        },
        "generation": {
          "type": [
            "integer",
            "null"
          ],
          "description": "snapshot generation"
        },
        "timestamp": {
          "type": [
            "integer",
            "null"
          ],
          "description": "snapshot timestamp",
          "minimum": 0,
          "example": 1443200456094
        },
        "transient": {
          "type": [
            "boolean"
          ],
          "description": "snapshot transient"
        },
        "trashed": {
          "type": [
            "boolean"
          ],
          "description": "waiting for garbage collection"
        },
        "xmd_refs": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "arbitrary string reference key"
          },
          "description": "array of extensible metadata reference keys"
        },
        "xref": {
          "type": [
            "string"
          ],
          "description": "arbitrary string reference"
        },
        "vdisk_refs": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "reverse dep from vdisk",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "example": "vdisk:67:6",
                "description": "dependent vdisk id"
              },
              "serial": {
                "type": [
                  "string"
                ],
                "description": "dependent vdisk serial"
              },
              "label": {
                "type": [
                  "string"
                ],
                "description": "dependent vdisk label"
              }
            },
            "required": [
              "id",
              "serial",
              "label"
            ],
            "additionalProperties": false
          },
          "description": "array of vdisk dependencies"
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "snapshot status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "offline"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "payment"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "xmd": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "per-linked xmd data",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "example": "xmd:96:13",
                "description": "no documentation"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference key"
              },
              "mtime": {
                "type": [
                  "integer"
                ],
                "description": "last modified time of xmd",
                "minimum": 0,
                "example": 1443200456094
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "self": {
                "type": [
                  "boolean"
                ],
                "description": "no documentation"
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "no documentation",
                "properties": {
                }
              }
            },
            "additionalProperties": false,
            "required": [
              "id",
              "ref",
              "mtime",
              "tags",
              "data"
            ]
          },
          "description": "array of api xmd results"
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing virtual disk snapshot.",
          "href": "/snapshot/{(%23%2Fdefinitions%2Fsnapshot%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate virtual disk snapshots.",
          "href": "/snapshot",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create a new snapshot of the contents of an internal virtual disk.",
          "href": "/snapshot",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "snapshot UUID"
              },
              "vdisk_id": {
                "type": [
                  "string"
                ],
                "example": "vdisk:30:14",
                "description": "virtual disk id"
              },
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "xref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "transient": {
                "type": [
                  "boolean"
                ],
                "description": "snapshot created for a transient clone"
              }
            },
            "description": "virtual disk snapshot create request arguments",
            "required": [
              "vdisk_id"
            ],
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "vdisk_snapshot_create"
        },
        {
          "description": "Remove an existing virtual disk snapshot.  Once the snapshot has been removed, the storage node starts reclaiming user data blocks that are no longer needed for other snapshots or for the virtual disk itself.",
          "href": "/snapshot/{(%23%2Fdefinitions%2Fsnapshot%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "vdisk_snapshot_remove"
        },
        {
          "description": "Change the configuration of an existing virtual disk snapshot.",
          "href": "/snapshot/{(%23%2Fdefinitions%2Fsnapshot%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              }
            },
            "description": "virtual disk snapshot update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "vdisk_snapshot_update"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/snapshot/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/snapshot/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/snapshot/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/snapshot/definitions/mtime"
        },
        "label": {
          "$ref": "#/definitions/snapshot/definitions/label"
        },
        "notes": {
          "$ref": "#/definitions/snapshot/definitions/notes"
        },
        "tags": {
          "$ref": "#/definitions/snapshot/definitions/tags"
        },
        "vss_id": {
          "$ref": "#/definitions/snapshot/definitions/vss_id"
        },
        "node_id": {
          "$ref": "#/definitions/snapshot/definitions/node_id"
        },
        "account_id": {
          "$ref": "#/definitions/snapshot/definitions/account_id"
        },
        "vdisk_id": {
          "$ref": "#/definitions/snapshot/definitions/vdisk_id"
        },
        "serial": {
          "$ref": "#/definitions/snapshot/definitions/serial"
        },
        "capacity": {
          "$ref": "#/definitions/snapshot/definitions/capacity"
        },
        "generation": {
          "$ref": "#/definitions/snapshot/definitions/generation"
        },
        "timestamp": {
          "$ref": "#/definitions/snapshot/definitions/timestamp"
        },
        "transient": {
          "$ref": "#/definitions/snapshot/definitions/transient"
        },
        "trashed": {
          "$ref": "#/definitions/snapshot/definitions/trashed"
        },
        "xmd_refs": {
          "$ref": "#/definitions/snapshot/definitions/xmd_refs"
        },
        "xref": {
          "$ref": "#/definitions/snapshot/definitions/xref"
        },
        "vdisk_refs": {
          "$ref": "#/definitions/snapshot/definitions/vdisk_refs"
        },
        "status": {
          "$ref": "#/definitions/snapshot/definitions/status"
        },
        "xmd": {
          "$ref": "#/definitions/snapshot/definitions/xmd"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "label",
        "notes",
        "vss_id",
        "node_id",
        "account_id",
        "vdisk_id",
        "serial",
        "capacity",
        "generation",
        "timestamp",
        "xmd_refs",
        "vdisk_refs",
        "status"
      ],
      "additionalProperties": false
    },
    "obj-store": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Object Store",
      "description": "The Object Store is endpoint and authentication configuration to support data backup to an object store such as Amazon S3 or OpenStack Swift.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/obj-store/definitions/id"
            },
            {
              "$ref": "#/definitions/obj-store/definitions/serial"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "minimum": 0,
          "description": "object store create time",
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "minimum": 0,
          "description": "object store last modified time",
          "example": 1443200456094
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "object store serial number"
        },
        "label": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned label"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "account_id": {
          "type": [
            "string"
          ],
          "example": "account:44:6",
          "description": "account id"
        },
        "type": {
          "type": [
            "string"
          ],
          "enum": [
            "s3"
          ],
          "description": "object store type",
          "example": "s3"
        },
        "bucket_name": {
          "type": [
            "string"
          ],
          "description": "bucket name"
        },
        "host_name": {
          "type": [
            "string",
            "null"
          ],
          "description": "host name"
        },
        "access_key_id": {
          "type": [
            "string",
            "null"
          ],
          "description": "access key id"
        },
        "secret_access_key_set": {
          "type": [
            "boolean"
          ],
          "description": "secret access key is set"
        },
        "security_token_set": {
          "type": [
            "boolean"
          ],
          "description": "security token is set"
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "object store status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "offline"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "offline"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "backup_id": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "backup identifier"
        },
        "protocol": {
          "type": [
            "string",
            "null"
          ],
          "description": "protocol"
        },
        "uri_style": {
          "type": [
            "string",
            "null"
          ],
          "description": "uri style"
        },
        "location": {
          "type": [
            "object"
          ],
          "description": "obj store location",
          "properties": {
            "country": {
              "type": [
                "string"
              ],
              "default": "",
              "description": "ISO 3166-1 alpha-3 country code"
            },
            "lat": {
              "type": [
                "number"
              ],
              "default": 0,
              "description": "latitude"
            },
            "long": {
              "type": [
                "number"
              ],
              "default": 0,
              "description": "longitude"
            },
            "city": {
              "type": [
                "string"
              ],
              "default": "",
              "description": "city"
            },
            "state": {
              "type": [
                "string"
              ],
              "default": "",
              "description": "state as two-character USPS abbreviation"
            }
          },
          "additionalProperties": false
        },
        "verified": {
          "type": [
            "object"
          ],
          "description": "obj store verified",
          "properties": {
            "status": {
              "type": [
                "string"
              ],
              "example": "success",
              "enum": [
                "unverified",
                "success",
                "failed"
              ],
              "description": "verified status"
            },
            "time": {
              "type": [
                "integer",
                "null"
              ],
              "example": 1443200456094,
              "minimum": 0,
              "description": "last verified time"
            },
            "detail": {
              "type": [
                "string"
              ],
              "description": "verified detail"
            }
          },
          "required": [
            "status",
            "time"
          ],
          "additionalProperties": false
        },
        "default_password_set": {
          "type": [
            "boolean"
          ],
          "description": "default password is set"
        },
        "default_wkey_password_set": {
          "type": [
            "boolean"
          ],
          "description": "default wkey password is set"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing object store definition.",
          "href": "/obj-store/{(%23%2Fdefinitions%2Fobj-store%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate object stores.",
          "href": "/obj-store",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Enumerate backups on an object-store.",
          "href": "/obj-store/{(%23%2Fdefinitions%2Fobj-store%2Fdefinitions%2Fidentity)}/backups",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "max_results": {
                "type": [
                  "integer"
                ],
                "default": 256,
                "description": "maximum number of results to return"
              },
              "token": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "continuation token for paged enumeration"
              }
            },
            "description": "list backups on an object store",
            "additionalProperties": false
          },
          "title": "List backups",
          "x_bb_method": "backup_list"
        },
        {
          "description": "Delete a backup from an object-store.",
          "href": "/obj-store/{(%23%2Fdefinitions%2Fobj-store%2Fdefinitions%2Fidentity)}/backups/{(%23%2Fdefinitions%2Fobj-store%2Fdefinitions%2Fbackup_id)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove backup",
          "x_bb_method": "backup_delete",
          "schema": {
            "type": [
              "object"
            ],
            "description": "delete a backup",
            "properties": {
              "force": {
                "type": [
                  "boolean"
                ],
                "default": false,
                "description": "remove in-progress backup"
              }
            },
            "additionalProperties": false
          }
        },
        {
          "description": "Create an object store definition.",
          "href": "/obj-store",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "type": {
                "type": [
                  "string"
                ],
                "default": "s3",
                "enum": [
                  "s3"
                ],
                "description": "object store type"
              },
              "bucket_name": {
                "type": [
                  "string"
                ],
                "description": "bucket name"
              },
              "host_name": {
                "type": [
                  "string"
                ],
                "description": "host name"
              },
              "access_key_id": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "access key id",
                "default": null
              },
              "secret_access_key": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "secret access key",
                "default": null
              },
              "security_token": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "security token",
                "default": null
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              },
              "protocol": {
                "type": [
                  "string",
                  "null"
                ],
                "default": "http",
                "enum": [
                  "http",
                  "https"
                ],
                "description": "object store protocol"
              },
              "uri_style": {
                "type": [
                  "string",
                  "null"
                ],
                "default": "path",
                "enum": [
                  "virtual_host",
                  "path"
                ],
                "description": "object store uri style"
              },
              "location": {
                "type": [
                  "object"
                ],
                "description": "location",
                "properties": {
                  "country": {
                    "type": [
                      "string"
                    ],
                    "default": "",
                    "description": "ISO 3166-1 alpha-3 country code"
                  },
                  "lat": {
                    "type": [
                      "number"
                    ],
                    "default": 0,
                    "description": "latitude"
                  },
                  "long": {
                    "type": [
                      "number"
                    ],
                    "default": 0,
                    "description": "longitude"
                  },
                  "city": {
                    "type": [
                      "string"
                    ],
                    "default": "",
                    "description": "city"
                  },
                  "state": {
                    "type": [
                      "string"
                    ],
                    "default": "",
                    "description": "state as two-character USPS abbreviation"
                  }
                },
                "additionalProperties": false
              },
              "default_wkey_password": {
                "type": [
                  "string",
                  "null"
                ],
                "default": null,
                "description": "default wrap key passphrase"
              }
            },
            "description": "obj_store create request arguments",
            "required": [
              "bucket_name",
              "host_name"
            ],
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "obj_store_create"
        },
        {
          "description": "Remove an obj_store definition.",
          "href": "/obj-store/{(%23%2Fdefinitions%2Fobj-store%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "obj_store_remove"
        },
        {
          "description": "Change the configuration of an existing object store definition.",
          "href": "/obj-store/{(%23%2Fdefinitions%2Fobj-store%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "bucket_name": {
                "type": [
                  "string"
                ],
                "description": "bucket name"
              },
              "host_name": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "host name"
              },
              "access_key_id": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "access key id"
              },
              "secret_access_key": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "secret access key"
              },
              "security_token": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "security token"
              },
              "protocol": {
                "type": [
                  "string",
                  "null"
                ],
                "example": "https",
                "enum": [
                  "http",
                  "https"
                ],
                "description": "object store protocol"
              },
              "location": {
                "type": [
                  "object"
                ],
                "description": "location",
                "properties": {
                  "country": {
                    "type": [
                      "string"
                    ],
                    "default": "",
                    "description": "ISO 3166-1 alpha-3 country code"
                  },
                  "lat": {
                    "type": [
                      "number"
                    ],
                    "default": 0,
                    "description": "latitude"
                  },
                  "long": {
                    "type": [
                      "number"
                    ],
                    "default": 0,
                    "description": "longitude"
                  },
                  "city": {
                    "type": [
                      "string"
                    ],
                    "default": "",
                    "description": "city"
                  },
                  "state": {
                    "type": [
                      "string"
                    ],
                    "default": "",
                    "description": "state as two-character USPS abbreviation"
                  }
                },
                "additionalProperties": false
              },
              "type": {
                "type": [
                  "string"
                ],
                "example": "s3",
                "enum": [
                  "s3"
                ],
                "description": "object store type"
              },
              "uri_style": {
                "type": [
                  "string",
                  "null"
                ],
                "example": "path",
                "enum": [
                  "virtual_host",
                  "path"
                ],
                "description": "object store uri style"
              },
              "default_wkey_password": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "default wrap key passphrase"
              }
            },
            "description": "obj_store update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "obj_store_update"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/obj-store/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/obj-store/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/obj-store/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/obj-store/definitions/mtime"
        },
        "serial": {
          "$ref": "#/definitions/obj-store/definitions/serial"
        },
        "label": {
          "$ref": "#/definitions/obj-store/definitions/label"
        },
        "notes": {
          "$ref": "#/definitions/obj-store/definitions/notes"
        },
        "account_id": {
          "$ref": "#/definitions/obj-store/definitions/account_id"
        },
        "location": {
          "$ref": "#/definitions/obj-store/definitions/location"
        },
        "verified": {
          "$ref": "#/definitions/obj-store/definitions/verified"
        },
        "type": {
          "$ref": "#/definitions/obj-store/definitions/type"
        },
        "bucket_name": {
          "$ref": "#/definitions/obj-store/definitions/bucket_name"
        },
        "host_name": {
          "$ref": "#/definitions/obj-store/definitions/host_name"
        },
        "protocol": {
          "$ref": "#/definitions/obj-store/definitions/protocol"
        },
        "uri_style": {
          "$ref": "#/definitions/obj-store/definitions/uri_style"
        },
        "access_key_id": {
          "$ref": "#/definitions/obj-store/definitions/access_key_id"
        },
        "secret_access_key_set": {
          "$ref": "#/definitions/obj-store/definitions/secret_access_key_set"
        },
        "security_token_set": {
          "$ref": "#/definitions/obj-store/definitions/security_token_set"
        },
        "default_wkey_password_set": {
          "$ref": "#/definitions/obj-store/definitions/default_wkey_password_set"
        },
        "status": {
          "$ref": "#/definitions/obj-store/definitions/status"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "serial",
        "label",
        "notes",
        "account_id",
        "location",
        "verified",
        "type",
        "bucket_name",
        "host_name",
        "protocol",
        "uri_style",
        "access_key_id",
        "secret_access_key_set",
        "security_token_set",
        "default_wkey_password_set",
        "status"
      ],
      "additionalProperties": false
    },
    "rule": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Disk Rule",
      "description": "",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "id": {
          "description": "object id",
          "type": [
            "string"
          ]
        },
        "name": {
          "description": "unique name of rule",
          "readOnly": true,
          "type": [
            "string"
          ]
        },
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/rule/definitions/id"
            },
            {
              "$ref": "#/definitions/rule/definitions/serial"
            }
          ]
        },
        "created_at": {
          "description": "when rule was created",
          "format": "date-time",
          "type": [
            "string"
          ]
        },
        "updated_at": {
          "description": "when rule was updated",
          "format": "date-time",
          "type": [
            "string"
          ]
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "example": 1443200456094,
          "minimum": 0,
          "description": "rule create time"
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "example": 1443200456094,
          "minimum": 0,
          "description": "rule last modified time"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "rule serial number"
        },
        "xmd_refs": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "arbitrary string reference key"
          },
          "description": "array of extensible metadata reference keys"
        },
        "xref": {
          "type": [
            "string"
          ],
          "description": "arbitrary string reference"
        },
        "label": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned label"
        },
        "account_id": {
          "type": [
            "string"
          ],
          "example": "account:14:7",
          "description": "account id"
        },
        "actions": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "rule action",
            "properties": {
              "type": {
                "type": [
                  "string"
                ],
                "example": "latency",
                "enum": [
                  "scsi_response",
                  "latency",
                  "event",
                  "email",
                  "statistic",
                  "device_mode",
                  "device_reset",
                  "attention_required",
                  "eject"
                ],
                "description": "action type"
              },
              "when": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "mode": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "time": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "num": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "user": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "response": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              }
            },
            "required": [
              "type",
              "when",
              "mode",
              "time",
              "num",
              "user",
              "response"
            ],
            "additionalProperties": false
          },
          "description": "list of actions"
        },
        "filters": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "rule filter",
            "properties": {
              "type": {
                "type": [
                  "string"
                ],
                "example": "scsi_command",
                "enum": [
                  "logical_block_access",
                  "scsi_command",
                  "signature_detection",
                  "custom_detection"
                ],
                "description": "filter type"
              },
              "access": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "extent_groups": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "commands": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              }
            },
            "required": [
              "type",
              "access",
              "extent_groups",
              "commands"
            ],
            "additionalProperties": false
          },
          "description": "list of filters"
        },
        "node_id": {
          "type": [
            "string"
          ],
          "example": "node:29:14",
          "description": "node id"
        },
        "vss_id": {
          "type": [
            "string"
          ],
          "example": "vss:80:15",
          "description": "virtual storage service id"
        },
        "ref_id": {
          "type": [
            "string",
            "null"
          ],
          "description": "rule reference id"
        },
        "sensors": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "rule sensor",
            "properties": {
              "type": {
                "type": [
                  "string"
                ],
                "example": "switch",
                "enum": [
                  "weekly",
                  "auth",
                  "logical_block_access",
                  "switch",
                  "alarm"
                ],
                "description": "sensor type"
              },
              "id": {
                "type": [
                  "integer"
                ],
                "description": "local sensor ID"
              },
              "start": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "end": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "keymap": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "secret": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "digit_num": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "access": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "req_hits": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "req_time": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "extent_groups": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "state": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "label": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "invert": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "toggle": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              },
              "timer": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              }
            },
            "required": [
              "type",
              "id",
              "start",
              "end",
              "keymap",
              "secret",
              "digit_num",
              "access",
              "req_hits",
              "req_time",
              "extent_groups",
              "state",
              "label",
              "invert",
              "toggle",
              "timer"
            ],
            "additionalProperties": false
          },
          "description": "list of sensors"
        },
        "type": {
          "type": [
            "string"
          ],
          "example": "vdisk",
          "enum": [
            "vdisk"
          ],
          "description": "type of rule"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "rule status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "example": "degraded",
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator"
            },
            "value": {
              "type": [
                "string"
              ],
              "example": "offline",
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "alarm_raised": {
          "type": [
            "boolean",
            "null"
          ],
          "description": "an alarm has been raised for this rule"
        },
        "alarm_raised_at": {
          "type": [
            "integer",
            "null"
          ],
          "example": 1443200456094,
          "minimum": 0,
          "description": "time when alarm was raised, if it is raised"
        },
        "xmd": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "per-linked xmd data",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "example": "xmd:5:13",
                "description": "no documentation"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference key"
              },
              "mtime": {
                "type": [
                  "integer"
                ],
                "example": 1443200456094,
                "minimum": 0,
                "description": "last modified time of xmd"
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "self": {
                "type": [
                  "boolean"
                ],
                "description": "no documentation"
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "properties": {
                },
                "description": "no documentation"
              }
            },
            "required": [
              "id",
              "ref",
              "mtime",
              "tags",
              "data"
            ],
            "additionalProperties": false
          },
          "description": "array of api xmd results"
        }
      },
      "links": [
        {
          "description": "Create a virtual disk rule.",
          "href": "/rule",
          "method": "POST",
          "rel": "create",
          "schema": {
            "properties": {
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              },
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "xref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference"
              },
              "vss_id": {
                "type": [
                  "string"
                ],
                "description": "virtual storage service id"
              },
              "type": {
                "type": [
                  "string"
                ],
                "example": "vdisk",
                "enum": [
                  "vdisk"
                ],
                "description": "type of rule"
              },
              "ref_id": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "reference id (virtual disk id)"
              },
              "sensors": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "set rule sensor",
                  "properties": {
                    "type": {
                      "type": [
                        "string"
                      ],
                      "example": "switch",
                      "enum": [
                        "weekly",
                        "auth",
                        "logical_block_access",
                        "switch",
                        "alarm"
                      ],
                      "description": "sensor type"
                    }
                  },
                  "required": [
                    "type"
                  ],
                  "additionalProperties": false
                },
                "description": "list of rule sensors"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "actions": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "rule action",
                  "properties": {
                    "type": {
                      "type": [
                        "string"
                      ],
                      "example": "device_reset",
                      "enum": [
                        "scsi_response",
                        "latency",
                        "event",
                        "email",
                        "statistic",
                        "device_mode",
                        "device_reset",
                        "attention_required",
                        "eject"
                      ],
                      "description": "action type"
                    },
                    "when": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "mode": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "time": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "num": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "user": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "response": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    }
                  },
                  "required": [
                    "type",
                    "when",
                    "mode",
                    "time",
                    "num",
                    "user",
                    "response"
                  ],
                  "additionalProperties": false
                },
                "description": "list of rule actions"
              },
              "filters": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "rule filter",
                  "properties": {
                    "type": {
                      "type": [
                        "string"
                      ],
                      "example": "scsi_command",
                      "enum": [
                        "logical_block_access",
                        "scsi_command",
                        "signature_detection",
                        "custom_detection"
                      ],
                      "description": "filter type"
                    },
                    "access": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "extent_groups": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "commands": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    }
                  },
                  "required": [
                    "type",
                    "access",
                    "extent_groups",
                    "commands"
                  ],
                  "additionalProperties": false
                },
                "description": "list of rule filters"
              }
            },
            "type": [
              "object"
            ],
            "description": "rule create request arguments",
            "required": [
              "vss_id",
              "type",
              "ref_id",
              "sensors",
              "label",
              "actions",
              "filters"
            ],
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "rule_create"
        },
        {
          "description": "Remove an existing virtual disk rule.",
          "href": "/rule/{(%23%2Fdefinitions%2Frule%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "rule_remove"
        },
        {
          "description": "Info for existing rule.",
          "href": "/rule/{(%23%2Fdefinitions%2Frule%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "List existing rules.",
          "href": "/rule",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Change the configuration of a virtual disk rule.",
          "href": "/rule/{(%23%2Fdefinitions%2Frule%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "title": "Update",
          "x_bb_method": "rule_update",
          "schema": {
            "type": [
              "object"
            ],
            "description": "rule update request arguments",
            "properties": {
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "ref_id": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "reference id (virtual disk id)"
              },
              "sensors": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "set rule sensor",
                  "properties": {
                    "type": {
                      "type": [
                        "string"
                      ],
                      "example": "alarm",
                      "enum": [
                        "weekly",
                        "auth",
                        "logical_block_access",
                        "switch",
                        "alarm"
                      ],
                      "description": "sensor type"
                    }
                  },
                  "required": [
                    "type"
                  ],
                  "additionalProperties": false
                },
                "description": "list of rule sensors"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "actions": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "rule action",
                  "properties": {
                    "type": {
                      "type": [
                        "string"
                      ],
                      "example": "latency",
                      "enum": [
                        "scsi_response",
                        "latency",
                        "event",
                        "email",
                        "statistic",
                        "device_mode",
                        "device_reset",
                        "attention_required",
                        "eject"
                      ],
                      "description": "action type"
                    },
                    "when": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "mode": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "time": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "num": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "user": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "response": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    }
                  },
                  "required": [
                    "type",
                    "when",
                    "mode",
                    "time",
                    "num",
                    "user",
                    "response"
                  ],
                  "additionalProperties": false
                },
                "description": "list of rule actions"
              },
              "filters": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "object"
                  ],
                  "description": "rule filter",
                  "properties": {
                    "type": {
                      "type": [
                        "string"
                      ],
                      "example": "signature_detection",
                      "enum": [
                        "logical_block_access",
                        "scsi_command",
                        "signature_detection",
                        "custom_detection"
                      ],
                      "description": "filter type"
                    },
                    "access": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "extent_groups": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    },
                    "commands": {
                      "type": [
                        "string",
                        "object",
                        "array",
                        "null"
                      ],
                      "properties": {
                      },
                      "description": "no documentation"
                    }
                  },
                  "required": [
                    "type",
                    "access",
                    "extent_groups",
                    "commands"
                  ],
                  "additionalProperties": false
                },
                "description": "list of rule filters"
              }
            },
            "additionalProperties": false
          }
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/rule/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/rule/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/rule/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/rule/definitions/mtime"
        },
        "serial": {
          "$ref": "#/definitions/rule/definitions/serial"
        },
        "xmd_refs": {
          "$ref": "#/definitions/rule/definitions/xmd_refs"
        },
        "xref": {
          "$ref": "#/definitions/rule/definitions/xref"
        },
        "label": {
          "$ref": "#/definitions/rule/definitions/label"
        },
        "account_id": {
          "$ref": "#/definitions/rule/definitions/account_id"
        },
        "actions": {
          "$ref": "#/definitions/rule/definitions/actions"
        },
        "filters": {
          "$ref": "#/definitions/rule/definitions/filters"
        },
        "node_id": {
          "$ref": "#/definitions/rule/definitions/node_id"
        },
        "vss_id": {
          "$ref": "#/definitions/rule/definitions/vss_id"
        },
        "ref_id": {
          "$ref": "#/definitions/rule/definitions/ref_id"
        },
        "sensors": {
          "$ref": "#/definitions/rule/definitions/sensors"
        },
        "type": {
          "$ref": "#/definitions/rule/definitions/type"
        },
        "notes": {
          "$ref": "#/definitions/rule/definitions/notes"
        },
        "status": {
          "$ref": "#/definitions/rule/definitions/status"
        },
        "alarm_raised": {
          "$ref": "#/definitions/rule/definitions/alarm_raised"
        },
        "alarm_raised_at": {
          "$ref": "#/definitions/rule/definitions/alarm_raised_at"
        },
        "xmd": {
          "$ref": "#/definitions/rule/definitions/xmd"
        }
      },
      "additionalProperties": false,
      "required": [
        "id",
        "ctime",
        "mtime",
        "serial",
        "xmd_refs",
        "label",
        "account_id",
        "actions",
        "filters",
        "node_id",
        "vss_id",
        "ref_id",
        "sensors",
        "type",
        "notes",
        "status",
        "alarm_raised",
        "alarm_raised_at"
      ]
    },
    "events": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Events",
      "description": "The Blockbridge system maintains an extensive audit history of administrative actions and status changes for each configuration object.  These events have a descriptive symbol, such as `TARGET_LOGIN` and several additional qualifiers, such as the ID and serial number of the affected objects, and in some cases the iSCSI initiator IQN, or the user's name. \n\nRequesting events from the REST API opens a distributed query to retrieve events from throughout the Blockbridge managment network.  If the response doesn't indicate end-of-file (`eof`), then increase the number of desired results with the `num` parameter, or shorten the specified time range.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "serial": {
          "description": "object serial number",
          "example": "TGT1D6AB94C40626460",
          "type": [
            "string"
          ]
        },
        "eof": {
          "type": [
            "boolean"
          ],
          "description": "end of results"
        },
        "batch": {
          "type": [
            "array"
          ],
          "description": "list of user events",
          "items": {
            "type": [
              "object"
            ],
            "description": "user event message",
            "properties": {
              "c": {
                "type": [
                  "string"
                ],
                "description": "cookie"
              },
              "eof": {
                "type": [
                  "boolean"
                ],
                "description": "end of results"
              },
              "d": {
                "type": [
                  "integer"
                ],
                "description": "process ID"
              },
              "g": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "enum": [
                    "account",
                    "datastore",
                    "disk",
                    "profile",
                    "user",
                    "service",
                    "target",
                    "task",
                    "audit"
                  ],
                  "description": "classification tag",
                  "example": "audit"
                },
                "description": "classification tags"
              },
              "f": {
                "type": [
                  "string"
                ],
                "description": "truncated source file"
              },
              "i": {
                "type": [
                  "string"
                ],
                "description": "primary context id (pcid)"
              },
              "h": {
                "type": [
                  "integer"
                ],
                "description": "HA cluster logical node ID"
              },
              "k": {
                "type": [
                  "integer"
                ],
                "description": "query sequence number"
              },
              "m": {
                "type": [
                  "string"
                ],
                "description": "formatted message string"
              },
              "l": {
                "type": [
                  "integer"
                ],
                "description": "source file line"
              },
              "n": {
                "type": [
                  "string"
                ],
                "example": "node:78:8",
                "description": "node ID"
              },
              "q": {
                "type": [
                  "integer"
                ],
                "description": "sequence number"
              },
              "s": {
                "type": [
                  "string"
                ],
                "description": "message symbol"
              },
              "r": {
                "type": [
                  "integer"
                ],
                "description": "reference sequence number"
              },
              "t": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "milliseconds since epoch",
                "example": 1443200456094
              },
              "y": {
                "type": [
                  "string"
                ],
                "enum": [
                  "l",
                  "e",
                  "c",
                  "s",
                  "m",
                  "h"
                ],
                "description": "data type, set to 'e' for events",
                "example": "m"
              },
              "p": {
                "type": [
                  "string"
                ],
                "enum": [
                  "unk",
                  "mp",
                  "cp",
                  "dcp",
                  "sp",
                  "con",
                  "slp",
                  "mlp",
                  "dlp",
                  "sl",
                  "ml",
                  "dl",
                  "dc",
                  "mclmon",
                  "sclmon",
                  "da",
                  "ha"
                ],
                "description": "process",
                "example": "mlp"
              },
              "pi": {
                "type": [
                  "string"
                ],
                "description": "primary ID"
              },
              "b": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "context block",
                "properties": {
                }
              },
              "v": {
                "type": [
                  "string"
                ],
                "enum": [
                  "dev",
                  "dbg",
                  "info",
                  "note",
                  "warn",
                  "err",
                  "crit",
                  "alrt"
                ],
                "description": "message severity",
                "example": "dbg"
              },
              "x": {
                "type": [
                  "integer"
                ],
                "description": "SP complex ID"
              }
            },
            "additionalProperties": false,
            "required": [
              "d",
              "g",
              "f",
              "i",
              "k",
              "m",
              "l",
              "n",
              "q",
              "s",
              "t",
              "y",
              "p",
              "pi",
              "b",
              "v"
            ]
          }
        }
      },
      "links": [
        {
          "description": "Retrieve all events for the requestor's account.",
          "href": "/events",
          "method": "GET",
          "rel": "instances",
          "x_bb_method": "events_account_rest",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "tstart": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "start time for query in milliseconds since epoch",
                "example": 0
              },
              "tend": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "end time for query in milliseconds since epoch (0 or unspecified for now)",
                "example": 1443200456094,
                "default": 0
              },
              "num": {
                "type": [
                  "integer"
                ],
                "minimum": 1,
                "maximum": 8192,
                "description": "number of events to return",
                "example": 1024
              },
              "sev": {
                "type": [
                  "string"
                ],
                "enum": [
                  "dbg",
                  "note",
                  "warn",
                  "err"
                ],
                "description": "minimum event severity",
                "example": "warn",
                "default": "note"
              }
            },
            "required": [
              "tstart",
              "num"
            ],
            "description": "no documentation",
            "additionalProperties": false
          },
          "title": "Query Account"
        },
        {
          "description": "Retrieve user and administrative events for the specified id or serial number.  Any type of id or serial number may be specified in place of `{events_identity}`.",
          "href": "/events/{(%23%2Fdefinitions%2Fevents%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "x_bb_method": "events_object_rest",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "tstart": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "start time for query in milliseconds since epoch",
                "example": 0
              },
              "tend": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "end time for query in milliseconds since epoch (0 or unspecified for now)",
                "example": 1443200456094,
                "default": 0
              },
              "num": {
                "type": [
                  "integer"
                ],
                "minimum": 1,
                "maximum": 8192,
                "description": "number of events to return",
                "example": 1024
              },
              "sev": {
                "type": [
                  "string"
                ],
                "enum": [
                  "dbg",
                  "note",
                  "warn",
                  "err"
                ],
                "description": "minimum event severity",
                "example": "warn",
                "default": "note"
              }
            },
            "required": [
              "tstart",
              "num"
            ],
            "description": "no documentation",
            "additionalProperties": false
          },
          "title": "Query"
        }
      ],
      "properties": {
        "eof": {
          "$ref": "#/definitions/events/definitions/eof"
        },
        "batch": {
          "$ref": "#/definitions/events/definitions/batch"
        }
      },
      "additionalProperties": false,
      "required": [
        "eof",
        "batch"
      ]
    },
    "stats": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Statistics",
      "description": "Blockbridge storage nodes keep a long history of how the node's storage resources have been used over time.  You can retrieve time-series information information such as block usage for virtual disks, IOPS, or write bandwidth for various types of resources. \n\nThese statistics are grouped into snapshots of related data points called statistics blocks.  Available statistics block types include:\n\n * **vdisk_history:** read/write bandwidth, I/O size histograms, IOPS and storage consumption for virtual disks\n * **target_history:** read/write bandwidth and IOPS, iSCSI PDUs sent and received for iSCSI targets\n * **vss_history:** storage consumption and IOPS usage for virtual storage services\n * **sys_ds_history:** storage consumption, IOPS, and other performance metrics for system datastores\n * **node_usage_history:**  counters for devices, services, virtual disks, snapshots, etc. for a storage node \n\nRequesting statistics from the REST API opens a query internally to the appropriate storage node. The statistics are reuturned in reverse time order, starting from `tend`. If the response doesn't indicate end-of-file (`eof`), then increase the number of desired results with the `num` parameter, or shorten the specified time range.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "serial": {
          "description": "object serial number",
          "example": "TGT1D6AB94C40626460",
          "type": [
            "string"
          ]
        },
        "eof": {
          "type": [
            "boolean"
          ],
          "description": "end of results"
        },
        "batch": {
          "type": [
            "array"
          ],
          "description": "list of statistics blocks",
          "items": {
            "type": [
              "object"
            ],
            "description": "stats data point",
            "properties": {
              "a": {
                "type": [
                  "string"
                ],
                "description": "account/admin ID"
              },
              "c": {
                "type": [
                  "string"
                ],
                "description": "cookie"
              },
              "eof": {
                "type": [
                  "boolean"
                ],
                "description": "end of results"
              },
              "e": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "extended key",
                "properties": {
                }
              },
              "d": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "statistics block sub-object, see additional notes",
                "properties": {
                }
              },
              "rt": {
                "type": [
                  "boolean"
                ],
                "description": "data point obtained in real time (open-ended query only)"
              },
              "k": {
                "type": [
                  "integer"
                ],
                "description": "query sequence number"
              },
              "o": {
                "type": [
                  "string"
                ],
                "description": "object OID"
              },
              "n": {
                "type": [
                  "string"
                ],
                "example": "node:91:9",
                "description": "node ID"
              },
              "t": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "milliseconds since epoch for measurement",
                "example": 1443200456094
              },
              "y": {
                "type": [
                  "string"
                ],
                "enum": [
                  "l",
                  "e",
                  "c",
                  "s",
                  "m",
                  "h"
                ],
                "description": "data type, set to 's' for statistics",
                "example": "s"
              },
              "x": {
                "type": [
                  "string"
                ],
                "description": "statistics block type"
              }
            },
            "additionalProperties": false,
            "required": [
              "d",
              "k",
              "o",
              "n",
              "t",
              "y",
              "x"
            ]
          }
        }
      },
      "links": [
        {
          "description": "Retrieve statistics for the specified id or serial number. Any type of id or serial number may be specified in place of `{stats_identity}`.",
          "href": "/stats/{(%23%2Fdefinitions%2Fstats%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "x_bb_method": "stats_rest",
          "rel": "self",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "tstart": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "start time for query in milliseconds since epoch",
                "example": 0
              },
              "tend": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "default": 0,
                "description": "end time for query in milliseconds since epoch (0 or unspecified for now)",
                "example": 1443200456094
              },
              "period": {
                "type": [
                  "integer"
                ],
                "minimum": 0,
                "description": "resolution to return data, in milliseconds (0 for all data)",
                "example": 1000
              },
              "num": {
                "type": [
                  "integer"
                ],
                "minimum": 1,
                "maximum": 8192,
                "description": "number of data points to return",
                "example": 1024
              }
            },
            "required": [
              "tstart",
              "period",
              "num"
            ],
            "description": "no documentation",
            "additionalProperties": false
          },
          "title": "Query"
        }
      ],
      "properties": {
        "eof": {
          "$ref": "#/definitions/stats/definitions/eof"
        },
        "batch": {
          "$ref": "#/definitions/stats/definitions/batch"
        }
      },
      "additionalProperties": false,
      "required": [
        "eof",
        "batch"
      ]
    },
    "xmd": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Extensible Metadata Record",
      "description": "The Extensible Metadata Record provides a way for applications to store free-form data in the Blockbridge management node.  The data can include information of use to the client itself, to other clients, or to the storage administrator.  The data can be associated with another object such as a virtual disk or service, so that it is removed when the associated object is deleted.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
          "anyOf": [
            {
              "$ref": "#/definitions/xmd/definitions/id"
            },
            {
              "$ref": "#/definitions/xmd/definitions/serial"
            },
            {
              "$ref": "#/definitions/xmd/definitions/ref"
            }
          ]
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "ctime": {
          "type": [
            "integer"
          ],
          "description": "extensible metadata create time",
          "minimum": 0,
          "example": 1443200456094
        },
        "mtime": {
          "type": [
            "integer"
          ],
          "description": "extensible metadata last modified time",
          "minimum": 0,
          "example": 1443200456094
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "extensible metadata serial number"
        },
        "label": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned label"
        },
        "account_id": {
          "type": [
            "string",
            "null"
          ],
          "example": "account:27:14",
          "description": "account id"
        },
        "vss_id": {
          "type": [
            "string",
            "null"
          ],
          "example": "vss:92:14",
          "description": "optional vss ref"
        },
        "ref": {
          "type": [
            "string"
          ],
          "description": "arbitrary string reference key"
        },
        "notes": {
          "type": [
            "string",
            "null"
          ],
          "description": "user assigned notes"
        },
        "tags": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "tag"
          },
          "description": "object tags"
        },
        "ext_status": {
          "type": [
            "object",
            "null"
          ],
          "description": "external application status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "online"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "online"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "data": {
          "type": [
            "object",
            "null"
          ],
          "description": "application-supplied data",
          "properties": {
          }
        },
        "xmd_refs": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "string"
            ],
            "description": "arbitrary string reference key"
          },
          "description": "array of extensible metadata reference keys"
        },
        "xref": {
          "type": [
            "string"
          ],
          "description": "arbitrary string reference"
        },
        "status": {
          "type": [
            "object"
          ],
          "description": "extensible metadata status",
          "properties": {
            "indicator": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "na"
              ],
              "description": "status indicator",
              "example": "online"
            },
            "value": {
              "type": [
                "string"
              ],
              "enum": [
                "online",
                "degraded",
                "offline",
                "pending",
                "payment"
              ],
              "description": "status value",
              "example": "payment"
            },
            "detail": {
              "type": [
                "string",
                "null"
              ],
              "description": "status detail"
            }
          },
          "required": [
            "indicator",
            "value",
            "detail"
          ],
          "additionalProperties": false
        },
        "rdeps": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "extensible metadata dependent objects",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "description": "dependent object id"
              },
              "serial": {
                "type": [
                  "string"
                ],
                "description": "dependent object serial number"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "dependent object label"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "dependent object reference key"
              },
              "type": {
                "type": [
                  "string"
                ],
                "description": "dependent object type"
              },
              "self": {
                "type": [
                  "boolean"
                ],
                "description": "dependent object references itself"
              }
            },
            "required": [
              "id",
              "serial",
              "type"
            ],
            "additionalProperties": false
          },
          "description": "no documentation"
        },
        "xmd": {
          "type": [
            "array"
          ],
          "items": {
            "type": [
              "object"
            ],
            "description": "per-linked xmd data",
            "properties": {
              "id": {
                "type": [
                  "string"
                ],
                "example": "xmd:40:5",
                "description": "no documentation"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference key"
              },
              "mtime": {
                "type": [
                  "integer"
                ],
                "description": "last modified time of xmd",
                "minimum": 0,
                "example": 1443200456094
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "self": {
                "type": [
                  "boolean"
                ],
                "description": "no documentation"
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "no documentation",
                "properties": {
                }
              }
            },
            "additionalProperties": false,
            "required": [
              "id",
              "ref",
              "mtime",
              "tags",
              "data"
            ]
          },
          "description": "array of api xmd results"
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "node_id": {
          "type": [
            "string",
            "null"
          ],
          "example": "node:61:13",
          "description": "optional node ref"
        },
        "type": {
          "type": [
            "string",
            "null"
          ],
          "description": "no documentation"
        },
        "publish": {
          "type": [
            "boolean"
          ],
          "description": "no documentation"
        },
        "system": {
          "type": [
            "boolean"
          ],
          "description": "system xmd"
        }
      },
      "links": [
        {
          "description": "Retrieve an existing external metadata object.",
          "href": "/xmd/{(%23%2Fdefinitions%2Fxmd%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate extensible metadata objects.",
          "href": "/xmd",
          "method": "GET",
          "rel": "instances",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          },
          "title": "List"
        },
        {
          "description": "Create an extensible metadata object.",
          "href": "/xmd",
          "method": "POST",
          "rel": "create",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "vss_id": {
                "type": [
                  "string"
                ],
                "example": "vss:21:15",
                "description": "virtual storage service id"
              },
              "ref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference key"
              },
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "xref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label",
                "default": null
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "ext_status": {
                "type": [
                  "object",
                  "null"
                ],
                "description": "external application status",
                "properties": {
                  "indicator": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "online",
                      "degraded",
                      "offline",
                      "na"
                    ],
                    "description": "status indicator",
                    "example": "degraded"
                  },
                  "value": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "online",
                      "degraded",
                      "offline",
                      "pending",
                      "payment"
                    ],
                    "description": "status value",
                    "example": "offline"
                  },
                  "detail": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "status detail"
                  }
                },
                "additionalProperties": false
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "application-supplied data",
                "properties": {
                }
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              },
              "replace": {
                "type": [
                  "boolean"
                ],
                "description": "replace existing xmd ref"
              },
              "type": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "no documentation"
              },
              "publish": {
                "type": [
                  "boolean"
                ],
                "description": "publish xmd"
              }
            },
            "description": "xmd create request arguments",
            "required": [
              "ref"
            ],
            "additionalProperties": false
          },
          "title": "Create",
          "x_bb_method": "xmd_create"
        },
        {
          "description": "Remove an extensible metadata object.",
          "href": "/xmd/{(%23%2Fdefinitions%2Fxmd%2Fdefinitions%2Fidentity)}",
          "method": "DELETE",
          "rel": "destroy",
          "title": "Remove",
          "x_bb_method": "xmd_remove"
        },
        {
          "description": "Change an extensible metadata object.",
          "href": "/xmd/{(%23%2Fdefinitions%2Fxmd%2Fdefinitions%2Fidentity)}",
          "method": "PATCH",
          "rel": "update",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "noent_action": {
                "type": [
                  "string"
                ],
                "default": "fail",
                "enum": [
                  "fail",
                  "success",
                  "create"
                ],
                "description": "response when metadata record not found"
              },
              "mode": {
                "type": [
                  "string"
                ],
                "default": "replace",
                "enum": [
                  "replace",
                  "merge",
                  "patch"
                ],
                "description": "update mode"
              },
              "xmd_refs": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "arbitrary string reference key"
                },
                "description": "array of extensible metadata reference keys"
              },
              "label": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "user assigned label"
              },
              "notes": {
                "type": [
                  "string"
                ],
                "description": "user assigned notes"
              },
              "tags": {
                "type": [
                  "array"
                ],
                "items": {
                  "type": [
                    "string"
                  ],
                  "description": "tag"
                },
                "description": "object tags"
              },
              "ext_status": {
                "type": [
                  "object",
                  "null"
                ],
                "description": "external application status",
                "properties": {
                  "indicator": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "online",
                      "degraded",
                      "offline",
                      "na"
                    ],
                    "description": "status indicator",
                    "example": "degraded"
                  },
                  "value": {
                    "type": [
                      "string"
                    ],
                    "enum": [
                      "online",
                      "degraded",
                      "offline",
                      "pending",
                      "payment"
                    ],
                    "description": "status value",
                    "example": "payment"
                  },
                  "detail": {
                    "type": [
                      "string",
                      "null"
                    ],
                    "description": "status detail"
                  }
                },
                "additionalProperties": false
              },
              "data": {
                "type": [
                  "string",
                  "object",
                  "array",
                  "null"
                ],
                "description": "application-supplied data",
                "properties": {
                }
              },
              "vss_id": {
                "type": [
                  "string"
                ],
                "description": "vss id"
              },
              "uuid": {
                "type": [
                  "string"
                ],
                "format": "uuid",
                "description": "object UUID"
              },
              "type": {
                "type": [
                  "string",
                  "null"
                ],
                "description": "no documentation"
              },
              "xref": {
                "type": [
                  "string"
                ],
                "description": "arbitrary string reference"
              },
              "publish": {
                "type": [
                  "boolean"
                ],
                "description": "publish xmd"
              }
            },
            "description": "xmd update request arguments",
            "additionalProperties": false
          },
          "title": "Update",
          "x_bb_method": "xmd_update"
        }
      ],
      "properties": {
        "id": {
          "$ref": "#/definitions/xmd/definitions/id"
        },
        "uuid": {
          "$ref": "#/definitions/xmd/definitions/uuid"
        },
        "ctime": {
          "$ref": "#/definitions/xmd/definitions/ctime"
        },
        "mtime": {
          "$ref": "#/definitions/xmd/definitions/mtime"
        },
        "serial": {
          "$ref": "#/definitions/xmd/definitions/serial"
        },
        "label": {
          "$ref": "#/definitions/xmd/definitions/label"
        },
        "account_id": {
          "$ref": "#/definitions/xmd/definitions/account_id"
        },
        "vss_id": {
          "$ref": "#/definitions/xmd/definitions/vss_id"
        },
        "ref": {
          "$ref": "#/definitions/xmd/definitions/ref"
        },
        "publish": {
          "$ref": "#/definitions/xmd/definitions/publish"
        },
        "type": {
          "$ref": "#/definitions/xmd/definitions/type"
        },
        "notes": {
          "$ref": "#/definitions/xmd/definitions/notes"
        },
        "tags": {
          "$ref": "#/definitions/xmd/definitions/tags"
        },
        "ext_status": {
          "$ref": "#/definitions/xmd/definitions/ext_status"
        },
        "data": {
          "$ref": "#/definitions/xmd/definitions/data"
        },
        "system": {
          "$ref": "#/definitions/xmd/definitions/system"
        },
        "xmd_refs": {
          "$ref": "#/definitions/xmd/definitions/xmd_refs"
        },
        "xref": {
          "$ref": "#/definitions/xmd/definitions/xref"
        },
        "status": {
          "$ref": "#/definitions/xmd/definitions/status"
        },
        "rdeps": {
          "$ref": "#/definitions/xmd/definitions/rdeps"
        },
        "xmd": {
          "$ref": "#/definitions/xmd/definitions/xmd"
        }
      },
      "required": [
        "id",
        "ctime",
        "mtime",
        "serial",
        "label",
        "account_id",
        "vss_id",
        "ref",
        "type",
        "notes",
        "tags",
        "ext_status",
        "data",
        "xmd_refs",
        "status",
        "rdeps"
      ],
      "additionalProperties": false
    },
    "ca-cert": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "CA Certificate",
      "description": "The Blockbridge management node may be configured with an embedded Certificate Authority that issues SSL certificates for clients to securely access to the API and the management web application.  Install its CA certificate on client machines that will use Blockbridge management services.  If no certificate authority is configured, SSL connections use self-signed certificates.",
      "stability": "prototype",
      "type": [
        "object"
      ],
      "definitions": {
        "data": {
          "description": "encoded ca-certificate data",
          "type": [
            "string"
          ]
        },
        "encoding": {
          "description": "additional encoding of response data",
          "type": [
            "string"
          ],
          "enum": [
            "base64"
          ],
          "example": "base64"
        },
        "identity": {
        }
      },
      "links": [
        {
          "description": "Retrieve the certificate authority certificate.",
          "href": "/ca-certificate",
          "method": "GET",
          "rel": "self",
          "title": "Info",
          "x_bb_method": "ca_cert_get",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
              "cert_format": {
                "type": [
                  "string"
                ],
                "default": "pem",
                "enum": [
                  "pem",
                  "der"
                ],
                "description": "ca cert format"
              }
            },
            "description": "retrieve blockbridge CA certificate",
            "additionalProperties": false
          }
        }
      ],
      "properties": {
        "data": {
          "$ref": "#/definitions/ca-cert/definitions/data"
        },
        "encoding": {
          "$ref": "#/definitions/ca-cert/definitions/encoding"
        }
      },
      "additionalProperties": false,
      "required": [
        "data",
        "encoding"
      ]
    },
    "status": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "API and system status",
      "description": "Examine API, authorization, and internal system status details.",
      "stability": "development",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
        },
        "process_id": {
          "type": [
            "integer"
          ],
          "description": "process id"
        }
      },
      "links": [
        {
          "description": "Retrieve API high-level status information.",
          "href": "/status/info",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Retrieve API authorization detail.",
          "href": "/status/authorization",
          "method": "GET",
          "rel": "self",
          "title": "Authorization"
        },
        {
          "description": "Retrieve API adapter debug state.",
          "href": "/status/debug",
          "method": "GET",
          "rel": "self",
          "title": "Debug"
        },
        {
          "description": "Retrieve API adapter and OS platform.",
          "href": "/status/platform",
          "method": "GET",
          "rel": "self",
          "title": "Platform"
        },
        {
          "description": "Retrieve API platform process listing.",
          "href": "/status/processes",
          "method": "GET",
          "rel": "self",
          "title": "Process list",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          }
        },
        {
          "description": "Retrieve API platform process info",
          "href": "/status/processes/{(%23%2Fdefinitions%2Fstatus%2Fdefinitions%2Fprocess_id)}",
          "method": "GET",
          "rel": "self",
          "title": "Process info"
        }
      ],
      "properties": {
      },
      "additionalProperties": false
    },
    "objects": {
      "$schema": "http://json-schema.org/draft-04/hyper-schema",
      "title": "Bulk object operations",
      "description": "Access and perform operations on objects of disparate types.",
      "stability": "development",
      "type": [
        "object"
      ],
      "definitions": {
        "identity": {
        },
        "uuid": {
          "type": [
            "string"
          ],
          "format": "uuid",
          "description": "object uuid"
        },
        "id": {
          "type": [
            "string"
          ],
          "description": "object id"
        },
        "serial": {
          "type": [
            "string"
          ],
          "description": "object serial number"
        },
        "xref": {
          "type": [
            "string"
          ],
          "description": "object external reference"
        }
      },
      "links": [
        {
          "description": "Enumerate objects",
          "href": "/objects",
          "method": "GET",
          "rel": "self",
          "title": "List",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          }
        },
        {
          "description": "Info for a single object.",
          "href": "/objects/{(%23%2Fdefinitions%2Fobjects%2Fdefinitions%2Fidentity)}",
          "method": "GET",
          "rel": "self",
          "title": "Info"
        },
        {
          "description": "Enumerate objects by xref",
          "href": "/objects/by-xref/{(%23%2Fdefinitions%2Fobjects%2Fdefinitions%2Fxref)}",
          "method": "GET",
          "rel": "self",
          "title": "List by xref",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          }
        },
        {
          "description": "Remove objects by xref.",
          "href": "/objects/by-xref/{(%23%2Fdefinitions%2Fobjects%2Fdefinitions%2Fxref)}",
          "method": "DELETE",
          "rel": "instances",
          "title": "Remove by xref",
          "schema": {
            "type": [
              "object"
            ],
            "properties": {
            }
          }
        }
      ],
      "properties": {
      },
      "additionalProperties": false
    }
  },
  "properties": {
    "account": {
      "$ref": "#/definitions/account"
    },
    "user-profile": {
      "$ref": "#/definitions/user-profile"
    },
    "oauth2-token": {
      "$ref": "#/definitions/oauth2-token"
    },
    "authz": {
      "$ref": "#/definitions/authz"
    },
    "node": {
      "$ref": "#/definitions/node"
    },
    "site": {
      "$ref": "#/definitions/site"
    },
    "net": {
      "$ref": "#/definitions/net"
    },
    "os-dev": {
      "$ref": "#/definitions/os-dev"
    },
    "sys-ds": {
      "$ref": "#/definitions/sys-ds"
    },
    "dev": {
      "$ref": "#/definitions/dev"
    },
    "product": {
      "$ref": "#/definitions/product"
    },
    "vss": {
      "$ref": "#/definitions/vss"
    },
    "vdisk": {
      "$ref": "#/definitions/vdisk"
    },
    "initiator-profile": {
      "$ref": "#/definitions/initiator-profile"
    },
    "target": {
      "$ref": "#/definitions/target"
    },
    "snapshot": {
      "$ref": "#/definitions/snapshot"
    },
    "obj-store": {
      "$ref": "#/definitions/obj-store"
    },
    "rule": {
      "$ref": "#/definitions/rule"
    },
    "events": {
      "$ref": "#/definitions/events"
    },
    "stats": {
      "$ref": "#/definitions/stats"
    },
    "xmd": {
      "$ref": "#/definitions/xmd"
    },
    "ca-cert": {
      "$ref": "#/definitions/ca-cert"
    },
    "status": {
      "$ref": "#/definitions/status"
    },
    "objects": {
      "$ref": "#/definitions/objects"
    }
  },
  "description": "Blockbridge REST API",
  "id": "http://api.blockbridge.io/schema",
  "links": [

  ],
  "title": "Blockbridge REST API"
}
HEROICS_SCHEMA
end
